@@ -22,36 +22,26 @@
  ***************************************************************************/
 
 
-
 #include "PreCompiled.h"
 
-#ifndef _PreComp_
-# include <stdexcept>
-#endif
-
+#include <Base/Console.h>
+#include <Base/Exception.h>
+#include <Base/FileInfo.h>
+#include <Base/Interpreter.h>
+#include <Base/Parameter.h>
+#include <Base/Sequencer.h>
 
 #include "Application.h"
-#include "Document.h"
 #include "DocumentPy.h"
 #include "DocumentObserverPython.h"
 #include "DocumentObjectPy.h"
 
-// FreeCAD Base header
-#include <Base/Interpreter.h>
-#include <Base/Exception.h>
-#include <Base/Parameter.h>
-#include <Base/Console.h>
-#include <Base/Factory.h>
-#include <Base/FileInfo.h>
-#include <Base/UnitsApi.h>
-#include <Base/Sequencer.h>
 
 //using Base::GetConsole;
 using namespace Base;
 using namespace App;
 
 
-
 //**************************************************************************
 // Python stuff
 
@@ -86,16 +76,24 @@ PyMethodDef Application::Methods[] = {
      "Change the export module name of a registered filetype"},
     {"getExportType",  (PyCFunction) Application::sGetExportType, METH_VARARGS,
      "Get the name of the module that can export the filetype"},
-    {"getResourceDir", (PyCFunction) Application::sGetResourceDir, METH_VARARGS,
+    {"getResourceDir", (PyCFunction) Application::sGetResourcePath, METH_VARARGS,
      "Get the root directory of all resources"},
-    {"getUserAppDataDir", (PyCFunction) Application::sGetUserAppDataDir, METH_VARARGS,
-     "Get the root directory of user settings"},
-    {"getUserMacroDir", (PyCFunction) Application::sGetUserMacroDir, METH_VARARGS,
+    {"getLibraryDir", (PyCFunction) Application::sGetLibraryPath, METH_VARARGS,
+     "Get the directory of all extension modules"},
+    {"getTempPath", (PyCFunction) Application::sGetTempPath, METH_VARARGS,
+     "Get the root directory of cached files"},
+    {"getUserCachePath", (PyCFunction) Application::sGetUserCachePath, METH_VARARGS,
+     "Get the root path of cached files"},
+    {"getUserConfigDir", (PyCFunction) Application::sGetUserConfigPath, METH_VARARGS,
+     "Get the root path of user config files"},
+    {"getUserAppDataDir", (PyCFunction) Application::sGetUserAppDataPath, METH_VARARGS,
+     "Get the root directory of application data"},
+    {"getUserMacroDir", (PyCFunction) Application::sGetUserMacroPath, METH_VARARGS,
      "getUserMacroDir(bool=False) -> string"
      "Get the directory of the user's macro directory\n"
      "If parameter is False (the default) it returns the standard path in the"
      "user's home directory, otherwise it returns the user-defined path."},
-    {"getHelpDir", (PyCFunction) Application::sGetHelpDir, METH_VARARGS,
+    {"getHelpDir", (PyCFunction) Application::sGetHelpPath, METH_VARARGS,
      "Get the directory of the documentation"},
     {"getHomePath",    (PyCFunction) Application::sGetHomePath, METH_VARARGS,
      "Get the home path, i.e. the parent directory of the executable"},
@@ -106,9 +104,9 @@ PyMethodDef Application::Methods[] = {
      "* If no module is given it will be determined by the file extension.\n"
      "* If more than one module can load a file the first one will be taken.\n"
      "* If no module exists to load the file an exception will be raised."},
-    {"open",   reinterpret_cast<PyCFunction>(reinterpret_cast<void (*) (void)>( Application::sOpenDocument )), METH_VARARGS|METH_KEYWORDS,
+    {"open",   reinterpret_cast<PyCFunction>(reinterpret_cast<void (*) ()>( Application::sOpenDocument )), METH_VARARGS|METH_KEYWORDS,
      "See openDocument(string)"},
-    {"openDocument",   reinterpret_cast<PyCFunction>(reinterpret_cast<void (*) (void)>( Application::sOpenDocument )), METH_VARARGS|METH_KEYWORDS,
+    {"openDocument",   reinterpret_cast<PyCFunction>(reinterpret_cast<void (*) ()>( Application::sOpenDocument )), METH_VARARGS|METH_KEYWORDS,
      "openDocument(filepath,hidden=False) -> object\n"
      "Create a document and load the project file into the document.\n\n"
      "filepath: file path to an existing file. If the file doesn't exist\n"
@@ -118,7 +116,7 @@ PyMethodDef Application::Methods[] = {
 //  {"saveDocument",   (PyCFunction) Application::sSaveDocument, METH_VARARGS,
 //   "saveDocument(string) -- Save the document to a file."},
 //  {"saveDocumentAs", (PyCFunction) Application::sSaveDocumentAs, METH_VARARGS},
-    {"newDocument",    reinterpret_cast<PyCFunction>(reinterpret_cast<void (*) (void)>( Application::sNewDocument )), METH_VARARGS|METH_KEYWORDS,
+    {"newDocument",    reinterpret_cast<PyCFunction>(reinterpret_cast<void (*) ()>( Application::sNewDocument )), METH_VARARGS|METH_KEYWORDS,
      "newDocument(name, label=None, hidden=False, temp=False) -> object\n"
      "Create a new document with a given name.\n\n"
      "name: unique document name which is checked automatically.\n"
@@ -184,21 +182,21 @@ PyMethodDef Application::Methods[] = {
      "This only works if there is an active sequencer (or ProgressIndicator in Python).\n"
      "There is an active sequencer during document restore and recomputation. User may\n"
      "abort the operation by pressing the ESC key. Once detected, this function will\n"
-     "trigger a BaseExceptionFreeCADAbort exception."},
-    {NULL, NULL, 0, NULL}		/* Sentinel */
+     "trigger a Base.FreeCADAbort exception."},
+    {nullptr, nullptr, 0, nullptr}		/* Sentinel */
 };
 
 
 PyObject* Application::sLoadFile(PyObject * /*self*/, PyObject *args)
 {
     char *path, *doc="",*mod="";
-    if (!PyArg_ParseTuple(args, "s|ss", &path, &doc, &mod))     // convert args: Python->C
-        return 0;                             // NULL triggers exception
+    if (!PyArg_ParseTuple(args, "s|ss", &path, &doc, &mod))
+        return nullptr;
     try {
         Base::FileInfo fi(path);
         if (!fi.isFile() || !fi.exists()) {
             PyErr_Format(PyExc_IOError, "File %s doesn't exist.", path);
-            return 0;
+            return nullptr;
         }
 
         std::string module = mod;
@@ -207,7 +205,7 @@ PyObject* Application::sLoadFile(PyObject * /*self*/, PyObject *args)
             std::vector<std::string> modules = GetApplication().getImportModules(ext.c_str());
             if (modules.empty()) {
                 PyErr_Format(PyExc_IOError, "Filetype %s is not supported.", ext.c_str());
-                return 0;
+                return nullptr;
             }
             else {
                 module = modules.front();
@@ -230,13 +228,13 @@ PyObject* Application::sLoadFile(PyObject * /*self*/, PyObject *args)
     catch (const std::exception& e) {
         // might be subclass from zipios
         PyErr_Format(PyExc_IOError, "Invalid project file %s: %s", path, e.what());
-        return 0;
+        return nullptr;
     }
 }
 
 PyObject* Application::sIsRestoring(PyObject * /*self*/, PyObject *args) {
     if (!PyArg_ParseTuple(args, ""))
-        return NULL;
+        return nullptr;
     return Py::new_reference_to(Py::Boolean(GetApplication().isRestoring()));
 }
 
@@ -244,10 +242,10 @@ PyObject* Application::sOpenDocument(PyObject * /*self*/, PyObject *args, PyObje
 {
     char* Name;
     PyObject *hidden = Py_False;
-    static char *kwlist[] = {"name","hidden",0};
+    static char *kwlist[] = {"name","hidden",nullptr};
     if (!PyArg_ParseTupleAndKeywords(args, kwd, "et|O", kwlist,
                 "utf-8", &Name, &hidden))
-        return NULL;
+        return nullptr;
     std::string EncodedName = std::string(Name);
     PyMem_Free(Name);
     try {
@@ -256,25 +254,25 @@ PyObject* Application::sOpenDocument(PyObject * /*self*/, PyObject *args, PyObje
     }
     catch (const Base::Exception& e) {
         PyErr_SetString(PyExc_IOError, e.what());
-        return 0L;
+        return nullptr;
     }
     catch (const std::exception& e) {
         // might be subclass from zipios
         PyErr_Format(PyExc_IOError, "Invalid project file %s: %s\n", EncodedName.c_str(), e.what());
-        return 0L;
+        return nullptr;
     }
 }
 
 PyObject* Application::sNewDocument(PyObject * /*self*/, PyObject *args, PyObject *kwd)
 {
-    char *docName = 0;
-    char *usrName = 0;
+    char *docName = nullptr;
+    char *usrName = nullptr;
     PyObject *hidden = Py_False;
     PyObject *temp = Py_False;
-    static char *kwlist[] = {"name","label","hidden","temp",0};
+    static char *kwlist[] = {"name","label","hidden","temp",nullptr};
     if (!PyArg_ParseTupleAndKeywords(args, kwd, "|etetOO", kwlist,
                 "utf-8", &docName, "utf-8", &usrName, &hidden, &temp))
-        return NULL;
+        return nullptr;
 
     PY_TRY {
         App::Document* doc = GetApplication().newDocument(docName, usrName,
@@ -288,16 +286,16 @@ PyObject* Application::sNewDocument(PyObject * /*self*/, PyObject *args, PyObjec
 
 PyObject* Application::sSetActiveDocument(PyObject * /*self*/, PyObject *args)
 {
-    char *pstr = 0;
-    if (!PyArg_ParseTuple(args, "s", &pstr))     // convert args: Python->C
-        return NULL;                             // NULL triggers exception
+    char *pstr = nullptr;
+    if (!PyArg_ParseTuple(args, "s", &pstr))
+        return nullptr;
 
     try {
         GetApplication().setActiveDocument(pstr);
     }
     catch (const Base::Exception& e) {
-        PyErr_SetString(Base::BaseExceptionFreeCADError, e.what());
-        return NULL;
+        e.setPyException();
+        return nullptr;
     }
 
     Py_Return;
@@ -305,23 +303,23 @@ PyObject* Application::sSetActiveDocument(PyObject * /*self*/, PyObject *args)
 
 PyObject* Application::sCloseDocument(PyObject * /*self*/, PyObject *args)
 {
-    char *pstr = 0;
-    if (!PyArg_ParseTuple(args, "s", &pstr))     // convert args: Python->C
-        return NULL;                             // NULL triggers exception
+    char *pstr = nullptr;
+    if (!PyArg_ParseTuple(args, "s", &pstr))
+        return nullptr;
 
     Document* doc = GetApplication().getDocument(pstr);
     if (!doc) {
         PyErr_Format(PyExc_NameError, "Unknown document '%s'", pstr);
-        return NULL;
+        return nullptr;
     }
     if (!doc->isClosable()) {
         PyErr_Format(PyExc_RuntimeError, "The document '%s' is not closable for the moment", pstr);
-        return NULL;
+        return nullptr;
     }
 
     if (GetApplication().closeDocument(pstr) == false) {
         PyErr_Format(PyExc_RuntimeError, "Closing the document '%s' failed", pstr);
-        return NULL;
+        return nullptr;
     }
 
     Py_Return;
@@ -330,19 +328,19 @@ PyObject* Application::sCloseDocument(PyObject * /*self*/, PyObject *args)
 PyObject* Application::sSaveDocument(PyObject * /*self*/, PyObject *args)
 {
     char *pDoc;
-    if (!PyArg_ParseTuple(args, "s", &pDoc))     // convert args: Python->C
-        return NULL;                             // NULL triggers exception
+    if (!PyArg_ParseTuple(args, "s", &pDoc))
+        return nullptr;
 
     Document* doc = GetApplication().getDocument(pDoc);
     if ( doc ) {
         if ( doc->save() == false ) {
-            PyErr_Format(Base::BaseExceptionFreeCADError, "Cannot save document '%s'", pDoc);
-            return 0L;
+            PyErr_Format(Base::PyExc_FC_GeneralError, "Cannot save document '%s'", pDoc);
+            return nullptr;
         }
     }
     else {
         PyErr_Format(PyExc_NameError, "Unknown document '%s'", pDoc);
-        return NULL;
+        return nullptr;
     }
 
     Py_Return;
@@ -351,8 +349,8 @@ PyObject* Application::sSaveDocument(PyObject * /*self*/, PyObject *args)
 PyObject* Application::sSaveDocumentAs(PyObject * /*self*/, PyObject *args)
 {
     char *pDoc, *pFileName;
-    if (!PyArg_ParseTuple(args, "ss", &pDoc, &pFileName))     // convert args: Python->C
-        return NULL;                             // NULL triggers exception
+    if (!PyArg_ParseTuple(args, "ss", &pDoc, &pFileName))
+        return nullptr;
 
     Document* doc = GetApplication().getDocument(pDoc);
     if (doc) {
@@ -368,8 +366,8 @@ PyObject* Application::sSaveDocumentAs(PyObject * /*self*/, PyObject *args)
 #endif
 PyObject* Application::sActiveDocument(PyObject * /*self*/, PyObject *args)
 {
-    if (!PyArg_ParseTuple(args, ""))     // convert args: Python->C
-        return NULL;                       // NULL triggers exception
+    if (!PyArg_ParseTuple(args, ""))
+        return nullptr;
 
     Document* doc = GetApplication().getActiveDocument();
     if (doc) {
@@ -383,14 +381,14 @@ PyObject* Application::sActiveDocument(PyObject * /*self*/, PyObject *args)
 
 PyObject* Application::sGetDocument(PyObject * /*self*/, PyObject *args)
 {
-    char *pstr=0;
-    if (!PyArg_ParseTuple(args, "s", &pstr))     // convert args: Python->C
-        return NULL;                             // NULL triggers exception
+    char *pstr=nullptr;
+    if (!PyArg_ParseTuple(args, "s", &pstr))
+        return nullptr;
 
     Document* doc = GetApplication().getDocument(pstr);
     if ( !doc ) {
         PyErr_Format(PyExc_NameError, "Unknown document '%s'", pstr);
-        return 0L;
+        return nullptr;
     }
 
     return doc->getPyObject();
@@ -398,9 +396,9 @@ PyObject* Application::sGetDocument(PyObject * /*self*/, PyObject *args)
 
 PyObject* Application::sGetParam(PyObject * /*self*/, PyObject *args)
 {
-    char *pstr=0;
-    if (!PyArg_ParseTuple(args, "s", &pstr))     // convert args: Python->C
-        return NULL;                             // NULL triggers exception
+    char *pstr=nullptr;
+    if (!PyArg_ParseTuple(args, "s", &pstr))
+        return nullptr;
 
     PY_TRY {
         return GetPyObject(GetApplication().GetParameterGroupByPath(pstr));
@@ -411,7 +409,7 @@ PyObject* Application::sSaveParameter(PyObject * /*self*/, PyObject *args)
 {
     char *pstr = "User parameter";
     if (!PyArg_ParseTuple(args, "|s", &pstr))
-        return NULL;
+        return nullptr;
 
     PY_TRY {
         ParameterManager* param = App::GetApplication().GetParameterSet(pstr);
@@ -419,13 +417,13 @@ PyObject* Application::sSaveParameter(PyObject * /*self*/, PyObject *args)
             std::stringstream str;
             str << "No parameter set found with name: " << pstr;
             PyErr_SetString(PyExc_ValueError, str.str().c_str());
-            return NULL;
+            return nullptr;
         }
         else if (!param->HasSerializer()) {
             std::stringstream str;
             str << "Parameter set cannot be serialized: " << pstr;
             PyErr_SetString(PyExc_RuntimeError, str.str().c_str());
-            return NULL;
+            return nullptr;
         }
 
         param->SaveDocument();
@@ -439,8 +437,8 @@ PyObject* Application::sGetConfig(PyObject * /*self*/, PyObject *args)
 {
     char *pstr;
 
-    if (!PyArg_ParseTuple(args, "s", &pstr))     // convert args: Python->C
-        return NULL;                             // NULL triggers exception
+    if (!PyArg_ParseTuple(args, "s", &pstr))
+        return nullptr;
     const std::map<std::string, std::string>& Map = GetApplication().Config();
 
     std::map<std::string, std::string>::const_iterator it = Map.find(pstr);
@@ -449,27 +447,19 @@ PyObject* Application::sGetConfig(PyObject * /*self*/, PyObject *args)
     }
     else {
         // do not set an error because this may break existing python code
-#if PY_MAJOR_VERSION >= 3
         return PyUnicode_FromString("");
-#else
-        return PyString_FromString("");
-#endif
     }
 }
 
 PyObject* Application::sDumpConfig(PyObject * /*self*/, PyObject *args)
 {
-    if (!PyArg_ParseTuple(args, "") )    // convert args: Python->C
-        return NULL;                             // NULL triggers exception
+    if (!PyArg_ParseTuple(args, ""))
+        return nullptr;
 
     PyObject *dict = PyDict_New();
     for (std::map<std::string,std::string>::iterator It= GetApplication()._mConfig.begin();
          It!=GetApplication()._mConfig.end();++It) {
-#if PY_MAJOR_VERSION >= 3
         PyDict_SetItemString(dict,It->first.c_str(), PyUnicode_FromString(It->second.c_str()));
-#else
-        PyDict_SetItemString(dict,It->first.c_str(), PyString_FromString(It->second.c_str()));
-#endif
     }
     return dict;
 }
@@ -478,8 +468,8 @@ PyObject* Application::sSetConfig(PyObject * /*self*/, PyObject *args)
 {
     char *pstr,*pstr2;
 
-    if (!PyArg_ParseTuple(args, "ss", &pstr,&pstr2))  // convert args: Python->C
-        return NULL; // NULL triggers exception
+    if (!PyArg_ParseTuple(args, "ss", &pstr,&pstr2))
+        return nullptr;
 
     GetApplication()._mConfig[pstr] = pstr2;
 
@@ -489,8 +479,8 @@ PyObject* Application::sSetConfig(PyObject * /*self*/, PyObject *args)
 
 PyObject* Application::sGetVersion(PyObject * /*self*/, PyObject *args)
 {
-    if (!PyArg_ParseTuple(args, ""))     // convert args: Python->C
-        return NULL; // NULL triggers exception
+    if (!PyArg_ParseTuple(args, ""))
+        return nullptr;
 
     Py::List list;
     const std::map<std::string, std::string>& cfg = Application::Config();
@@ -502,6 +492,9 @@ PyObject* Application::sGetVersion(PyObject * /*self*/, PyObject *args)
     it = cfg.find("BuildVersionMinor");
     list.append(Py::String(it != cfg.end() ? it->second : ""));
 
+    it = cfg.find("BuildVersionPoint");
+    list.append(Py::String(it != cfg.end() ? it->second : ""));
+
     it = cfg.find("BuildRevision");
     list.append(Py::String(it != cfg.end() ? it->second : ""));
 
@@ -527,7 +520,7 @@ PyObject* Application::sAddImportType(PyObject * /*self*/, PyObject *args)
     char *psKey,*psMod;
 
     if (!PyArg_ParseTuple(args, "ss", &psKey,&psMod))
-        return NULL;
+        return nullptr;
 
     GetApplication().addImportType(psKey,psMod);
 
@@ -548,10 +541,10 @@ PyObject* Application::sChangeImportModule(PyObject * /*self*/, PyObject *args)
 
 PyObject* Application::sGetImportType(PyObject * /*self*/, PyObject *args)
 {
-    char*       psKey=0;
+    char*       psKey=nullptr;
 
-    if (!PyArg_ParseTuple(args, "|s", &psKey))     // convert args: Python->C
-        return NULL;                             // NULL triggers exception
+    if (!PyArg_ParseTuple(args, "|s", &psKey))
+        return nullptr;
 
     if (psKey) {
         Py::List list;
@@ -591,7 +584,7 @@ PyObject* Application::sAddExportType(PyObject * /*self*/, PyObject *args)
     char *psKey,*psMod;
 
     if (!PyArg_ParseTuple(args, "ss", &psKey,&psMod))
-        return NULL;
+        return nullptr;
 
     GetApplication().addExportType(psKey,psMod);
 
@@ -612,10 +605,10 @@ PyObject* Application::sChangeExportModule(PyObject * /*self*/, PyObject *args)
 
 PyObject* Application::sGetExportType(PyObject * /*self*/, PyObject *args)
 {
-    char*       psKey=0;
+    char*       psKey=nullptr;
 
-    if (!PyArg_ParseTuple(args, "|s", &psKey))     // convert args: Python->C
-        return NULL;                             // NULL triggers exception
+    if (!PyArg_ParseTuple(args, "|s", &psKey))
+        return nullptr;
 
     if (psKey) {
         Py::List list;
@@ -650,29 +643,65 @@ PyObject* Application::sGetExportType(PyObject * /*self*/, PyObject *args)
     }
 }
 
-PyObject* Application::sGetResourceDir(PyObject * /*self*/, PyObject *args)
+PyObject* Application::sGetResourcePath(PyObject * /*self*/, PyObject *args)
 {
-    if (!PyArg_ParseTuple(args, ""))     // convert args: Python->C
-        return NULL;                       // NULL triggers exception
+    if (!PyArg_ParseTuple(args, ""))
+        return nullptr;
 
     Py::String datadir(Application::getResourceDir(),"utf-8");
     return Py::new_reference_to(datadir);
 }
 
-PyObject* Application::sGetUserAppDataDir(PyObject * /*self*/, PyObject *args)
+PyObject* Application::sGetLibraryPath(PyObject * /*self*/, PyObject *args)
 {
-    if (!PyArg_ParseTuple(args, ""))     // convert args: Python->C
-        return NULL;                       // NULL triggers exception
+    if (!PyArg_ParseTuple(args, ""))
+        return nullptr;
+
+    Py::String datadir(Application::getLibraryDir(),"utf-8");
+    return Py::new_reference_to(datadir);
+}
+
+PyObject* Application::sGetTempPath(PyObject * /*self*/, PyObject *args)
+{
+    if (!PyArg_ParseTuple(args, ""))
+        return nullptr;
+
+    Py::String datadir(Application::getTempPath(),"utf-8");
+    return Py::new_reference_to(datadir);
+}
+
+PyObject* Application::sGetUserCachePath(PyObject * /*self*/, PyObject *args)
+{
+    if (!PyArg_ParseTuple(args, ""))
+        return nullptr;
+
+    Py::String datadir(Application::getUserCachePath(),"utf-8");
+    return Py::new_reference_to(datadir);
+}
+
+PyObject* Application::sGetUserConfigPath(PyObject * /*self*/, PyObject *args)
+{
+    if (!PyArg_ParseTuple(args, ""))
+        return nullptr;
+
+    Py::String datadir(Application::getUserConfigPath(),"utf-8");
+    return Py::new_reference_to(datadir);
+}
+
+PyObject* Application::sGetUserAppDataPath(PyObject * /*self*/, PyObject *args)
+{
+    if (!PyArg_ParseTuple(args, ""))
+        return nullptr;
 
     Py::String user_data_dir(Application::getUserAppDataDir(),"utf-8");
     return Py::new_reference_to(user_data_dir);
 }
 
-PyObject* Application::sGetUserMacroDir(PyObject * /*self*/, PyObject *args)
+PyObject* Application::sGetUserMacroPath(PyObject * /*self*/, PyObject *args)
 {
     PyObject *actual = Py_False;
     if (!PyArg_ParseTuple(args, "|O!", &PyBool_Type, &actual))
-        return NULL;
+        return nullptr;
 
     std::string macroDir = Application::getUserMacroDir();
     if (PyObject_IsTrue(actual)) {
@@ -685,10 +714,10 @@ PyObject* Application::sGetUserMacroDir(PyObject * /*self*/, PyObject *args)
     return Py::new_reference_to(user_macro_dir);
 }
 
-PyObject* Application::sGetHelpDir(PyObject * /*self*/, PyObject *args)
+PyObject* Application::sGetHelpPath(PyObject * /*self*/, PyObject *args)
 {
-    if (!PyArg_ParseTuple(args, ""))     // convert args: Python->C
-        return NULL;                       // NULL triggers exception
+    if (!PyArg_ParseTuple(args, ""))
+        return nullptr;
 
     Py::String user_macro_dir(Application::getHelpDir(),"utf-8");
     return Py::new_reference_to(user_macro_dir);
@@ -696,18 +725,18 @@ PyObject* Application::sGetHelpDir(PyObject * /*self*/, PyObject *args)
 
 PyObject* Application::sGetHomePath(PyObject * /*self*/, PyObject *args)
 {
-    if (!PyArg_ParseTuple(args, ""))     // convert args: Python->C
-        return NULL;                       // NULL triggers exception
+    if (!PyArg_ParseTuple(args, ""))
+        return nullptr;
 
-    Py::String homedir(GetApplication().getHomePath(),"utf-8");
+    Py::String homedir(Application::getHomePath(),"utf-8");
     return Py::new_reference_to(homedir);
 }
 
 PyObject* Application::sListDocuments(PyObject * /*self*/, PyObject *args)
 {
     PyObject *sort = Py_False;
-    if (!PyArg_ParseTuple(args, "|O",&sort))     // convert args: Python->C
-        return NULL;                       // NULL triggers exception
+    if (!PyArg_ParseTuple(args, "|O",&sort))
+        return nullptr;
     PY_TRY {
         PyObject *pDict = PyDict_New();
         PyObject *pKey;
@@ -718,11 +747,7 @@ PyObject* Application::sListDocuments(PyObject * /*self*/, PyObject *args)
             docs = Document::getDependentDocuments(docs,true);
 
         for (auto doc : docs) {
-#if PY_MAJOR_VERSION >= 3
             pKey   = PyUnicode_FromString(doc->getName());
-#else
-            pKey   = PyString_FromString(doc->getName());
-#endif
             // GetPyObject() increments
             pValue = static_cast<Base::PyObjectBase*>(doc->getPyObject());
             PyDict_SetItem(pDict, pKey, pValue);
@@ -738,7 +763,7 @@ PyObject* Application::sAddDocObserver(PyObject * /*self*/, PyObject *args)
 {
     PyObject* o;
     if (!PyArg_ParseTuple(args, "O",&o))
-        return NULL;
+        return nullptr;
     PY_TRY {
         DocumentObserverPython::addObserver(Py::Object(o));
         Py_Return;
@@ -749,7 +774,7 @@ PyObject* Application::sRemoveDocObserver(PyObject * /*self*/, PyObject *args)
 {
     PyObject* o;
     if (!PyArg_ParseTuple(args, "O",&o))
-        return NULL;
+        return nullptr;
     PY_TRY {
         DocumentObserverPython::removeObserver(Py::Object(o));
         Py_Return;
@@ -761,16 +786,11 @@ PyObject *Application::sSetLogLevel(PyObject * /*self*/, PyObject *args)
     char *tag;
     PyObject *pcObj;
     if (!PyArg_ParseTuple(args, "sO", &tag, &pcObj))
-        return NULL;
+        return nullptr;
     PY_TRY{
         int l;
-#if PY_MAJOR_VERSION < 3
-        if (PyString_Check(pcObj)) {
-            const char *pstr = PyString_AsString(pcObj);
-#else
         if (PyUnicode_Check(pcObj)) {
             const char *pstr = PyUnicode_AsUTF8(pcObj);
-#endif
             if(strcmp(pstr,"Log") == 0)
                 l = FC_LOGLEVEL_LOG;
             else if(strcmp(pstr,"Warning") == 0)
@@ -784,9 +804,9 @@ PyObject *Application::sSetLogLevel(PyObject * /*self*/, PyObject *args)
             else if(strcmp(pstr,"Default") == 0)
                 l = FC_LOGLEVEL_DEFAULT;
             else {
-                Py_Error(Base::BaseExceptionFreeCADError,
+                Py_Error(PyExc_ValueError,
                         "Unknown Log Level (use 'Default', 'Error', 'Warning', 'Message', 'Log', 'Trace' or an integer)");
-                return NULL;
+                return nullptr;
             }
         }else
             l = PyLong_AsLong(pcObj);
@@ -810,7 +830,7 @@ PyObject *Application::sGetLogLevel(PyObject * /*self*/, PyObject *args)
 {
     char *tag;
     if (!PyArg_ParseTuple(args, "s", &tag))
-        return NULL;
+        return nullptr;
 
     PY_TRY{
         int l = -1;
@@ -850,7 +870,7 @@ PyObject *Application::sCheckLinkDepth(PyObject * /*self*/, PyObject *args)
 {
     short depth = 0;
     if (!PyArg_ParseTuple(args, "h", &depth))
-        return NULL;
+        return nullptr;
 
     PY_TRY {
         return Py::new_reference_to(Py::Int(GetApplication().checkLinkDepth(depth,false)));
@@ -863,14 +883,14 @@ PyObject *Application::sGetLinksTo(PyObject * /*self*/, PyObject *args)
     int options = 0;
     short count = 0;
     if (!PyArg_ParseTuple(args, "|Oih",&pyobj,&options, &count))
-        return NULL;
+        return nullptr;
 
     PY_TRY {
-        DocumentObject *obj = 0;
+        DocumentObject *obj = nullptr;
         if(pyobj!=Py_None) {
             if(!PyObject_TypeCheck(pyobj,&DocumentObjectPy::Type)) {
                 PyErr_SetString(PyExc_TypeError, "Expect the first argument of type document object");
-                return 0;
+                return nullptr;
             }
             obj = static_cast<DocumentObjectPy*>(pyobj)->getDocumentObjectPtr();
         }
@@ -888,24 +908,27 @@ PyObject *Application::sGetDependentObjects(PyObject * /*self*/, PyObject *args)
     PyObject *obj;
     int options = 0;
     if (!PyArg_ParseTuple(args, "O|i", &obj,&options))
-        return 0;
+        return nullptr;
 
     std::vector<App::DocumentObject*> objs;
-    if(PySequence_Check(obj)) {
+    if (PySequence_Check(obj)) {
         Py::Sequence seq(obj);
-        for(Py_ssize_t i=0;i<seq.size();++i) {
+        for (Py_ssize_t i=0;i<seq.size();++i) {
             if(!PyObject_TypeCheck(seq[i].ptr(),&DocumentObjectPy::Type)) {
                 PyErr_SetString(PyExc_TypeError, "Expect element in sequence to be of type document object");
-                return 0;
+                return nullptr;
             }
             objs.push_back(static_cast<DocumentObjectPy*>(seq[i].ptr())->getDocumentObjectPtr());
         }
-    }else if(!PyObject_TypeCheck(obj,&DocumentObjectPy::Type)) {
+    }
+    else if(!PyObject_TypeCheck(obj,&DocumentObjectPy::Type)) {
         PyErr_SetString(PyExc_TypeError,
             "Expect first argument to be either a document object or sequence of document objects");
-        return 0;
-    }else
+        return nullptr;
+    }
+    else {
         objs.push_back(static_cast<DocumentObjectPy*>(obj)->getDocumentObjectPtr());
+    }
 
     PY_TRY {
         auto ret = App::Document::getDependencyList(objs,options);
@@ -923,7 +946,7 @@ PyObject *Application::sSetActiveTransaction(PyObject * /*self*/, PyObject *args
     char *name;
     PyObject *persist = Py_False;
     if (!PyArg_ParseTuple(args, "s|O", &name,&persist))
-        return 0;
+        return nullptr;
 
     PY_TRY {
         Py::Int ret(GetApplication().setActiveTransaction(name,PyObject_IsTrue(persist)));
@@ -934,7 +957,7 @@ PyObject *Application::sSetActiveTransaction(PyObject * /*self*/, PyObject *args
 PyObject *Application::sGetActiveTransaction(PyObject * /*self*/, PyObject *args)
 {
     if (!PyArg_ParseTuple(args, ""))
-        return 0;
+        return nullptr;
 
     PY_TRY {
         int id = 0;
@@ -953,7 +976,7 @@ PyObject *Application::sCloseActiveTransaction(PyObject * /*self*/, PyObject *ar
     PyObject *abort = Py_False;
     int id = 0;
     if (!PyArg_ParseTuple(args, "|Oi", &abort,&id))
-        return 0;
+        return nullptr;
 
     PY_TRY {
         GetApplication().closeActiveTransaction(PyObject_IsTrue(abort),id);
@@ -964,7 +987,7 @@ PyObject *Application::sCloseActiveTransaction(PyObject * /*self*/, PyObject *ar
 PyObject *Application::sCheckAbort(PyObject * /*self*/, PyObject *args)
 {
     if (!PyArg_ParseTuple(args, ""))
-        return 0;
+        return nullptr;
 
     PY_TRY {
         Base::Sequencer().checkAbort();
