@@ -23,22 +23,16 @@
 
 #include "PreCompiled.h"
 
-#ifndef _PreComp_
-# include <sstream>
-#endif
-
-#include <boost_bind_bind.hpp>
-
 #include <Base/Tools.h>
+
 #include "Application.h"
-#include "Document.h"
-#include "DocumentObject.h"
-#include "DocumentObserver.h"
 #include "ComplexGeoData.h"
+#include "Document.h"
+#include "DocumentObserver.h"
 #include "GeoFeature.h"
 
 using namespace App;
-namespace bp = boost::placeholders;
+namespace sp = std::placeholders;
 
 
 DocumentT::DocumentT()
@@ -124,6 +118,13 @@ DocumentObjectT::DocumentObjectT(const Property* prop)
     *this = prop;
 }
 
+DocumentObjectT::DocumentObjectT(const Document* doc, const std::string& objName)
+{
+    if (doc && doc->getName())
+        document = doc->getName();
+    object = objName;
+}
+
 DocumentObjectT::DocumentObjectT(const char *docName, const char *objName)
 {
     if(docName)
@@ -174,7 +175,7 @@ void DocumentObjectT::operator=(const DocumentObject* obj)
 }
 
 void DocumentObjectT::operator=(const Property *prop) {
-    if(!prop || !prop->getName()
+    if(!prop || !prop->hasName()
              || !prop->getContainer()
              || !prop->getContainer()->isDerivedFrom(App::DocumentObject::getClassTypeId()))
     {
@@ -217,7 +218,7 @@ std::string DocumentObjectT::getDocumentPython() const
 
 DocumentObject* DocumentObjectT::getObject() const
 {
-    DocumentObject* obj = 0;
+    DocumentObject* obj = nullptr;
     Document* doc = getDocument();
     if (doc) {
         obj = doc->getObject(object.c_str());
@@ -249,10 +250,8 @@ const std::string &DocumentObjectT::getPropertyName() const {
 std::string DocumentObjectT::getPropertyPython() const
 {
     std::stringstream str;
-    str << "FreeCAD.getDocument('" << document
-        << "').getObject('" << object
-        << "')";
-    if(property.size())
+    str << getObjectPython();
+    if (property.size())
         str << '.' << property;
     return str.str();
 }
@@ -261,7 +260,7 @@ Property *DocumentObjectT::getProperty() const {
     auto obj = getObject();
     if(obj)
         return obj->getPropertyByName(property.c_str());
-    return 0;
+    return nullptr;
 }
 
 // -----------------------------------------------------------------------------
@@ -284,6 +283,11 @@ SubObjectT::SubObjectT(const DocumentObject *obj, const char *s)
 {
 }
 
+SubObjectT::SubObjectT(const DocumentObject *obj)
+    :DocumentObjectT(obj)
+{
+}
+
 SubObjectT::SubObjectT(const DocumentObjectT& obj, const char *s)
     :DocumentObjectT(obj),subname(s?s:"")
 {
@@ -328,6 +332,22 @@ SubObjectT &SubObjectT::operator=(SubObjectT &&other)
     return *this;
 }
 
+SubObjectT &SubObjectT::operator=(const DocumentObjectT &other)
+{
+    if (this == &other)
+        return *this;
+    static_cast<DocumentObjectT&>(*this) = other;
+    subname.clear();
+    return *this;
+}
+
+SubObjectT &SubObjectT::operator=(const DocumentObject *other)
+{
+    static_cast<DocumentObjectT&>(*this) = other;
+    subname.clear();
+    return *this;
+}
+
 bool SubObjectT::operator==(const SubObjectT &other) const {
     return static_cast<const DocumentObjectT&>(*this) == other
         && subname == other.subname;
@@ -380,7 +400,7 @@ App::DocumentObject *SubObjectT::getSubObject() const {
     auto obj = getObject();
     if(obj)
         return obj->getSubObject(subname.c_str());
-    return 0;
+    return nullptr;
 }
 
 std::string SubObjectT::getSubObjectPython(bool force) const {
@@ -399,14 +419,144 @@ std::vector<App::DocumentObject*> SubObjectT::getSubObjectList() const {
     return {};
 }
 
+std::string SubObjectT::getObjectFullName(const char *docName) const
+{
+    std::ostringstream ss;
+    if (!docName || getDocumentName() != docName) {
+        ss << getDocumentName();
+        if (auto doc = getDocument()) {
+            if (doc->Label.getStrValue() != getDocumentName())
+                ss << "(" << doc->Label.getValue() << ")";
+        }
+        ss << "#";
+    }
+    ss << getObjectName();
+    if (getObjectLabel().size() && getObjectLabel() != getObjectName())
+        ss << " (" << getObjectLabel() << ")";
+    return ss.str();
+}
+
+std::string SubObjectT::getSubObjectFullName(const char *docName) const
+{
+    if (subname.empty())
+        return getObjectFullName(docName);
+    std::ostringstream ss;
+    if (!docName || getDocumentName() != docName) {
+        ss << getDocumentName();
+        if (auto doc = getDocument()) {
+            if (doc->Label.getStrValue() != getDocumentName())
+                ss << "(" << doc->Label.getValue() << ")";
+        }
+        ss << "#";
+    }
+    ss << getObjectName() << "." << subname;
+    auto sobj = getSubObject();
+    if (sobj && sobj->Label.getStrValue() != sobj->getNameInDocument())
+        ss << " (" << sobj->Label.getValue() << ")";
+    return ss.str();
+}
+
+// -----------------------------------------------------------------------------
+
+PropertyLinkT::PropertyLinkT()
+    : toPython("None")
+{
+}
+
+PropertyLinkT::PropertyLinkT(DocumentObject *obj)
+    : PropertyLinkT()
+{
+    if (obj) {
+        std::ostringstream str;
+        DocumentObjectT objT(obj);
+        str << objT.getObjectPython();
+
+        toPython = str.str();
+    }
+}
+
+PropertyLinkT::PropertyLinkT(DocumentObject *obj, const std::vector<std::string>& subNames)
+    : PropertyLinkT()
+{
+    if (obj) {
+        std::ostringstream str;
+        DocumentObjectT objT(obj);
+        str << "(" << objT.getObjectPython() << ",[";
+        for(const auto& it : subNames)
+            str << "'" << it << "',";
+        str << "])";
+
+        toPython = str.str();
+    }
+}
+
+PropertyLinkT::PropertyLinkT(const std::vector<DocumentObject*>& objs)
+    : PropertyLinkT()
+{
+    if (!objs.empty()) {
+        std::stringstream str;
+        str << "[";
+        for (std::size_t i = 0; i < objs.size(); i++) {
+            if (i > 0)
+                str << ", ";
+
+            App::DocumentObject* obj = objs[i];
+            if (obj) {
+                DocumentObjectT objT(obj);
+                str << objT.getObjectPython();
+            }
+            else {
+                str << "None";
+            }
+        }
+
+        str << "]";
+    }
+}
+
+PropertyLinkT::PropertyLinkT(const std::vector<DocumentObject*>& objs, const std::vector<std::string>& subNames)
+    : PropertyLinkT()
+{
+    if (!objs.empty() && objs.size() == subNames.size()) {
+        std::stringstream str;
+        str << "[";
+        for (std::size_t i = 0; i < subNames.size(); i++) {
+            if (i>0)
+                str << ",(";
+            else
+                str << "(";
+
+            App::DocumentObject* obj = objs[i];
+            if (obj) {
+                DocumentObjectT objT(obj);
+                str << objT.getObjectPython();
+            }
+            else {
+                str << "None";
+            }
+
+            str << ",";
+            str << "'" << subNames[i] << "'";
+            str << ")";
+        }
+
+        str << "]";
+    }
+}
+
+std::string PropertyLinkT::getPropertyPython() const
+{
+    return toPython;
+}
+
 // -----------------------------------------------------------------------------
 
 class DocumentWeakPtrT::Private {
 public:
     Private(App::Document* doc) : _document(doc) {
         if (doc) {
-            connectApplicationDeletedDocument = App::GetApplication().signalDeleteDocument.connect(boost::bind
-                (&Private::deletedDocument, this, bp::_1));
+            connectApplicationDeletedDocument = App::GetApplication().signalDeleteDocument.connect(std::bind
+                (&Private::deletedDocument, this, sp::_1));
         }
     }
 
@@ -443,7 +593,12 @@ bool DocumentWeakPtrT::expired() const noexcept
     return (d->_document == nullptr);
 }
 
-App::Document* DocumentWeakPtrT::operator->() noexcept
+App::Document* DocumentWeakPtrT::operator*() const noexcept
+{
+    return d->_document;
+}
+
+App::Document* DocumentWeakPtrT::operator->() const noexcept
 {
     return d->_document;
 }
@@ -483,13 +638,13 @@ public:
         object = obj;
         if (obj) {
             indocument = true;
-            connectApplicationDeletedDocument = App::GetApplication().signalDeleteDocument.connect(boost::bind
-            (&Private::deletedDocument, this, bp::_1));
+            connectApplicationDeletedDocument = App::GetApplication().signalDeleteDocument.connect(std::bind
+            (&Private::deletedDocument, this, sp::_1));
             App::Document* doc = obj->getDocument();
-            connectDocumentCreatedObject = doc->signalNewObject.connect(boost::bind
-            (&Private::createdObject, this, bp::_1));
-            connectDocumentDeletedObject = doc->signalDeletedObject.connect(boost::bind
-            (&Private::deletedObject, this, bp::_1));
+            connectDocumentCreatedObject = doc->signalNewObject.connect(std::bind
+            (&Private::createdObject, this, sp::_1));
+            connectDocumentDeletedObject = doc->signalDeletedObject.connect(std::bind
+            (&Private::deletedObject, this, sp::_1));
         }
     }
     App::DocumentObject* get() const noexcept {
@@ -536,7 +691,12 @@ DocumentObjectWeakPtrT& DocumentObjectWeakPtrT::operator= (App::DocumentObject*
     return *this;
 }
 
-App::DocumentObject* DocumentObjectWeakPtrT::operator->() noexcept
+App::DocumentObject* DocumentObjectWeakPtrT::operator*() const noexcept
+{
+    return d->get();
+}
+
+App::DocumentObject* DocumentObjectWeakPtrT::operator->() const noexcept
 {
     return d->get();
 }
@@ -555,19 +715,17 @@ bool DocumentObjectWeakPtrT::operator!= (const DocumentObjectWeakPtrT& p) const
 
 DocumentObserver::DocumentObserver() : _document(nullptr)
 {
-    this->connectApplicationCreatedDocument = App::GetApplication().signalNewDocument.connect(boost::bind
-        (&DocumentObserver::slotCreatedDocument, this, bp::_1));
-    this->connectApplicationDeletedDocument = App::GetApplication().signalDeleteDocument.connect(boost::bind
-        (&DocumentObserver::slotDeletedDocument, this, bp::_1));
+    this->connectApplicationCreatedDocument = App::GetApplication().signalNewDocument.connect(std::bind
+        (&DocumentObserver::slotCreatedDocument, this, sp::_1));
+    this->connectApplicationDeletedDocument = App::GetApplication().signalDeleteDocument.connect(std::bind
+        (&DocumentObserver::slotDeletedDocument, this, sp::_1));
+    this->connectApplicationActivateDocument = App::GetApplication().signalActiveDocument.connect(std::bind
+        (&DocumentObserver::slotActivateDocument, this, sp::_1));
 }
 
-DocumentObserver::DocumentObserver(Document* doc) : _document(nullptr)
+DocumentObserver::DocumentObserver(Document* doc) : DocumentObserver()
 {
     // Connect to application and given document
-    this->connectApplicationCreatedDocument = App::GetApplication().signalNewDocument.connect(boost::bind
-        (&DocumentObserver::slotCreatedDocument, this, bp::_1));
-    this->connectApplicationDeletedDocument = App::GetApplication().signalDeleteDocument.connect(boost::bind
-        (&DocumentObserver::slotDeletedDocument, this, bp::_1));
     attachDocument(doc);
 }
 
@@ -576,6 +734,7 @@ DocumentObserver::~DocumentObserver()
     // disconnect from application and document
     this->connectApplicationCreatedDocument.disconnect();
     this->connectApplicationDeletedDocument.disconnect();
+    this->connectApplicationActivateDocument.disconnect();
     detachDocument();
 }
 
@@ -590,16 +749,16 @@ void DocumentObserver::attachDocument(Document* doc)
         detachDocument();
         _document = doc;
 
-        this->connectDocumentCreatedObject = _document->signalNewObject.connect(boost::bind
-            (&DocumentObserver::slotCreatedObject, this, bp::_1));
-        this->connectDocumentDeletedObject = _document->signalDeletedObject.connect(boost::bind
-            (&DocumentObserver::slotDeletedObject, this, bp::_1));
-        this->connectDocumentChangedObject = _document->signalChangedObject.connect(boost::bind
-            (&DocumentObserver::slotChangedObject, this, bp::_1, bp::_2));
-        this->connectDocumentRecomputedObject = _document->signalRecomputedObject.connect(boost::bind
-            (&DocumentObserver::slotRecomputedObject, this, bp::_1));
-        this->connectDocumentRecomputed = _document->signalRecomputed.connect(boost::bind
-            (&DocumentObserver::slotRecomputedDocument, this, bp::_1));
+        this->connectDocumentCreatedObject = _document->signalNewObject.connect(std::bind
+            (&DocumentObserver::slotCreatedObject, this, sp::_1));
+        this->connectDocumentDeletedObject = _document->signalDeletedObject.connect(std::bind
+            (&DocumentObserver::slotDeletedObject, this, sp::_1));
+        this->connectDocumentChangedObject = _document->signalChangedObject.connect(std::bind
+            (&DocumentObserver::slotChangedObject, this, sp::_1, sp::_2));
+        this->connectDocumentRecomputedObject = _document->signalRecomputedObject.connect(std::bind
+            (&DocumentObserver::slotRecomputedObject, this, sp::_1));
+        this->connectDocumentRecomputed = _document->signalRecomputed.connect(std::bind
+            (&DocumentObserver::slotRecomputedDocument, this, sp::_1));
     }
 }
 
@@ -623,6 +782,10 @@ void DocumentObserver::slotDeletedDocument(const App::Document& /*Doc*/)
 {
 }
 
+void DocumentObserver::slotActivateDocument(const App::Document& /*Doc*/)
+{
+}
+
 void DocumentObserver::slotCreatedObject(const App::DocumentObject& /*Obj*/)
 {
 }
