@@ -31,36 +31,27 @@
 #endif
 
 #include <boost/algorithm/string/predicate.hpp>
-#include <boost/io/ios_state.hpp>
-
-#include <Base/Console.h>
-#include "Base/Exception.h"
-#include <Base/Interpreter.h>
-#include <App/Application.h>
-#include <App/Document.h>
-#include <App/DocumentPy.h>
-#include <App/DocumentObject.h>
-#include <App/PropertyUnits.h>
-#include <Base/QuantityPy.h>
-#include <Base/MatrixPy.h>
-#include <Base/PlacementPy.h>
-#include <Base/RotationPy.h>
-#include <Base/VectorPy.h>
-#include <QStringList>
-#include <string>
-#include <sstream>
-#include <math.h>
-#include <stdio.h>
-#include <stack>
-#include <deque>
-#include <algorithm>
-#include "ExpressionParser.h"
-#include <Base/Unit.h>
-#include <App/PropertyUnits.h>
-#include <App/ObjectIdentifier.h>
 #include <boost/math/special_functions/round.hpp>
 #include <boost/math/special_functions/trunc.hpp>
 
+#include <sstream>
+#include <stack>
+#include <string>
+
+#include <App/Application.h>
+#include <App/DocumentObject.h>
+#include <App/ObjectIdentifier.h>
+#include <App/PropertyUnits.h>
+#include <Base/Interpreter.h>
+#include <Base/MatrixPy.h>
+#include <Base/PlacementPy.h>
+#include <Base/QuantityPy.h>
+#include <Base/RotationPy.h>
+#include <Base/VectorPy.h>
+
+#include "ExpressionParser.h"
+
+
 /** \defgroup Expression Expressions framework
     \ingroup APP
     \brief The expression system allows users to write expressions and formulas that produce values
@@ -69,7 +60,7 @@
 using namespace Base;
 using namespace App;
 
-FC_LOG_LEVEL_INIT("Expression",true,true)
+FC_LOG_LEVEL_INIT("Expression", true, true)
 
 #ifndef M_PI
 #define M_PI       3.14159265358979323846
@@ -129,7 +120,7 @@ FC_LOG_LEVEL_INIT("Expression",true,true)
 
 static inline std::ostream &operator<<(std::ostream &os, const App::Expression *expr) {
     if(expr) {
-        os << std::endl;
+        os << "\nin expression: ";
         expr->toString(os);
     }
     return os;
@@ -240,17 +231,7 @@ std::string unquote(const std::string & input)
 //
 // ExpressionVistor
 //
-void ExpressionVisitor::getDeps(Expression &e, ExpressionDeps &deps) {
-    e._getDeps(deps);
-}
-
-void ExpressionVisitor::getDepObjects(Expression &e,
-        std::set<App::DocumentObject*> &deps, std::vector<std::string> *labels)
-{
-    e._getDepObjects(deps,labels);
-}
-
-void ExpressionVisitor::getIdentifiers(Expression &e, std::set<App::ObjectIdentifier> &ids) {
+void ExpressionVisitor::getIdentifiers(Expression &e, std::map<App::ObjectIdentifier,bool> &ids) {
     e._getIdentifiers(ids);
 }
 
@@ -445,17 +426,8 @@ static Py::Object _pyObjectFromAny(const App::any &value, const Expression *e) {
     else if (is_type(value,typeid(float)))
         return Py::Float(cast<float>(value));
     else if (is_type(value,typeid(int)))
-#if PY_MAJOR_VERSION < 3
-        return Py::Int(cast<int>(value));
-#else
         return Py::Long(cast<int>(value));
-#endif
     else if (is_type(value,typeid(long))) {
-#if PY_MAJOR_VERSION < 3
-        long l = cast<long>(value);
-        if(std::abs(l)<=INT_MAX)
-            return Py::Int(int(l));
-#endif
         return Py::Long(cast<long>(value));
     } else if (is_type(value,typeid(bool)))
         return Py::Boolean(cast<bool>(value));
@@ -469,7 +441,7 @@ static Py::Object _pyObjectFromAny(const App::any &value, const Expression *e) {
 
 namespace App {
 Py::Object pyObjectFromAny(const App::any &value) {
-    return _pyObjectFromAny(value,0);
+    return _pyObjectFromAny(value,nullptr);
 }
 
 App::any pyObjectToAny(Py::Object value, bool check) {
@@ -490,31 +462,15 @@ App::any pyObjectToAny(Py::Object value, bool check) {
     }
     if (PyFloat_Check(pyvalue))
         return App::any(PyFloat_AsDouble(pyvalue));
-#if PY_MAJOR_VERSION < 3
-    if (PyInt_Check(pyvalue))
-        return App::any(PyInt_AsLong(pyvalue));
-#endif
     if (PyLong_Check(pyvalue))
         return App::any(PyLong_AsLong(pyvalue));
-#if PY_MAJOR_VERSION < 3
-    else if (PyString_Check(pyvalue))
-        return App::any(std::string(PyString_AsString(pyvalue)));
     else if (PyUnicode_Check(pyvalue)) {
-        PyObject * s = PyUnicode_AsUTF8String(pyvalue);
-        if(!s)
-            FC_THROWM(Base::ValueError,"Invalid unicode string");
-        Py::Object o(s,true);
-        return App::any(std::string(PyString_AsString(s)));
-    }
-#else
-    else if (PyUnicode_Check(pyvalue)) {
-        const char* value = PyUnicode_AsUTF8(pyvalue);
-        if (!value) {
+        const char* utf8value = PyUnicode_AsUTF8(pyvalue);
+        if (!utf8value) {
             FC_THROWM(Base::ValueError, "Invalid unicode string");
         }
-        return App::any(std::string(value));
+        return App::any(std::string(utf8value));
     }
-#endif
     else {
         return App::any(pyObjectWrap(pyvalue));
     }
@@ -525,10 +481,6 @@ bool pyToQuantity(Quantity &q, const Py::Object &pyobj) {
         q = *static_cast<Base::QuantityPy*>(*pyobj)->getQuantityPtr();
     else if (PyFloat_Check(*pyobj))
         q = Quantity(PyFloat_AsDouble(*pyobj));
-#if PY_MAJOR_VERSION < 3
-    else if (PyInt_Check(*pyobj))
-        q = Quantity(PyInt_AsLong(*pyobj));
-#endif
     else if (PyLong_Check(*pyobj))
         q = Quantity(PyLong_AsLong(*pyobj));
     else
@@ -537,7 +489,7 @@ bool pyToQuantity(Quantity &q, const Py::Object &pyobj) {
 }
 
 static inline Quantity pyToQuantity(const Py::Object &pyobj,
-        const Expression *e, const char *msg=0)
+        const Expression *e, const char *msg=nullptr)
 {
     Quantity q;
     if(!pyToQuantity(q,pyobj)) {
@@ -556,9 +508,6 @@ Py::Object pyFromQuantity(const Quantity &quantity) {
     int i;
     switch(essentiallyInteger(v,l,i)) {
     case 1:
-#if PY_MAJOR_VERSION < 3
-        return Py::Int(i);
-#endif
     case 2:
         return Py::Long(l);
     default:
@@ -715,7 +664,7 @@ Expression* expressionFromPy(const DocumentObject *owner, const Py::Object &valu
 //
 Expression::Component::Component(const std::string &n)
     :comp(ObjectIdentifier::SimpleComponent(n))
-    ,e1(0) ,e2(0) ,e3(0)
+    ,e1(nullptr) ,e2(nullptr) ,e3(nullptr)
 {}
 
 Expression::Component::Component(Expression *_e1, Expression *_e2, Expression *_e3, bool isRange)
@@ -727,14 +676,14 @@ Expression::Component::Component(Expression *_e1, Expression *_e2, Expression *_
 
 Expression::Component::Component(const ObjectIdentifier::Component &comp)
     :comp(comp)
-    ,e1(0) ,e2(0) ,e3(0)
+    ,e1(nullptr) ,e2(nullptr) ,e3(nullptr)
 {}
 
 Expression::Component::Component(const Component &other)
     :comp(other.comp)
-    ,e1(other.e1?other.e1->copy():0)
-    ,e2(other.e2?other.e2->copy():0)
-    ,e3(other.e3?other.e3->copy():0)
+    ,e1(other.e1?other.e1->copy():nullptr)
+    ,e2(other.e2?other.e2->copy():nullptr)
+    ,e3(other.e3?other.e3->copy():nullptr)
 {}
 
 Expression::Component::~Component()
@@ -937,58 +886,61 @@ Expression * Expression::parse(const DocumentObject *owner, const std::string &b
     return ExpressionParser::parse(owner, buffer.c_str());
 }
 
-class GetDepsExpressionVisitor : public ExpressionVisitor {
-public:
-    GetDepsExpressionVisitor(ExpressionDeps &deps)
-        :deps(deps)
-    {}
-
-    virtual void visit(Expression &e) {
-        this->getDeps(e,deps);
+void Expression::getDeps(ExpressionDeps &deps, int option)  const {
+    for(auto &v : getIdentifiers()) {
+        bool hidden = v.second;
+        const ObjectIdentifier &var = v.first;
+        if((hidden && option==DepNormal)
+                || (!hidden && option==DepHidden))
+            continue;
+        for(auto &dep : var.getDep(true)) {
+            DocumentObject *obj = dep.first;
+            for(auto &propName : dep.second) {
+                deps[obj][propName].push_back(var);
+            }
+        }
     }
-
-    ExpressionDeps &deps;
-};
-
-void Expression::getDeps(ExpressionDeps &deps)  const {
-    GetDepsExpressionVisitor v(deps);
-    const_cast<Expression*>(this)->visit(v);
 }
 
-ExpressionDeps Expression::getDeps()  const {
+ExpressionDeps Expression::getDeps(int option)  const {
     ExpressionDeps deps;
-    getDeps(deps);
+    getDeps(deps, option);
     return deps;
 }
 
-class GetDepObjsExpressionVisitor : public ExpressionVisitor {
-public:
-    GetDepObjsExpressionVisitor(std::set<App::DocumentObject*> &deps, std::vector<std::string> *labels)
-        :deps(deps),labels(labels)
-    {}
+void Expression::getDepObjects(
+        std::map<App::DocumentObject*,bool> &deps, std::vector<std::string> *labels)  const 
+{
+    for(auto &v : getIdentifiers()) {
+        bool hidden = v.second;
+        const ObjectIdentifier &var = v.first;
+        std::vector<std::string> strings;
+        for(auto &dep : var.getDep(false, &strings)) {
+            DocumentObject *obj = dep.first;
+            if (!obj->testStatus(ObjectStatus::Remove)) {
+                if (labels) {
+                    std::copy(strings.begin(), strings.end(), std::back_inserter(*labels));
+                }
 
-    virtual void visit(Expression &e) {
-        this->getDepObjects(e,deps,labels);
+                auto res = deps.insert(std::make_pair(obj, hidden));
+                if (!hidden || res.second)
+                    res.first->second = hidden;
+            }
+
+            strings.clear();
+        }
     }
-
-    std::set<App::DocumentObject*> &deps;
-    std::vector<std::string> *labels;
-};
-
-void Expression::getDepObjects(std::set<App::DocumentObject*> &deps, std::vector<std::string> *labels)  const {
-    GetDepObjsExpressionVisitor v(deps,labels);
-    const_cast<Expression *>(this)->visit(v);
 }
 
-std::set<App::DocumentObject*> Expression::getDepObjects(std::vector<std::string> *labels)  const {
-    std::set<App::DocumentObject*> deps;
+std::map<App::DocumentObject*,bool> Expression::getDepObjects(std::vector<std::string> *labels)  const {
+    std::map<App::DocumentObject*,bool> deps;
     getDepObjects(deps,labels);
     return deps;
 }
 
 class GetIdentifiersExpressionVisitor : public ExpressionVisitor {
 public:
-    GetIdentifiersExpressionVisitor(std::set<App::ObjectIdentifier> &deps)
+    GetIdentifiersExpressionVisitor(std::map<App::ObjectIdentifier,bool> &deps)
         :deps(deps)
     {}
 
@@ -996,16 +948,16 @@ public:
         this->getIdentifiers(e,deps);
     }
 
-    std::set<App::ObjectIdentifier> &deps;
+    std::map<App::ObjectIdentifier,bool> &deps;
 };
 
-void Expression::getIdentifiers(std::set<App::ObjectIdentifier> &deps)  const {
+void Expression::getIdentifiers(std::map<App::ObjectIdentifier,bool> &deps)  const {
     GetIdentifiersExpressionVisitor v(deps);
     const_cast<Expression*>(this)->visit(v);
 }
 
-std::set<App::ObjectIdentifier> Expression::getIdentifiers()  const {
-    std::set<App::ObjectIdentifier> deps;
+std::map<App::ObjectIdentifier,bool> Expression::getIdentifiers()  const {
+    std::map<App::ObjectIdentifier,bool> deps;
     getIdentifiers(deps);
     return deps;
 }
@@ -1046,9 +998,9 @@ public:
 
 ExpressionPtr Expression::importSubNames(const std::map<std::string,std::string> &nameMap) const {
     if(!owner || !owner->getDocument())
-        return 0;
+        return nullptr;
     ObjectIdentifier::SubNameMap subNameMap;
-    for(auto &dep : getDeps()) {
+    for(auto &dep : getDeps(DepAll)) {
         for(auto &info : dep.second) {
             for(auto &path : info.second) {
                 auto obj = path.getDocumentObject();
@@ -1068,7 +1020,7 @@ ExpressionPtr Expression::importSubNames(const std::map<std::string,std::string>
         }
     }
     if(subNameMap.empty())
-        return 0;
+        return nullptr;
     ImportSubNamesExpressionVisitor v(subNameMap);
     auto res = copy();
     res->visit(v);
@@ -1096,7 +1048,8 @@ ExpressionPtr Expression::updateLabelReference(
     if(ref.size()<=2)
         return ExpressionPtr();
     std::vector<std::string> labels;
-    getDepObjects(&labels);
+    for(auto &v : getIdentifiers())
+        v.first.getDepLabels(labels);
     for(auto &label : labels) {
         // ref contains something like $label. and we need to strip '$' and '.'
         if(ref.compare(1,ref.size()-2,label)==0) {
@@ -1187,12 +1140,13 @@ Expression* Expression::eval() const {
     return expressionFromPy(owner,getPyValue());
 }
 
-bool Expression::isSame(const Expression &other) const {
+bool Expression::isSame(const Expression &other, bool checkComment) const {
     if(&other == this)
         return true;
     if(getTypeId()!=other.getTypeId())
         return false;
-    return comment==other.comment && toString(true,true) == other.toString(true,true);
+    return (!checkComment || comment==other.comment)
+        && toString(true,true) == other.toString(true,true);
 }
 
 std::string Expression::toString(bool persistent, bool checkPriority, int indent) const {
@@ -1255,7 +1209,7 @@ void UnitExpression::setQuantity(const Quantity &_quantity)
     if(cache) {
         Base::PyGILStateLocker lock;
         Py::_XDECREF(cache);
-        cache = 0;
+        cache = nullptr;
     }
 }
 
@@ -1273,7 +1227,7 @@ void UnitExpression::setUnit(const Quantity &_quantity)
     if(cache) {
         Base::PyGILStateLocker lock;
         Py::_XDECREF(cache);
-        cache = 0;
+        cache = nullptr;
     }
 }
 
@@ -1479,30 +1433,6 @@ static Py::Object calc(const Expression *expr, int op,
     BINARY_OP(DIV,TrueDivide)
     case OperatorExpression::ADD: {
         PyObject *res;
-#if PY_MAJOR_VERSION < 3
-        if (PyString_CheckExact(*l) && PyString_CheckExact(*r)) {
-            Py_ssize_t v_len = PyString_GET_SIZE(*l);
-            Py_ssize_t w_len = PyString_GET_SIZE(*r);
-            Py_ssize_t new_len = v_len + w_len;
-            if (new_len < 0)
-                __EXPR_THROW(OverflowError, "strings are too large to concat", expr);
-
-            if (l.ptr()->ob_refcnt==1 && !PyString_CHECK_INTERNED(l.ptr())) {
-                res = Py::new_reference_to(l);
-                // Must make sure ob_refcnt is still 1
-                l = Py::Object();
-                if (_PyString_Resize(&res, new_len) != 0)
-                    EXPR_PY_THROW(expr);
-                memcpy(PyString_AS_STRING(res) + v_len, PyString_AS_STRING(*r), w_len);
-            }else{
-                res = Py::new_reference_to(l);
-                l = Py::Object();
-                PyString_Concat(&res,*r);
-                if(!res) EXPR_PY_THROW(expr);
-            }
-            return Py::asObject(res);
-        }
-#else
         if (PyUnicode_CheckExact(*l) && PyUnicode_CheckExact(*r)) {
             if(inplace) {
                 res = Py::new_reference_to(l);
@@ -1516,7 +1446,6 @@ static Py::Object calc(const Expression *expr, int op,
             if(!res) EXPR_PY_THROW(expr);
             return Py::asObject(res);
         }
-#endif
         _BINARY_OP(Add);
     }
     case OperatorExpression::POW: {
@@ -1530,15 +1459,9 @@ static Py::Object calc(const Expression *expr, int op,
     }
     case OperatorExpression::MOD: {
         PyObject *res;
-#if PY_MAJOR_VERSION < 3
-        if (PyString_CheckExact(l.ptr()) &&
-                (!PyString_Check(r.ptr()) || PyString_CheckExact(r.ptr())))
-            res = PyString_Format(l.ptr(), r.ptr());
-#else
         if (PyUnicode_CheckExact(l.ptr()) &&
                 (!PyUnicode_Check(r.ptr()) || PyUnicode_CheckExact(r.ptr())))
             res = PyUnicode_Format(l.ptr(), r.ptr());
-#endif
         else if(inplace)
             res = PyNumber_InPlaceRemainder(l.ptr(),r.ptr());
         else
@@ -1594,7 +1517,7 @@ void OperatorExpression::_toString(std::ostream &s, bool persistent,int) const
         leftOperator = static_cast<OperatorExpression*>(left)->op;
     if (left->priority() < priority()) // Check on operator priority first
         needsParens = true;
-    else if (leftOperator == op) { // Equal priority?
+    else if (leftOperator == op) { // Same operator ?
         if (!isLeftAssociative())
             needsParens = true;
         //else if (!isCommutative())
@@ -1665,14 +1588,14 @@ void OperatorExpression::_toString(std::ostream &s, bool persistent,int) const
         rightOperator = static_cast<OperatorExpression*>(right)->op;
     if (right->priority() < priority()) // Check on operator priority first
         needsParens = true;
-    else if (rightOperator == op) { // Equal priority?
+    else if (rightOperator == op) { // Same operator ?
         if (!isRightAssociative())
             needsParens = true;
         else if (!isCommutative())
             needsParens = true;
     }
-    else if (right->priority() == priority()) {
-        if (!isRightAssociative())
+    else if (right->priority() == priority()) { // Same priority ?
+        if (!isRightAssociative() || rightOperator == MOD)
             needsParens = true;
     }
 
@@ -1772,12 +1695,96 @@ bool OperatorExpression::isRightAssociative() const
 
 TYPESYSTEM_SOURCE(App::FunctionExpression, App::UnitExpression)
 
+static int _HiddenReference;
+
+struct HiddenReference {
+    HiddenReference(bool cond)
+        :cond(cond)
+    {
+        if(cond)
+            ++_HiddenReference;
+    }
+    ~HiddenReference() {
+        if(cond)
+            --_HiddenReference;
+    }
+
+    static bool check(int option) {
+        return (option==Expression::DepNormal && _HiddenReference)
+            || (option==Expression::DepHidden && !_HiddenReference);
+    }
+
+    static bool isHidden() {
+        return _HiddenReference!=0;
+    }
+
+    bool cond;
+};
+
 FunctionExpression::FunctionExpression(const DocumentObject *_owner, Function _f, std::string &&name, std::vector<Expression *> _args)
     : UnitExpression(_owner)
     , f(_f)
     , fname(std::move(name))
     , args(_args)
 {
+    switch (f) {
+    case ACOS:
+    case ASIN:
+    case ATAN:
+    case ABS:
+    case EXP:
+    case LOG:
+    case LOG10:
+    case SIN:
+    case SINH:
+    case TAN:
+    case TANH:
+    case SQRT:
+    case COS:
+    case COSH:
+    case ROUND:
+    case TRUNC:
+    case CEIL:
+    case FLOOR:
+    case MINVERT:
+    case STR:
+    case HIDDENREF:
+    case HREF:
+        if (args.size() != 1)
+            EXPR_THROW("Invalid number of arguments: exactly one required.");
+        break;
+    case MOD:
+    case ATAN2:
+    case POW:
+        if (args.size() != 2)
+            EXPR_THROW("Invalid number of arguments: exactly two required.");
+        break;
+    case HYPOT:
+    case CATH:
+        if (args.size() < 2 || args.size() > 3)
+            EXPR_THROW("Invalid number of arguments: exactly two, or three required.");
+        break;
+    case STDDEV:
+    case SUM:
+    case AVERAGE:
+    case COUNT:
+    case MIN:
+    case MAX:
+    case CREATE:
+    case MSCALE:
+        if (args.size() == 0)
+            EXPR_THROW("Invalid number of arguments: at least one required.");
+        break;
+    case LIST:
+    case TUPLE:
+        break;
+    case NONE:
+    case AGGREGATES:
+    case LAST:
+    default:
+        PARSER_THROW("Unknown function");
+        break;
+    }
 }
 
 FunctionExpression::~FunctionExpression()
@@ -1969,11 +1976,11 @@ Py::Object FunctionExpression::evalAggregate(
                 if (!p)
                     continue;
 
-                if ((qp = freecad_dynamic_cast<PropertyQuantity>(p)) != 0)
+                if ((qp = freecad_dynamic_cast<PropertyQuantity>(p)) != nullptr)
                     c->collect(qp->getQuantityValue());
-                else if ((fp = freecad_dynamic_cast<PropertyFloat>(p)) != 0)
+                else if ((fp = freecad_dynamic_cast<PropertyFloat>(p)) != nullptr)
                     c->collect(Quantity(fp->getValue()));
-                else if ((ip = freecad_dynamic_cast<PropertyInteger>(p)) != 0)
+                else if ((ip = freecad_dynamic_cast<PropertyInteger>(p)) != nullptr)
                     c->collect(Quantity(ip->getValue()));
                 else
                     _EXPR_THROW("Invalid property type for aggregate.", owner);
@@ -2092,6 +2099,10 @@ Py::Object FunctionExpression::evaluate(const Expression *expr, int f, const std
             PyObjectBase::__PyInit(res.ptr(),tuple.ptr(),dict.ptr());
         }
         return res;
+    } else if (f == STR) {
+        return Py::String(args[0]->getPyValue().as_string());
+    } else if (f == HIDDENREF || f == HREF) {
+        return args[0]->getPyValue();
     }
 
     Py::Object e1 = args[0]->getPyValue();
@@ -2224,7 +2235,7 @@ Py::Object FunctionExpression::evaluate(const Expression *expr, int f, const std
         unit = v1.getUnit();
         break;
     default:
-        _EXPR_THROW("Unknown function: " << f,expr);
+        _EXPR_THROW("Unknown function: " << f,0);
     }
 
     /* Compute result */
@@ -2304,7 +2315,7 @@ Py::Object FunctionExpression::evaluate(const Expression *expr, int f, const std
         output = floor(value);
         break;
     default:
-        _EXPR_THROW("Unknown function: " << f,expr);
+        _EXPR_THROW("Unknown function: " << f,0);
     }
 
     return Py::asObject(new QuantityPy(new Quantity(scaler * output, unit)));
@@ -2424,6 +2435,12 @@ void FunctionExpression::_toString(std::ostream &ss, bool persistent,int) const
         ss << "minvert("; break;;
     case CREATE:
         ss << "create("; break;;
+    case STR:
+        ss << "str("; break;;
+    case HIDDENREF:
+        ss << "hiddenref("; break;;
+    case HREF:
+        ss << "href("; break;;
     default:
         ss << fname << "("; break;;
     }
@@ -2457,6 +2474,7 @@ void FunctionExpression::_visit(ExpressionVisitor &v)
 {
     std::vector<Expression*>::const_iterator i = args.begin();
 
+    HiddenReference ref(f == HIDDENREF || f == HREF);
     while (i != args.end()) {
         (*i)->visit(v);
         ++i;
@@ -2595,24 +2613,12 @@ Expression *VariableExpression::_copy() const
     return new VariableExpression(owner, var);
 }
 
-void VariableExpression::_getDeps(ExpressionDeps &deps) const
+void VariableExpression::_getIdentifiers(std::map<App::ObjectIdentifier,bool> &deps) const
 {
-    auto dep = var.getDep();
-    if(dep.first)
-        deps[dep.first][dep.second].push_back(var);
-}
-
-void VariableExpression::_getDepObjects(
-        std::set<App::DocumentObject*> &deps, std::vector<std::string> *labels) const
-{
-    auto dep = var.getDep(labels);
-    if(dep.first)
-        deps.insert(dep.first);
-}
-
-void VariableExpression::_getIdentifiers(std::set<App::ObjectIdentifier> &deps) const
-{
-    deps.insert(var);
+    bool hidden = HiddenReference::isHidden();
+    auto res = deps.insert(std::make_pair(var,hidden));
+    if(!hidden || res.second)
+        res.first->second = hidden;
 }
 
 bool VariableExpression::_relabeledDocument(const std::string &oldName,
@@ -2704,12 +2710,18 @@ void VariableExpression::_offsetCells(int rowOffset, int colOffset, ExpressionVi
     if(!addr.isValid() || (addr.isAbsoluteCol() && addr.isAbsoluteRow()))
         return;
 
-    v.aboutToChange();
     if(!addr.isAbsoluteCol())
         addr.setCol(addr.col()+colOffset);
     if(!addr.isAbsoluteRow())
         addr.setRow(addr.row()+rowOffset);
-    var.setComponent(idx,ObjectIdentifier::SimpleComponent(addr.toString()));
+    if(!addr.isValid()) {
+        FC_WARN("Not changing relative cell reference '"
+                << comp.getName() << "' due to invalid offset "
+                << '(' << colOffset << ", " << rowOffset << ')');
+    } else {
+        v.aboutToChange();
+        var.setComponent(idx,ObjectIdentifier::SimpleComponent(addr.toString()));
+    }
 }
 
 void VariableExpression::setPath(const ObjectIdentifier &path)
@@ -2846,7 +2858,7 @@ Expression *ConditionalExpression::simplify() const
     std::unique_ptr<Expression> e(condition->simplify());
     NumberExpression * v = freecad_dynamic_cast<NumberExpression>(e.get());
 
-    if (v == 0)
+    if (v == nullptr)
         return new ConditionalExpression(owner, condition->simplify(), trueExpr->simplify(), falseExpr->simplify());
     else {
         if (fabs(v->getValue()) > 0.5)
@@ -2980,16 +2992,19 @@ Expression *RangeExpression::simplify() const
     return copy();
 }
 
-void RangeExpression::_getDeps(ExpressionDeps &deps) const
+void RangeExpression::_getIdentifiers(std::map<App::ObjectIdentifier,bool> &deps) const
 {
+    bool hidden = HiddenReference::isHidden();
+
     assert(owner);
 
     Range i(getRange());
 
-    auto &dep = deps[owner];
     do {
-        std::string address = i.address();
-        dep[address].push_back(ObjectIdentifier(owner,address));
+        ObjectIdentifier var(owner,i.address());
+        auto res = deps.insert(std::make_pair(var,hidden));
+        if(!hidden || res.second)
+            res.first->second = hidden;
     } while (i.next());
 }
 
@@ -3104,7 +3119,7 @@ void RangeExpression::_offsetCells(int rowOffset, int colOffset, ExpressionVisit
 
 ////////////////////////////////////////////////////////////////////////////////////
 
-static Base::XMLReader *_Reader = 0;
+static Base::XMLReader *_Reader = nullptr;
 ExpressionParser::ExpressionImporter::ExpressionImporter(Base::XMLReader &reader) {
     assert(!_Reader);
     _Reader = &reader;
@@ -3112,7 +3127,7 @@ ExpressionParser::ExpressionImporter::ExpressionImporter(Base::XMLReader &reader
 
 ExpressionParser::ExpressionImporter::~ExpressionImporter() {
     assert(_Reader);
-    _Reader = 0;
+    _Reader = nullptr;
 }
 
 Base::XMLReader *ExpressionParser::ExpressionImporter::reader() {
@@ -3152,12 +3167,13 @@ double num_change(char* yytext,char dez_delim,char grp_delim)
         else
             temp[i++] = *c;
         // check buffer overflow
-        if (i>39) return 0.0;
+        if (i>39)
+            return 0.0;
     }
     temp[i] = '\0';
 
     errno = 0;
-    ret_val = strtod( temp, NULL );
+    ret_val = strtod( temp, nullptr );
     if (ret_val == 0 && errno == ERANGE)
         throw Base::UnderflowError("Number underflow.");
     if (ret_val == HUGE_VAL || ret_val == -HUGE_VAL)
@@ -3166,8 +3182,8 @@ double num_change(char* yytext,char dez_delim,char grp_delim)
     return ret_val;
 }
 
-static Expression * ScanResult = 0;                    /**< The resulting expression after a successful parsing */
-static const App::DocumentObject * DocumentObject = 0; /**< The DocumentObject that will own the expression */
+static Expression * ScanResult = nullptr;                    /**< The resulting expression after a successful parsing */
+static const App::DocumentObject * DocumentObject = nullptr; /**< The DocumentObject that will own the expression */
 static bool unitExpression = false;                    /**< True if the parsed string is a unit only */
 static bool valueExpression = false;                   /**< True if the parsed string is a full expression */
 static std::stack<std::string> labels;                /**< Label string primitive */
@@ -3177,7 +3193,7 @@ static int column;
 
 // show the parser the lexer method
 #define yylex ExpressionParserlex
-int ExpressionParserlex(void);
+int ExpressionParserlex();
 
 // Parser, defined in ExpressionParser.y
 # define YYTOKENTYPE
@@ -3210,7 +3226,7 @@ static void initParser(const App::DocumentObject *owner)
 
     using namespace App::ExpressionParser;
 
-    ScanResult = 0;
+    ScanResult = nullptr;
     App::ExpressionParser::DocumentObject = owner;
     labels = std::stack<std::string>();
     column = 0;
@@ -3245,6 +3261,9 @@ static void initParser(const App::DocumentObject *owner)
         registered_functions["mscale"] = FunctionExpression::MSCALE;
         registered_functions["minvert"] = FunctionExpression::MINVERT;
         registered_functions["create"] = FunctionExpression::CREATE;
+        registered_functions["str"] = FunctionExpression::STR;
+        registered_functions["hiddenref"] = FunctionExpression::HIDDENREF;
+        registered_functions["href"] = FunctionExpression::HREF;
 
         // Aggregates
         registered_functions["sum"] = FunctionExpression::SUM;
@@ -3258,16 +3277,16 @@ static void initParser(const App::DocumentObject *owner)
     }
 }
 
-std::vector<boost::tuple<int, int, std::string> > tokenize(const std::string &str)
+std::vector<std::tuple<int, int, std::string> > tokenize(const std::string &str)
 {
     ExpressionParser::YY_BUFFER_STATE buf = ExpressionParser_scan_string(str.c_str());
-    std::vector<boost::tuple<int, int, std::string> > result;
+    std::vector<std::tuple<int, int, std::string> > result;
     int token;
 
     column = 0;
     try {
         while ( (token  = ExpressionParserlex()) != 0)
-            result.push_back(boost::make_tuple(token, ExpressionParser::last_column, yytext));
+            result.push_back(std::make_tuple(token, ExpressionParser::last_column, yytext));
     }
     catch (...) {
         // Ignore all exceptions
@@ -3308,7 +3327,7 @@ Expression * App::ExpressionParser::parse(const App::DocumentObject *owner, cons
     if (result != 0)
         throw ParserError("Failed to parse expression.");
 
-    if (ScanResult == 0)
+    if (ScanResult == nullptr)
         throw ParserError("Unknown error in expression");
 
     if (valueExpression)
@@ -3316,7 +3335,7 @@ Expression * App::ExpressionParser::parse(const App::DocumentObject *owner, cons
     else {
         delete ScanResult;
         throw Expression::Exception("Expression can not evaluate to a value.");
-        return 0;
+        return nullptr;
     }
 }
 
@@ -3336,7 +3355,7 @@ UnitExpression * ExpressionParser::parseUnit(const App::DocumentObject *owner, c
     if (result != 0)
         throw ParserError("Failed to parse expression.");
 
-    if (ScanResult == 0)
+    if (ScanResult == nullptr)
         throw ParserError("Unknown error in expression");
 
     // Simplify expression
@@ -3368,7 +3387,7 @@ UnitExpression * ExpressionParser::parseUnit(const App::DocumentObject *owner, c
     else {
         delete simplified;
         throw Expression::Exception("Expression is not a unit.");
-        return 0;
+        return nullptr;
     }
 }
 
