@@ -31,209 +31,262 @@
 import FreeCAD
 
 def removeFromPath(module_name):
-	"""removes the module from the sys.path. The entry point for imports
-		will therefore always be FreeCAD.
-		eg.: from FreeCAD.Module.submodule import function"""
-	import sys
-	paths = sys.path
-	for path in paths:
-		if module_name in path:
-			sys.path.remove(path)
-			return
-	Wrn(module_name + " not found in sys.path\n")
+    """removes the module from the sys.path. The entry point for imports
+        will therefore always be FreeCAD.
+        eg.: from FreeCAD.Module.submodule import function"""
+    import sys
+    paths = sys.path
+    for path in paths:
+        if module_name in path:
+            sys.path.remove(path)
+            return
+    Wrn(module_name + " not found in sys.path\n")
 
 def setupSearchPaths(PathExtension):
-	# DLL resolution in Python 3.8 on Windows has changed
-	import sys
-	if sys.platform == 'win32' and hasattr(os, "add_dll_directory"):
-		if "FREECAD_LIBPACK_BIN" in os.environ:
-			os.add_dll_directory(os.environ["FREECAD_LIBPACK_BIN"])
-		for path in PathExtension:
-			os.add_dll_directory(path)
+    # DLL resolution in Python 3.8 on Windows has changed
+    import sys
+    if sys.platform == 'win32' and hasattr(os, "add_dll_directory"):
+        if "FREECAD_LIBPACK_BIN" in os.environ:
+            os.add_dll_directory(os.environ["FREECAD_LIBPACK_BIN"])
+        if "WINDIR" in os.environ:
+            os.add_dll_directory(os.environ["WINDIR"] + os.sep + "system32")
+        for path in PathExtension:
+            os.add_dll_directory(path)
 
-	PathEnvironment = PathExtension.pop(0) + os.pathsep
-	for path in PathExtension:
-		try:
-			PathEnvironment += path + os.pathsep
-		except UnicodeDecodeError:
-			Wrn('Filter invalid module path: u{}\n'.format(repr(path)))
+    PathEnvironment = PathExtension.pop(0) + os.pathsep
+    for path in PathExtension:
+        try:
+            PathEnvironment += path + os.pathsep
+        except UnicodeDecodeError:
+            Wrn('Filter invalid module path: u{}\n'.format(repr(path)))
 
-	# new paths must be prepended to avoid to load a wrong version of a library
-	try:
-		os.environ["PATH"] = PathEnvironment + os.environ["PATH"]
-	except UnicodeDecodeError:
-		# See #0002238. FIXME: check again once ported to Python 3.x
-		Log('UnicodeDecodeError was raised when concatenating unicode string with PATH. Try to remove non-ascii paths...\n')
-		path = os.environ["PATH"].split(os.pathsep)
-		cleanpath=[]
-		for i in path:
-			if test_ascii(i):
-				cleanpath.append(i)
-		os.environ["PATH"] = PathEnvironment + os.pathsep.join(cleanpath)
-		Log('done\n')
-	except UnicodeEncodeError:
-		Log('UnicodeEncodeError was raised when concatenating unicode string with PATH. Try to replace non-ascii chars...\n')
-		os.environ["PATH"] = PathEnvironment.encode(errors='replace') + os.environ["PATH"]
-		Log('done\n')
-	except KeyError:
-		os.environ["PATH"] = PathEnvironment
+    # new paths must be prepended to avoid to load a wrong version of a library
+    try:
+        os.environ["PATH"] = PathEnvironment + os.environ["PATH"]
+    except UnicodeDecodeError:
+        # See #0002238. FIXME: check again once ported to Python 3.x
+        Log('UnicodeDecodeError was raised when concatenating unicode string with PATH. Try to remove non-ascii paths...\n')
+        path = os.environ["PATH"].split(os.pathsep)
+        cleanpath=[]
+        for i in path:
+            if test_ascii(i):
+                cleanpath.append(i)
+        os.environ["PATH"] = PathEnvironment + os.pathsep.join(cleanpath)
+        Log('done\n')
+    except UnicodeEncodeError:
+        Log('UnicodeEncodeError was raised when concatenating unicode string with PATH. Try to replace non-ascii chars...\n')
+        os.environ["PATH"] = PathEnvironment.encode(errors='replace') + os.environ["PATH"]
+        Log('done\n')
+    except KeyError:
+        os.environ["PATH"] = PathEnvironment
 
 FreeCAD._importFromFreeCAD = removeFromPath
 
 
 def InitApplications():
-	# Checking on FreeCAD module path ++++++++++++++++++++++++++++++++++++++++++
-	ModDir = FreeCAD.getHomePath()+'Mod'
-	ModDir = os.path.realpath(ModDir)
-	ExtDir = FreeCAD.getHomePath()+'Ext'
-	ExtDir = os.path.realpath(ExtDir)
-	BinDir = FreeCAD.getHomePath()+'bin'
-	BinDir = os.path.realpath(BinDir)
-	libpaths = []
-	LibDir = FreeCAD.getHomePath()+'lib'
-	LibDir = os.path.realpath(LibDir)
-	if os.path.exists(LibDir):
-		libpaths.append(LibDir)
-	Lib64Dir = FreeCAD.getHomePath()+'lib64'
-	Lib64Dir = os.path.realpath(Lib64Dir)
-	if os.path.exists(Lib64Dir):
-		libpaths.append(Lib64Dir)
-	if sys.version_info[0] == 3:
-		LibPyDir = FreeCAD.getHomePath()+'lib-py3'
-	else:
-		LibPyDir = FreeCAD.getHomePath()+'lib-py2'
-	LibPyDir = os.path.realpath(LibPyDir)
-	if (os.path.exists(LibPyDir)):
-		libpaths.append(LibPyDir)
-	AddPath = FreeCAD.ConfigGet("AdditionalModulePaths").split(";")
-	HomeMod = FreeCAD.getUserAppDataDir()+"Mod"
-	HomeMod = os.path.realpath(HomeMod)
-	MacroDir = FreeCAD.ParamGet("User parameter:BaseApp/Preferences/Macro").GetString("MacroPath")
-	MacroMod = os.path.realpath(MacroDir+"/Mod")
-	SystemWideMacroDir = FreeCAD.getHomePath()+'Macro'
-	SystemWideMacroDir = os.path.realpath(SystemWideMacroDir)
+    # Checking on FreeCAD module path ++++++++++++++++++++++++++++++++++++++++++
+    ModDir = FreeCAD.getHomePath()+'Mod'
+    ModDir = os.path.realpath(ModDir)
+    ExtDir = FreeCAD.getHomePath()+'Ext'
+    ExtDir = os.path.realpath(ExtDir)
+    BinDir = FreeCAD.getHomePath()+'bin'
+    BinDir = os.path.realpath(BinDir)
+    libpaths = []
+    LibDir = FreeCAD.getHomePath()+'lib'
+    LibDir = os.path.realpath(LibDir)
+    if os.path.exists(LibDir):
+        libpaths.append(LibDir)
+    Lib64Dir = FreeCAD.getHomePath()+'lib64'
+    Lib64Dir = os.path.realpath(Lib64Dir)
+    if os.path.exists(Lib64Dir):
+        libpaths.append(Lib64Dir)
+    LibPyDir = FreeCAD.getHomePath()+'lib-py3'
+    LibPyDir = os.path.realpath(LibPyDir)
+    if (os.path.exists(LibPyDir)):
+        libpaths.append(LibPyDir)
+    LibFcDir = FreeCAD.getLibraryDir()
+    LibFcDir = os.path.realpath(LibFcDir)
+    if (os.path.exists(LibFcDir) and not LibFcDir in libpaths):
+        libpaths.append(LibFcDir)
+    AddPath = FreeCAD.ConfigGet("AdditionalModulePaths").split(";")
+    HomeMod = FreeCAD.getUserAppDataDir()+"Mod"
+    HomeMod = os.path.realpath(HomeMod)
+    MacroStd = App.getUserMacroDir(False)
+    MacroDir = App.getUserMacroDir(True)
+    MacroMod = os.path.realpath(MacroDir+"/Mod")
+    SystemWideMacroDir = FreeCAD.getHomePath()+'Macro'
+    SystemWideMacroDir = os.path.realpath(SystemWideMacroDir)
 
-	#print FreeCAD.getHomePath()
-	if os.path.isdir(FreeCAD.getHomePath()+'src\\Tools'):
-		sys.path.append(FreeCAD.getHomePath()+'src\\Tools')
+    #print FreeCAD.getHomePath()
+    if os.path.isdir(FreeCAD.getHomePath()+'src\\Tools'):
+        sys.path.append(FreeCAD.getHomePath()+'src\\Tools')
 
 
 
-	# Searching for module dirs +++++++++++++++++++++++++++++++++++++++++++++++++++
-	# Use dict to handle duplicated module names
-	ModDict = {}
-	if os.path.isdir(ModDir):
-		ModDirs = os.listdir(ModDir)
-		for i in ModDirs: ModDict[i.lower()] = os.path.join(ModDir,i)
-	else:
-		Wrn ("No modules found in " + ModDir + "\n")
-	# Search for additional modules in the home directory
-	if os.path.isdir(HomeMod):
-		HomeMods = os.listdir(HomeMod)
-		for i in HomeMods: ModDict[i.lower()] = os.path.join(HomeMod,i)
-	# Search for additional modules in the macro directory
-	if os.path.isdir(MacroMod):
-		MacroMods = os.listdir(MacroMod)
-		for i in MacroMods:
-			key = i.lower()
-			if key not in ModDict: ModDict[key] = os.path.join(MacroMod,i)
-	# Search for additional modules in command line
-	for i in AddPath:
-		if os.path.isdir(i): ModDict[i] = i
-	#AddModPaths = App.ParamGet("System parameter:AdditionalModulePaths")
-	#Err( AddModPaths)
-	# add also this path so that all modules search for libraries
-	# they depend on first here
-	PathExtension = []
-	PathExtension.append(BinDir)
+    # Searching for module dirs +++++++++++++++++++++++++++++++++++++++++++++++++++
+    # Use dict to handle duplicated module names
+    ModDict = {}
+    if os.path.isdir(ModDir):
+        ModDirs = os.listdir(ModDir)
+        for i in ModDirs: ModDict[i.lower()] = os.path.join(ModDir,i)
+    else:
+        Wrn ("No modules found in " + ModDir + "\n")
+    # Search for additional modules in the home directory
+    if os.path.isdir(HomeMod):
+        HomeMods = os.listdir(HomeMod)
+        for i in HomeMods: ModDict[i.lower()] = os.path.join(HomeMod,i)
+    elif os.path.isdir(os.path.join(os.path.expanduser("~"),".FreeCAD","Mod")):
+        # Check if old location exists
+        Wrn ("User path has changed to " + FreeCAD.getUserAppDataDir() + ". Please move user modules and macros\n")
+    # Search for additional modules in the macro directory
+    if os.path.isdir(MacroMod):
+        MacroMods = os.listdir(MacroMod)
+        for i in MacroMods:
+            key = i.lower()
+            if key not in ModDict: ModDict[key] = os.path.join(MacroMod,i)
+    # Search for additional modules in command line
+    for i in AddPath:
+        if os.path.isdir(i): ModDict[i] = i
+    #AddModPaths = App.ParamGet("System parameter:AdditionalModulePaths")
+    #Err( AddModPaths)
+    # add also this path so that all modules search for libraries
+    # they depend on first here
+    PathExtension = []
+    PathExtension.append(BinDir)
 
-	# prepend all module paths to Python search path
-	Log('Init:   Searching for modules...\n')
+    # prepend all module paths to Python search path
+    Log('Init:   Searching for modules...\n')
 
 
-	# to have all the module-paths available in FreeCADGuiInit.py:
-	FreeCAD.__ModDirs__ = list(ModDict.values())
+    # to have all the module-paths available in FreeCADGuiInit.py:
+    FreeCAD.__ModDirs__ = list(ModDict.values())
 
-	# this allows importing with:
-	# from FreeCAD.Module import package
-	FreeCAD.__path__ = [ModDir] + libpaths + [HomeMod]
+    # this allows importing with:
+    # from FreeCAD.Module import package
+    FreeCAD.__path__ = [ModDir] + libpaths + [HomeMod]
 
-	# also add these directories to the sys.path to
-	# not change the old behaviour. once we have moved to
-	# proper python modules this can eventuelly be removed.
-	sys.path = [ModDir] + libpaths + [ExtDir] + sys.path
+    # also add these directories to the sys.path to
+    # not change the old behaviour. once we have moved to
+    # proper python modules this can eventually be removed.
+    sys.path = [ModDir] + libpaths + [ExtDir] + sys.path
 
-	for Dir in ModDict.values():
-		if ((Dir != '') & (Dir != 'CVS') & (Dir != '__init__.py')):
-			sys.path.insert(0,Dir)
-			PathExtension.append(Dir)
-			InstallFile = os.path.join(Dir,"Init.py")
-			if (os.path.exists(InstallFile)):
-				try:
-					# XXX: This looks scary securitywise...
-					if sys.version_info.major < 3:
-						with open(InstallFile) as f:
-							exec(f.read())
-					else:
-						with open(file=InstallFile, encoding="utf-8") as f:
-							exec(f.read())
-				except Exception as inst:
-					Log('Init:      Initializing ' + Dir + '... failed\n')
-					Log('-'*100+'\n')
-					Log(traceback.format_exc())
-					Log('-'*100+'\n')
-					Err('During initialization the error "' + str(inst) + '" occurred in ' + InstallFile + '\n')
-					Err('Please look into the log file for further information\n')
-				else:
-					Log('Init:      Initializing ' + Dir + '... done\n')
-			else:
-				Log('Init:      Initializing ' + Dir + '(Init.py not found)... ignore\n')
+    # The AddonManager may install additional Python packages in
+    # this path:
+    additional_packages_path = os.path.join(FreeCAD.getUserAppDataDir(),"AdditionalPythonPackages")
+    if os.path.isdir(additional_packages_path):
+        sys.path.append(additional_packages_path)
 
-	extension_modules = []
+    def RunInitPy(Dir):
+        InstallFile = os.path.join(Dir,"Init.py")
+        if (os.path.exists(InstallFile)):
+            try:
+                with open(file=InstallFile, encoding="utf-8") as f:
+                    exec(f.read())
+            except Exception as inst:
+                Log('Init:      Initializing ' + Dir + '... failed\n')
+                Log('-'*100+'\n')
+                Log(traceback.format_exc())
+                Log('-'*100+'\n')
+                Err('During initialization the error "' + str(inst) + '" occurred in ' + InstallFile + '\n')
+                Err('Please look into the log file for further information\n')
+            else:
+                Log('Init:      Initializing ' + Dir + '... done\n')
+        else:
+            Log('Init:      Initializing ' + Dir + '(Init.py not found)... ignore\n')
 
-	try:
-		import pkgutil
-		import importlib
-		import freecad
-		for _, freecad_module_name, freecad_module_ispkg in pkgutil.iter_modules(freecad.__path__, "freecad."):
-			if freecad_module_ispkg:
-				Log('Init: Initializing ' + freecad_module_name + '\n')
-				try:
-					freecad_module = importlib.import_module(freecad_module_name)
-					extension_modules += [freecad_module_name]
-					if any (module_name == 'init' for _, module_name, ispkg in pkgutil.iter_modules(freecad_module.__path__)):
-						importlib.import_module(freecad_module_name + '.init')
-						Log('Init: Initializing ' + freecad_module_name + '... done\n')
-					else:
-						Log('Init: No init module found in ' + freecad_module_name + ', skipping\n')
-				except Exception as inst:
-					Err('During initialization the error "' + str(inst) + '" occurred in ' + freecad_module_name + '\n')
-					Err('-'*80+'\n')
-					Err(traceback.format_exc())
-					Err('-'*80+'\n')
-					Log('Init:      Initializing ' + freecad_module_name + '... failed\n')
-					Log('-'*80+'\n')
-					Log(traceback.format_exc())
-					Log('-'*80+'\n')
-	except ImportError as inst:
-		Err('During initialization the error "' + str(inst) + '" occurred\n')
+    for Dir in ModDict.values():
+        if ((Dir != '') & (Dir != 'CVS') & (Dir != '__init__.py')):
+            stopFile = os.path.join(Dir, "ADDON_DISABLED")
+            if os.path.exists(stopFile):
+                Msg(f'NOTICE: Addon "{Dir}" disabled by presence of ADDON_DISABLED stopfile\n')
+                continue
+            sys.path.insert(0,Dir)
+            PathExtension.append(Dir)
+            MetadataFile = os.path.join(Dir, "package.xml")
+            if os.path.exists(MetadataFile):
+                meta = FreeCAD.Metadata(MetadataFile)
+                if not meta.supportsCurrentFreeCAD():
+                    Msg(f'NOTICE: {meta.Name} does not support this version of FreeCAD, so is being skipped\n')
+                    continue
+                content = meta.Content
+                if "workbench" in content:
+                    workbenches = content["workbench"]
+                    for workbench in workbenches:
+                        if not workbench.supportsCurrentFreeCAD():
+                            Msg(f'NOTICE: {meta.Name} content item {workbench.Name} does not support this version of FreeCAD, so is being skipped\n')
+                            continue
+                        subdirectory = workbench.Name if not workbench.Subdirectory else workbench.Subdirectory
+                        subdirectory = subdirectory.replace("/",os.path.sep)
+                        subdirectory = os.path.join(Dir, subdirectory)
+                        #classname = workbench.Classname
+                        sys.path.insert(0,subdirectory)
+                        PathExtension.append(subdirectory)
+                        RunInitPy(subdirectory)
+                else:
+                    pass # The package content says there are no workbenches here, so just skip
+            else:
+                RunInitPy(Dir)
 
-	Log("Using "+ModDir+" as module path!\n")
-	# In certain cases the PathExtension list can contain invalid strings. We concatenate them to a single string
-	# but check that the output is a valid string
-	setupSearchPaths(PathExtension)
-	path = os.environ["PATH"].split(os.pathsep)
-	Log("System path after init:\n")
-	for i in path:
-		Log("   " + i + "\n")
-	# add MacroDir to path (RFE #0000504)
-	sys.path.append(MacroDir)
-	# add SystemWideMacroDir to path
-	sys.path.append(SystemWideMacroDir)
-	# add special path for MacOSX (bug #0000307)
-	import platform
-	if len(platform.mac_ver()[0]) > 0:
-		sys.path.append(os.path.expanduser('~/Library/Application Support/FreeCAD/Mod'))
+    extension_modules = []
+
+    try:
+        import pkgutil
+        import importlib
+        import freecad
+        for _, freecad_module_name, freecad_module_ispkg in pkgutil.iter_modules(freecad.__path__, "freecad."):
+            if freecad_module_ispkg:
+                Log('Init: Initializing ' + freecad_module_name + '\n')
+                try:
+                    # Check for a stopfile
+                    stopFile = os.path.join(FreeCAD.getUserAppDataDir(), "Mod", freecad_module_name[8:], "ADDON_DISABLED")
+                    if os.path.exists(stopFile):
+                        Msg(f'NOTICE: Addon "{freecad_module_name}" disabled by presence of ADDON_DISABLED stopfile\n')
+                        continue
+
+                    # Make sure that package.xml (if present) does not exclude this version of FreeCAD
+                    MetadataFile = os.path.join(FreeCAD.getUserAppDataDir(), "Mod", freecad_module_name[8:], "package.xml")
+                    if os.path.exists(MetadataFile):
+                        meta = FreeCAD.Metadata(MetadataFile)
+                        if not meta.supportsCurrentFreeCAD():
+                            Msg(f'NOTICE: Addon "{freecad_module_name}" does not support this version of FreeCAD, so is being skipped\n')
+                            continue
+
+                    freecad_module = importlib.import_module(freecad_module_name)
+                    extension_modules += [freecad_module_name]
+                    if any (module_name == 'init' for _, module_name, ispkg in pkgutil.iter_modules(freecad_module.__path__)):
+                        importlib.import_module(freecad_module_name + '.init')
+                        Log('Init: Initializing ' + freecad_module_name + '... done\n')
+                    else:
+                        Log('Init: No init module found in ' + freecad_module_name + ', skipping\n')
+                except Exception as inst:
+                    Err('During initialization the error "' + str(inst) + '" occurred in ' + freecad_module_name + '\n')
+                    Err('-'*80+'\n')
+                    Err(traceback.format_exc())
+                    Err('-'*80+'\n')
+                    Log('Init:      Initializing ' + freecad_module_name + '... failed\n')
+                    Log('-'*80+'\n')
+                    Log(traceback.format_exc())
+                    Log('-'*80+'\n')
+    except ImportError as inst:
+        Err('During initialization the error "' + str(inst) + '" occurred\n')
+
+    Log("Using "+ModDir+" as module path!\n")
+    # In certain cases the PathExtension list can contain invalid strings. We concatenate them to a single string
+    # but check that the output is a valid string
+    setupSearchPaths(PathExtension)
+    path = os.environ["PATH"].split(os.pathsep)
+    Log("System path after init:\n")
+    for i in path:
+        Log("   " + i + "\n")
+    # add MacroDir to path (RFE #0000504)
+    sys.path.append(MacroStd)
+    sys.path.append(MacroDir)
+    # add SystemWideMacroDir to path
+    sys.path.append(SystemWideMacroDir)
+    # add special path for MacOSX (bug #0000307)
+    import platform
+    if len(platform.mac_ver()[0]) > 0:
+        sys.path.append(os.path.expanduser('~/Library/Application Support/FreeCAD/Mod'))
 
 # some often used shortcuts (for lazy people like me  ;-)
 App = FreeCAD
@@ -631,12 +684,12 @@ FreeCAD.Logger = FCADLogger
 
 # init every application by importing Init.py
 try:
-	InitApplications()
+    InitApplications()
 except Exception as e:
-	Err('Error in InitApplications ' + str(e) + '\n')
-	Err('-'*80+'\n')
-	Err(traceback.format_exc())
-	Err('-'*80+'\n')
+    Err('Error in InitApplications ' + str(e) + '\n')
+    Err('-'*80+'\n')
+    Err(traceback.format_exc())
+    Err('-'*80+'\n')
 
 FreeCAD.addImportType("FreeCAD document (*.FCStd)","FreeCAD")
 
@@ -705,6 +758,11 @@ App.Units.MilliNewton   = App.Units.Quantity('mN')
 App.Units.KiloNewton    = App.Units.Quantity('kN')
 App.Units.MegaNewton    = App.Units.Quantity('MN')
 
+App.Units.NewtonPerMeter        = App.Units.Quantity('N/m')
+App.Units.MilliNewtonPerMeter   = App.Units.Quantity('mN/m')
+App.Units.KiloNewtonPerMeter    = App.Units.Quantity('kN/m')
+App.Units.MegaNewtonPerMeter    = App.Units.Quantity('MN/m')
+
 App.Units.Pascal        = App.Units.Quantity('Pa')
 App.Units.KiloPascal    = App.Units.Quantity('kPa')
 App.Units.MegaPascal    = App.Units.Quantity('MPa')
@@ -731,6 +789,8 @@ App.Units.Volt          = App.Units.Quantity('V')
 App.Units.MilliVolt     = App.Units.Quantity('mV')
 App.Units.KiloVolt      = App.Units.Quantity('kV')
 
+App.Units.MegaSiemens   = App.Units.Quantity('MS')
+App.Units.KiloSiemens   = App.Units.Quantity('kS')
 App.Units.Siemens       = App.Units.Quantity('S')
 App.Units.MilliSiemens  = App.Units.Quantity('mS')
 App.Units.MicroSiemens  = App.Units.Quantity('uS')
@@ -807,6 +867,7 @@ App.Units.ElectricalCapacitance = App.Units.Unit(-2,-1,4,2)
 App.Units.ElectricalInductance  = App.Units.Unit(2,1,-2,-2)
 App.Units.ElectricalConductance = App.Units.Unit(-2,-1,3,2)
 App.Units.ElectricalResistance  = App.Units.Unit(2,1,-3,-2)
+App.Units.ElectricalConductivity = App.Units.Unit(-3,-1,3,2)
 App.Units.AmountOfSubstance = App.Units.Unit(0,0,0,0,0,1)
 App.Units.LuminousIntensity = App.Units.Unit(0,0,0,0,0,0,1)
 
@@ -823,6 +884,8 @@ App.Units.Force         = App.Units.Unit(1,1,-2)
 App.Units.Work          = App.Units.Unit(2,1,-2)
 App.Units.Power         = App.Units.Unit(2,1,-3)
 
+App.Units.Stiffness     = App.Units.Unit(0,1,-2)
+
 App.Units.SpecificEnergy               = App.Units.Unit(2,0,-2)
 App.Units.ThermalConductivity          = App.Units.Unit(1,1,-3,0,-1)
 App.Units.ThermalExpansionCoefficient  = App.Units.Unit(0,0,0,0,-1)
@@ -835,10 +898,7 @@ App.Units.KinematicViscosity           = App.Units.Unit(2,0,-1)
 App.Units.VacuumPermittivity           = App.Units.Unit(-3,-1,4,2)
 
 # Add an enum for the different unit schemes
-if sys.version_info.major < 3:
-    IntEnum = object
-else:
-    from enum import IntEnum
+from enum import IntEnum
 
 # The values must match with that of the
 # C++ enum class UnitSystem
@@ -855,6 +915,26 @@ class Scheme(IntEnum):
 
 App.Units.Scheme = Scheme
 
+class ScaleType(IntEnum):
+    Other = -1
+    NoScaling = 0
+    NonUniformRight = 1
+    NonUniformLeft = 2
+    Uniform = 3
+
+App.ScaleType = ScaleType
+
+class PropertyType(IntEnum):
+    Prop_None = 0
+    Prop_ReadOnly = 1
+    Prop_Transient = 2
+    Prop_Hidden = 4
+    Prop_Output = 8
+    Prop_NoRecompute = 16
+    Prop_NoPersist = 32
+
+App.PropertyType = PropertyType
+
 # clean up namespace
 del(InitApplications)
 del(test_ascii)
