@@ -23,17 +23,15 @@
 #include "PreCompiled.h"
 #ifndef _PreComp_
 # include <stack>
-# include <boost_bind_bind.hpp>
 #endif
 
 #include <QCoreApplication>
-
-#include "MergeDocuments.h"
-#include <Base/Console.h>
+#include <App/Document.h>
 #include <Base/Reader.h>
 #include <Base/Writer.h>
-#include <App/Document.h>
-#include <App/DocumentObject.h>
+
+#include "MergeDocuments.h"
+
 
 using namespace App;
 namespace bp = boost::placeholders;
@@ -125,7 +123,7 @@ private:
 };
 }
 
-MergeDocuments::MergeDocuments(App::Document* doc) : guiup(false), verbose(true), stream(0), appdoc(doc)
+MergeDocuments::MergeDocuments(App::Document* doc) : guiup(false), verbose(true), stream(nullptr), appdoc(doc)
 {
     connectExport = doc->signalExportObjects.connect
         (boost::bind(&MergeDocuments::exportObject, this, bp::_1, bp::_2));
@@ -159,7 +157,7 @@ MergeDocuments::importObjects(std::istream& input)
     std::vector<App::DocumentObject*> objs = appdoc->importObjects(reader);
 
     delete this->stream;
-    this->stream = 0;
+    this->stream = nullptr;
 
     return objs;
 }
