@@ -24,11 +24,11 @@
 #ifndef APP_Part_H
 #define APP_Part_H
 
+#include "GeoFeature.h"
 #include "OriginGroupExtension.h"
 #include "PropertyLinks.h"
 
 
-
 namespace App
 {
 
@@ -53,7 +53,7 @@ public:
     /// unique identifier of the Item
     App::PropertyUUID    Uid;
     /// material descriptions
-    App::PropertyMap     Material;
+    App::PropertyLink    Material;
     /// Meta descriptions
     App::PropertyMap     Meta;
 
@@ -76,14 +76,17 @@ public:
     //@}
 
     /// Constructor
-    Part(void);
+    Part();
     virtual ~Part();
 
     /// returns the type name of the ViewProvider
-    virtual const char* getViewProviderName(void) const override {
+    virtual const char* getViewProviderName() const override {
         return "Gui::ViewProviderPart";
     }
 
+
+    virtual void handleChangedPropertyType(Base::XMLReader &reader, const char *TypeName, App::Property *prop) override;
+
     /**
      * Returns the part which contains this object.
      * In case this object does not belong to any Part, 0 is returned.
@@ -92,7 +95,7 @@ public:
      */
     static App::Part* getPartOfObject (const DocumentObject* obj, bool recursive=true);
 
-    virtual PyObject *getPyObject(void) override;
+    virtual PyObject *getPyObject() override;
 };
 
 //typedef App::FeaturePythonT<Part> PartPython;
