@@ -23,8 +23,6 @@
 
 #include "PreCompiled.h"
 
-#include "App/Part.h"
-
 // inclusion of the generated files (generated out of PartPy.xml)
 #include "PartPy.h"
 #include "PartPy.cpp"
@@ -37,14 +35,9 @@ std::string PartPy::representation(void) const
     return std::string("<Part object>");
 }
 
-
-
-
-
-
 PyObject *PartPy::getCustomAttributes(const char* /*attr*/) const
 {
-    return 0;
+    return nullptr;
 }
 
 int PartPy::setCustomAttributes(const char* /*attr*/, PyObject* /*obj*/)
