@@ -24,13 +24,13 @@
 #ifndef APP_PROPERTY_H
 #define APP_PROPERTY_H
 
-// Std. configurations
-
 #include <Base/Exception.h>
 #include <Base/Persistence.h>
 #include <boost/any.hpp>
-#include <string>
+#include <boost/signals2.hpp>
 #include <bitset>
+#include <string>
+#include <FCGlobal.h>
 
 namespace Py {
 class Object;
@@ -75,6 +75,9 @@ public:
                       // relevant for the container using it
         EvalOnRestore = 14, // In case of expression binding, evaluate the
                             // expression on restore and touch the object on value change.
+        Busy = 15, // internal use to avoid recursive signaling
+        CopyOnChange = 16, // for Link to copy the linked object on change of the property with this flag
+        UserEdit = 17, // cause property editor to create button for user defined editing
 
         // The following bits are corresponding to PropertyType set when the
         // property added. These types are meant to be static, and cannot be
@@ -114,8 +117,20 @@ public:
         return sizeof(father) + sizeof(StatusBits);
     }
 
-    /// get the name of this property in the belonging container
+    /** Get the name of this property in the belonging container
+     * With \ref hasName() it can be checked beforehand if a valid name is set.
+     * @note If no name is set this function returns an empty string, i.e. "".
+     */
     const char* getName(void) const;
+    /** Check if the property has a name set.
+     * If no name is set then \ref getName() will return an empty string
+     */
+    bool hasName() const;
+    /** Check if the passed name is valid.
+     * If \a name is null or an empty string it's considered invalid,
+     * and valid otherwise.
+     */
+    static bool isValidName(const char* name);
 
     std::string getFullName() const;
 
@@ -233,6 +248,19 @@ public:
     /// Called before a child property changing value
     virtual void aboutToSetChildValue(Property &) {}
 
+    /// Compare if this property has the same content as the given one
+    virtual bool isSame(const Property &other) const;
+
+    /** Return a unique ID for the property
+     *
+     * The ID of a property is generated from a monotonically increasing
+     * internal counter. The intention of the ID is to be used as a key for
+     * mapping, instead of using the raw pointer. Because, it is possible for
+     * the runtime memory allocator to reuse just deleted memory, which will
+     * cause hard to debug problem if use pointer as key. 
+     */
+    int64_t getID() const {return _id;}
+
     friend class PropertyContainer;
     friend struct PropertyData;
     friend class DynamicProperty;
@@ -269,6 +297,10 @@ private:
 private:
     PropertyContainer *father;
     const char *myName;
+    int64_t _id;
+
+public:
+    boost::signals2::signal<void (const App::Property&)> signalChanged;
 };
 
 
@@ -431,7 +463,7 @@ public:
     // if the order of the elements in the list relevant?
     // if yes, certain operations, like restoring must make sure that the
     // order is kept despite errors.
-    inline void setOrderRelevant(bool on) { this->setStatus(Status::Ordered,on); };
+    inline void setOrderRelevant(bool on) { this->setStatus(Status::Ordered,on); }
     inline bool isOrderRelevant() const { return this->testStatus(Status::Ordered);}
 
 };
@@ -486,6 +518,13 @@ public:
 
     const_reference operator[] (int idx) const {return _lValueList[idx];} 
 
+    virtual bool isSame(const Property &other) const override {
+        if (&other == this)
+            return true;
+        return this->getTypeId() == other.getTypeId()
+            && this->getValue() == static_cast<decltype(this)>(&other)->getValue();
+    }
+
     virtual void setPyObject(PyObject *value) override {
         try {
             setValue(getPyValue(value));
