@@ -23,22 +23,14 @@
 
 #include "PreCompiled.h"
 
-#ifndef _PreComp_
-# include <cassert>
-# include <algorithm>
-# include <functional>
-#endif
-
-/// Here the FreeCAD includes sorted by Base,App,Gui......
-#include <Base/Reader.h>
-#include <Base/Writer.h>
 #include <Base/Console.h>
 #include <Base/Exception.h>
+#include <Base/Reader.h>
+#include <Base/Writer.h>
 
-#include "Application.h"
 #include "Property.h"
 #include "PropertyContainer.h"
-#include "PropertyLinks.h"
+
 
 FC_LOG_LEVEL_INIT("App",true,true)
 
@@ -55,7 +47,7 @@ TYPESYSTEM_SOURCE(App::PropertyContainer,Base::Persistence)
 // Here's the implementation! Description should take place in the header file!
 PropertyContainer::PropertyContainer()
 {
-    propertyData.parentPropertyData = 0;
+    propertyData.parentPropertyData = nullptr;
 }
 
 PropertyContainer::~PropertyContainer()
@@ -85,7 +77,8 @@ App::Property* PropertyContainer::addDynamicProperty(
 Property *PropertyContainer::getPropertyByName(const char* name) const
 {
     auto prop = dynamicProps.getDynamicPropertyByName(name);
-    if(prop) return prop;
+    if(prop)
+        return prop;
     return getPropertyData().getPropertyByName(this,name);
 }
 
@@ -101,6 +94,12 @@ void PropertyContainer::getPropertyList(std::vector<Property*> &List) const
     getPropertyData().getPropertyList(this,List);
 }
 
+void PropertyContainer::getPropertyNamedList(std::vector<std::pair<const char*, Property*> > &List) const
+{
+    dynamicProps.getPropertyNamedList(List);
+    getPropertyData().getPropertyNamedList(this,List);
+}
+
 void PropertyContainer::setPropertyStatus(unsigned char bit,bool value)
 {
     std::vector<Property*> List;
@@ -122,28 +121,32 @@ short PropertyContainer::getPropertyType(const char *name) const
 const char* PropertyContainer::getPropertyGroup(const Property* prop) const
 {
     auto group = dynamicProps.getPropertyGroup(prop);
-    if(group) return group;
+    if(group)
+        return group;
     return getPropertyData().getGroup(this,prop);
 }
 
 const char* PropertyContainer::getPropertyGroup(const char *name) const
 {
     auto group = dynamicProps.getPropertyGroup(name);
-    if(group) return group;
+    if(group)
+        return group;
     return getPropertyData().getGroup(this,name);
 }
 
 const char* PropertyContainer::getPropertyDocumentation(const Property* prop) const
 {
     auto doc = dynamicProps.getPropertyDocumentation(prop);
-    if(doc) return doc;
+    if(doc)
+        return doc;
     return getPropertyData().getDocumentation(this,prop);
 }
 
 const char* PropertyContainer::getPropertyDocumentation(const char *name) const
 {
     auto doc = dynamicProps.getPropertyDocumentation(name);
-    if(doc) return doc;
+    if(doc)
+        return doc;
     return getPropertyData().getDocumentation(this,name);
 }
 
@@ -332,27 +335,27 @@ void PropertyContainer::Restore(Base::XMLReader &reader)
         reader.readElement("Property");
         std::string PropName = reader.getAttribute("name");
         std::string TypeName = reader.getAttribute("type");
-        auto prop = dynamicProps.restore(*this,PropName.c_str(),TypeName.c_str(),reader);
-        if(!prop)
-            prop = getPropertyByName(PropName.c_str());
-
-        decltype(Property::StatusBits) status;
-        if(reader.hasAttribute("status")) {
-            status = decltype(status)(reader.getAttributeAsUnsigned("status"));
-            if(prop)
-                prop->setStatusValue(status.to_ulong());
-        }
         // NOTE: We must also check the type of the current property because a
         // subclass of PropertyContainer might change the type of a property but
         // not its name. In this case we would force to read-in a wrong property
         // type and the behaviour would be undefined.
         try {
+            auto prop = getPropertyByName(PropName.c_str());
+            if(!prop || prop->getContainer() != this)
+                prop = dynamicProps.restore(*this,PropName.c_str(),TypeName.c_str(),reader);
+
+            decltype(Property::StatusBits) status;
+            if(reader.hasAttribute("status")) {
+                status = decltype(status)(reader.getAttributeAsUnsigned("status"));
+                if(prop)
+                    prop->setStatusValue(status.to_ulong());
+            }
             // name and type match
             if (prop && strcmp(prop->getTypeId().getName(), TypeName.c_str()) == 0) {
                 if (!prop->testStatus(Property::Transient) 
                         && !status.test(Property::Transient)
                         && !status.test(Property::PropTransient)
-                        && !(getPropertyType(prop) & Prop_Transient))
+                        && !prop->testStatus(Property::PropTransient))
                 {
                     FC_TRACE("restore property '" << prop->getName() << "'");
                     prop->Restore(reader);
@@ -472,7 +475,7 @@ const PropertyData::PropertySpec *PropertyData::findProperty(OffsetBase offsetBa
     auto it = index.find(PropName);
     if(it != index.end())
         return &(*it);
-    return 0;
+    return nullptr;
 }
 
 const PropertyData::PropertySpec *PropertyData::findProperty(OffsetBase offsetBase,const Property* prop) const
@@ -480,14 +483,14 @@ const PropertyData::PropertySpec *PropertyData::findProperty(OffsetBase offsetBa
     merge();
     int diff = offsetBase.getOffsetTo(prop);
     if(diff<0)
-        return 0;
+        return nullptr;
 
     auto &index = propertyData.get<2>();
     auto it = index.find(diff);
     if(it!=index.end())
         return &(*it);
   
-    return 0;
+    return nullptr;
 }
 
 const char* PropertyData::getName(OffsetBase offsetBase,const Property* prop) const
@@ -497,7 +500,7 @@ const char* PropertyData::getName(OffsetBase offsetBase,const Property* prop) co
   if(Spec)
     return Spec->Name;
   else
-    return 0;
+    return nullptr;
 }
 
 short PropertyData::getType(OffsetBase offsetBase,const Property* prop) const
@@ -527,7 +530,7 @@ const char* PropertyData::getGroup(OffsetBase offsetBase,const Property* prop) c
   if(Spec)
     return Spec->Group;
   else
-    return 0;
+    return nullptr;
 }
 
 const char* PropertyData::getGroup(OffsetBase offsetBase,const char* name) const
@@ -537,7 +540,7 @@ const char* PropertyData::getGroup(OffsetBase offsetBase,const char* name) const
   if(Spec)
     return Spec->Group;
   else
-    return 0;
+    return nullptr;
 }
 
 const char* PropertyData::getDocumentation(OffsetBase offsetBase,const Property* prop) const
@@ -547,7 +550,7 @@ const char* PropertyData::getDocumentation(OffsetBase offsetBase,const Property*
   if(Spec)
     return Spec->Docu;
   else
-    return 0;
+    return nullptr;
 }
 
 const char* PropertyData::getDocumentation(OffsetBase offsetBase,const char* name) const
@@ -557,7 +560,7 @@ const char* PropertyData::getDocumentation(OffsetBase offsetBase,const char* nam
   if(Spec)
     return Spec->Docu;
   else
-    return 0;
+    return nullptr;
 }
 
 Property *PropertyData::getPropertyByName(OffsetBase offsetBase,const char* name) const
@@ -567,7 +570,7 @@ Property *PropertyData::getPropertyByName(OffsetBase offsetBase,const char* name
   if(Spec)
     return (Property *) (Spec->Offset + offsetBase.getOffset());
   else
-    return 0;
+    return nullptr;
 }
 
 void PropertyData::getPropertyMap(OffsetBase offsetBase,std::map<std::string,Property*> &Map) const
@@ -586,6 +589,18 @@ void PropertyData::getPropertyList(OffsetBase offsetBase,std::vector<Property*>
         List.push_back((Property *) (spec.Offset + offsetBase.getOffset()));
 }
 
+void PropertyData::getPropertyNamedList(OffsetBase offsetBase,
+        std::vector<std::pair<const char*,Property*> > &List) const
+{
+    merge();
+    size_t base = List.size();
+    List.reserve(base+propertyData.size());
+    for (auto &spec : propertyData.get<0>()) {
+        auto prop = (Property *) (spec.Offset + offsetBase.getOffset());
+        List.emplace_back(prop->getName(),prop);
+    }
+}
+
 
 
 /** \defgroup PropFrame Property framework
