@@ -23,25 +23,18 @@
 
 #include "PreCompiled.h"
 
-#ifndef _PreComp_
-# include <algorithm>
-# include <sstream>
-#endif
-
-/// Here the FreeCAD includes sorted by Base,App,Gui......
-
-#include <Base/Exception.h>
-#include <Base/Reader.h>
-#include <Base/Writer.h>
-#include <Base/Stream.h>
 #include <Base/Console.h>
 #include <Base/PyObjectBase.h>
+#include <Base/Reader.h>
+#include <Base/Stream.h>
+#include <Base/Writer.h>
 #include <Base/Uuid.h>
 
 #include "PropertyFile.h"
 #include "Document.h"
-#include "PropertyContainer.h"
 #include "DocumentObject.h"
+#include "PropertyContainer.h"
+
 
 using namespace App;
 using namespace Base;
@@ -71,7 +64,7 @@ PropertyFileIncluded::~PropertyFileIncluded()
     }
 }
 
-void PropertyFileIncluded::aboutToSetValue(void)
+void PropertyFileIncluded::aboutToSetValue()
 {
     // This is a trick to check in Copy() if it is called
     // directly from outside or by the Undo/Redo mechanism.
@@ -85,7 +78,7 @@ void PropertyFileIncluded::aboutToSetValue(void)
     this->StatusBits.reset(10);
 }
 
-std::string PropertyFileIncluded::getDocTransientPath(void) const
+std::string PropertyFileIncluded::getDocTransientPath() const
 {
     std::string path;
     PropertyContainer *co = getContainer();
@@ -107,13 +100,13 @@ std::string PropertyFileIncluded::getUniqueFileName(const std::string& path, con
     return fi.filePath();
 }
 
-std::string PropertyFileIncluded::getExchangeTempFile(void) const
+std::string PropertyFileIncluded::getExchangeTempFile() const
 {
     return Base::FileInfo::getTempFileName(Base::FileInfo
         (getValue()).fileName().c_str(), getDocTransientPath().c_str());
 }
 
-std::string PropertyFileIncluded::getOriginalFileName(void) const
+std::string PropertyFileIncluded::getOriginalFileName() const
 {
     return _OriginalName;
 }
@@ -239,25 +232,24 @@ void PropertyFileIncluded::setValue(const char* sFile, const char* sName)
     }
 }
 
-const char* PropertyFileIncluded::getValue(void) const
+const char* PropertyFileIncluded::getValue() const
 {
      return _cValue.c_str();
 }
 
-PyObject *PropertyFileIncluded::getPyObject(void)
+PyObject *PropertyFileIncluded::getPyObject()
 {
-    PyObject *p = PyUnicode_DecodeUTF8(_cValue.c_str(),_cValue.size(),0);
+    PyObject *p = PyUnicode_DecodeUTF8(_cValue.c_str(),_cValue.size(),nullptr);
     if (!p) {
         throw Base::UnicodeError("PropertyFileIncluded: UTF-8 conversion failure");
     }
     return p;
 }
 
-#if PY_MAJOR_VERSION >= 3
 namespace App {
 const char* getNameFromFile(PyObject* value)
 {
-    const char* string = 0;
+    const char* string = nullptr;
     PyObject *oname = PyObject_GetAttrString (value, "name");
     if (oname) {
         if (PyUnicode_Check (oname)) {
@@ -286,11 +278,9 @@ bool isIOFile(PyObject* file)
     return isFile;
 }
 }
-#endif
 
 void PropertyFileIncluded::setPyObject(PyObject *value)
 {
-#if PY_MAJOR_VERSION >= 3
     std::string string;
     if (PyUnicode_Check(value)) {
         string = PyUnicode_AsUTF8(value);
@@ -301,21 +291,6 @@ void PropertyFileIncluded::setPyObject(PyObject *value)
     else if (isIOFile(value)){
         string = getNameFromFile(value);
     }
-#else
-    std::string string;
-    if (PyUnicode_Check(value)) {
-        PyObject* unicode = PyUnicode_AsUTF8String(value);
-        string = PyString_AsString(unicode);
-        Py_DECREF(unicode);
-    }
-    else if (PyString_Check(value)) {
-        string = PyString_AsString(value);
-    }
-    else if (PyFile_Check(value)) {
-        PyObject* FileName = PyFile_Name(value);
-        string = PyString_AsString(FileName);
-    }
-#endif
     else if (PyTuple_Check(value)) {
         if (PyTuple_Size(value) != 2)
             throw Base::TypeError("Tuple needs size of (filePath,newFileName)"); 
@@ -324,7 +299,6 @@ void PropertyFileIncluded::setPyObject(PyObject *value)
 
         // decoding file
         std::string fileStr;
-#if PY_MAJOR_VERSION >= 3
         if (PyUnicode_Check(file)) {
             fileStr = PyUnicode_AsUTF8(file);
         }
@@ -334,20 +308,6 @@ void PropertyFileIncluded::setPyObject(PyObject *value)
         else if (isIOFile(value)) {
             fileStr = getNameFromFile(file);
         }
-#else
-        if (PyUnicode_Check(file)) {
-            PyObject* unicode = PyUnicode_AsUTF8String(file);
-            fileStr = PyString_AsString(unicode);
-            Py_DECREF(unicode);
-        }
-        else if (PyString_Check(file)) {
-            fileStr = PyString_AsString(file);
-        }
-        else if (PyFile_Check(file)) {
-            PyObject* FileName = PyFile_Name(file);
-            fileStr = PyString_AsString(FileName);
-        }
-#endif
         else {
             std::string error = std::string("First item in tuple must be a file or string, not ");
             error += file->ob_type->tp_name;
@@ -356,7 +316,6 @@ void PropertyFileIncluded::setPyObject(PyObject *value)
 
         // decoding name
         std::string nameStr;
-#if PY_MAJOR_VERSION >= 3
         if (PyUnicode_Check(name)) {
             nameStr = PyUnicode_AsUTF8(name);
         }
@@ -366,15 +325,6 @@ void PropertyFileIncluded::setPyObject(PyObject *value)
         else if (isIOFile(value)) {
             nameStr = getNameFromFile(name);
         }
-#else
-        if (PyString_Check(name)) {
-            nameStr = PyString_AsString(name);
-        }
-        else if (PyFile_Check(name)) {
-            PyObject* FileName = PyFile_Name(name);
-            nameStr = PyString_AsString(FileName);
-        }
-#endif
         else {
             std::string error = std::string("Second item in tuple must be a string, not ");
             error += name->ob_type->tp_name;
@@ -514,7 +464,7 @@ void PropertyFileIncluded::RestoreDocFile(Base::Reader &reader)
     hasSetValue();
 }
 
-Property *PropertyFileIncluded::Copy(void) const
+Property *PropertyFileIncluded::Copy() const
 {
     std::unique_ptr<PropertyFileIncluded> prop(new PropertyFileIncluded());
 
@@ -614,7 +564,7 @@ void PropertyFileIncluded::Paste(const Property &from)
     hasSetValue();
 }
 
-unsigned int PropertyFileIncluded::getMemSize (void) const
+unsigned int PropertyFileIncluded::getMemSize () const
 {
     unsigned int mem = Property::getMemSize();
     mem += _cValue.size();
