@@ -24,15 +24,10 @@
 #ifndef APP_PROPERTYLINKS_H
 #define APP_PROPERTYLINKS_H
 
-// Std. configurations
-#include <boost_signals2.hpp>
-
-#include <vector>
-#include <map>
 #include <list>
+#include <map>
 #include <string>
-#include <memory>
-#include <cinttypes>
+#include <vector>
 #include "Property.h"
 
 namespace Base {
@@ -93,8 +88,8 @@ public:
      * Retrieve what kind of links are allowed. Only in the Local GeoFeatureGroup, in this and
      * all Childs or to all objects within the Glocal scope.
      */
-    LinkScope getScope() {return _pcScope;};
-
+    LinkScope getScope() const {return _pcScope;};
+    
 protected:
     LinkScope _pcScope = LinkScope::Local;
 };
@@ -166,7 +161,7 @@ public:
      * @return For external linked object, return 2 in case the link is
      * missing, and 1 if the time stamp has changed.
      */
-    virtual int checkRestore(std::string *msg=0) const {
+    virtual int checkRestore(std::string *msg=nullptr) const {
         (void)msg;
         return 0;
     }
@@ -181,7 +176,7 @@ public:
      * @param newStyle: whether to return new or old style subname reference
      */
     virtual void getLinks(std::vector<App::DocumentObject *> &objs,
-            bool all=false, std::vector<std::string> *subs=0, bool newStyle=true) const = 0;
+            bool all=false, std::vector<std::string> *subs=nullptr, bool newStyle=true) const = 0;
 
     /** Called to reset this link property
      *
@@ -229,7 +224,7 @@ public:
      */
     virtual Property *CopyOnImportExternal(const std::map<std::string,std::string> &nameMap) const {
         (void)nameMap;
-        return 0;
+        return nullptr;
     }
 
     /** Update object label reference in this property
@@ -247,7 +242,7 @@ public:
         (void)obj;
         (void)ref;
         (void)newLabel;
-        return 0;
+        return nullptr;
     }
 
     /// Helper function to return all linked objects of this property
@@ -288,6 +283,8 @@ public:
     }
     //@}
 
+    virtual bool isSame(const Property &other) const override;
+
     /** Enable/disable temporary holding external object without throwing exception
      *
      * Warning, non-PropertyXLink related property does not have internal
@@ -322,7 +319,7 @@ public:
     static std::pair<App::DocumentObject*,std::string> tryReplaceLink(
             const App::PropertyContainer *owner, App::DocumentObject *obj,
             const App::DocumentObject *parent, App::DocumentObject *oldObj,
-            App::DocumentObject *newObj, const char *sub=0);
+            App::DocumentObject *newObj, const char *sub=nullptr);
 
     /** Helper function to check and replace a link with multiple subname references
      *
@@ -486,7 +483,7 @@ public:
      * afterRestore() function, which calls this function to do the string
      * parsing.
      */
-    static void restoreLabelReference(const App::DocumentObject *obj, std::string &sub, ShadowSub *shadow=0);
+    static void restoreLabelReference(const App::DocumentObject *obj, std::string &sub, ShadowSub *shadow=nullptr);
 
     /** Helper function to extract labels from a subname reference
      *
@@ -540,6 +537,7 @@ public:
         LinkRestoring,
         LinkAllowPartial,
         LinkRestoreLabel,
+        LinkSyncSubObject, // used by DlgPropertyLink
     };
     inline bool testFlag(int flag) const {
         return _Flags.test((std::size_t)flag);
@@ -623,7 +621,7 @@ public:
     { return "Gui::PropertyEditor::PropertyLinkItem"; }
 
     virtual void getLinks(std::vector<App::DocumentObject *> &objs,
-            bool all=false, std::vector<std::string> *subs=0, bool newStyle=true) const override;
+            bool all=false, std::vector<std::string> *subs=nullptr, bool newStyle=true) const override;
 
     virtual void breakLink(App::DocumentObject *obj, bool clear) override;
 
@@ -713,7 +711,7 @@ public:
     { return "Gui::PropertyEditor::PropertyLinkListItem"; }
 
     virtual void getLinks(std::vector<App::DocumentObject *> &objs,
-            bool all=false, std::vector<std::string> *subs=0, bool newStyle=true) const override;
+            bool all=false, std::vector<std::string> *subs=nullptr, bool newStyle=true) const override;
 
     virtual void breakLink(App::DocumentObject *obj, bool clear) override;
 
@@ -722,9 +720,9 @@ public:
     virtual Property *CopyOnLinkReplace(const App::DocumentObject *parent,
             App::DocumentObject *oldObj, App::DocumentObject *newObj) const override;
 
-    DocumentObject *find(const std::string &, int *pindex=0) const;
-    DocumentObject *find(const char *sub, int *pindex=0) const {
-        if(!sub) return 0;
+    DocumentObject *find(const std::string &, int *pindex=nullptr) const;
+    DocumentObject *find(const char *sub, int *pindex=nullptr) const {
+        if(!sub) return nullptr;
         return find(std::string(sub),pindex);
     }
 
@@ -854,12 +852,13 @@ public:
     virtual bool referenceChanged() const override;
 
     virtual void getLinks(std::vector<App::DocumentObject *> &objs,
-            bool all=false, std::vector<std::string> *subs=0, bool newStyle=true) const override;
+            bool all=false, std::vector<std::string> *subs=nullptr, bool newStyle=true) const override;
 
     virtual void breakLink(App::DocumentObject *obj, bool clear) override;
 
     virtual bool adjustLink(const std::set<App::DocumentObject *> &inList) override;
 
+    void setSyncSubObject(bool enable);
 protected:
     App::DocumentObject*     _pcLinkSub;
     std::vector<std::string> _cSubList;
@@ -935,6 +934,8 @@ public:
      */
     void setValue(App::DocumentObject *lValue, const std::vector<std::string> &SubList=std::vector<std::string>());
 
+    void addValue(App::DocumentObject *obj, const std::vector<std::string> &SubList={}, bool reset = false);
+
     const std::vector<DocumentObject*> &getValues(void) const {
         return _lValueList;
     }
@@ -973,6 +974,7 @@ public:
 
     virtual void Save (Base::Writer &writer) const override;
     virtual void Restore(Base::XMLReader &reader) override;
+    bool upgrade(Base::XMLReader &reader, const char *typeName);
 
     virtual Property *Copy(void) const override;
     virtual void Paste(const Property &from) override;
@@ -997,12 +999,17 @@ public:
     virtual bool referenceChanged() const override;
 
     virtual void getLinks(std::vector<App::DocumentObject *> &objs,
-            bool all=false, std::vector<std::string> *subs=0, bool newStyle=true) const override;
+            bool all=false, std::vector<std::string> *subs=nullptr, bool newStyle=true) const override;
 
     virtual void breakLink(App::DocumentObject *obj, bool clear) override;
 
     virtual bool adjustLink(const std::set<App::DocumentObject *> &inList) override;
 
+    void setSyncSubObject(bool enable);
+
+private:
+    void verifyObject(App::DocumentObject *, App::DocumentObject *);
+
 private:
     //FIXME: Do not make two independent lists because this will lead to some inconsistencies!
     std::vector<DocumentObject*> _lValueList;
@@ -1047,7 +1054,7 @@ class AppExport PropertyXLink : public PropertyLinkGlobal
     TYPESYSTEM_HEADER_WITH_OVERRIDE();
 
 public:
-    PropertyXLink(bool allowPartial=false, PropertyLinkBase *parent=0);
+    PropertyXLink(bool allowPartial=false, PropertyLinkBase *parent=nullptr);
 
     virtual ~PropertyXLink();
 
@@ -1080,7 +1087,7 @@ public:
     const char *getDocumentPath() const;
     const char *getObjectName() const;
 
-    virtual int checkRestore(std::string *msg=0) const override;
+    virtual int checkRestore(std::string *msg=nullptr) const override;
 
     virtual void Save (Base::Writer &writer) const override;
     virtual void Restore(Base::XMLReader &reader) override;
@@ -1104,9 +1111,9 @@ public:
 
     static bool supportXLink(const App::Property *prop);
     static bool hasXLink(const App::Document *doc);
-    static bool hasXLink(const std::vector<App::DocumentObject*> &objs, std::vector<App::Document*> *unsaved=0);
-    static std::map<App::Document*,std::set<App::Document*> > getDocumentOutList(App::Document *doc=0);
-    static std::map<App::Document*,std::set<App::Document*> > getDocumentInList(App::Document *doc=0);
+    static bool hasXLink(const std::vector<App::DocumentObject*> &objs, std::vector<App::Document*> *unsaved=nullptr);
+    static std::map<App::Document*,std::set<App::Document*> > getDocumentOutList(App::Document *doc=nullptr);
+    static std::map<App::Document*,std::set<App::Document*> > getDocumentInList(App::Document *doc=nullptr);
     static void restoreDocument(const App::Document &doc);
 
     virtual void updateElementReference(
@@ -1115,7 +1122,7 @@ public:
     virtual bool referenceChanged() const override;
 
     virtual void getLinks(std::vector<App::DocumentObject *> &objs,
-            bool all=false, std::vector<std::string> *subs=0, bool newStyle=true) const override;
+            bool all=false, std::vector<std::string> *subs=nullptr, bool newStyle=true) const override;
 
     virtual bool adjustLink(const std::set<App::DocumentObject *> &inList) override;
 
@@ -1136,13 +1143,15 @@ public:
 
     virtual bool upgrade(Base::XMLReader &reader, const char *typeName);
 
+    void setSyncSubObject(bool enable);
+
 protected:
     void unlink();
     void detach();
 
     void restoreLink(App::DocumentObject *);
 
-    void copyTo(PropertyXLink &other, App::DocumentObject *linked=0, std::vector<std::string> *subs=0) const;
+    void copyTo(PropertyXLink &other, App::DocumentObject *linked=nullptr, std::vector<std::string> *subs=nullptr) const;
 
     virtual void aboutToSetValue() override;
 
@@ -1169,7 +1178,7 @@ class AppExport PropertyXLinkSub: public PropertyXLink {
     TYPESYSTEM_HEADER_WITH_OVERRIDE();
 
 public:
-    PropertyXLinkSub(bool allowPartial=false, PropertyLinkBase *parent=0);
+    PropertyXLinkSub(bool allowPartial=false, PropertyLinkBase *parent=nullptr);
 
     virtual ~PropertyXLinkSub();
 
@@ -1274,7 +1283,7 @@ public:
     virtual bool referenceChanged() const override;
 
     virtual void getLinks(std::vector<App::DocumentObject *> &objs,
-            bool all=false, std::vector<std::string> *subs=0, bool newStyle=true) const override;
+            bool all=false, std::vector<std::string> *subs=nullptr, bool newStyle=true) const override;
 
     virtual void breakLink(App::DocumentObject *obj, bool clear) override;
 
@@ -1282,13 +1291,15 @@ public:
 
     bool upgrade(Base::XMLReader &reader, const char *typeName);
 
-    virtual int checkRestore(std::string *msg=0) const override;
+    virtual int checkRestore(std::string *msg=nullptr) const override;
 
     virtual void setAllowPartial(bool enable) override;
 
     virtual void hasSetChildValue(Property &) override;
     virtual void aboutToSetChildValue(Property &) override;
 
+    void setSyncSubObject(bool enable);
+
 protected:
     std::list<PropertyXLinkSub> _Links;
 };
@@ -1323,12 +1334,12 @@ public:
     ~PropertyXLinkContainer();
 
     virtual void afterRestore() override;
-    virtual int checkRestore(std::string *msg=0) const override;
+    virtual int checkRestore(std::string *msg=nullptr) const override;
     virtual void Save (Base::Writer &writer) const override;
     virtual void Restore(Base::XMLReader &reader) override;
     virtual void breakLink(App::DocumentObject *obj, bool clear) override;
     virtual void getLinks(std::vector<App::DocumentObject *> &objs,
-            bool all=false, std::vector<std::string> *subs=0, bool newStyle=true) const override;
+            bool all=false, std::vector<std::string> *subs=nullptr, bool newStyle=true) const override;
 
     bool isLinkedToDocument(const App::Document &doc) const;
 
@@ -1338,11 +1349,11 @@ protected:
     virtual void onBreakLink(App::DocumentObject *obj);
     virtual void onAddDep(App::DocumentObject *) {}
     virtual void onRemoveDep(App::DocumentObject *) {}
-    void updateDeps(std::set<DocumentObject*> &&newDeps);
+    void updateDeps(std::map<DocumentObject*,bool> &&newDeps);
     void clearDeps();
 
 protected:
-    std::set<App::DocumentObject*> _Deps;
+    std::map<App::DocumentObject*,bool> _Deps;
     std::map<std::string, std::unique_ptr<PropertyXLink> > _XLinks;
     std::map<std::string, std::string> _DocMap;
     bool _LinkRestored;
@@ -1352,6 +1363,7 @@ private:
         std::unique_ptr<PropertyXLink> xlink;
         std::string docName;
         std::string docLabel;
+        bool hidden=false;
     };
     std::unique_ptr<std::vector<RestoreInfo> > _XLinkRestores;
 };
