@@ -24,21 +24,19 @@
 #ifndef APP_PROPERTYSTANDARD_H
 #define APP_PROPERTYSTANDARD_H
 
-// Std. configurations
-
-
+#include <list>
 #include <memory>
 #include <string>
-#include <list>
 #include <vector>
 #include <boost/dynamic_bitset.hpp>
 #include <boost/filesystem/path.hpp>
-
 #include <Base/Uuid.h>
-#include "Enumeration.h"
+
 #include "Property.h"
+#include "Enumeration.h"
 #include "Material.h"
 
+
 namespace Base {
 class Writer;
 }
@@ -81,6 +79,13 @@ public:
     virtual void setPathValue(const App::ObjectIdentifier & path, const boost::any & value);
     virtual const boost::any getPathValue(const App::ObjectIdentifier & /*path*/) const { return _lValue; }
 
+    virtual bool isSame(const Property &other) const {
+        if (&other == this)
+            return true;
+        return getTypeId() == other.getTypeId()
+            && getValue() == static_cast<decltype(this)>(&other)->getValue();
+    }
+
 protected:
     long _lValue;
 };
@@ -107,7 +112,7 @@ public:
 
     /** This method returns a string representation of the property
      */
-    boost::filesystem::path getValue(void) const;
+    const boost::filesystem::path &getValue(void) const;
 
     virtual const char* getEditorName(void) const { return "Gui::PropertyEditor::PropertyPathItem"; }
 
@@ -122,6 +127,13 @@ public:
 
     virtual unsigned int getMemSize (void) const;
 
+    virtual bool isSame(const Property &other) const {
+        if (&other == this)
+            return true;
+        return getTypeId() == other.getTypeId()
+            && getValue() == static_cast<decltype(this)>(&other)->getValue();
+    }
+
 protected:
     boost::filesystem::path _cValue;
 };
@@ -186,11 +198,13 @@ public:
     const char * getValueAsString(void) const;
 
     /// Returns Enumeration object
-    Enumeration getEnum(void) const;
+    const Enumeration &getEnum(void) const;
 
     /// get all possible enum values as vector of strings
     std::vector<std::string> getEnumVector(void) const;
 
+    /// set enum values as vector of strings
+    void setEnumVector(const std::vector<std::string> &);
     /// get the pointer to the enum list
     const char ** getEnums(void) const;
 
@@ -211,7 +225,16 @@ public:
     virtual void Paste(const Property &from);
 
     virtual void setPathValue(const App::ObjectIdentifier & path, const boost::any & value);
-    virtual const boost::any getPathValue(const App::ObjectIdentifier & /*path*/) const { return _enum; }
+    virtual bool setPyPathValue(const App::ObjectIdentifier & path, const Py::Object &value);
+    virtual const boost::any getPathValue(const App::ObjectIdentifier & /*path*/) const;
+    virtual bool getPyPathValue(const ObjectIdentifier &path, Py::Object &r) const;
+
+    virtual bool isSame(const Property &other) const {
+        if (&other == this)
+            return true;
+        return getTypeId() == other.getTypeId()
+            && getEnum() == static_cast<decltype(this)>(&other)->getEnum();
+    }
 
 private:
     Enumeration _enum;
@@ -281,6 +304,10 @@ public:
     const Constraints*  getConstraints(void) const;
     //@}
 
+    long getMinimum() const;
+    long getMaximum() const;
+    long getStepSize() const;
+
     virtual const char* getEditorName(void) const { return "Gui::PropertyEditor::PropertyIntegerConstraintItem"; }
     virtual void setPyObject(PyObject *);
 
@@ -383,6 +410,12 @@ public:
     virtual void Paste(const Property &from);
     virtual unsigned int getMemSize (void) const;
 
+    virtual bool isSame(const Property &other) const {
+        if (&other == this)
+            return true;
+        return getTypeId() == other.getTypeId()
+            && getValues() == static_cast<decltype(this)>(&other)->getValues();
+    }
 private:
     std::set<long> _lValueSet;
 };
@@ -436,7 +469,13 @@ public:
     virtual void Paste(const Property &from);
 
     virtual unsigned int getMemSize (void) const;
-
+    
+    virtual bool isSame(const Property &other) const {
+        if (&other == this)
+            return true;
+        return getTypeId() == other.getTypeId()
+            && getValues() == static_cast<decltype(this)>(&other)->getValues();
+    }
 
 private:
     std::map<std::string,std::string> _lValueList;
@@ -487,6 +526,13 @@ public:
     void setPathValue(const App::ObjectIdentifier &path, const boost::any &value);
     const boost::any getPathValue(const App::ObjectIdentifier &path) const;
 
+    virtual bool isSame(const Property &other) const {
+        if (&other == this)
+            return true;
+        return getTypeId() == other.getTypeId()
+            && getValue() == static_cast<decltype(this)>(&other)->getValue();
+    }
+
 protected:
     double _dValue;
 };
@@ -561,6 +607,10 @@ public:
     const Constraints*  getConstraints(void) const;
     //@}
 
+    double getMinimum() const;
+    double getMaximum() const;
+    double getStepSize() const;
+
     virtual const char* getEditorName(void) const
     { return "Gui::PropertyEditor::PropertyFloatConstraintItem"; }
 
@@ -667,6 +717,13 @@ public:
     void setPathValue(const App::ObjectIdentifier &path, const boost::any &value);
     const boost::any getPathValue(const App::ObjectIdentifier &path) const;
 
+    virtual bool isSame(const Property &other) const {
+        if (&other == this)
+            return true;
+        return getTypeId() == other.getTypeId()
+            && getStrValue() == static_cast<decltype(this)>(&other)->getStrValue();
+    }
+
 protected:
     std::string _cValue;
 };
@@ -710,6 +767,13 @@ public:
     virtual void Paste(const Property &from);
     virtual unsigned int getMemSize (void) const;
 
+    virtual bool isSame(const Property &other) const {
+        if (&other == this)
+            return true;
+        return getTypeId() == other.getTypeId()
+            && _uuid.getValue() == static_cast<decltype(this)>(&other)->_uuid.getValue();
+    }
+
 private:
     Base::Uuid _uuid;
 };
@@ -726,6 +790,13 @@ public:
     virtual ~PropertyFont();
     virtual const char* getEditorName(void) const
     { return "Gui::PropertyEditor::PropertyFontItem"; }
+
+    virtual bool isSame(const Property &other) const {
+        if (&other == this)
+            return true;
+        return getTypeId() == other.getTypeId()
+            && getValue() == static_cast<decltype(this)>(&other)->getValue();
+    }
 };
 
 class AppExport PropertyStringList: public PropertyListsT<std::string>
@@ -807,6 +878,13 @@ public:
     void setPathValue(const App::ObjectIdentifier &path, const boost::any &value);
     const boost::any getPathValue(const App::ObjectIdentifier &path) const;
 
+    virtual bool isSame(const Property &other) const {
+        if (&other == this)
+            return true;
+        return getTypeId() == other.getTypeId()
+            && getValue() == static_cast<decltype(this)>(&other)->getValue();
+    }
+
 private:
     bool _lValue;
 };
@@ -880,7 +958,13 @@ public:
     virtual void Paste(const Property &from);
 
     virtual unsigned int getMemSize (void) const{return sizeof(Color);}
-
+    
+    virtual bool isSame(const Property &other) const {
+        if (&other == this)
+            return true;
+        return getTypeId() == other.getTypeId()
+            && getValue() == static_cast<decltype(this)>(&other)->getValue();
+    }
 
 private:
     Color _cCol;
@@ -967,6 +1051,13 @@ public:
     virtual void Paste(const Property &from);
 
     virtual unsigned int getMemSize (void) const{return sizeof(_cMat);}
+    
+    virtual bool isSame(const Property &other) const {
+        if (&other == this)
+            return true;
+        return getTypeId() == other.getTypeId()
+            && getValue() == static_cast<decltype(this)>(&other)->getValue();
+    }
 
 private:
     Material _cMat;
