@@ -23,15 +23,9 @@
 
 #include "PreCompiled.h"
 
-#ifndef _PreComp_
-# include <sstream>
-#endif
-
-#include <Base/Writer.h>
-#include <Base/Exception.h>
-
-#include "Document.h"
 #include "TransactionalObject.h"
+#include "Document.h"
+
 
 using namespace App;
 
