@@ -23,17 +23,15 @@
 
 #include "PreCompiled.h"
 
-#ifndef _PreComp_
-#endif
-
 #include "VRMLObject.h"
 #include "Document.h"
 #include "DocumentObjectPy.h"
 #include <Base/FileInfo.h>
-#include <Base/Stream.h>
 #include <Base/Reader.h>
+#include <Base/Stream.h>
 #include <Base/Writer.h>
 
+
 using namespace App;
 
 PROPERTY_SOURCE(App::VRMLObject, App::GeoFeature)
@@ -41,7 +39,7 @@ PROPERTY_SOURCE(App::VRMLObject, App::GeoFeature)
 
 VRMLObject::VRMLObject() : index(0)
 {
-    ADD_PROPERTY_TYPE(VrmlFile,(0),"",Prop_None,"Included file with the VRML definition");
+    ADD_PROPERTY_TYPE(VrmlFile,(nullptr),"",Prop_None,"Included file with the VRML definition");
     ADD_PROPERTY_TYPE(Urls,(""),"",static_cast<PropertyType>(Prop_ReadOnly|Prop_Output|Prop_Transient),
         "Resource files loaded by the VRML file");
     ADD_PROPERTY_TYPE(Resources,(""),"",static_cast<PropertyType>(Prop_ReadOnly|Prop_Output),
