@@ -27,6 +27,9 @@
 #ifndef BASE_BASE64_H
 #define BASE_BASE64_H
 
+#include <FCGlobal.h>
+#include <string>
+
 
 namespace Base
 {
