@@ -23,28 +23,10 @@
 
 #include "PreCompiled.h"
 
-#ifndef _PreComp_
-# include <xercesc/sax/SAXParseException.hpp>
-# include <xercesc/sax/SAXException.hpp>
-# include <xercesc/sax2/XMLReaderFactory.hpp>
-#endif
-
-// ---------------------------------------------------------------------------
-//  Includes
-// ---------------------------------------------------------------------------
-#include <xercesc/util/Janitor.hpp>
-#include <xercesc/util/PlatformUtils.hpp>
-#include <xercesc/util/XMLExceptMsgs.hpp>
-#include <xercesc/util/XMLString.hpp>
-#include <xercesc/util/PlatformUtils.hpp>
-#include <xercesc/util/XMLString.hpp>
-#include <xercesc/util/XMLUniDefs.hpp>
-
-/// Here the FreeCAD includes sorted by Base,App,Gui......
 #include "InputSource.h"
-#include "Exception.h"
 #include "XMLTools.h"
 
+
 XERCES_CPP_NAMESPACE_USE
 
 using namespace Base;
@@ -107,28 +89,28 @@ unsigned int StdInputStream::readBytes( XMLByte* const  toFill, const unsigned i
 #else
 XMLFilePos StdInputStream::curPos() const
 {
-  return stream.tellg();
+  return static_cast<XMLFilePos>(stream.tellg());
 }
 
-XMLSize_t StdInputStream::readBytes( XMLByte* const  toFill, const XMLSize_t maxToRead )
+XMLSize_t StdInputStream::readBytes(XMLByte* const  toFill, const XMLSize_t maxToRead)
 {
   //
   //  Read up to the maximum bytes requested. We return the number
   //  actually read.
   //
 
-  stream.read((char *)toFill,maxToRead);
-  XMLSize_t len = stream.gcount();
+  stream.read(reinterpret_cast<char *>(toFill), static_cast<std::streamsize>(maxToRead));
+  std::streamsize len = stream.gcount();
 
   QTextCodec *codec = QTextCodec::codecForName("UTF-8");
-  const QString text = codec->toUnicode((char *)toFill, len, &state);
+  const QString text = codec->toUnicode(reinterpret_cast<char *>(toFill), static_cast<int>(len), &state);
   if (state.invalidChars > 0) {
       // In case invalid characters were found decode back to 'utf-8' and replace
       // them with '?'
       // First, Qt replaces invalid characters with '\0' (see ConvertInvalidToNull)
       // but Xerces doesn't like this because it handles this as termination. Thus,
       // we have to go through the array and replace '\0' with '?'.
-      XMLSize_t pos = 0;
+      std::streamsize pos = 0;
       QByteArray ba = codec->fromUnicode(text);
       for (int i=0; i<ba.length(); i++, pos++) {
           if (pos < len && ba[i] == '\0')
@@ -136,7 +118,7 @@ XMLSize_t StdInputStream::readBytes( XMLByte* const  toFill, const XMLSize_t max
       }
   }
 
-  return len;
+  return static_cast<XMLSize_t>(len);
 }
 #endif
 
