@@ -23,10 +23,6 @@
 
 #include "PreCompiled.h"
 
-#include <climits>
-#include <cmath>
-#include "Base/Matrix.h"
-
 // inclusion of the generated files (generated out of MatrixPy.xml)
 #include "RotationPy.h"
 #include "VectorPy.h"
@@ -35,10 +31,11 @@
 #include "MatrixPy.h"
 #include "MatrixPy.cpp"
 
+
 using namespace Base;
 
 // returns a string which represents the object e.g. when printed in python
-std::string MatrixPy::representation(void) const
+std::string MatrixPy::representation() const
 {
     const Base::Matrix4D& m = *(this->getMatrixPtr());
     std::stringstream str;
@@ -71,7 +68,7 @@ int MatrixPy::PyInit(PyObject* args, PyObject* /*kwd*/)
                           &a21,&a22,&a23,&a24,
                           &a31,&a32,&a33,&a34,
                           &a41,&a42,&a43,&a44)) {
-        MatrixPy::PointerType ptr = reinterpret_cast<MatrixPy::PointerType>(_pcTwinPointer);
+        MatrixPy::PointerType ptr = getMatrixPtr();
         (*ptr) = Matrix4D(a11,a12,a13,a14,
                           a21,a22,a23,a24,
                           a31,a32,a33,a34,
@@ -82,24 +79,60 @@ int MatrixPy::PyInit(PyObject* args, PyObject* /*kwd*/)
     PyErr_Clear();
     PyObject *o;
     if (PyArg_ParseTuple(args, "O!", &(Base::MatrixPy::Type), &o)) {
-        MatrixPy::PointerType ptr = reinterpret_cast<MatrixPy::PointerType>(_pcTwinPointer);
+        MatrixPy::PointerType ptr = getMatrixPtr();
         (*ptr) = static_cast<MatrixPy*>(o)->value();
         return 0;
     }
 
-    PyErr_SetString(Base::BaseExceptionFreeCADError, "matrix or up to 16 floats expected");
+    PyErr_Clear();
+    PyObject *o1;
+    PyObject *o2;
+    PyObject *o3;
+    PyObject *o4 = nullptr;
+    if (PyArg_ParseTuple(args, "O!O!O!|O!", &(Base::VectorPy::Type), &o1
+                                          , &(Base::VectorPy::Type), &o2
+                                          , &(Base::VectorPy::Type), &o3
+                                          , &(Base::VectorPy::Type), &o4)) {
+        Base::Vector3d v1 = Py::Vector(o1, false).toVector();
+        Base::Vector3d v2 = Py::Vector(o2, false).toVector();
+        Base::Vector3d v3 = Py::Vector(o3, false).toVector();
+        Base::Vector3d v4;
+        if (o4)
+            v4 = Py::Vector(o4, false).toVector();
+        MatrixPy::PointerType ptr = this->getMatrixPtr();
+
+        (*ptr)[0][0] = v1.x;
+        (*ptr)[1][0] = v1.y;
+        (*ptr)[2][0] = v1.z;
+
+        (*ptr)[0][1] = v2.x;
+        (*ptr)[1][1] = v2.y;
+        (*ptr)[2][1] = v2.z;
+
+        (*ptr)[0][2] = v3.x;
+        (*ptr)[1][2] = v3.y;
+        (*ptr)[2][2] = v3.z;
+
+        (*ptr)[0][3] = v4.x;
+        (*ptr)[1][3] = v4.y;
+        (*ptr)[2][3] = v4.z;
+
+        return 0;
+    }
+
+    PyErr_SetString(PyExc_TypeError, "Base.Matrix, four Base.Vector or up to 16 floats expected");
     return -1;
 }
 
 PyObject* MatrixPy::number_add_handler(PyObject *self, PyObject *other)
 {
     if (!PyObject_TypeCheck(self, &(MatrixPy::Type))) {
-        PyErr_SetString(PyExc_NotImplementedError, "");
-        return 0;
+        PyErr_SetString(PyExc_TypeError, "First arg must be Matrix");
+        return nullptr;
     }
     if (!PyObject_TypeCheck(other, &(MatrixPy::Type))) {
         PyErr_SetString(PyExc_TypeError, "Second arg must be Matrix");
-        return 0;
+        return nullptr;
     }
     Base::Matrix4D a = static_cast<MatrixPy*>(self)->value();
     Base::Matrix4D b = static_cast<MatrixPy*>(other)->value();
@@ -109,12 +142,12 @@ PyObject* MatrixPy::number_add_handler(PyObject *self, PyObject *other)
 PyObject* MatrixPy::number_subtract_handler(PyObject *self, PyObject *other)
 {
     if (!PyObject_TypeCheck(self, &(MatrixPy::Type))) {
-        PyErr_SetString(PyExc_NotImplementedError, "");
-        return 0;
+        PyErr_SetString(PyExc_TypeError, "First arg must be Matrix");
+        return nullptr;
     }
     if (!PyObject_TypeCheck(other, &(MatrixPy::Type))) {
         PyErr_SetString(PyExc_TypeError, "Second arg must be Matrix");
-        return 0;
+        return nullptr;
     }
     Base::Matrix4D a = static_cast<MatrixPy*>(self)->value();
     Base::Matrix4D b = static_cast<MatrixPy*>(other)->value();
@@ -149,44 +182,39 @@ PyObject* MatrixPy::number_multiply_handler(PyObject *self, PyObject *other)
         }
 
         if (PyNumber_Check(other)) {
-            double v = PyFloat_AsDouble(self);
-            a.scale(v,v,v);
-            return new MatrixPy(a);
+            double v = PyFloat_AsDouble(other);
+            return new MatrixPy(a * v);
         }
     }
 
     PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
+    return nullptr;
 }
 
 PyObject * MatrixPy::number_power_handler (PyObject* self, PyObject* other, PyObject* arg)
 {
     if (!PyObject_TypeCheck(self, &(MatrixPy::Type)) ||
 
-#if PY_MAJOR_VERSION < 3
-            !PyInt_Check(other)
-#else
             !PyLong_Check(other)
-#endif
             || arg != Py_None
        )
     {
         PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-        return 0;
+        return nullptr;
     }
 
     Base::Matrix4D a = static_cast<MatrixPy*>(self)->value();
 
     long b = Py::Int(other);
-    if (!b)
+    if (b == 0)
         return new MatrixPy(Matrix4D());
 
     if (b < 0) {
         if (fabs(a.determinant()) > DBL_EPSILON)
             a.inverseGauss();
         else {
-            PyErr_SetString(Base::BaseExceptionFreeCADError, "Cannot invert singular matrix");
-            return 0;
+            PyErr_SetString(PyExc_RuntimeError, "Cannot invert singular matrix");
+            return nullptr;
         }
         b = -b;
     }
@@ -204,11 +232,11 @@ PyObject* MatrixPy::richCompare(PyObject *v, PyObject *w, int op)
         Matrix4D m1 = static_cast<MatrixPy*>(v)->value();
         Matrix4D m2 = static_cast<MatrixPy*>(w)->value();
 
-        PyObject *res=0;
+        PyObject *res=nullptr;
         if (op != Py_EQ && op != Py_NE) {
             PyErr_SetString(PyExc_TypeError,
             "no ordering relation is defined for Matrix");
-            return 0;
+            return nullptr;
         }
         else if (op == Py_EQ) {
             res = (m1 == m2) ? Py_True : Py_False;
@@ -234,34 +262,38 @@ PyObject* MatrixPy::move(PyObject * args)
     Base::Vector3d vec;
     PyObject *pcVecObj;
 
-    if (PyArg_ParseTuple(args, "ddd", &x,&y,&z)) {   // convert args: Python->C
-        vec.x = x;
-        vec.y = y;
-        vec.z = z;
-    }
-    else if (PyArg_ParseTuple(args, "O!:three floats or a vector is needed",
+    do { // dummy do..while for cascaded if
+        if (PyArg_ParseTuple(args, "ddd", &x,&y,&z)) {
+            vec.x = x;
+            vec.y = y;
+            vec.z = z;
+            break;
+        }
+        // clears the error from previous PyArg_ParseTuple()
+        PyErr_Clear();
+        if (PyArg_ParseTuple(args, "O!",
         &PyTuple_Type, &pcVecObj)) {
-        vec = getVectorFromTuple<double>(pcVecObj);
-        // clears the error from the first PyArg_ParseTuple()6
+            vec = getVectorFromTuple<double>(pcVecObj);
+            break;
+        }
+        // clears the error from previous PyArg_ParseTuple()
         PyErr_Clear();
-    }
-    else if (PyArg_ParseTuple(args, "O!:three floats or a vector is needed",
+        if (PyArg_ParseTuple(args, "O!;three floats, or a tuple, or a vector is needed",
         &(Base::VectorPy::Type), &pcVecObj)) {
-        Base::VectorPy  *pcObject = static_cast<Base::VectorPy*>(pcVecObj);
-        Base::Vector3d* val = pcObject->getVectorPtr();
-        vec.Set(val->x,val->y,val->z);
-        // clears the error from the first PyArg_ParseTuple()6
-        PyErr_Clear();
+            Base::VectorPy  *pcObject = static_cast<Base::VectorPy*>(pcVecObj);
+            Base::Vector3d* val = pcObject->getVectorPtr();
+            vec.Set(val->x,val->y,val->z);
+            break;
+        }
+        return nullptr;
     }
-    else
-        return NULL;
+    while(false);
 
     PY_TRY {
         getMatrixPtr()->move(vec);
+        Py_Return;
     }
     PY_CATCH;
-
-    Py_Return;
 }
 
 PyObject* MatrixPy::scale(PyObject * args)
@@ -270,54 +302,102 @@ PyObject* MatrixPy::scale(PyObject * args)
     Base::Vector3d vec;
     PyObject *pcVecObj;
 
-    if (PyArg_ParseTuple(args, "ddd", &x,&y,&z)) {   // convert args: Python->C
-        vec.x = x;
-        vec.y = y;
-        vec.z = z;
-    }
-    else if (PyArg_ParseTuple(args, "O!:three floats or a vector is needed",
-        &PyTuple_Type, &pcVecObj)) {
-        vec = getVectorFromTuple<double>(pcVecObj);
-        // clears the error from the first PyArg_ParseTuple()6
+    do { // dummy do..while for cascaded if
+        if (PyArg_ParseTuple(args, "ddd", &x,&y,&z)) {
+            vec.x = x;
+            vec.y = y;
+            vec.z = z;
+            break;
+        }
+        // clears the error from previous PyArg_ParseTuple()
         PyErr_Clear();
-    }
-    else if (PyArg_ParseTuple(args, "O!:three floats or a vector is needed", &(Base::VectorPy::Type), &pcVecObj)) {
-        // convert args: Python->C
-        Base::VectorPy  *pcObject = static_cast<Base::VectorPy*>(pcVecObj);
-        Base::Vector3d* val = pcObject->getVectorPtr();
-        vec.Set(val->x,val->y,val->z);
-        // clears the error from the first PyArg_ParseTuple()6
+        if (PyArg_ParseTuple(args, "d", &x)) {
+            vec.x = vec.y = vec.z = x;
+            break;
+        }
+        // clears the error from previous PyArg_ParseTuple()
         PyErr_Clear();
+        if (PyArg_ParseTuple(args, "O!", &PyTuple_Type, &pcVecObj)) {
+            vec = getVectorFromTuple<double>(pcVecObj);
+            break;
+        }
+        // clears the error from previous PyArg_ParseTuple()
+        PyErr_Clear();
+        if (PyArg_ParseTuple(args, "O!;one or three floats, or a tuple, or a vector is needed",
+        &(Base::VectorPy::Type), &pcVecObj)) {
+            Base::VectorPy  *pcObject = static_cast<Base::VectorPy*>(pcVecObj);
+            Base::Vector3d* val = pcObject->getVectorPtr();
+            vec.Set(val->x,val->y,val->z);
+            break;
+        }
+        return nullptr;
     }
-    else
-        return NULL;
+    while(false);
 
     PY_TRY {
         getMatrixPtr()->scale(vec);
+        Py_Return;
     }
     PY_CATCH;
-
-    Py_Return;
 }
 
 PyObject* MatrixPy::hasScale(PyObject * args)
 {
     double tol=0;
     if (!PyArg_ParseTuple(args, "|d", &tol))
-        return 0;
-    return Py::new_reference_to(Py::Int(getMatrixPtr()->hasScale(tol)));
+        return nullptr;
+
+    ScaleType type = getMatrixPtr()->hasScale(tol);
+    Py::Module mod("FreeCAD");
+    return Py::new_reference_to(mod.callMemberFunction("ScaleType", Py::TupleN(Py::Int(static_cast<int>(type)))));
+}
+
+PyObject* MatrixPy::nullify(PyObject * args)
+{
+    if (!PyArg_ParseTuple(args, ""))
+      return nullptr;
+
+    PY_TRY {
+        getMatrixPtr()->nullify();
+        Py_Return;
+    }
+    PY_CATCH;
+}
+
+PyObject* MatrixPy::isNull(PyObject * args)
+{
+    if (!PyArg_ParseTuple(args, ""))
+      return nullptr;
+
+    PY_TRY {
+        bool ok = getMatrixPtr()->isNull();
+        return Py::new_reference_to(Py::Boolean(ok));
+    }
+    PY_CATCH;
 }
 
 PyObject* MatrixPy::unity(PyObject * args)
 {
-    if (!PyArg_ParseTuple(args, ""))     // convert args: Python->C
-      return NULL;                             // NULL triggers exception
+    if (!PyArg_ParseTuple(args, ""))
+      return nullptr;
+
     PY_TRY {
         getMatrixPtr()->setToUnity();
+        Py_Return;
     }
     PY_CATCH;
+}
 
-    Py_Return;
+PyObject* MatrixPy::isUnity(PyObject * args)
+{
+    if (!PyArg_ParseTuple(args, ""))
+      return nullptr;
+
+    PY_TRY {
+        bool ok = getMatrixPtr()->isUnity();
+        return Py::new_reference_to(Py::Boolean(ok));
+    }
+    PY_CATCH;
 }
 
 PyObject* MatrixPy::transform(PyObject * args)
@@ -326,23 +406,106 @@ PyObject* MatrixPy::transform(PyObject * args)
     Matrix4D mat;
     PyObject *pcVecObj,*pcMatObj;
 
-    if (PyArg_ParseTuple(args, "O!O!: a transform point (Vector) and a transform matrix (Matrix) is needed",
-        &(Base::VectorPy::Type), &pcVecObj, &(MatrixPy::Type), &pcMatObj) ) {   // convert args: Python->C
-        Base::VectorPy  *pcObject = static_cast<Base::VectorPy*>(pcVecObj);
-        Base::Vector3d* val = pcObject->getVectorPtr();
-        vec.Set(val->x,val->y,val->z);
-        mat = *(static_cast<MatrixPy*>(pcMatObj)->getMatrixPtr());
-        // clears the error from the first PyArg_ParseTuple()6
-        PyErr_Clear();
-    }
-    else
-        return NULL;                                 // NULL triggers exception
+    if (!PyArg_ParseTuple(args, "O!O!: a transform point (Vector) and a transform matrix (Matrix) is needed",
+        &(Base::VectorPy::Type), &pcVecObj, &(MatrixPy::Type), &pcMatObj))
+        return nullptr;
 
-    PY_TRY {
-        getMatrixPtr()->transform(vec,mat);
-    }
-    PY_CATCH;
+    Base::VectorPy  *pcObject = static_cast<Base::VectorPy*>(pcVecObj);
+    Base::Vector3d* val = pcObject->getVectorPtr();
+    vec.Set(val->x,val->y,val->z);
+    mat = *(static_cast<MatrixPy*>(pcMatObj)->getMatrixPtr());
 
+    getMatrixPtr()->transform(vec,mat);
+    Py_Return;
+}
+
+PyObject* MatrixPy::col(PyObject * args)
+{
+    int index;
+    if (!PyArg_ParseTuple(args, "i", &index))
+        return nullptr;
+
+    if (index < 0 || index > 3) {
+        PyErr_SetString(PyExc_ValueError, "Index expected in the range [0, 3]");
+        return nullptr;
+    }
+
+    Matrix4D* mat = getMatrixPtr();
+    Base::Vector3d v = mat->getCol(index);
+    return Py::new_reference_to(Py::Vector(v));
+}
+
+PyObject* MatrixPy::setCol(PyObject * args)
+{
+    int index;
+    PyObject* o;
+    if (!PyArg_ParseTuple(args, "iO!", &index, &(VectorPy::Type), &o))
+        return nullptr;
+
+    if (index < 0 || index > 3) {
+        PyErr_SetString(PyExc_ValueError, "Index expected in the range [0, 3]");
+        return nullptr;
+    }
+
+    Base::Vector3d v = Py::Vector(o, false).toVector();
+    Matrix4D* mat = getMatrixPtr();
+    mat->setCol(index, v);
+    Py_Return;
+}
+
+PyObject* MatrixPy::row(PyObject * args)
+{
+    int index;
+    if (!PyArg_ParseTuple(args, "i", &index))
+        return nullptr;
+
+    if (index < 0 || index > 3) {
+        PyErr_SetString(PyExc_ValueError, "Index expected in the range [0, 3]");
+        return nullptr;
+    }
+
+    Matrix4D* mat = getMatrixPtr();
+    Base::Vector3d v = mat->getRow(index);
+    return Py::new_reference_to(Py::Vector(v));
+}
+
+PyObject* MatrixPy::setRow(PyObject * args)
+{
+    int index;
+    PyObject* o;
+    if (!PyArg_ParseTuple(args, "iO!", &index, &(VectorPy::Type), &o))
+        return nullptr;
+
+    if (index < 0 || index > 3) {
+        PyErr_SetString(PyExc_ValueError, "Index expected in the range [0, 3]");
+        return nullptr;
+    }
+
+    Base::Vector3d v = Py::Vector(o, false).toVector();
+    Matrix4D* mat = getMatrixPtr();
+    mat->setRow(index, v);
+    Py_Return;
+}
+
+PyObject* MatrixPy::trace(PyObject * args)
+{
+    if (!PyArg_ParseTuple(args, ""))
+        return nullptr;
+
+    Matrix4D* mat = getMatrixPtr();
+    Base::Vector3d v = mat->trace();
+    return Py::new_reference_to(Py::Vector(v));
+}
+
+PyObject* MatrixPy::setTrace(PyObject * args)
+{
+    PyObject* o;
+    if (!PyArg_ParseTuple(args, "O!", &(VectorPy::Type), &o))
+        return nullptr;
+
+    Base::Vector3d v = Py::Vector(o, false).toVector();
+    Matrix4D* mat = getMatrixPtr();
+    mat->setTrace(v);
     Py_Return;
 }
 
@@ -365,16 +528,15 @@ PyObject* MatrixPy::rotateX(PyObject * args)
         }
 
         PyErr_SetString(PyExc_TypeError, "For angle either float or Quantity expected");
-        return 0;
+        return nullptr;
     }
     while (false);
 
     PY_TRY {
         getMatrixPtr()->rotX(angle);
+        Py_Return;
     }
     PY_CATCH;
-
-    Py_Return;
 }
 
 PyObject* MatrixPy::rotateY(PyObject * args)
@@ -396,16 +558,15 @@ PyObject* MatrixPy::rotateY(PyObject * args)
         }
 
         PyErr_SetString(PyExc_TypeError, "For angle either float or Quantity expected");
-        return 0;
+        return nullptr;
     }
     while (false);
 
     PY_TRY {
         getMatrixPtr()->rotY(angle);
+        Py_Return;
     }
     PY_CATCH;
-
-    Py_Return;
 }
 
 PyObject* MatrixPy::rotateZ(PyObject * args)
@@ -427,16 +588,15 @@ PyObject* MatrixPy::rotateZ(PyObject * args)
         }
 
         PyErr_SetString(PyExc_TypeError, "For angle either float or Quantity expected");
-        return 0;
+        return nullptr;
     }
     while (false);
 
     PY_TRY {
         getMatrixPtr()->rotZ(angle);
+        Py_Return;
     }
     PY_CATCH;
-
-    Py_Return;
 }
 
 PyObject* MatrixPy::multiply(PyObject * args)
@@ -453,15 +613,16 @@ PyObject* MatrixPy::multiply(PyObject * args)
         return new VectorPy(new Vector3d(vec));
     }
 
-    PyErr_SetString(Base::BaseExceptionFreeCADError, "either vector or matrix expected");
-    return 0;
+    PyErr_SetString(PyExc_TypeError, "either vector or matrix expected");
+    return nullptr;
 }
 
 PyObject* MatrixPy::multVec(PyObject * args)
 {
     PyObject *obj;
     if (!PyArg_ParseTuple(args, "O!", &(VectorPy::Type), &obj))
-        return NULL;
+        return nullptr;
+
     Base::Vector3d vec(static_cast<VectorPy*>(obj)->value());
     getMatrixPtr()->multVec(vec, vec);
     return new VectorPy(new Vector3d(vec));
@@ -470,25 +631,25 @@ PyObject* MatrixPy::multVec(PyObject * args)
 PyObject* MatrixPy::invert(PyObject * args)
 {
     if (!PyArg_ParseTuple(args, ""))
-        return NULL;
+        return nullptr;
 
     PY_TRY {
-        if (fabs(getMatrixPtr()->determinant()) > DBL_EPSILON)
+        if (fabs(getMatrixPtr()->determinant()) > DBL_EPSILON) {
             getMatrixPtr()->inverseGauss();
+            Py_Return;
+        }
         else {
-            PyErr_SetString(Base::BaseExceptionFreeCADError, "Cannot invert singular matrix");
-            return 0;
+            PyErr_SetString(Base::PyExc_FC_GeneralError, "Cannot invert singular matrix");
+            return nullptr;
         }
     }
     PY_CATCH;
-
-    Py_Return;
 }
 
 PyObject* MatrixPy::inverse(PyObject * args)
 {
     if (!PyArg_ParseTuple(args, ""))
-        return NULL;
+        return nullptr;
 
     PY_TRY {
         if (fabs(getMatrixPtr()->determinant()) > DBL_EPSILON) {
@@ -497,19 +658,18 @@ PyObject* MatrixPy::inverse(PyObject * args)
             return new MatrixPy(m);
         }
         else {
-            PyErr_SetString(Base::BaseExceptionFreeCADError, "Cannot invert singular matrix");
-            return 0;
+            PyErr_SetString(Base::PyExc_FC_GeneralError, "Cannot invert singular matrix");
+            return nullptr;
         }
     }
     PY_CATCH;
-
-    Py_Return;
 }
 
 PyObject* MatrixPy::determinant(PyObject * args)
 {
     if (!PyArg_ParseTuple(args, ""))
-        return NULL;
+        return nullptr;
+
     return PyFloat_FromDouble(getMatrixPtr()->determinant());
 }
 
@@ -517,10 +677,11 @@ PyObject* MatrixPy::submatrix(PyObject * args)
 {
     int dim;
     if (!PyArg_ParseTuple(args, "i", &dim))
-        return NULL;
+        return nullptr;
+
     if (dim < 1 || dim > 4) {
         PyErr_SetString(PyExc_IndexError, "Dimension out of range");
-        return NULL;
+        return nullptr;
     }
 
     const Base::Matrix4D& mat = *getMatrixPtr();
@@ -551,7 +712,8 @@ PyObject* MatrixPy::isOrthogonal(PyObject * args)
 {
     double eps=1.0e-06;
     if (!PyArg_ParseTuple(args, "|d",&eps))
-        return 0;
+        return nullptr;
+
     const Base::Matrix4D& mat = *getMatrixPtr();
     Base::Matrix4D trp = mat;
     trp.transpose();
@@ -559,8 +721,8 @@ PyObject* MatrixPy::isOrthogonal(PyObject * args)
 
     bool ok = true;
     double mult = trp[0][0];
-    for (int i=0; i<4 && ok; i++) {
-        for (int j=0; j<4 && ok; j++) {
+    for (unsigned short i=0; i<4 && ok; i++) {
+        for (unsigned short j=0; j<4 && ok; j++) {
             if (i != j) {
                 if (fabs(trp[i][j]) > eps) {
                     ok = false;
@@ -582,7 +744,7 @@ PyObject* MatrixPy::isOrthogonal(PyObject * args)
 PyObject* MatrixPy::transposed(PyObject * args)
 {
     if (!PyArg_ParseTuple(args, ""))
-        return NULL;
+        return nullptr;
 
     PY_TRY {
         Base::Matrix4D m = *getMatrixPtr();
@@ -590,14 +752,12 @@ PyObject* MatrixPy::transposed(PyObject * args)
         return new MatrixPy(m);
     }
     PY_CATCH;
-
-    Py_Return;
 }
 
 PyObject* MatrixPy::transpose(PyObject * args)
 {
     if (!PyArg_ParseTuple(args, ""))
-        return NULL;
+        return nullptr;
 
     PY_TRY {
         getMatrixPtr()->transpose();
@@ -609,20 +769,16 @@ PyObject* MatrixPy::transpose(PyObject * args)
 PyObject* MatrixPy::analyze(PyObject * args)
 {
     if (!PyArg_ParseTuple(args, ""))
-        return NULL;
+        return nullptr;
 
     PY_TRY {
         std::string type = getMatrixPtr()->analyse();
-#if PY_MAJOR_VERSION < 3
-        return PyString_FromString(type.c_str());
-#else
         return PyUnicode_FromString(type.c_str());
-#endif
     }
     PY_CATCH;
 }
 
-Py::Float MatrixPy::getA11(void) const
+Py::Float MatrixPy::getA11() const
 {
     double val = (*this->getMatrixPtr())[0][0];
     return Py::Float(val);
@@ -630,10 +786,10 @@ Py::Float MatrixPy::getA11(void) const
 
 void  MatrixPy::setA11(Py::Float arg)
 {
-    (*this->getMatrixPtr())[0][0] = (double)arg;
+    (*this->getMatrixPtr())[0][0] = static_cast<double>(arg);
 }
 
-Py::Float MatrixPy::getA12(void) const
+Py::Float MatrixPy::getA12() const
 {
     double val = (*this->getMatrixPtr())[0][1];
     return Py::Float(val);
@@ -641,10 +797,10 @@ Py::Float MatrixPy::getA12(void) const
 
 void  MatrixPy::setA12(Py::Float arg)
 {
-    (*this->getMatrixPtr())[0][1] = (double)arg;
+    (*this->getMatrixPtr())[0][1] = static_cast<double>(arg);
 }
 
-Py::Float MatrixPy::getA13(void) const
+Py::Float MatrixPy::getA13() const
 {
     double val = (*this->getMatrixPtr())[0][2];
     return Py::Float(val);
@@ -652,10 +808,10 @@ Py::Float MatrixPy::getA13(void) const
 
 void  MatrixPy::setA13(Py::Float arg)
 {
-    (*this->getMatrixPtr())[0][2] = (double)arg;
+    (*this->getMatrixPtr())[0][2] = static_cast<double>(arg);
 }
 
-Py::Float MatrixPy::getA14(void) const
+Py::Float MatrixPy::getA14() const
 {
     double val = (*this->getMatrixPtr())[0][3];
     return Py::Float(val);
@@ -663,10 +819,10 @@ Py::Float MatrixPy::getA14(void) const
 
 void  MatrixPy::setA14(Py::Float arg)
 {
-    (*this->getMatrixPtr())[0][3] = (double)arg;
+    (*this->getMatrixPtr())[0][3] = static_cast<double>(arg);
 }
 
-Py::Float MatrixPy::getA21(void) const
+Py::Float MatrixPy::getA21() const
 {
     double val = (*this->getMatrixPtr())[1][0];
     return Py::Float(val);
@@ -674,10 +830,10 @@ Py::Float MatrixPy::getA21(void) const
 
 void  MatrixPy::setA21(Py::Float arg)
 {
-    (*this->getMatrixPtr())[1][0] = (double)arg;
+    (*this->getMatrixPtr())[1][0] = static_cast<double>(arg);
 }
 
-Py::Float MatrixPy::getA22(void) const
+Py::Float MatrixPy::getA22() const
 {
     double val = (*this->getMatrixPtr())[1][1];
     return Py::Float(val);
@@ -685,10 +841,10 @@ Py::Float MatrixPy::getA22(void) const
 
 void  MatrixPy::setA22(Py::Float arg)
 {
-    (*this->getMatrixPtr())[1][1] = (double)arg;
+    (*this->getMatrixPtr())[1][1] = static_cast<double>(arg);
 }
 
-Py::Float MatrixPy::getA23(void) const
+Py::Float MatrixPy::getA23() const
 {
     double val = (*this->getMatrixPtr())[1][2];
     return Py::Float(val);
@@ -696,10 +852,10 @@ Py::Float MatrixPy::getA23(void) const
 
 void  MatrixPy::setA23(Py::Float arg)
 {
-    (*this->getMatrixPtr())[1][2] = (double)arg;
+    (*this->getMatrixPtr())[1][2] = static_cast<double>(arg);
 }
 
-Py::Float MatrixPy::getA24(void) const
+Py::Float MatrixPy::getA24() const
 {
     double val = (*this->getMatrixPtr())[1][3];
     return Py::Float(val);
@@ -707,10 +863,10 @@ Py::Float MatrixPy::getA24(void) const
 
 void  MatrixPy::setA24(Py::Float arg)
 {
-    (*this->getMatrixPtr())[1][3] = (double)arg;
+    (*this->getMatrixPtr())[1][3] = static_cast<double>(arg);
 }
 
-Py::Float MatrixPy::getA31(void) const
+Py::Float MatrixPy::getA31() const
 {
     double val = (*this->getMatrixPtr())[2][0];
     return Py::Float(val);
@@ -718,10 +874,10 @@ Py::Float MatrixPy::getA31(void) const
 
 void  MatrixPy::setA31(Py::Float arg)
 {
-    (*this->getMatrixPtr())[2][0] = (double)arg;
+    (*this->getMatrixPtr())[2][0] = static_cast<double>(arg);
 }
 
-Py::Float MatrixPy::getA32(void) const
+Py::Float MatrixPy::getA32() const
 {
     double val = (*this->getMatrixPtr())[2][1];
     return Py::Float(val);
@@ -729,10 +885,10 @@ Py::Float MatrixPy::getA32(void) const
 
 void  MatrixPy::setA32(Py::Float arg)
 {
-    (*this->getMatrixPtr())[2][1] = (double)arg;
+    (*this->getMatrixPtr())[2][1] = static_cast<double>(arg);
 }
 
-Py::Float MatrixPy::getA33(void) const
+Py::Float MatrixPy::getA33() const
 {
     double val = (*this->getMatrixPtr())[2][2];
     return Py::Float(val);
@@ -740,10 +896,10 @@ Py::Float MatrixPy::getA33(void) const
 
 void  MatrixPy::setA33(Py::Float arg)
 {
-    (*this->getMatrixPtr())[2][2] = (double)arg;
+    (*this->getMatrixPtr())[2][2] = static_cast<double>(arg);
 }
 
-Py::Float MatrixPy::getA34(void) const
+Py::Float MatrixPy::getA34() const
 {
     double val = (*this->getMatrixPtr())[2][3];
     return Py::Float(val);
@@ -751,10 +907,10 @@ Py::Float MatrixPy::getA34(void) const
 
 void  MatrixPy::setA34(Py::Float arg)
 {
-    (*this->getMatrixPtr())[2][3] = (double)arg;
+    (*this->getMatrixPtr())[2][3] = static_cast<double>(arg);
 }
 
-Py::Float MatrixPy::getA41(void) const
+Py::Float MatrixPy::getA41() const
 {
     double val = (*this->getMatrixPtr())[3][0];
     return Py::Float(val);
@@ -762,10 +918,10 @@ Py::Float MatrixPy::getA41(void) const
 
 void  MatrixPy::setA41(Py::Float arg)
 {
-    (*this->getMatrixPtr())[3][0] = (double)arg;
+    (*this->getMatrixPtr())[3][0] = static_cast<double>(arg);
 }
 
-Py::Float MatrixPy::getA42(void) const
+Py::Float MatrixPy::getA42() const
 {
     double val = (*this->getMatrixPtr())[3][1];
     return Py::Float(val);
@@ -773,10 +929,10 @@ Py::Float MatrixPy::getA42(void) const
 
 void  MatrixPy::setA42(Py::Float arg)
 {
-    (*this->getMatrixPtr())[3][1] = (double)arg;
+    (*this->getMatrixPtr())[3][1] = static_cast<double>(arg);
 }
 
-Py::Float MatrixPy::getA43(void) const
+Py::Float MatrixPy::getA43() const
 {
     double val = (*this->getMatrixPtr())[3][2];
     return Py::Float(val);
@@ -784,10 +940,10 @@ Py::Float MatrixPy::getA43(void) const
 
 void  MatrixPy::setA43(Py::Float arg)
 {
-    (*this->getMatrixPtr())[3][2] = (double)arg;
+    (*this->getMatrixPtr())[3][2] = static_cast<double>(arg);
 }
 
-Py::Float MatrixPy::getA44(void) const
+Py::Float MatrixPy::getA44() const
 {
     double val = (*this->getMatrixPtr())[3][3];
     return Py::Float(val);
@@ -795,10 +951,10 @@ Py::Float MatrixPy::getA44(void) const
 
 void  MatrixPy::setA44(Py::Float arg)
 {
-    (*this->getMatrixPtr())[3][3] = (double)arg;
+    (*this->getMatrixPtr())[3][3] = static_cast<double>(arg);
 }
 
-Py::Sequence MatrixPy::getA(void) const
+Py::Sequence MatrixPy::getA() const
 {
     double mat[16];
     this->getMatrixPtr()->getMatrix(mat);
@@ -816,7 +972,7 @@ void MatrixPy::setA(Py::Sequence arg)
 
     int index=0;
     for (Py::Sequence::iterator it = arg.begin(); it != arg.end() && index < 16; ++it) {
-        mat[index++] = (double)Py::Float(*it);
+        mat[index++] = static_cast<double>(Py::Float(*it));
     }
 
     this->getMatrixPtr()->setMatrix(mat);
@@ -824,7 +980,7 @@ void MatrixPy::setA(Py::Sequence arg)
 
 PyObject *MatrixPy::getCustomAttributes(const char* /*attr*/) const
 {
-    return 0;
+    return nullptr;
 }
 
 int MatrixPy::setCustomAttributes(const char* /*attr*/, PyObject* /*obj*/)
@@ -835,37 +991,47 @@ int MatrixPy::setCustomAttributes(const char* /*attr*/, PyObject* /*obj*/)
 PyObject * MatrixPy::number_divide_handler (PyObject* /*self*/, PyObject* /*other*/)
 {
     PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
+    return nullptr;
 }
 
 PyObject * MatrixPy::number_remainder_handler (PyObject* /*self*/, PyObject* /*other*/)
 {
     PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
+    return nullptr;
 }
 
 PyObject * MatrixPy::number_divmod_handler (PyObject* /*self*/, PyObject* /*other*/)
 {
     PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
+    return nullptr;
 }
 
-PyObject * MatrixPy::number_negative_handler (PyObject* /*self*/)
+PyObject * MatrixPy::number_negative_handler (PyObject* self)
 {
-    PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
+    if (!PyObject_TypeCheck(self, &(MatrixPy::Type))) {
+        PyErr_SetString(PyExc_TypeError, "arg must be Matrix");
+        return nullptr;
+    }
+
+    Base::Matrix4D a = static_cast<MatrixPy*>(self)->value();
+    return new MatrixPy(a * -1);
 }
 
-PyObject * MatrixPy::number_positive_handler (PyObject* /*self*/)
+PyObject * MatrixPy::number_positive_handler (PyObject* self)
 {
-    PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
+    if (!PyObject_TypeCheck(self, &(MatrixPy::Type))) {
+        PyErr_SetString(PyExc_TypeError, "arg must be Matrix");
+        return nullptr;
+    }
+
+    Base::Matrix4D a = static_cast<MatrixPy*>(self)->value();
+    return new MatrixPy(a);
 }
 
 PyObject * MatrixPy::number_absolute_handler (PyObject* /*self*/)
 {
     PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
+    return nullptr;
 }
 
 int MatrixPy::number_nonzero_handler (PyObject* /*self*/)
@@ -876,76 +1042,47 @@ int MatrixPy::number_nonzero_handler (PyObject* /*self*/)
 PyObject * MatrixPy::number_invert_handler (PyObject* /*self*/)
 {
     PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
+    return nullptr;
 }
 
 PyObject * MatrixPy::number_lshift_handler (PyObject* /*self*/, PyObject* /*other*/)
 {
     PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
+    return nullptr;
 }
 
 PyObject * MatrixPy::number_rshift_handler (PyObject* /*self*/, PyObject* /*other*/)
 {
     PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
+    return nullptr;
 }
 
 PyObject * MatrixPy::number_and_handler (PyObject* /*self*/, PyObject* /*other*/)
 {
     PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
+    return nullptr;
 }
 
 PyObject * MatrixPy::number_xor_handler (PyObject* /*self*/, PyObject* /*other*/)
 {
     PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
+    return nullptr;
 }
 
 PyObject * MatrixPy::number_or_handler (PyObject* /*self*/, PyObject* /*other*/)
 {
     PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
+    return nullptr;
 }
 
-#if PY_MAJOR_VERSION < 3
-int MatrixPy::number_coerce_handler (PyObject ** /*self*/, PyObject ** /*other*/)
-{
-    return 1;
-}
-#endif
-
 PyObject * MatrixPy::number_int_handler (PyObject * /*self*/)
 {
     PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
+    return nullptr;
 }
 
-#if PY_MAJOR_VERSION < 3
-PyObject * MatrixPy::number_long_handler (PyObject * /*self*/)
-{
-    PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
-}
-#endif
-
 PyObject * MatrixPy::number_float_handler (PyObject * /*self*/)
 {
     PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
+    return nullptr;
 }
-
-#if PY_MAJOR_VERSION < 3
-PyObject * MatrixPy::number_oct_handler (PyObject * /*self*/)
-{
-    PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
-}
-
-PyObject * MatrixPy::number_hex_handler (PyObject * /*self*/)
-{
-    PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
-}
-#endif
