@@ -22,6 +22,10 @@
 
 #ifndef BASE_MEMDEBUG_H
 #define BASE_MEMDEBUG_H
+#ifndef FC_GLOBAL_H
+#include <crtdbg.h>
+#include <FCGlobal.h>
+#endif
 
 namespace Base
 {
