@@ -1,5 +1,5 @@
 /***************************************************************************
- *   (c) Jürgen Riegel (juergen.riegel@web.de) 2002                        *   
+ *   Copyright (c) 2002 Jürgen Riegel <juergen.riegel@web.de>              *
  *                                                                         *
  *   This file is part of the FreeCAD CAx development system.              *
  *                                                                         *
@@ -10,31 +10,27 @@
  *   for detail see the LICENCE text file.                                 *
  *                                                                         *
  *   FreeCAD is distributed in the hope that it will be useful,            *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        * 
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
  *   GNU Library General Public License for more details.                  *
  *                                                                         *
  *   You should have received a copy of the GNU Library General Public     *
- *   License along with FreeCAD; if not, write to the Free Software        * 
+ *   License along with FreeCAD; if not, write to the Free Software        *
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  *
  *   USA                                                                   *
  *                                                                         *
- *   Juergen Riegel 2002                                                   *
  ***************************************************************************/
 
 
 #ifndef BASE_OBSERVER_H
 #define BASE_OBSERVER_H
 
-// Std. configurations
-
-#include <assert.h>
-#include <set>
+#include <cassert>
 #include <cstring>
-#include <cstdio>
-#include <exception>
-#include "Exception.h"
+#include <set>
 #include "Console.h"
+#include "Exception.h"
+
 
 namespace Base
 {
@@ -45,7 +41,7 @@ template <class MessageType> class Subject;
 /** Observer class
  *  Implementation of the well known Observer Design Pattern.
  *  The observed object, which inherit FCSubject, will call all
- *  its observers in case of changes. A observer class has to 
+ *  its observers in case of changes. A observer class has to
  *  Attach itself to the observed object.
  *  @see FCSubject
  */
@@ -86,16 +82,16 @@ public:
 
   /**
    * This method can be reimplemented from the concrete Observer
-   * and returns the name of the observer. Needed to use the Get 
+   * and returns the name of the observer. Needed to use the Get
    * Method of the Subject.
    */
-  virtual const char *Name(void){return 0L;}
+  virtual const char *Name(){return nullptr;}
 };
 
 /** Subject class
  *  Implementation of the well known Observer Design Pattern.
  *  The observed object, which inherit FCSubject, will call all
- *  its observers in case of changes. A observer class has to 
+ *  its observers in case of changes. A observer class has to
  *  Attach itself to the observed object.
  *  @see FCObserver
  */
@@ -106,8 +102,8 @@ public:
 
   typedef  Observer<_MessageType> ObserverType;
   typedef  _MessageType             MessageType;
-  typedef  Subject<_MessageType>  SubjectType;   
-     
+  typedef  Subject<_MessageType>  SubjectType;
+
   /**
    * A constructor.
    * No special function so far.
@@ -128,7 +124,7 @@ public:
   }
 
   /** Attach an Observer
-   * Attach an Observer to the list of Observers which get   
+   * Attach an Observer to the list of Observers which get
    * called when Notify is called.
    * @param ToObserv A pointer to a concrete Observer
    * @see Notify
@@ -140,14 +136,14 @@ public:
     //printf("Attach observer %p\n", ToObserv);
     _ObserverSet.insert(ToObserv);
     if ( _ObserverSet.size() == count )
-      printf("Observer %p already attached\n", ToObserv);
+      printf("Observer %p already attached\n", static_cast<void*>(ToObserv));
 #else
     _ObserverSet.insert(ToObserv);
 #endif
   }
 
   /** Detach an Observer
-   * Detach an Observer from the list of Observers which get   
+   * Detach an Observer from the list of Observers which get
    * called when Notify is called.
    * @param ToObserv A pointer to a concrete Observer
    * @see Notify
@@ -159,7 +155,7 @@ public:
     //printf("Detach observer %p\n", ToObserv);
     _ObserverSet.erase(ToObserv);
     if ( _ObserverSet.size() == count )
-      printf("Observer %p already detached\n", ToObserv);
+      printf("Observer %p already detached\n", static_cast<void*>(ToObserv));
 #else
     _ObserverSet.erase(ToObserv);
 #endif
@@ -167,7 +163,7 @@ public:
 
   /** Notify all Observers
    * Send a message to all Observers attached to this subject.
-   * The Message depends on the implementation of a concrete 
+   * The Message depends on the implementation of a concrete
    * Oberserver and Subject.
    * @see Notify
    */
@@ -203,10 +199,10 @@ public:
         return *Iter;
     }
 
-    return 0L;
+    return nullptr;
   }
 
-  /** Clears the list of all registered observers. 
+  /** Clears the list of all registered observers.
    * @note Using this function in your code may be an indication of design problems.
    */
   void ClearObserver()
