@@ -25,47 +25,32 @@
 #include "PreCompiled.h"
 
 #ifndef _PreComp_
-#   include <assert.h>
+#   include <cassert>
 #   include <memory>
-#   include <xercesc/util/PlatformUtils.hpp>
-#   include <xercesc/util/XercesVersion.hpp>
 #   include <xercesc/dom/DOM.hpp>
-#   include <xercesc/dom/DOMImplementation.hpp>
-#   include <xercesc/dom/DOMImplementationLS.hpp>
 #   if (XERCES_VERSION_MAJOR == 2)
 #   include <xercesc/dom/DOMWriter.hpp>
 #   endif
-#   include <xercesc/framework/StdOutFormatTarget.hpp>
 #   include <xercesc/framework/LocalFileFormatTarget.hpp>
 #   include <xercesc/framework/LocalFileInputSource.hpp>
 #   include <xercesc/framework/MemBufFormatTarget.hpp>
 #   include <xercesc/framework/MemBufInputSource.hpp>
 #   include <xercesc/parsers/XercesDOMParser.hpp>
-#   include <xercesc/util/XMLUni.hpp>
-#   include <xercesc/util/XMLUniDefs.hpp>
-#   include <xercesc/util/XMLString.hpp>
 #   include <xercesc/sax/ErrorHandler.hpp>
 #   include <xercesc/sax/SAXParseException.hpp>
-#   include <fcntl.h>
-#   include <sys/types.h>
-#   include <sys/stat.h>
-#   ifdef FC_OS_WIN32
-#   include <io.h>
-#   endif
 #   include <sstream>
-#   include <stdio.h>
+#   include <string>
+#   include <utility>
 #endif
 
-
-#include <fcntl.h>
 #ifdef FC_OS_LINUX
 #   include <unistd.h>
 #endif
 
 #include "Parameter.h"
 #include "Parameter.inl"
-#include "Exception.h"
 #include "Console.h"
+#include "Exception.h"
 
 
 //#ifdef XERCES_HAS_CPP_NAMESPACE
@@ -327,34 +312,35 @@ void ParameterGrp::insert(const char* FileName)
 Base::Reference<ParameterGrp> ParameterGrp::GetGroup(const char* Name)
 {
     std::string cName = Name;
+    if (cName.empty())
+        throw Base::ValueError("Empty group name");
+
+    // Remove all leading slashes
+    std::string::size_type beg = cName.find_first_not_of('/');
+    if (beg > 0) {
+        cName.erase(0, beg);
+    }
+
+    // Remove all trailing slashes
+    std::string::size_type end = cName.find_last_not_of('/');
+    if (end+1 < cName.size()) {
+        cName.erase(end+1);
+    }
 
     std::string::size_type pos = cName.find('/');
 
     // is there a path separator ?
     if (pos == std::string::npos) {
-        return _GetGroup(Name);
-    }
-    else if (pos == cName.size()) {
-        // ending slash! cut it away
-        cName.erase(pos);
         return _GetGroup(cName.c_str());
     }
-    else if (pos == 0) {
-        // a leading slash is not handled (root unknown)
-        //throw FCException("ParameterGrp::GetGroup() leading slash not allowed");
-        // remove leading slash
-        cName.erase(0,1);
-        // subsequent call
-        return GetGroup(cName.c_str());
-    }
     else {
         // path, split the first path
         std::string cTemp;
         // getting the first part
-        cTemp.assign(cName,0,pos);
+        cTemp.assign(cName, 0, pos);
         // removing the first part from the original
-        cName.erase(0,pos+1);
-        //sbsequent call
+        cName.erase(0, pos+1);
+        //subsequent call
         return _GetGroup(cTemp.c_str())->GetGroup(cName.c_str());
     }
 }
@@ -362,7 +348,6 @@ Base::Reference<ParameterGrp> ParameterGrp::GetGroup(const char* Name)
 Base::Reference<ParameterGrp> ParameterGrp::_GetGroup(const char* Name)
 {
     Base::Reference<ParameterGrp> rParamGrp;
-    DOMElement *pcTemp;
 
     // already created?
     if ((rParamGrp=_GroupMap[Name]).isValid()) {
@@ -371,7 +356,7 @@ Base::Reference<ParameterGrp> ParameterGrp::_GetGroup(const char* Name)
     }
 
     // search if Group node already there
-    pcTemp = FindOrCreateElement(_pGroupNode,"FCParamGroup",Name);
+    DOMElement *pcTemp = FindOrCreateElement(_pGroupNode,"FCParamGroup",Name);
 
     // create and register handle
     rParamGrp = Base::Reference<ParameterGrp> (new ParameterGrp(pcTemp,Name));
@@ -384,16 +369,14 @@ std::vector<Base::Reference<ParameterGrp> > ParameterGrp::GetGroups(void)
 {
     Base::Reference<ParameterGrp> rParamGrp;
     std::vector<Base::Reference<ParameterGrp> >  vrParamGrp;
-    DOMElement *pcTemp; //= _pGroupNode->getFirstChild();
     std::string Name;
 
-    pcTemp = FindElement(_pGroupNode,"FCParamGroup");
-
+    DOMElement *pcTemp = FindElement(_pGroupNode,"FCParamGroup");
     while (pcTemp) {
-        Name = StrX(static_cast<DOMElement*>(pcTemp)->getAttributes()->getNamedItem(XStr("Name").unicodeForm())->getNodeValue()).c_str();
+        Name = StrX(pcTemp->getAttributes()->getNamedItem(XStr("Name").unicodeForm())->getNodeValue()).c_str();
         // already created?
         if (!(rParamGrp=_GroupMap[Name]).isValid()) {
-            rParamGrp = Base::Reference<ParameterGrp> (new ParameterGrp(static_cast<DOMElement*>(pcTemp),Name.c_str()));
+            rParamGrp = Base::Reference<ParameterGrp> (new ParameterGrp(pcTemp,Name.c_str()));
             _GroupMap[Name] = rParamGrp;
         }
         vrParamGrp.push_back( rParamGrp );
@@ -405,7 +388,7 @@ std::vector<Base::Reference<ParameterGrp> > ParameterGrp::GetGroups(void)
 }
 
 /// test if this group is empty
-bool ParameterGrp::IsEmpty(void) const
+bool ParameterGrp::IsEmpty() const
 {
     if ( _pGroupNode->getFirstChild() )
         return false;
@@ -419,7 +402,7 @@ bool ParameterGrp::HasGroup(const char* Name) const
     if ( _GroupMap.find(Name) != _GroupMap.end() )
         return true;
 
-    if ( FindElement(_pGroupNode,"FCParamGroup",Name) != 0 )
+    if ( FindElement(_pGroupNode,"FCParamGroup",Name) != nullptr )
         return true;
 
     return false;
@@ -430,7 +413,8 @@ bool ParameterGrp::GetBool(const char* Name, bool bPreset) const
     // check if Element in group
     DOMElement *pcElem = FindElement(_pGroupNode,"FCBool",Name);
     // if not return preset
-    if (!pcElem) return bPreset;
+    if (!pcElem)
+        return bPreset;
     // if yes check the value and return
     if (strcmp(StrX(pcElem->getAttribute(XStr("Value").unicodeForm())).c_str(),"1"))
         return false;
@@ -453,15 +437,14 @@ void  ParameterGrp::SetBool(const char* Name, bool bValue)
 std::vector<bool> ParameterGrp::GetBools(const char * sFilter) const
 {
     std::vector<bool>  vrValues;
-    DOMElement *pcTemp;// = _pGroupNode->getFirstChild();
     std::string Name;
 
-    pcTemp = FindElement(_pGroupNode,"FCBool");
+    DOMElement *pcTemp = FindElement(_pGroupNode,"FCBool");
     while ( pcTemp) {
-        Name = StrX(static_cast<DOMElement*>(pcTemp)->getAttributes()->getNamedItem(XStr("Name").unicodeForm())->getNodeValue()).c_str();
+        Name = StrX(pcTemp->getAttribute(XStr("Name").unicodeForm())).c_str();
         // check on filter condition
-        if (sFilter == NULL || Name.find(sFilter)!= std::string::npos) {
-            if (strcmp(StrX(static_cast<DOMElement*>(pcTemp)->getAttribute(XStr("Value").unicodeForm())).c_str(),"1"))
+        if (sFilter == nullptr || Name.find(sFilter)!= std::string::npos) {
+            if (strcmp(StrX(pcTemp->getAttribute(XStr("Value").unicodeForm())).c_str(),"1"))
                 vrValues.push_back(false);
             else
                 vrValues.push_back(true);
@@ -475,15 +458,14 @@ std::vector<bool> ParameterGrp::GetBools(const char * sFilter) const
 std::vector<std::pair<std::string,bool> > ParameterGrp::GetBoolMap(const char * sFilter) const
 {
     std::vector<std::pair<std::string,bool> >  vrValues;
-    DOMElement *pcTemp;// = _pGroupNode->getFirstChild();
     std::string Name;
 
-    pcTemp = FindElement(_pGroupNode,"FCBool");
+    DOMElement *pcTemp = FindElement(_pGroupNode,"FCBool");
     while ( pcTemp) {
-        Name = StrX(static_cast<DOMElement*>(pcTemp)->getAttributes()->getNamedItem(XStr("Name").unicodeForm())->getNodeValue()).c_str();
+        Name = StrX(pcTemp->getAttribute(XStr("Name").unicodeForm())).c_str();
         // check on filter condition
-        if (sFilter == NULL || Name.find(sFilter)!= std::string::npos) {
-            if (strcmp(StrX(static_cast<DOMElement*>(pcTemp)->getAttribute(XStr("Value").unicodeForm())).c_str(),"1"))
+        if (sFilter == nullptr || Name.find(sFilter)!= std::string::npos) {
+            if (strcmp(StrX(pcTemp->getAttribute(XStr("Value").unicodeForm())).c_str(),"1"))
                 vrValues.emplace_back(Name, false);
             else
                 vrValues.emplace_back(Name, true);
@@ -499,7 +481,8 @@ long ParameterGrp::GetInt(const char* Name, long lPreset) const
     // check if Element in group
     DOMElement *pcElem = FindElement(_pGroupNode,"FCInt",Name);
     // if not return preset
-    if (!pcElem) return lPreset;
+    if (!pcElem)
+        return lPreset;
     // if yes check the value and return
     return atol (StrX(pcElem->getAttribute(XStr("Value").unicodeForm())).c_str());
 }
@@ -521,15 +504,14 @@ void  ParameterGrp::SetInt(const char* Name, long lValue)
 std::vector<long> ParameterGrp::GetInts(const char * sFilter) const
 {
     std::vector<long>  vrValues;
-    DOMNode *pcTemp;// = _pGroupNode->getFirstChild();
     std::string Name;
 
-    pcTemp = FindElement(_pGroupNode,"FCInt") ;
+    DOMElement *pcTemp = FindElement(_pGroupNode,"FCInt") ;
     while ( pcTemp ) {
-        Name = StrX(static_cast<DOMElement*>(pcTemp)->getAttributes()->getNamedItem(XStr("Name").unicodeForm())->getNodeValue()).c_str();
+        Name = StrX(pcTemp->getAttribute(XStr("Name").unicodeForm())).c_str();
         // check on filter condition
-        if (sFilter == NULL || Name.find(sFilter)!= std::string::npos) {
-            vrValues.push_back(atol(StrX(static_cast<DOMElement*>(pcTemp)->getAttribute(XStr("Value").unicodeForm())).c_str()) );
+        if (sFilter == nullptr || Name.find(sFilter)!= std::string::npos) {
+            vrValues.push_back(atol(StrX(pcTemp->getAttribute(XStr("Value").unicodeForm())).c_str()) );
         }
         pcTemp = FindNextElement(pcTemp,"FCInt") ;
     }
@@ -540,16 +522,15 @@ std::vector<long> ParameterGrp::GetInts(const char * sFilter) const
 std::vector<std::pair<std::string,long> > ParameterGrp::GetIntMap(const char * sFilter) const
 {
     std::vector<std::pair<std::string,long> > vrValues;
-    DOMNode *pcTemp;// = _pGroupNode->getFirstChild();
     std::string Name;
 
-    pcTemp = FindElement(_pGroupNode,"FCInt") ;
+    DOMElement *pcTemp = FindElement(_pGroupNode,"FCInt") ;
     while ( pcTemp ) {
-        Name = StrX(static_cast<DOMElement*>(pcTemp)->getAttributes()->getNamedItem(XStr("Name").unicodeForm())->getNodeValue()).c_str();
+        Name = StrX(pcTemp->getAttribute(XStr("Name").unicodeForm())).c_str();
         // check on filter condition
-        if (sFilter == NULL || Name.find(sFilter)!= std::string::npos) {
+        if (sFilter == nullptr || Name.find(sFilter)!= std::string::npos) {
             vrValues.emplace_back(Name,
-                               ( atol (StrX(static_cast<DOMElement*>(pcTemp)->getAttribute(XStr("Value").unicodeForm())).c_str())));
+                               ( atol (StrX(pcTemp->getAttribute(XStr("Value").unicodeForm())).c_str())));
         }
         pcTemp = FindNextElement(pcTemp,"FCInt") ;
     }
@@ -562,9 +543,10 @@ unsigned long ParameterGrp::GetUnsigned(const char* Name, unsigned long lPreset)
     // check if Element in group
     DOMElement *pcElem = FindElement(_pGroupNode,"FCUInt",Name);
     // if not return preset
-    if (!pcElem) return lPreset;
+    if (!pcElem)
+        return lPreset;
     // if yes check the value and return
-    return strtoul (StrX(pcElem->getAttribute(XStr("Value").unicodeForm())).c_str(),0,10);
+    return strtoul (StrX(pcElem->getAttribute(XStr("Value").unicodeForm())).c_str(),nullptr,10);
 }
 
 void  ParameterGrp::SetUnsigned(const char* Name, unsigned long lValue)
@@ -584,15 +566,14 @@ void  ParameterGrp::SetUnsigned(const char* Name, unsigned long lValue)
 std::vector<unsigned long> ParameterGrp::GetUnsigneds(const char * sFilter) const
 {
     std::vector<unsigned long>  vrValues;
-    DOMNode *pcTemp;// = _pGroupNode->getFirstChild();
     std::string Name;
 
-    pcTemp = FindElement(_pGroupNode,"FCUInt");
+    DOMElement *pcTemp = FindElement(_pGroupNode,"FCUInt");
     while ( pcTemp ) {
-        Name = StrX(static_cast<DOMElement*>(pcTemp)->getAttributes()->getNamedItem(XStr("Name").unicodeForm())->getNodeValue()).c_str();
+        Name = StrX(pcTemp->getAttribute(XStr("Name").unicodeForm())).c_str();
         // check on filter condition
-        if (sFilter == NULL || Name.find(sFilter)!= std::string::npos) {
-            vrValues.push_back( strtoul (StrX(static_cast<DOMElement*>(pcTemp)->getAttribute(XStr("Value").unicodeForm())).c_str(),0,10) );
+        if (sFilter == nullptr || Name.find(sFilter)!= std::string::npos) {
+            vrValues.push_back( strtoul (StrX(pcTemp->getAttribute(XStr("Value").unicodeForm())).c_str(),nullptr,10) );
         }
         pcTemp = FindNextElement(pcTemp,"FCUInt") ;
     }
@@ -603,16 +584,15 @@ std::vector<unsigned long> ParameterGrp::GetUnsigneds(const char * sFilter) cons
 std::vector<std::pair<std::string,unsigned long> > ParameterGrp::GetUnsignedMap(const char * sFilter) const
 {
     std::vector<std::pair<std::string,unsigned long> > vrValues;
-    DOMNode *pcTemp;// = _pGroupNode->getFirstChild();
     std::string Name;
 
-    pcTemp = FindElement(_pGroupNode,"FCUInt");
+    DOMElement *pcTemp = FindElement(_pGroupNode,"FCUInt");
     while ( pcTemp ) {
-        Name = StrX(static_cast<DOMElement*>(pcTemp)->getAttributes()->getNamedItem(XStr("Name").unicodeForm())->getNodeValue()).c_str();
+        Name = StrX(pcTemp->getAttribute(XStr("Name").unicodeForm())).c_str();
         // check on filter condition
-        if (sFilter == NULL || Name.find(sFilter)!= std::string::npos) {
+        if (sFilter == nullptr || Name.find(sFilter)!= std::string::npos) {
             vrValues.emplace_back(Name,
-                               ( strtoul (StrX(static_cast<DOMElement*>(pcTemp)->getAttribute(XStr("Value").unicodeForm())).c_str(),0,10) ));
+                               ( strtoul (StrX(pcTemp->getAttribute(XStr("Value").unicodeForm())).c_str(),nullptr,10) ));
         }
         pcTemp = FindNextElement(pcTemp,"FCUInt");
     }
@@ -625,7 +605,8 @@ double ParameterGrp::GetFloat(const char* Name, double dPreset) const
     // check if Element in group
     DOMElement *pcElem = FindElement(_pGroupNode,"FCFloat",Name);
     // if not return preset
-    if (!pcElem) return dPreset;
+    if (!pcElem)
+        return dPreset;
     // if yes check the value and return
     return atof (StrX(pcElem->getAttribute(XStr("Value").unicodeForm())).c_str());
 }
@@ -647,15 +628,14 @@ void  ParameterGrp::SetFloat(const char* Name, double dValue)
 std::vector<double> ParameterGrp::GetFloats(const char * sFilter) const
 {
     std::vector<double>  vrValues;
-    DOMElement *pcTemp ;//= _pGroupNode->getFirstChild();
     std::string Name;
 
-    pcTemp = FindElement(_pGroupNode,"FCFloat") ;
+    DOMElement *pcTemp = FindElement(_pGroupNode,"FCFloat") ;
     while ( pcTemp ) {
-        Name = StrX(static_cast<DOMElement*>(pcTemp)->getAttributes()->getNamedItem(XStr("Name").unicodeForm())->getNodeValue()).c_str();
+        Name = StrX(pcTemp->getAttribute(XStr("Name").unicodeForm())).c_str();
         // check on filter condition
-        if (sFilter == NULL || Name.find(sFilter)!= std::string::npos) {
-            vrValues.push_back( atof (StrX(static_cast<DOMElement*>(pcTemp)->getAttribute(XStr("Value").unicodeForm())).c_str()) );
+        if (sFilter == nullptr || Name.find(sFilter)!= std::string::npos) {
+            vrValues.push_back( atof (StrX(pcTemp->getAttribute(XStr("Value").unicodeForm())).c_str()) );
         }
         pcTemp = FindNextElement(pcTemp,"FCFloat");
     }
@@ -666,16 +646,15 @@ std::vector<double> ParameterGrp::GetFloats(const char * sFilter) const
 std::vector<std::pair<std::string,double> > ParameterGrp::GetFloatMap(const char * sFilter) const
 {
     std::vector<std::pair<std::string,double> > vrValues;
-    DOMElement *pcTemp ;//= _pGroupNode->getFirstChild();
     std::string Name;
 
-    pcTemp = FindElement(_pGroupNode,"FCFloat") ;
+    DOMElement *pcTemp = FindElement(_pGroupNode,"FCFloat") ;
     while ( pcTemp ) {
-        Name = StrX(static_cast<DOMElement*>(pcTemp)->getAttributes()->getNamedItem(XStr("Name").unicodeForm())->getNodeValue()).c_str();
+        Name = StrX(pcTemp->getAttribute(XStr("Name").unicodeForm())).c_str();
         // check on filter condition
-        if (sFilter == NULL || Name.find(sFilter)!= std::string::npos) {
+        if (sFilter == nullptr || Name.find(sFilter)!= std::string::npos) {
             vrValues.emplace_back(Name,
-                               ( atof (StrX(static_cast<DOMElement*>(pcTemp)->getAttribute(XStr("Value").unicodeForm())).c_str())));
+                               ( atof (StrX(pcTemp->getAttribute(XStr("Value").unicodeForm())).c_str())));
         }
         pcTemp = FindNextElement(pcTemp,"FCFloat");
     }
@@ -683,8 +662,6 @@ std::vector<std::pair<std::string,double> > ParameterGrp::GetFloatMap(const char
     return vrValues;
 }
 
-
-
 void  ParameterGrp::SetBlob(const char* /*Name*/, void* /*pValue*/, long /*lLength*/)
 {
     // not implemented so far
@@ -723,7 +700,7 @@ std::string ParameterGrp::GetASCII(const char* Name, const char * pPreset) const
     DOMElement *pcElem = FindElement(_pGroupNode,"FCText",Name);
     // if not return preset
     if (!pcElem) {
-        if (pPreset==0)
+        if (pPreset==nullptr)
             return std::string("");
         else
             return std::string(pPreset);
@@ -732,28 +709,26 @@ std::string ParameterGrp::GetASCII(const char* Name, const char * pPreset) const
     DOMNode *pcElem2 = pcElem->getFirstChild();
     if (pcElem2)
         return std::string(StrXUTF8(pcElem2->getNodeValue()).c_str());
-    else if (pPreset==0)
-        return std::string("");
-
     else
-        return std::string(pPreset);
+        return std::string("");
 }
 
 std::vector<std::string> ParameterGrp::GetASCIIs(const char * sFilter) const
 {
     std::vector<std::string>  vrValues;
-    DOMElement *pcTemp;// = _pGroupNode->getFirstChild();
     std::string Name;
 
-    pcTemp = FindElement(_pGroupNode,"FCText");
+    DOMElement *pcTemp = FindElement(_pGroupNode,"FCText");
     while ( pcTemp  ) {
-        Name = StrXUTF8(static_cast<DOMElement*>(pcTemp)->getAttributes()->getNamedItem(XStr("Name").unicodeForm())->getNodeValue()).c_str();
+        Name = StrXUTF8(pcTemp->getAttribute(XStr("Name").unicodeForm())).c_str();
         // check on filter condition
-        if (sFilter == NULL || Name.find(sFilter)!= std::string::npos) {
+        if (sFilter == nullptr || Name.find(sFilter)!= std::string::npos) {
             // retrieve the text element
             DOMNode *pcElem2 = pcTemp->getFirstChild();
             if (pcElem2)
                 vrValues.emplace_back(StrXUTF8(pcElem2->getNodeValue()).c_str() );
+            else
+                vrValues.emplace_back(""); // For a string, an empty value is possible and allowed
         }
         pcTemp = FindNextElement(pcTemp,"FCText");
     }
@@ -764,18 +739,19 @@ std::vector<std::string> ParameterGrp::GetASCIIs(const char * sFilter) const
 std::vector<std::pair<std::string,std::string> > ParameterGrp::GetASCIIMap(const char * sFilter) const
 {
     std::vector<std::pair<std::string,std::string> >  vrValues;
-    DOMElement *pcTemp;// = _pGroupNode->getFirstChild();
     std::string Name;
 
-    pcTemp = FindElement(_pGroupNode,"FCText");
+    DOMElement *pcTemp = FindElement(_pGroupNode,"FCText");
     while ( pcTemp) {
-        Name = StrXUTF8(static_cast<DOMElement*>(pcTemp)->getAttributes()->getNamedItem(XStr("Name").unicodeForm())->getNodeValue()).c_str();
+        Name = StrXUTF8(pcTemp->getAttribute(XStr("Name").unicodeForm())).c_str();
         // check on filter condition
-        if (sFilter == NULL || Name.find(sFilter)!= std::string::npos) {
+        if (sFilter == nullptr || Name.find(sFilter)!= std::string::npos) {
             // retrieve the text element
             DOMNode *pcElem2 = pcTemp->getFirstChild();
             if (pcElem2)
                 vrValues.emplace_back(Name, std::string(StrXUTF8(pcElem2->getNodeValue()).c_str()));
+            else
+                vrValues.emplace_back(Name, std::string()); // For a string, an empty value is possible and allowed
         }
         pcTemp = FindNextElement(pcTemp,"FCText");
     }
@@ -954,7 +930,7 @@ void ParameterGrp::Clear(void)
     }
 
     // searching all non-group nodes
-    for (DOMNode *child = _pGroupNode->getFirstChild(); child != 0;  child = child->getNextSibling()) {
+    for (DOMNode *child = _pGroupNode->getFirstChild(); child != nullptr;  child = child->getNextSibling()) {
         if (XMLString::compareString(child->getNodeName(), XStr("FCParamGroup").unicodeForm()) != 0)
             vecNodes.push_back(child);
     }
@@ -976,7 +952,7 @@ bool ParameterGrp::ShouldRemove() const
 {
     if (this->getRefCount() > 1)
         return false;
-    for (auto it : _GroupMap) {
+    for (const auto& it : _GroupMap) {
         bool ok = it.second->ShouldRemove();
         if (!ok)
             return false;
@@ -991,13 +967,14 @@ XERCES_CPP_NAMESPACE_QUALIFIER DOMElement *ParameterGrp::FindElement(XERCES_CPP_
         Base::Console().Warning("FindElement: %s cannot have the element %s of type %s\n", StrX(Start->getNodeName()).c_str(), Name, Type);
         return nullptr;
     }
-    for (DOMNode *clChild = Start->getFirstChild(); clChild != 0;  clChild = clChild->getNextSibling()) {
+    for (DOMNode *clChild = Start->getFirstChild(); clChild != nullptr;  clChild = clChild->getNextSibling()) {
         if (clChild->getNodeType() == DOMNode::ELEMENT_NODE) {
             // the right node Type
             if (!strcmp(Type,StrX(clChild->getNodeName()).c_str())) {
                 if (clChild->getAttributes()->getLength() > 0) {
                     if (Name) {
-                        if (!strcmp(Name,StrX(clChild->getAttributes()->getNamedItem(XStr("Name").unicodeForm())->getNodeValue()).c_str()))
+                        DOMNode* attr = FindAttribute(clChild, "Name");
+                        if (attr && !strcmp(Name,StrX(attr->getNodeValue()).c_str()))
                             return static_cast<DOMElement*>(clChild);
                     }
                     else
@@ -1007,7 +984,7 @@ XERCES_CPP_NAMESPACE_QUALIFIER DOMElement *ParameterGrp::FindElement(XERCES_CPP_
             }
         }
     }
-    return NULL;
+    return nullptr;
 }
 
 XERCES_CPP_NAMESPACE_QUALIFIER DOMElement *ParameterGrp::FindNextElement(XERCES_CPP_NAMESPACE_QUALIFIER DOMNode *Prev, const char* Type) const
@@ -1016,7 +993,7 @@ XERCES_CPP_NAMESPACE_QUALIFIER DOMElement *ParameterGrp::FindNextElement(XERCES_
     if (!clChild)
         return nullptr;
 
-    while ((clChild = clChild->getNextSibling())!=0) {
+    while ((clChild = clChild->getNextSibling()) != nullptr) {
         if (clChild->getNodeType() == DOMNode::ELEMENT_NODE) {
             // the right node Type
             if (!strcmp(Type,StrX(clChild->getNodeName()).c_str())) {
@@ -1024,7 +1001,7 @@ XERCES_CPP_NAMESPACE_QUALIFIER DOMElement *ParameterGrp::FindNextElement(XERCES_
             }
         }
     }
-    return NULL;
+    return nullptr;
 }
 
 XERCES_CPP_NAMESPACE_QUALIFIER DOMElement *ParameterGrp::FindOrCreateElement(XERCES_CPP_NAMESPACE_QUALIFIER DOMElement *Start, const char* Type, const char* Name) const
@@ -1049,6 +1026,15 @@ XERCES_CPP_NAMESPACE_QUALIFIER DOMElement *ParameterGrp::FindOrCreateElement(XER
     return pcElem;
 }
 
+XERCES_CPP_NAMESPACE_QUALIFIER DOMNode *ParameterGrp::FindAttribute(XERCES_CPP_NAMESPACE_QUALIFIER DOMNode *Node, const char* Name) const
+{
+    DOMNamedNodeMap* attr = Node->getAttributes();
+    if (attr) {
+        return attr->getNamedItem(XStr(Name).unicodeForm());
+    }
+    return nullptr;
+}
+
 void ParameterGrp::NotifyAll()
 {
     // get all ints and notify
@@ -1118,7 +1104,7 @@ static XercesDOMParser::ValSchemes    gValScheme       = XercesDOMParser::Val_Au
 /** Default construction
   */
 ParameterManager::ParameterManager()
-  : ParameterGrp(), _pDocument(0), paramSerializer(0)
+  : ParameterGrp(), _pDocument(nullptr), paramSerializer(nullptr)
 {
     // initialize the XML system
     Init();
@@ -1169,8 +1155,8 @@ ParameterManager::ParameterManager()
     gSchemaFullChecking    = false;
     gDoCreate              = true;
 
-    gOutputEncoding        = 0;
-    gMyEOLSequence         = 0;
+    gOutputEncoding        = nullptr;
+    gMyEOLSequence         = nullptr;
 
     gSplitCdataSections    = true;
     gDiscardDefaultContent = true;
@@ -1187,7 +1173,7 @@ ParameterManager::~ParameterManager()
     delete paramSerializer;
 }
 
-void ParameterManager::Init(void)
+void ParameterManager::Init()
 {
     static bool Init = false;
     if (!Init) {
@@ -1211,10 +1197,9 @@ void ParameterManager::Init(void)
     }
 }
 
-void ParameterManager::Terminate(void)
+void ParameterManager::Terminate()
 {
-    StrXUTF8::terminate();
-    XUTF8Str::terminate();
+    XMLTools::terminate();
     XMLPlatformUtils::Terminate();
 }
 
@@ -1230,7 +1215,7 @@ void ParameterManager::SetSerializer(ParameterSerializer* ps)
 
 bool ParameterManager::HasSerializer() const
 {
-    return (paramSerializer != 0);
+    return (paramSerializer != nullptr);
 }
 
 int ParameterManager::LoadDocument()
@@ -1518,20 +1503,20 @@ void  ParameterManager::SaveDocument(XMLFormatTarget* pFormatTarget) const
 #endif
 }
 
-void  ParameterManager::CreateDocument(void)
+void  ParameterManager::CreateDocument()
 {
     // creating a document from screatch
     DOMImplementation* impl =  DOMImplementationRegistry::getDOMImplementation(XStr("Core").unicodeForm());
     delete _pDocument;
     _pDocument = impl->createDocument(
-                     0,                                          // root element namespace URI.
+                     nullptr,                                    // root element namespace URI.
                      XStr("FCParameters").unicodeForm(),         // root element name
-                     0);                                         // document type object (DTD).
+                     nullptr);                                   // document type object (DTD).
 
     // creating the node for the root group
     DOMElement* rootElem = _pDocument->getDocumentElement();
     _pGroupNode = _pDocument->createElement(XStr("FCParamGroup").unicodeForm());
-    static_cast<DOMElement*>(_pGroupNode)->setAttribute(XStr("Name").unicodeForm(), XStr("Root").unicodeForm());
+    _pGroupNode->setAttribute(XStr("Name").unicodeForm(), XStr("Root").unicodeForm());
     rootElem->appendChild(_pGroupNode);
 }
 
