@@ -23,7 +23,6 @@
 
 #include "PreCompiled.h"
 
-#include "Placement.h"
 #include "GeometryPyCXX.h"
 
 // inclusion of the generated files (generated out of PlacementPy.xml)
@@ -38,10 +37,10 @@
 using namespace Base;
 
 // returns a string which represents the object e.g. when printed in python
-std::string PlacementPy::representation(void) const
+std::string PlacementPy::representation() const
 {
     double A,B,C;
-    PlacementPy::PointerType ptr = reinterpret_cast<PlacementPy::PointerType>(_pcTwinPointer);
+    PlacementPy::PointerType ptr = getPlacementPtr();
     std::stringstream str;
     ptr->getRotation().getYawPitchRoll(A,B,C);
 
@@ -115,7 +114,7 @@ int PlacementPy::PyInit(PyObject* args, PyObject* /*kwd*/)
         return 0;
     }
 
-    PyErr_SetString(Base::BaseExceptionFreeCADError, "empty parameter list, matrix or placement expected");
+    PyErr_SetString(PyExc_TypeError, "empty parameter list, matrix or placement expected");
     return -1;
 }
 
@@ -126,11 +125,11 @@ PyObject* PlacementPy::richCompare(PyObject *v, PyObject *w, int op)
         Base::Placement p1 = *static_cast<PlacementPy*>(v)->getPlacementPtr();
         Base::Placement p2 = *static_cast<PlacementPy*>(w)->getPlacementPtr();
 
-        PyObject *res=0;
+        PyObject *res=nullptr;
         if (op != Py_EQ && op != Py_NE) {
             PyErr_SetString(PyExc_TypeError,
             "no ordering relation is defined for Placement");
-            return 0;
+            return nullptr;
         }
         else if (op == Py_EQ) {
             res = (p1 == p2) ? Py_True : Py_False;
@@ -154,7 +153,7 @@ PyObject* PlacementPy::move(PyObject * args)
 {
     PyObject *vec;
     if (!PyArg_ParseTuple(args, "O!", &(VectorPy::Type), &vec))
-        return NULL;
+        return nullptr;
     getPlacementPtr()->move(static_cast<VectorPy*>(vec)->value());
     Py_Return;
 }
@@ -168,7 +167,7 @@ PyObject* PlacementPy::rotate(PyObject *args) {
     PyObject *obj1, *obj2;
     double angle;
     if (!PyArg_ParseTuple(args, "OOd", &obj1, &obj2, &angle))
-        return NULL;
+        return nullptr;
 
     try {
         Py::Sequence p1(obj1), p2(obj2);
@@ -183,7 +182,7 @@ PyObject* PlacementPy::rotate(PyObject *args) {
         Py_Return;
     }
     catch (const Py::Exception&) {
-        return NULL;
+        return nullptr;
     }
 }
 
@@ -191,7 +190,7 @@ PyObject* PlacementPy::multiply(PyObject * args)
 {
     PyObject *plm;
     if (!PyArg_ParseTuple(args, "O!", &(PlacementPy::Type), &plm))
-        return NULL;
+        return nullptr;
     Placement mult = (*getPlacementPtr()) * (*static_cast<PlacementPy*>(plm)->getPlacementPtr());
     return new PlacementPy(new Placement(mult));
 }
@@ -200,7 +199,7 @@ PyObject* PlacementPy::multVec(PyObject * args)
 {
     PyObject *vec;
     if (!PyArg_ParseTuple(args, "O!", &(VectorPy::Type), &vec))
-        return NULL;
+        return nullptr;
     Base::Vector3d pnt(static_cast<VectorPy*>(vec)->value());
     getPlacementPtr()->multVec(pnt, pnt);
     return new VectorPy(new Vector3d(pnt));
@@ -209,14 +208,14 @@ PyObject* PlacementPy::multVec(PyObject * args)
 PyObject* PlacementPy::copy(PyObject * args)
 {
     if (!PyArg_ParseTuple(args, ""))
-        return NULL;
+        return nullptr;
     return new PlacementPy(new Placement(*getPlacementPtr()));
 }
 
 PyObject* PlacementPy::toMatrix(PyObject * args)
 {
     if (!PyArg_ParseTuple(args, ""))
-        return NULL;
+        return nullptr;
     Base::Matrix4D mat = getPlacementPtr()->toMatrix();
     return new MatrixPy(new Matrix4D(mat));
 }
@@ -224,7 +223,7 @@ PyObject* PlacementPy::toMatrix(PyObject * args)
 PyObject* PlacementPy::inverse(PyObject * args)
 {
     if (!PyArg_ParseTuple(args, ""))
-        return NULL;
+        return nullptr;
     Base::Placement p = getPlacementPtr()->inverse();
     return new PlacementPy(new Placement(p));
 }
@@ -266,12 +265,12 @@ PyObject* PlacementPy::slerp(PyObject* args)
 PyObject* PlacementPy::isIdentity(PyObject *args)
 {
     if (!PyArg_ParseTuple(args, ""))
-        return NULL;
+        return nullptr;
     bool none = getPlacementPtr()->isIdentity();
     return Py_BuildValue("O", (none ? Py_True : Py_False));
 }
 
-Py::Object PlacementPy::getBase(void) const
+Py::Object PlacementPy::getBase() const
 {
     return Py::Vector(getPlacementPtr()->getPosition());
 }
@@ -281,7 +280,7 @@ void PlacementPy::setBase(Py::Object arg)
     getPlacementPtr()->setPosition(Py::Vector(arg).toVector());
 }
 
-Py::Object PlacementPy::getRotation(void) const
+Py::Object PlacementPy::getRotation() const
 {
     return Py::Rotation(getPlacementPtr()->getRotation());
 }
@@ -290,16 +289,16 @@ void PlacementPy::setRotation(Py::Object arg)
 {
     Py::Rotation rot;
     if (rot.accepts(arg.ptr())) {
-        getPlacementPtr()->setRotation((Base::Rotation)Py::Rotation(arg));
+        getPlacementPtr()->setRotation(static_cast<Base::Rotation>(Py::Rotation(arg)));
         return;
     }
     Py::Tuple tuple;
     if (tuple.accepts(arg.ptr())) {
         tuple = arg;
-        getPlacementPtr()->setRotation(Base::Rotation((double)Py::Float(tuple[0]),
-                                                      (double)Py::Float(tuple[1]),
-                                                      (double)Py::Float(tuple[2]),
-                                                      (double)Py::Float(tuple[3])
+        getPlacementPtr()->setRotation(Base::Rotation(static_cast<double>(Py::Float(tuple[0])),
+                                                      static_cast<double>(Py::Float(tuple[1])),
+                                                      static_cast<double>(Py::Float(tuple[2])),
+                                                      static_cast<double>(Py::Float(tuple[3]))
                                                      ));
         return;
     }
@@ -307,7 +306,7 @@ void PlacementPy::setRotation(Py::Object arg)
     throw Py::TypeError("either Rotation or tuple of four floats expected");
 }
 
-Py::Object PlacementPy::getMatrix(void) const
+Py::Object PlacementPy::getMatrix() const
 {
     return Py::Matrix(getPlacementPtr()->toMatrix());
 }
@@ -326,16 +325,12 @@ PyObject *PlacementPy::getCustomAttributes(const char* attr) const
     // for backward compatibility
     if (strcmp(attr, "isNull") == 0) {
         PyObject *w, *res;
-#if PY_MAJOR_VERSION >= 3
         w = PyUnicode_InternFromString("isIdentity");
-#else
-        w = PyString_InternFromString("isIdentity");
-#endif
         res = PyObject_GenericGetAttr(const_cast<PlacementPy *>(this), w);
         Py_XDECREF(w);
         return res;
     }
-    return 0;
+    return nullptr;
 }
 
 int PlacementPy::setCustomAttributes(const char* /*attr*/, PyObject* /*obj*/)
@@ -371,7 +366,7 @@ PyObject* PlacementPy::number_multiply_handler(PyObject *self, PyObject *other)
     }
 
     PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
+    return nullptr;
 }
 
 PyObject * PlacementPy::number_power_handler (PyObject* self, PyObject* other, PyObject* arg)
@@ -389,7 +384,7 @@ PyObject * PlacementPy::number_power_handler (PyObject* self, PyObject* other, P
         || arg != Py_None)
     {
         PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-        return 0;
+        return nullptr;
     }
 
     Placement a = static_cast<PlacementPy*>(self)->value();
@@ -399,49 +394,49 @@ PyObject * PlacementPy::number_power_handler (PyObject* self, PyObject* other, P
 PyObject* PlacementPy::number_add_handler(PyObject * /*self*/, PyObject * /*other*/)
 {
     PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
+    return nullptr;
 }
 
 PyObject* PlacementPy::number_subtract_handler(PyObject * /*self*/, PyObject * /*other*/)
 {
     PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
+    return nullptr;
 }
 
 PyObject * PlacementPy::number_divide_handler (PyObject* /*self*/, PyObject* /*other*/)
 {
     PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
+    return nullptr;
 }
 
 PyObject * PlacementPy::number_remainder_handler (PyObject* /*self*/, PyObject* /*other*/)
 {
     PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
+    return nullptr;
 }
 
 PyObject * PlacementPy::number_divmod_handler (PyObject* /*self*/, PyObject* /*other*/)
 {
     PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
+    return nullptr;
 }
 
 PyObject * PlacementPy::number_negative_handler (PyObject* /*self*/)
 {
     PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
+    return nullptr;
 }
 
 PyObject * PlacementPy::number_positive_handler (PyObject* /*self*/)
 {
     PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
+    return nullptr;
 }
 
 PyObject * PlacementPy::number_absolute_handler (PyObject* /*self*/)
 {
     PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
+    return nullptr;
 }
 
 int PlacementPy::number_nonzero_handler (PyObject* /*self*/)
@@ -452,76 +447,48 @@ int PlacementPy::number_nonzero_handler (PyObject* /*self*/)
 PyObject * PlacementPy::number_invert_handler (PyObject* /*self*/)
 {
     PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
+    return nullptr;
 }
 
 PyObject * PlacementPy::number_lshift_handler (PyObject* /*self*/, PyObject* /*other*/)
 {
     PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
+    return nullptr;
 }
 
 PyObject * PlacementPy::number_rshift_handler (PyObject* /*self*/, PyObject* /*other*/)
 {
     PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
+    return nullptr;
 }
 
 PyObject * PlacementPy::number_and_handler (PyObject* /*self*/, PyObject* /*other*/)
 {
     PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
+    return nullptr;
 }
 
 PyObject * PlacementPy::number_xor_handler (PyObject* /*self*/, PyObject* /*other*/)
 {
     PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
+    return nullptr;
 }
 
 PyObject * PlacementPy::number_or_handler (PyObject* /*self*/, PyObject* /*other*/)
 {
     PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
+    return nullptr;
 }
 
-#if PY_MAJOR_VERSION < 3
-int PlacementPy::number_coerce_handler (PyObject ** /*self*/, PyObject ** /*other*/)
-{
-    return 1;
-}
-#endif
-
 PyObject * PlacementPy::number_int_handler (PyObject * /*self*/)
 {
     PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
+    return nullptr;
 }
 
-#if PY_MAJOR_VERSION < 3
-PyObject * PlacementPy::number_long_handler (PyObject * /*self*/)
-{
-    PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
-}
-#endif
-
 PyObject * PlacementPy::number_float_handler (PyObject * /*self*/)
 {
     PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
+    return nullptr;
 }
 
-#if PY_MAJOR_VERSION < 3
-PyObject * PlacementPy::number_oct_handler (PyObject * /*self*/)
-{
-    PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
-}
-
-PyObject * PlacementPy::number_hex_handler (PyObject * /*self*/)
-{
-    PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
-}
-#endif
