@@ -24,39 +24,31 @@
 #include "PreCompiled.h"
 
 #ifndef _PreComp_
-# include <xercesc/sax/SAXParseException.hpp>
-# include <xercesc/sax/SAXException.hpp>
 # include <xercesc/sax2/XMLReaderFactory.hpp>
-# include <xercesc/sax2/SAX2XMLReader.hpp>
 #endif
 
 #include <locale>
 
-/// Here the FreeCAD includes sorted by Base,App,Gui......
 #include "Reader.h"
 #include "Base64.h"
-#include "Exception.h"
-#include "Persistence.h"
-#include "InputSource.h"
 #include "Console.h"
+#include "InputSource.h"
+#include "Persistence.h"
 #include "Sequencer.h"
+#include "Stream.h"
+#include "XMLTools.h"
 
 #ifdef _MSC_VER
 #include <zipios++/zipios-config.h>
 #endif
-#include <zipios++/zipfile.h>
 #include <zipios++/zipinputstream.h>
-#include <zipios++/zipoutputstream.h>
-#include <zipios++/meta-iostreams.h>
 
-#include "XMLTools.h"
 
 XERCES_CPP_NAMESPACE_USE
 
 using namespace std;
 
 
-
 // ---------------------------------------------------------------------------
 //  Base::XMLReader: Constructors and Destructor
 // ---------------------------------------------------------------------------
@@ -115,14 +107,14 @@ Base::XMLReader::~XMLReader()
     delete parser;
 }
 
-const char* Base::XMLReader::localName(void) const
+const char* Base::XMLReader::localName() const
 {
     return LocalName.c_str();
 }
 
-unsigned int Base::XMLReader::getAttributeCount(void) const
+unsigned int Base::XMLReader::getAttributeCount() const
 {
-    return (unsigned int)AttrMap.size();
+    return static_cast<unsigned int>(AttrMap.size());
 }
 
 long Base::XMLReader::getAttributeAsInteger(const char* AttrName) const
@@ -145,7 +137,7 @@ unsigned long Base::XMLReader::getAttributeAsUnsigned(const char* AttrName) cons
     AttrMapType::const_iterator pos = AttrMap.find(AttrName);
 
     if (pos != AttrMap.end()) {
-        return strtoul(pos->second.c_str(),0,10);
+        return strtoul(pos->second.c_str(),nullptr,10);
     }
     else {
         // wrong name, use hasAttribute if not sure!
@@ -190,7 +182,7 @@ bool Base::XMLReader::hasAttribute (const char* AttrName) const
     return AttrMap.find(AttrName) != AttrMap.end();
 }
 
-bool Base::XMLReader::read(void)
+bool Base::XMLReader::read()
 {
     ReadType = None;
 
@@ -287,7 +279,7 @@ void Base::XMLReader::readEndElement(const char* ElementName, int level)
                         || (level>=0 && level!=Level))));
 }
 
-void Base::XMLReader::readCharacters(void)
+void Base::XMLReader::readCharacters()
 {
 }
 
@@ -527,12 +519,12 @@ void Base::XMLReader::resetErrors()
 
 bool Base::XMLReader::testStatus(ReaderStatus pos) const
 {
-    return StatusBits.test((size_t)pos);
+    return StatusBits.test(static_cast<size_t>(pos));
 }
 
 void Base::XMLReader::setStatus(ReaderStatus pos, bool on)
 {
-    StatusBits.set((size_t)pos, on);
+    StatusBits.set(static_cast<size_t>(pos), on);
 }
 
 void Base::XMLReader::setPartialRestore(bool on)
@@ -543,20 +535,20 @@ void Base::XMLReader::setPartialRestore(bool on)
     setStatus(PartialRestoreInObject, on);
 }
 
-void Base::XMLReader::clearPartialRestoreDocumentObject(void)
+void Base::XMLReader::clearPartialRestoreDocumentObject()
 {
     setStatus(PartialRestoreInDocumentObject, false);
     setStatus(PartialRestoreInProperty, false);
     setStatus(PartialRestoreInObject, false);
 }
 
-void Base::XMLReader::clearPartialRestoreProperty(void)
+void Base::XMLReader::clearPartialRestoreProperty()
 {
     setStatus(PartialRestoreInProperty, false);
     setStatus(PartialRestoreInObject, false);
 }
 
-void Base::XMLReader::clearPartialRestoreObject(void)
+void Base::XMLReader::clearPartialRestoreObject()
 {
     setStatus(PartialRestoreInObject, false);
 }
@@ -568,10 +560,6 @@ Base::Reader::Reader(std::istream& str, const std::string& name, int version)
 {
 }
 
-Base::Reader::~Reader()
-{
-}
-
 std::string Base::Reader::getFileName() const
 {
     return this->_name;
