@@ -22,14 +22,13 @@
 
 
 #include "PreCompiled.h"
-#ifndef _PreComp_
-# include <cmath>
-# include <climits>
-#endif
+
+#include <boost/algorithm/string/predicate.hpp>
+#include "Base/Exception.h"
 
 #include "Rotation.h"
 #include "Matrix.h"
-#include "Base/Exception.h"
+
 
 using namespace Base;
 
@@ -103,7 +102,7 @@ void Rotation::operator = (const Rotation& rot)
     this->_angle   = rot._angle;
 }
 
-const double * Rotation::getValue(void) const
+const double * Rotation::getValue() const
 {
     return &this->quat[0];
 }
@@ -173,10 +172,14 @@ void Rotation::getValue(Matrix4D & matrix) const
 {
     // Taken from <http://de.wikipedia.org/wiki/Quaternionen>
     //
-    const double x = this->quat[0];
-    const double y = this->quat[1];
-    const double z = this->quat[2];
-    const double w = this->quat[3];
+    const double l = sqrt(this->quat[0] * this->quat[0] +
+                          this->quat[1] * this->quat[1] +
+                          this->quat[2] * this->quat[2] +
+                          this->quat[3] * this->quat[3]);
+    const double x = this->quat[0] / l;
+    const double y = this->quat[1] / l;
+    const double z = this->quat[2] / l;
+    const double w = this->quat[3] / l;
 
     matrix[0][0] = 1.0-2.0*(y*y+z*z);
     matrix[0][1] = 2.0*(x*y-z*w);
@@ -314,7 +317,7 @@ void Rotation::normalize()
     }
 }
 
-Rotation & Rotation::invert(void)
+Rotation & Rotation::invert()
 {
     this->quat[0] = -this->quat[0];
     this->quat[1] = -this->quat[1];
@@ -327,7 +330,7 @@ Rotation & Rotation::invert(void)
     return *this;
 }
 
-Rotation Rotation::inverse(void) const
+Rotation Rotation::inverse() const
 {
     Rotation rot;
     rot.quat[0] = -this->quat[0];
@@ -338,6 +341,7 @@ Rotation Rotation::inverse(void) const
     rot._axis[0] = -this->_axis[0];
     rot._axis[1] = -this->_axis[1];
     rot._axis[2] = -this->_axis[2];
+    rot._angle = this->_angle;
     return rot;
 }
 
@@ -365,14 +369,14 @@ Rotation Rotation::operator*(const Rotation & q) const
 
 bool Rotation::operator==(const Rotation & q) const
 {
-     if ((this->quat[0] == q.quat[0] &&
-          this->quat[1] == q.quat[1] &&
-          this->quat[2] == q.quat[2] &&
-          this->quat[3] == q.quat[3]) ||
-         (this->quat[0] == -q.quat[0] &&
-          this->quat[1] == -q.quat[1] &&
-          this->quat[2] == -q.quat[2] &&
-          this->quat[3] == -q.quat[3]))
+    if ((this->quat[0] == q.quat[0] &&
+         this->quat[1] == q.quat[1] &&
+         this->quat[2] == q.quat[2] &&
+         this->quat[3] == q.quat[3]) ||
+        (this->quat[0] == -q.quat[0] &&
+         this->quat[1] == -q.quat[1] &&
+         this->quat[2] == -q.quat[2] &&
+         this->quat[3] == -q.quat[3]))
         return true;
     return false;
 }
@@ -480,7 +484,7 @@ Rotation Rotation::slerp(const Rotation & q0, const Rotation & q1, double t)
     return Rotation(x, y, z, w);
 }
 
-Rotation Rotation::identity(void)
+Rotation Rotation::identity()
 {
     return Rotation(0.0, 0.0, 0.0, 1.0);
 }
@@ -516,7 +520,7 @@ Rotation Rotation::makeRotationByAxes(Vector3d xdir, Vector3d ydir, Vector3d zdi
 
 
     auto dropPriority = [&order](int index){
-        char tmp;
+        int tmp;
         if (index == 0){
             tmp = order[0];
             order[0] = order[1];
@@ -532,7 +536,7 @@ Rotation Rotation::makeRotationByAxes(Vector3d xdir, Vector3d ydir, Vector3d zdi
     //pick up the strict direction
     Vector3d mainDir;
     for (int i = 0; i < 3; ++i){
-        mainDir = *(dirs[order[0]]);
+        mainDir = *(dirs[size_t(order[0])]);
         if (mainDir.Length() > tol)
             break;
         else
@@ -545,7 +549,7 @@ Rotation Rotation::makeRotationByAxes(Vector3d xdir, Vector3d ydir, Vector3d zdi
     //pick up the 2nd priority direction, "hint" direction.
     Vector3d hintDir;
     for (int i = 0; i < 2; ++i){
-        hintDir = *(dirs[order[1]]);
+        hintDir = *(dirs[size_t(order[1])]);
         if ((hintDir.Cross(mainDir)).Length() > tol)
             break;
         else
@@ -672,17 +676,17 @@ void Rotation::getYawPitchRoll(double& y, double& p, double& r) const
     double qd2 = 2.0*(q13-q02);
 
     // handle gimbal lock
-    if (fabs(qd2-1.0) < DBL_EPSILON) {
+    if (fabs(qd2-1.0) <= 16 * DBL_EPSILON) { // Tolerance copied from OCC "gp_Quaternion.cxx"
         // north pole
         y = 0.0;
         p = D_PI/2.0;
         r = 2.0 * atan2(quat[0],quat[3]);
     }
-    else if (fabs(qd2+1.0) < DBL_EPSILON) {
+    else if (fabs(qd2+1.0) <= 16 * DBL_EPSILON) { // Tolerance copied from OCC "gp_Quaternion.cxx"
         // south pole
         y = 0.0;
         p = -D_PI/2.0;
-        r = -2.0 * atan2(quat[0],quat[3]);
+        r = 2.0 * atan2(quat[0],quat[3]);
     }
     else {
         y = atan2(2.0*(q01+q23),(q00+q33)-(q11+q22));
@@ -712,3 +716,271 @@ bool Rotation::isNull() const
             this->quat[2] == 0.0 &&
             this->quat[3] == 0.0);
 }
+
+//=======================================================================
+// The following code is borrowed from OCCT gp/gp_Quaternion.cxx
+
+namespace { // anonymous namespace
+//=======================================================================
+//function : translateEulerSequence
+//purpose  : 
+// Code supporting conversion between quaternion and generalized 
+// Euler angles (sequence of three rotations) is based on
+// algorithm by Ken Shoemake, published in Graphics Gems IV, p. 222-22
+// http://tog.acm.org/resources/GraphicsGems/gemsiv/euler_angle/EulerAngles.c
+//=======================================================================
+
+struct EulerSequence_Parameters
+{
+    int i;           // first rotation axis
+    int j;           // next axis of rotation
+    int k;           // third axis
+    bool isOdd;       // true if order of two first rotation axes is odd permutation, e.g. XZ
+    bool isTwoAxes;   // true if third rotation is about the same axis as first 
+    bool isExtrinsic; // true if rotations are made around fixed axes
+
+    EulerSequence_Parameters (int theAx1, 
+                              bool theisOdd, 
+                              bool theisTwoAxes,
+                              bool theisExtrinsic)
+        : i(theAx1), 
+        j(1 + (theAx1 + (theisOdd ? 1 : 0)) % 3), 
+        k(1 + (theAx1 + (theisOdd ? 0 : 1)) % 3), 
+        isOdd(theisOdd), 
+        isTwoAxes(theisTwoAxes), 
+        isExtrinsic(theisExtrinsic)
+        {}
+};
+
+EulerSequence_Parameters translateEulerSequence (const Rotation::EulerSequence theSeq)
+{
+    typedef EulerSequence_Parameters Params;
+    const bool F = false;
+    const bool T = true;
+
+    switch (theSeq)
+    {
+    case Rotation::Extrinsic_XYZ: return Params (1, F, F, T);
+    case Rotation::Extrinsic_XZY: return Params (1, T, F, T);
+    case Rotation::Extrinsic_YZX: return Params (2, F, F, T);
+    case Rotation::Extrinsic_YXZ: return Params (2, T, F, T);
+    case Rotation::Extrinsic_ZXY: return Params (3, F, F, T);
+    case Rotation::Extrinsic_ZYX: return Params (3, T, F, T);
+
+    // Conversion of intrinsic angles is made by the same code as for extrinsic,
+    // using equivalence rule: intrinsic rotation is equivalent to extrinsic
+    // rotation by the same angles but with inverted order of elemental rotations.
+    // Swapping of angles (Alpha <-> Gamma) is done inside conversion procedure;
+    // sequence of axes is inverted by setting appropriate parameters here.
+    // Note that proper Euler angles (last block below) are symmetric for sequence of axes.
+    case Rotation::Intrinsic_XYZ: return Params (3, T, F, F);
+    case Rotation::Intrinsic_XZY: return Params (2, F, F, F);
+    case Rotation::Intrinsic_YZX: return Params (1, T, F, F);
+    case Rotation::Intrinsic_YXZ: return Params (3, F, F, F);
+    case Rotation::Intrinsic_ZXY: return Params (2, T, F, F);
+    case Rotation::Intrinsic_ZYX: return Params (1, F, F, F);
+
+    case Rotation::Extrinsic_XYX: return Params (1, F, T, T);
+    case Rotation::Extrinsic_XZX: return Params (1, T, T, T);
+    case Rotation::Extrinsic_YZY: return Params (2, F, T, T);
+    case Rotation::Extrinsic_YXY: return Params (2, T, T, T);
+    case Rotation::Extrinsic_ZXZ: return Params (3, F, T, T);
+    case Rotation::Extrinsic_ZYZ: return Params (3, T, T, T);
+
+    case Rotation::Intrinsic_XYX: return Params (1, F, T, F);
+    case Rotation::Intrinsic_XZX: return Params (1, T, T, F);
+    case Rotation::Intrinsic_YZY: return Params (2, F, T, F);
+    case Rotation::Intrinsic_YXY: return Params (2, T, T, F);
+    case Rotation::Intrinsic_ZXZ: return Params (3, F, T, F);
+    case Rotation::Intrinsic_ZYZ: return Params (3, T, T, F);
+
+    default:
+    case Rotation::EulerAngles : return Params (3, F, T, F); // = Intrinsic_ZXZ
+    case Rotation::YawPitchRoll: return Params (1, F, F, F); // = Intrinsic_ZYX
+    };
+}
+
+class Mat : public Base::Matrix4D
+{
+public:
+    double operator()(int i, int j) const {
+        return this->operator[](i-1)[j-1];
+    }
+    double & operator()(int i, int j) {
+        return this->operator[](i-1)[j-1];
+    }
+};
+
+const char *EulerSequenceNames[] = {
+    //! Classic Euler angles, alias to Intrinsic_ZXZ
+    "Euler",
+
+    //! Yaw Pitch Roll (or nautical) angles, alias to Intrinsic_ZYX
+    "YawPitchRoll",
+
+    // Tait-Bryan angles (using three different axes)
+    "XYZ",
+    "XZY",
+    "YZX",
+    "YXZ",
+    "ZXY",
+    "ZYX",
+
+    "IXYZ",
+    "IXZY",
+    "IYZX",
+    "IYXZ",
+    "IZXY",
+    "IZYX",
+
+    // Proper Euler angles (using two different axes, first and third the same)
+    "XYX",
+    "XZX",
+    "YZY",
+    "YXY",
+    "ZYZ",
+    "ZXZ",
+
+    "IXYX",
+    "IXZX",
+    "IYZY",
+    "IYXY",
+    "IZXZ",
+    "IZYZ",
+};
+
+} // anonymous namespace
+
+const char * Rotation::eulerSequenceName(EulerSequence seq)
+{
+    if (seq == Invalid || seq >= EulerSequenceLast)
+        return nullptr;
+    return EulerSequenceNames[seq-1];
+}
+
+Rotation::EulerSequence Rotation::eulerSequenceFromName(const char *name)
+{
+    if (name) {
+        for (unsigned i=0; i<sizeof(EulerSequenceNames)/sizeof(EulerSequenceNames[0]); ++i) {
+            if (boost::iequals(name, EulerSequenceNames[i]))
+                return (EulerSequence)(i+1);
+        }
+    }
+    return Invalid;
+}
+
+void Rotation::setEulerAngles(EulerSequence theOrder,
+                              double theAlpha,
+                              double theBeta,
+                              double theGamma)
+{
+    if (theOrder == Invalid || theOrder >= EulerSequenceLast)
+        throw Base::ValueError("invalid euler sequence");
+
+    EulerSequence_Parameters o = translateEulerSequence (theOrder);
+
+    theAlpha *= D_PI/180.0;
+    theBeta *= D_PI/180.0;
+    theGamma *= D_PI/180.0;
+
+    double a = theAlpha, b = theBeta, c = theGamma;
+    if ( ! o.isExtrinsic )
+        std::swap(a, c);
+
+    if ( o.isOdd )
+        b = -b;
+
+    double ti = 0.5 * a; 
+    double tj = 0.5 * b; 
+    double th = 0.5 * c;
+    double ci = cos (ti);  
+    double cj = cos (tj);  
+    double ch = cos (th);
+    double si = sin (ti);
+    double sj = sin (tj);
+    double sh = sin (th);
+    double cc = ci * ch; 
+    double cs = ci * sh; 
+    double sc = si * ch; 
+    double ss = si * sh;
+
+    double values[4]; // w, x, y, z
+    if ( o.isTwoAxes ) 
+    {
+        values[o.i] = cj * (cs + sc);
+        values[o.j] = sj * (cc + ss);
+        values[o.k] = sj * (cs - sc);
+        values[0]   = cj * (cc - ss);
+    } 
+    else 
+    {
+        values[o.i] = cj * sc - sj * cs;
+        values[o.j] = cj * ss + sj * cc;
+        values[o.k] = cj * cs - sj * sc;
+        values[0]   = cj * cc + sj * ss;
+    }
+    if ( o.isOdd ) 
+        values[o.j] = -values[o.j];
+
+    quat[0] = values[1];
+    quat[1] = values[2];
+    quat[2] = values[3];
+    quat[3] = values[0];
+}
+
+void Rotation::getEulerAngles(EulerSequence theOrder,
+                              double& theAlpha,
+                              double& theBeta,
+                              double& theGamma) const
+{
+    Mat M;
+    getValue(M);
+
+    EulerSequence_Parameters o = translateEulerSequence (theOrder);
+    if ( o.isTwoAxes ) 
+    {
+        double sy = sqrt (M(o.i, o.j) * M(o.i, o.j) + M(o.i, o.k) * M(o.i, o.k));
+        if (sy > 16 * DBL_EPSILON) 
+        {
+            theAlpha = atan2 (M(o.i, o.j),  M(o.i, o.k));
+            theGamma = atan2 (M(o.j, o.i), -M(o.k, o.i));
+        } 
+        else 
+        {
+            theAlpha = atan2 (-M(o.j, o.k), M(o.j, o.j));
+            theGamma = 0.;
+        }
+        theBeta = atan2 (sy, M(o.i, o.i));
+    } 
+    else 
+    {
+        double cy = sqrt (M(o.i, o.i) * M(o.i, o.i) + M(o.j, o.i) * M(o.j, o.i));
+        if (cy > 16 * DBL_EPSILON) 
+        {
+            theAlpha = atan2 (M(o.k, o.j), M(o.k, o.k));
+            theGamma = atan2 (M(o.j, o.i), M(o.i, o.i));
+        } 
+        else 
+        {
+            theAlpha = atan2 (-M(o.j, o.k), M(o.j, o.j));
+            theGamma = 0.;
+        }
+        theBeta = atan2 (-M(o.k, o.i), cy);
+    }
+    if ( o.isOdd ) 
+    {
+        theAlpha = -theAlpha;
+        theBeta  = -theBeta;
+        theGamma = -theGamma;
+    }
+    if ( ! o.isExtrinsic ) 
+    { 
+        double aFirst = theAlpha; 
+        theAlpha = theGamma;
+        theGamma = aFirst;
+    }
+
+    theAlpha *= 180.0/D_PI;
+    theBeta *= 180.0/D_PI;
+    theGamma *= 180.0/D_PI;
+}
