@@ -23,31 +23,31 @@
 
 #include "PreCompiled.h"
 
-#include <Base/Rotation.h>
-#include <Base/Tools.h>
 #include <Base/GeometryPyCXX.h>
+#include <Base/Tools.h>
 
 // inclusion of the generated files (generated out of RotationPy.xml)
-#include "VectorPy.h"
 #include "RotationPy.h"
 #include "RotationPy.cpp"
+#include "VectorPy.h"
+
 
 using namespace Base;
 
 // returns a string which represents the object e.g. when printed in python
-std::string RotationPy::representation(void) const
+std::string RotationPy::representation() const
 {
-    RotationPy::PointerType ptr = reinterpret_cast<RotationPy::PointerType>(_pcTwinPointer);
+    RotationPy::PointerType ptr = getRotationPtr();
     Py::Float q0(ptr->getValue()[0]);
     Py::Float q1(ptr->getValue()[1]);
     Py::Float q2(ptr->getValue()[2]);
     Py::Float q3(ptr->getValue()[3]);
     std::stringstream str;
     str << "Rotation (";
-    str << (std::string)q0.repr() << ", "
-        << (std::string)q1.repr() << ", "
-        << (std::string)q2.repr() << ", "
-        << (std::string)q3.repr();
+    str << static_cast<std::string>(q0.repr()) << ", "
+        << static_cast<std::string>(q1.repr()) << ", "
+        << static_cast<std::string>(q2.repr()) << ", "
+        << static_cast<std::string>(q3.repr());
     str << ")";
 
     return str.str();
@@ -60,7 +60,7 @@ PyObject *RotationPy::PyMake(struct _typeobject *, PyObject *, PyObject *)  // P
 }
 
 // constructor method
-int RotationPy::PyInit(PyObject* args, PyObject* /*kwd*/)
+int RotationPy::PyInit(PyObject* args, PyObject* kwds)
 {
     PyObject* o;
     if (PyArg_ParseTuple(args, "")) {
@@ -76,10 +76,18 @@ int RotationPy::PyInit(PyObject* args, PyObject* /*kwd*/)
 
     PyErr_Clear();
     double angle;
-    if (PyArg_ParseTuple(args, "O!d", &(Base::VectorPy::Type), &o, &angle)) {
-      // NOTE: The last parameter defines the rotation angle in degree.
-      getRotationPtr()->setValue(static_cast<Base::VectorPy*>(o)->value(), Base::toRadians<double>(angle));
-      return 0;
+    static char *kw_deg[] = {"Axis", "Degree", nullptr};
+    if (PyArg_ParseTupleAndKeywords(args, kwds, "O!d", kw_deg, &(Base::VectorPy::Type), &o, &angle)) {
+        // NOTE: The last parameter defines the rotation angle in degree.
+        getRotationPtr()->setValue(static_cast<Base::VectorPy*>(o)->value(), Base::toRadians<double>(angle));
+        return 0;
+    }
+
+    PyErr_Clear();
+    static char *kw_rad[] = {"Axis", "Radian", nullptr};
+    if (PyArg_ParseTupleAndKeywords(args, kwds, "O!d", kw_rad, &(Base::VectorPy::Type), &o, &angle)) {
+        getRotationPtr()->setValue(static_cast<Base::VectorPy*>(o)->value(), angle);
+        return 0;
     }
 
     PyErr_Clear();
@@ -102,6 +110,17 @@ int RotationPy::PyInit(PyObject* args, PyObject* /*kwd*/)
         return 0;
     }
 
+    PyErr_Clear();
+    const char *seq;
+    double a, b, c;
+    if (PyArg_ParseTuple(args, "sddd", &seq, &a, &b, &c)) {
+        PY_TRY {
+            getRotationPtr()->setEulerAngles(
+                    Rotation::eulerSequenceFromName(seq), a, b, c);
+            return 0;
+        } _PY_CATCH(return -1)
+    }
+
     double a11 = 1.0, a12 = 0.0, a13 = 0.0, a14 = 0.0;
     double a21 = 0.0, a22 = 1.0, a23 = 0.0, a24 = 0.0;
     double a31 = 0.0, a32 = 0.0, a33 = 1.0, a34 = 0.0;
@@ -151,7 +170,7 @@ int RotationPy::PyInit(PyObject* args, PyObject* /*kwd*/)
 
     PyErr_Clear();
     PyObject *v3;
-    char *priority = nullptr;
+    const char *priority = nullptr;
     if (PyArg_ParseTuple(args, "O!O!O!|s", &(Base::VectorPy::Type), &v1,
                                            &(Base::VectorPy::Type), &v2,
                                            &(Base::VectorPy::Type), &v3,
@@ -168,7 +187,7 @@ int RotationPy::PyInit(PyObject* args, PyObject* /*kwd*/)
             str += "FreeCAD exception thrown (";
             str += e.what();
             str += ")";
-            PyErr_SetString(Base::BaseExceptionFreeCADError,str.c_str());
+            PyErr_SetString(Base::PyExc_FC_GeneralError,str.c_str());
             return -1;
         }
 
@@ -197,11 +216,11 @@ PyObject* RotationPy::richCompare(PyObject *v, PyObject *w, int op)
         Base::Rotation r1 = *static_cast<RotationPy*>(v)->getRotationPtr();
         Base::Rotation r2 = *static_cast<RotationPy*>(w)->getRotationPtr();
 
-        PyObject *res=0;
+        PyObject *res=nullptr;
         if (op != Py_EQ && op != Py_NE) {
             PyErr_SetString(PyExc_TypeError,
             "no ordering relation is defined for Rotation");
-            return 0;
+            return nullptr;
         }
         else if (op == Py_EQ) {
             res = (r1 == r2) ? Py_True : Py_False;
@@ -224,7 +243,7 @@ PyObject* RotationPy::richCompare(PyObject *v, PyObject *w, int op)
 PyObject* RotationPy::invert(PyObject * args)
 {
     if (!PyArg_ParseTuple(args, ""))
-        return 0;
+        return nullptr;
     this->getRotationPtr()->invert();
     Py_Return;
 }
@@ -232,7 +251,7 @@ PyObject* RotationPy::invert(PyObject * args)
 PyObject* RotationPy::inverted(PyObject * args)
 {
     if (!PyArg_ParseTuple(args, ""))
-        return 0;
+        return nullptr;
     Rotation mult = this->getRotationPtr()->inverse();
     return new RotationPy(new Rotation(mult));
 }
@@ -241,7 +260,7 @@ PyObject* RotationPy::multiply(PyObject * args)
 {
     PyObject *rot;
     if (!PyArg_ParseTuple(args, "O!", &(RotationPy::Type), &rot))
-        return NULL;
+        return nullptr;
     Rotation mult = (*getRotationPtr()) * (*static_cast<RotationPy*>(rot)->getRotationPtr());
     return new RotationPy(new Rotation(mult));
 }
@@ -250,7 +269,7 @@ PyObject* RotationPy::multVec(PyObject * args)
 {
     PyObject *obj;
     if (!PyArg_ParseTuple(args, "O!", &(VectorPy::Type), &obj))
-        return NULL;
+        return nullptr;
     Base::Vector3d vec(static_cast<VectorPy*>(obj)->value());
     getRotationPtr()->multVec(vec, vec);
     return new VectorPy(new Vector3d(vec));
@@ -261,17 +280,26 @@ PyObject* RotationPy::slerp(PyObject * args)
     PyObject *rot;
     double t;
     if (!PyArg_ParseTuple(args, "O!d", &(RotationPy::Type), &rot, &t))
-        return 0;
+        return nullptr;
     Rotation *rot0 = this->getRotationPtr();
     Rotation *rot1 = static_cast<RotationPy*>(rot)->getRotationPtr();
     Rotation sl = Rotation::slerp(*rot0, *rot1, t);
     return new RotationPy(new Rotation(sl));
 }
 
-PyObject* RotationPy::toEuler(PyObject * args)
+PyObject* RotationPy::setYawPitchRoll(PyObject * args)
+{
+    double A,B,C;
+    if (!PyArg_ParseTuple(args, "ddd", &A, &B, &C))
+        return nullptr;
+    this->getRotationPtr()->setYawPitchRoll(A,B,C);
+    Py_Return;
+}
+
+PyObject* RotationPy::getYawPitchRoll(PyObject * args)
 {
     if (!PyArg_ParseTuple(args, ""))
-        return NULL;
+        return nullptr;
     double A,B,C;
     this->getRotationPtr()->getYawPitchRoll(A,B,C);
 
@@ -282,10 +310,54 @@ PyObject* RotationPy::toEuler(PyObject * args)
     return Py::new_reference_to(tuple);
 }
 
+PyObject* RotationPy::setEulerAngles(PyObject * args)
+{
+    const char *seq;
+    double A,B,C;
+    if (!PyArg_ParseTuple(args, "sddd", &seq, &A, &B, &C))
+        return nullptr;
+
+    try {
+        getRotationPtr()->setEulerAngles(
+                Rotation::eulerSequenceFromName(seq), A, B, C);
+        Py_Return;
+    }
+    catch (const Base::Exception& e) {
+        e.setPyException();
+        return nullptr;
+    }
+}
+
+PyObject* RotationPy::toEulerAngles(PyObject * args)
+{
+    const char *seq = nullptr;
+    if (!PyArg_ParseTuple(args, "|s", &seq))
+        return nullptr;
+    if (!seq) {
+        Py::List res;
+        for (int i=1; i<Rotation::EulerSequenceLast; ++i)
+            res.append(Py::String(Rotation::eulerSequenceName((Rotation::EulerSequence)i)));
+        return Py::new_reference_to(res);
+    }
+
+    PY_TRY {
+        double A,B,C;
+        this->getRotationPtr()->getEulerAngles(
+                Rotation::eulerSequenceFromName(seq),A,B,C);
+
+        Py::Tuple tuple(3);
+        tuple.setItem(0, Py::Float(A));
+        tuple.setItem(1, Py::Float(B));
+        tuple.setItem(2, Py::Float(C));
+        return Py::new_reference_to(tuple);
+    } PY_CATCH
+
+}
+
 PyObject* RotationPy::toMatrix(PyObject * args)
 {
     if (!PyArg_ParseTuple(args, ""))
-        return NULL;
+        return nullptr;
     Base::Matrix4D mat;
     getRotationPtr()->getValue(mat);
     return new MatrixPy(new Matrix4D(mat));
@@ -296,7 +368,7 @@ PyObject* RotationPy::isSame(PyObject *args)
     PyObject *rot;
     double tol = 0.0;
     if (!PyArg_ParseTuple(args, "O!|d", &(RotationPy::Type), &rot, &tol))
-        return NULL;
+        return nullptr;
     Base::Rotation rot1 = * getRotationPtr();
     Base::Rotation rot2 = * static_cast<RotationPy*>(rot)->getRotationPtr();
     bool same = tol > 0.0 ? rot1.isSame(rot2, tol) : rot1.isSame(rot2);
@@ -306,7 +378,7 @@ PyObject* RotationPy::isSame(PyObject *args)
 PyObject* RotationPy::isIdentity(PyObject *args)
 {
     if (!PyArg_ParseTuple(args, ""))
-        return NULL;
+        return nullptr;
     bool null = getRotationPtr()->isIdentity();
     return Py_BuildValue("O", (null ? Py_True : Py_False));
 }
@@ -314,12 +386,12 @@ PyObject* RotationPy::isIdentity(PyObject *args)
 PyObject* RotationPy::isNull(PyObject *args)
 {
     if (!PyArg_ParseTuple(args, ""))
-        return NULL;
+        return nullptr;
     bool null = getRotationPtr()->isNull();
     return Py_BuildValue("O", (null ? Py_True : Py_False));
 }
 
-Py::Tuple RotationPy::getQ(void) const
+Py::Tuple RotationPy::getQ() const
 {
     double q0, q1, q2, q3;
     this->getRotationPtr()->getValue(q0,q1,q2,q3);
@@ -334,14 +406,14 @@ Py::Tuple RotationPy::getQ(void) const
 
 void RotationPy::setQ(Py::Tuple arg)
 {
-    double q0 = (double)Py::Float(arg.getItem(0));
-    double q1 = (double)Py::Float(arg.getItem(1));
-    double q2 = (double)Py::Float(arg.getItem(2));
-    double q3 = (double)Py::Float(arg.getItem(3));
+    double q0 = static_cast<double>(Py::Float(arg.getItem(0)));
+    double q1 = static_cast<double>(Py::Float(arg.getItem(1)));
+    double q2 = static_cast<double>(Py::Float(arg.getItem(2)));
+    double q3 = static_cast<double>(Py::Float(arg.getItem(3)));
     this->getRotationPtr()->setValue(q0,q1,q2,q3);
 }
 
-Py::Object RotationPy::getRawAxis(void) const
+Py::Object RotationPy::getRawAxis() const
 {
     Base::Vector3d axis; double angle;
     this->getRotationPtr()->getRawValue(axis, angle);
@@ -363,7 +435,7 @@ void RotationPy::setAxis(Py::Object arg)
     this->getRotationPtr()->setValue(axis, angle);
 }
 
-Py::Float RotationPy::getAngle(void) const
+Py::Float RotationPy::getAngle() const
 {
     Base::Vector3d axis; double angle;
     this->getRotationPtr()->getValue(axis, angle);
@@ -400,7 +472,11 @@ PyObject *RotationPy::getCustomAttributes(const char* attr) const
         this->getRotationPtr()->getYawPitchRoll(A,B,C);
         return PyFloat_FromDouble(C);
     }
-    return 0;
+    else if (strcmp(attr, "toEuler") == 0) {
+        Py::Object self(const_cast<RotationPy*>(this), false);
+        return Py::new_reference_to(self.getAttr("getYawPitchRoll"));
+    }
+    return nullptr;
 }
 
 int RotationPy::setCustomAttributes(const char* attr, PyObject* obj)
@@ -484,23 +560,17 @@ PyObject* RotationPy::number_multiply_handler(PyObject *self, PyObject *other)
     }
 
     PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
+    return nullptr;
 }
 
 PyObject * RotationPy::number_power_handler (PyObject* self, PyObject* other, PyObject* arg)
 {
     if (!PyObject_TypeCheck(self, &(RotationPy::Type)) ||
-
-#if PY_MAJOR_VERSION < 3
-            !PyInt_Check(other)
-#else
-            !PyLong_Check(other)
-#endif
-            || arg != Py_None
-       )
+        !PyLong_Check(other) ||
+        arg != Py_None)
     {
         PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-        return 0;
+        return nullptr;
     }
 
     Rotation a = static_cast<RotationPy*>(self)->value();
@@ -519,49 +589,49 @@ PyObject * RotationPy::number_power_handler (PyObject* self, PyObject* other, Py
 PyObject* RotationPy::number_add_handler(PyObject * /*self*/, PyObject * /*other*/)
 {
     PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
+    return nullptr;
 }
 
 PyObject* RotationPy::number_subtract_handler(PyObject * /*self*/, PyObject * /*other*/)
 {
     PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
+    return nullptr;
 }
 
 PyObject * RotationPy::number_divide_handler (PyObject* /*self*/, PyObject* /*other*/)
 {
     PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
+    return nullptr;
 }
 
 PyObject * RotationPy::number_remainder_handler (PyObject* /*self*/, PyObject* /*other*/)
 {
     PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
+    return nullptr;
 }
 
 PyObject * RotationPy::number_divmod_handler (PyObject* /*self*/, PyObject* /*other*/)
 {
     PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
+    return nullptr;
 }
 
 PyObject * RotationPy::number_negative_handler (PyObject* /*self*/)
 {
     PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
+    return nullptr;
 }
 
 PyObject * RotationPy::number_positive_handler (PyObject* /*self*/)
 {
     PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
+    return nullptr;
 }
 
 PyObject * RotationPy::number_absolute_handler (PyObject* /*self*/)
 {
     PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
+    return nullptr;
 }
 
 int RotationPy::number_nonzero_handler (PyObject* /*self*/)
@@ -572,76 +642,48 @@ int RotationPy::number_nonzero_handler (PyObject* /*self*/)
 PyObject * RotationPy::number_invert_handler (PyObject* /*self*/)
 {
     PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
+    return nullptr;
 }
 
 PyObject * RotationPy::number_lshift_handler (PyObject* /*self*/, PyObject* /*other*/)
 {
     PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
+    return nullptr;
 }
 
 PyObject * RotationPy::number_rshift_handler (PyObject* /*self*/, PyObject* /*other*/)
 {
     PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
+    return nullptr;
 }
 
 PyObject * RotationPy::number_and_handler (PyObject* /*self*/, PyObject* /*other*/)
 {
     PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
+    return nullptr;
 }
 
 PyObject * RotationPy::number_xor_handler (PyObject* /*self*/, PyObject* /*other*/)
 {
     PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
+    return nullptr;
 }
 
 PyObject * RotationPy::number_or_handler (PyObject* /*self*/, PyObject* /*other*/)
 {
     PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
+    return nullptr;
 }
 
-#if PY_MAJOR_VERSION < 3
-int RotationPy::number_coerce_handler (PyObject ** /*self*/, PyObject ** /*other*/)
-{
-    return 1;
-}
-#endif
-
 PyObject * RotationPy::number_int_handler (PyObject * /*self*/)
 {
     PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
+    return nullptr;
 }
 
-#if PY_MAJOR_VERSION < 3
-PyObject * RotationPy::number_long_handler (PyObject * /*self*/)
-{
-    PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
-}
-#endif
-
 PyObject * RotationPy::number_float_handler (PyObject * /*self*/)
 {
     PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
+    return nullptr;
 }
 
-#if PY_MAJOR_VERSION < 3
-PyObject * RotationPy::number_oct_handler (PyObject * /*self*/)
-{
-    PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
-}
-
-PyObject * RotationPy::number_hex_handler (PyObject * /*self*/)
-{
-    PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-    return 0;
-}
-#endif
