@@ -26,21 +26,17 @@
 #ifndef _PreComp_
 # include <QBuffer>
 # include <QByteArray>
-# include <QDataStream>
 # include <QIODevice>
-# include <cstdlib>
-# include <string>
-# include <cstdio>
 # include <cstring>
 #ifdef __GNUC__
-# include <stdint.h>
+# include <cstdint>
 #endif
 #endif
 
 #include "Stream.h"
 #include "Swap.h"
 #include <CXX/Objects.hxx>
-#include <Python.h>
+
 
 using namespace Base;
 
@@ -243,7 +239,7 @@ std::streambuf::int_type
 ByteArrayOStreambuf::overflow(std::streambuf::int_type c)
 {
     if (c != EOF) {
-        char z = c;
+        char z = static_cast<char>(c);
         if (_buffer->write (&z, 1) != 1) {
             return EOF;
         }
@@ -379,7 +375,7 @@ std::streambuf::int_type
 IODeviceOStreambuf::overflow(std::streambuf::int_type c)
 {
     if (c != EOF) {
-        char z = c;
+        char z = static_cast<char>(c);
         if (device->write (&z, 1) != 1) {
             return EOF;
         }
@@ -430,7 +426,7 @@ IODeviceOStreambuf::seekpos(std::streambuf::pos_type pos,
 
 // ----------------------------------------------------------------------
 
-IODeviceIStreambuf::IODeviceIStreambuf(QIODevice* dev) : device(dev)
+IODeviceIStreambuf::IODeviceIStreambuf(QIODevice* dev) : device(dev), buffer{}
 {
     setg (buffer+pbSize,     // beginning of putback area
           buffer+pbSize,     // read position
@@ -572,7 +568,6 @@ PyStreambuf::int_type PyStreambuf::underflow()
     try {
         std::string c;
         Py::Object res(meth.apply(arg));
-#if PY_MAJOR_VERSION >= 3
         if (res.isBytes()) {
             c = static_cast<std::string>(Py::Bytes(res));
         }
@@ -583,9 +578,7 @@ PyStreambuf::int_type PyStreambuf::underflow()
             // wrong type
             return traits_type::eof();
         }
-#else
-        c = static_cast<std::string>(Py::String(res));
-#endif
+
         n = c.size();
         if (n == 0) {
             return traits_type::eof();
@@ -608,7 +601,7 @@ PyStreambuf::overflow(PyStreambuf::int_type ch)
 #ifdef PYSTREAM_BUFFERED
     sync();
     if (ch != traits_type::eof()) {
-        *pptr() = ch;
+        *pptr() = static_cast<char>(ch);
         pbump(1);
         return ch;
     }
@@ -656,11 +649,7 @@ bool PyStreambuf::writeStr(const char* str, std::streamsize num)
             return true;
         }
         else if (type == BytesIO) {
-#if PY_MAJOR_VERSION >= 3
             arg.setItem(0, Py::Bytes(str, num));
-#else
-            arg.setItem(0, Py::String(str, num));
-#endif
             meth.apply(arg);
             return true;
         }
@@ -675,11 +664,7 @@ bool PyStreambuf::writeStr(const char* str, std::streamsize num)
             catch (Py::Exception& e) {
                 if (PyErr_ExceptionMatches(PyExc_TypeError)) {
                     e.clear();
-#if PY_MAJOR_VERSION >= 3
                     arg.setItem(0, Py::Bytes(str, num));
-#else
-                    arg.setItem(0, Py::String(str, num));
-#endif
                     meth.apply(arg);
                     type = BytesIO;
                     return true;
