@@ -24,13 +24,13 @@
 #ifndef BASE_UNITSAPI_H
 #define BASE_UNITSAPI_H
 
-#include <CXX/WrapPython.h>
 #include <memory>
-#include <string>
 #include <QString>
 #include "UnitsSchema.h"
 #include "Quantity.h"
 
+typedef struct _object PyObject;
+typedef struct PyMethodDef PyMethodDef;
 
 namespace Base {
 typedef std::unique_ptr<UnitsSchema> UnitsSchemaPtr;
@@ -42,11 +42,6 @@ class BaseExport UnitsApi
 {
 
 public:
-    /** Constructs a UnitsApi object. */
-    UnitsApi(const char* filter);
-    UnitsApi(const std::string& filter);
-    virtual ~UnitsApi();
-
     /** set Schema
      * set the UnitsSchema of the Application
      * this a represented by a class of type UnitSchema which
@@ -55,7 +50,9 @@ public:
      */
     static void setSchema(UnitSystem s);
     /// return the active schema
-    static UnitSystem getSchema(void){return actSystem;}
+    static UnitSystem getSchema() {
+        return currentSystem;
+    }
     /// Returns a brief description of a schema
     static const char* getDescription(UnitSystem);
 
@@ -66,17 +63,31 @@ public:
         return UnitsApi::schemaTranslate(quant, dummy1, dummy2);
     }
 
+    /** Get a number as string for a quantity of a given format.
+     * The string is a number in C locale (i.e. the decimal separator is always a dot) and if
+     * needed represented in scientific notation. The string also includes the unit of the quantity.
+     */
+    static QString toString(const Base::Quantity& q, const QuantityFormat& f = QuantityFormat(QuantityFormat::Default));
+    /** Get a number as string for a quantity of a given format.
+     * The string is a number in C locale (i.e. the decimal separator is always a dot) and if
+     * needed represented in scientific notation. The string doesn't include the unit of the quantity.
+     */
+    static QString toNumber(const Base::Quantity& q, const QuantityFormat& f = QuantityFormat(QuantityFormat::Default));
+    /** Get a number as string for a double of a given format.
+     * The string is a number in C locale (i.e. the decimal separator is always a dot) and if
+     * needed represented in scientific notation. The string doesn't include the unit of the quantity.
+     */
+    static QString toNumber(double d, const QuantityFormat& f = QuantityFormat(QuantityFormat::Default));
+
     /// generate a value for a quantity with default user preferred system
-    static double toDbl(PyObject *ArgObj,const Base::Unit &u=Base::Unit());
+    static double toDouble(PyObject* args, const Base::Unit& u = Base::Unit());
     /// generate a value for a quantity with default user preferred system
-    static Quantity toQuantity(PyObject *ArgObj,const Base::Unit &u=Base::Unit());
+    static Quantity toQuantity(PyObject* args, const Base::Unit& u = Base::Unit());
 
     // set the number of decimals
     static void setDecimals(int);
     // get the number of decimals
     static int getDecimals();
-    /// set the application defaults
-    //static void setDefaults(void);
     //@}
 
     //double Result;
@@ -84,29 +95,24 @@ public:
     // Python interface
     static PyMethodDef    Methods[];
 
-    static double defaultFactor;
-
     /// return an instance of the given enum value
     static UnitsSchemaPtr createSchema(UnitSystem s);
 
 protected:
     // not used at the moment
     static UnitsSchemaPtr UserPrefSystem;
-    static UnitSystem actSystem;
+    static UnitSystem currentSystem;
     /// number of decimals for floats
     static int      UserPrefDecimals;
 
-    // do the real work
-    //static double parse(const char*,bool &UsedUnit);
-
-protected: // the python API wrapper methods
-    //static PyObject *sTranslateUnit   (PyObject *self,PyObject *args);
-    //static PyObject *sGetWithPrefs    (PyObject *self,PyObject *args);
+protected:
+    // the python API wrapper methods
     static PyObject *sParseQuantity   (PyObject *self,PyObject *args);
     static PyObject *sListSchemas     (PyObject *self,PyObject *args);
     static PyObject *sGetSchema       (PyObject *self,PyObject *args);
     static PyObject *sSetSchema       (PyObject *self,PyObject *args);
     static PyObject *sSchemaTranslate (PyObject *self,PyObject *args);
+    static PyObject *sToNumber        (PyObject *self,PyObject *args);
 };
 
 } // namespace Base
