@@ -26,13 +26,12 @@
 # include <unistd.h>
 #endif
 
-#include <QString>
 #include <QLocale>
+#include <QString>
 
-#include "Exception.h"
-#include "UnitsApi.h"
 #include "UnitsSchema.h"
 
+
 using namespace Base;
 
 QString UnitsSchema::toLocale(const Base::Quantity& quant, double factor, const QString& unitString) const
@@ -41,7 +40,7 @@ QString UnitsSchema::toLocale(const Base::Quantity& quant, double factor, const
     QLocale Lc;
     const QuantityFormat& format = quant.getFormat();
     if (format.option != QuantityFormat::None) {
-        uint opt = static_cast<uint>(format.option);
+        int opt = format.option;
         Lc.setNumberOptions(static_cast<QLocale::NumberOptions>(opt));
     }
 
