@@ -22,8 +22,12 @@
 
 
 #include "PreCompiled.h"
-#include "Tools.h"
+
+#include <limits>
+
 #include "Vector3D.h"
+#include "Tools.h"
+
 
 using namespace Base;
 
@@ -35,14 +39,6 @@ Vector3<_Precision>::Vector3 (_Precision fx, _Precision fy, _Precision fz)
 {
 }
 
-template <class _Precision>
-Vector3<_Precision>::Vector3 (const Vector3<_Precision>& rcVct)
-  : x(rcVct.x),
-    y(rcVct.y),
-    z(rcVct.z)
-{
-}
-
 template <class _Precision>
 _Precision& Vector3<_Precision>::operator [] (unsigned short usIndex)
 {
@@ -98,7 +94,7 @@ Vector3<_Precision> Vector3<_Precision>::operator -  (const Vector3<_Precision>&
 }
 
 template <class _Precision>
-Vector3<_Precision> Vector3<_Precision>::operator - (void) const
+Vector3<_Precision> Vector3<_Precision>::operator - () const
 {
     return Vector3(-x, -y, -z);
 }
@@ -151,15 +147,6 @@ Vector3<_Precision> Vector3<_Precision>::operator / (_Precision fDiv) const
     return Vector3<_Precision>(this->x/fDiv,this->y/fDiv,this->z/fDiv);
 }
 
-template <class _Precision>
-Vector3<_Precision>& Vector3<_Precision>::operator =  (const Vector3<_Precision>& rcVct)
-{
-    x = rcVct.x;
-    y = rcVct.y;
-    z = rcVct.z;
-    return *this;
-}
-
 template <class _Precision>
 _Precision Vector3<_Precision>::operator *  (const Vector3<_Precision>& rcVct) const
 {
@@ -258,7 +245,7 @@ _Precision Vector3<_Precision>::DistanceToPlane (const Vector3<_Precision> &rclB
 }
 
 template <class _Precision>
-_Precision Vector3<_Precision>::Length (void) const
+_Precision Vector3<_Precision>::Length () const
 {
     return (_Precision)sqrt ((x * x) + (y * y) + (z * z));
 }
@@ -302,7 +289,7 @@ Vector3<_Precision> Vector3<_Precision>::Perpendicular(const Vector3<_Precision>
 }
 
 template <class _Precision>
-_Precision Vector3<_Precision>::Sqr (void) const
+_Precision Vector3<_Precision>::Sqr () const
 {
     return (_Precision) ((x * x) + (y * y) + (z * z));
 }
@@ -404,7 +391,7 @@ void Vector3<_Precision>::RotateZ (_Precision f)
 }
 
 template <class _Precision>
-Vector3<_Precision> & Vector3<_Precision>::Normalize (void)
+Vector3<_Precision> & Vector3<_Precision>::Normalize ()
 {
     _Precision fLen = Length ();
     if (fLen != (_Precision)0.0 && fLen != (_Precision)1.0) {
@@ -415,24 +402,31 @@ Vector3<_Precision> & Vector3<_Precision>::Normalize (void)
     return *this;
 }
 
+template <class _Precision>
+bool Vector3<_Precision>::IsNull() const
+{
+    _Precision n{0.0};
+    return (x == n) && (y == n) && (z == n);
+}
+
 template <class _Precision>
 _Precision Vector3<_Precision>::GetAngle (const Vector3 &rcVect) const
 {
-    _Precision divid, fNum;
+    _Precision len1 = Length();
+    _Precision len2 = rcVect.Length();
+    if (len1 <= traits_type::epsilon() || len2 <= traits_type::epsilon())
+        return std::numeric_limits<_Precision>::quiet_NaN(); // division by zero
 
-    divid = Length() * ((Vector3<_Precision>&)rcVect).Length();
+    _Precision dot = Dot(rcVect);
+    dot /= len1;
+    dot /= len2;
 
-    if ((divid < -1e-10f) || (divid > 1e-10f)) {
-        fNum = (*this * rcVect) / divid;
-        if (fNum < -1)
-            return traits_type::pi();
-        else if (fNum > 1)
-            return 0.0F;
-        else
-            return _Precision(acos(fNum));
-    }
-    else
-        return traits_type::maximum(); // division by zero
+    if (dot <= -1.0)
+        return traits_type::pi();
+    else if (dot >= 1.0)
+        return 0.0;
+
+    return _Precision(acos(dot));
 }
 
 template <class _Precision>
