@@ -32,22 +32,22 @@
 // inclusion of the generated files (generated out of VectorPy.xml)
 #include "GeometryPyCXX.h"
 #include "VectorPy.h"
-#include "MatrixPy.h"
-#include "RotationPy.h"
 #include "VectorPy.cpp"
 
 using namespace Base;
 
 // returns a string which represent the object e.g. when printed in python
-std::string VectorPy::representation(void) const
+std::string VectorPy::representation() const
 {
-    VectorPy::PointerType ptr = reinterpret_cast<VectorPy::PointerType>(_pcTwinPointer);
+    VectorPy::PointerType ptr = getVectorPtr();
     Py::Float x(ptr->x);
     Py::Float y(ptr->y);
     Py::Float z(ptr->z);
     std::stringstream str;
     str << "Vector (";
-    str << (std::string)x.repr() << ", "<< (std::string)y.repr() << ", "<< (std::string)z.repr();
+    str << static_cast<std::string>(x.repr()) << ", "
+        << static_cast<std::string>(y.repr()) << ", "
+        << static_cast<std::string>(z.repr());
     str << ")";
 
     return str.str();
@@ -64,14 +64,13 @@ int VectorPy::PyInit(PyObject* args, PyObject* /*kwd*/)
 {
     double  x=0.0,y=0.0,z=0.0;
     PyObject *object;
-    VectorPy::PointerType ptr = reinterpret_cast<VectorPy::PointerType>(_pcTwinPointer);
+    VectorPy::PointerType ptr = getVectorPtr();
     if (PyArg_ParseTuple(args, "|ddd", &x,&y,&z)) {
         ptr->Set(x,y,z);
         return 0;
     }
     PyErr_Clear(); // set by PyArg_ParseTuple()
     if (PyArg_ParseTuple(args,"O!",&(Base::VectorPy::Type), &object)) {
-        // Note: must be static_cast, not reinterpret_cast
         *ptr = *(static_cast<Base::VectorPy*>(object)->getVectorPtr());
         return 0;
     }
@@ -93,7 +92,7 @@ int VectorPy::PyInit(PyObject* args, PyObject* /*kwd*/)
 PyObject*  VectorPy::__reduce__(PyObject *args)
 {
     if (!PyArg_ParseTuple(args, ""))
-        return 0;
+        return nullptr;
 
     Py::Tuple tuple(2);
 
@@ -114,11 +113,11 @@ PyObject* VectorPy::number_add_handler(PyObject *self, PyObject *other)
 {
     if (!PyObject_TypeCheck(self, &(VectorPy::Type))) {
         PyErr_SetString(PyExc_TypeError, "First arg must be Vector");
-        return 0;
+        return nullptr;
     }
     if (!PyObject_TypeCheck(other, &(VectorPy::Type))) {
         PyErr_SetString(PyExc_TypeError, "Second arg must be Vector");
-        return 0;
+        return nullptr;
     }
     Base::Vector3d a = static_cast<VectorPy*>(self)->value();
     Base::Vector3d b = static_cast<VectorPy*>(other)->value();
@@ -129,11 +128,11 @@ PyObject* VectorPy::number_subtract_handler(PyObject *self, PyObject *other)
 {
     if (!PyObject_TypeCheck(self, &(VectorPy::Type))) {
         PyErr_SetString(PyExc_TypeError, "First arg must be Vector");
-        return 0;
+        return nullptr;
     }
     if (!PyObject_TypeCheck(other, &(VectorPy::Type))) {
         PyErr_SetString(PyExc_TypeError, "Second arg must be Vector");
-        return 0;
+        return nullptr;
     }
     Base::Vector3d a = static_cast<VectorPy*>(self)->value();
     Base::Vector3d b = static_cast<VectorPy*>(other)->value();
@@ -150,49 +149,29 @@ PyObject* VectorPy::number_multiply_handler(PyObject *self, PyObject *other)
             Py::Float mult(a * b);
             return Py::new_reference_to(mult);
         }
-
-        else if (PyFloat_Check(other)) {
+        else if (PyNumber_Check(other)) {
             double b = PyFloat_AsDouble(other);
             return new VectorPy(a * b);
         }
-#if PY_MAJOR_VERSION < 3
-    else if (PyInt_Check(other)) {
-        Base::Vector3d a = static_cast<VectorPy*>(self) ->value();
-        long b = PyInt_AsLong(other);
-#else
-    else if (PyLong_Check(other)) {
-        long b = PyLong_AsLong(other);
-#endif
-            return new VectorPy(a * (double)b);
-        }
         else {
-            PyErr_SetString(PyExc_NotImplementedError, "Not implemented");
-            return 0;
+            PyErr_SetString(PyExc_TypeError, "A Vector can only be multiplied by Vector or number");
+            return nullptr;
         }
     }
     else if (PyObject_TypeCheck(other, &(VectorPy::Type))) {
         Base::Vector3d a = static_cast<VectorPy*>(other) ->value();
-        if (PyFloat_Check(self)) {
+        if (PyNumber_Check(self)) {
             double b = PyFloat_AsDouble(self);
             return new VectorPy(a * b);
         }
-#if PY_MAJOR_VERSION >= 3
-        else if (PyLong_Check(self)) {
-            long b = PyLong_AsLong(self);
-#else
-        else if (PyInt_Check(self)) {
-            long b = PyInt_AsLong(self);
-#endif
-            return new VectorPy(a * (double)b);
-        }
         else {
             PyErr_SetString(PyExc_TypeError, "A Vector can only be multiplied by Vector or number");
-            return 0;
+            return nullptr;
         }
     }
     else {
         PyErr_SetString(PyExc_TypeError, "First or second arg must be Vector");
-        return 0;
+        return nullptr;
     }
 }
 
@@ -205,15 +184,17 @@ PyObject * VectorPy::sequence_item (PyObject *self, Py_ssize_t index)
 {
     if (!PyObject_TypeCheck(self, &(VectorPy::Type))) {
         PyErr_SetString(PyExc_TypeError, "first arg must be Vector");
-        return 0;
+        return nullptr;
     }
     if (index < 0 || index > 2) {
         PyErr_SetString(PyExc_IndexError, "index out of range");
-        return 0;
+        return nullptr;
     }
 
+    unsigned short pos = index % 3;
+
     Base::Vector3d a = static_cast<VectorPy*>(self)->value();
-    return Py_BuildValue("d", a[index]);
+    return Py_BuildValue("d", a[pos]);
 }
 
 int VectorPy::sequence_ass_item(PyObject *self, Py_ssize_t index, PyObject *value)
@@ -227,9 +208,11 @@ int VectorPy::sequence_ass_item(PyObject *self, Py_ssize_t index, PyObject *valu
         return -1;
     }
 
-    if (PyFloat_Check(value)) {
+    unsigned short pos = index % 3;
+
+    if (PyNumber_Check(value)) {
         VectorPy::PointerType ptr = static_cast<VectorPy*>(self)->getVectorPtr();
-        (*ptr)[index] = PyFloat_AsDouble(value);
+        (*ptr)[pos] = PyFloat_AsDouble(value);
     }
     else {
         PyErr_SetString(PyExc_ValueError, "value must be float");
@@ -245,23 +228,19 @@ PyObject * VectorPy::mapping_subscript(PyObject *self, PyObject *item)
     if (PyIndex_Check(item)) {
         Py_ssize_t i = PyNumber_AsSsize_t(item, PyExc_IndexError);
         if (i == -1 && PyErr_Occurred())
-            return NULL;
+            return nullptr;
         if (i < 0)
             i += sequence_length(self);
         return sequence_item(self, i);
     }
     else if (PySlice_Check(item)) {
         Py_ssize_t start, stop, step, slicelength, cur, i;
-#if PY_MAJOR_VERSION < 3
-        PySliceObject* slice = reinterpret_cast<PySliceObject*>(item);
-#else
         PyObject* slice = item;
-#endif
 
         if (PySlice_GetIndicesEx(slice,
                          sequence_length(self),
                          &start, &stop, &step, &slicelength) < 0) {
-            return NULL;
+            return nullptr;
         }
 
         if (slicelength <= 0) {
@@ -279,11 +258,11 @@ PyObject * VectorPy::mapping_subscript(PyObject *self, PyObject *item)
         }
         else if (PyObject_TypeCheck(self, &(VectorPy::Type))) {
             Base::Vector3d v = static_cast<VectorPy*>(self) ->value();
-            Py::Tuple xyz(slicelength);
+            Py::Tuple xyz(static_cast<size_t>(slicelength));
 
-            for (cur = start, i = 0; i < slicelength;
-                 cur += step, i++) {
-                xyz.setItem(i, Py::Float(v[cur]));
+            for (cur = start, i = 0; i < slicelength; cur += step, i++) {
+                unsigned short pos = cur % 3;
+                xyz.setItem(static_cast<Py::sequence_index_type>(i), Py::Float(v[pos]));
             }
 
             return Py::new_reference_to(xyz);
@@ -293,19 +272,19 @@ PyObject * VectorPy::mapping_subscript(PyObject *self, PyObject *item)
     PyErr_Format(PyExc_TypeError,
                  "Vector indices must be integers or slices, not %.200s",
                  Py_TYPE(item)->tp_name);
-    return NULL;
+    return nullptr;
 }
 
 PyObject*  VectorPy::add(PyObject *args)
 {
     PyObject *obj;
     if (!PyArg_ParseTuple(args, "O!", &(VectorPy::Type), &obj))
-        return 0;
+        return nullptr;
 
     VectorPy* vec = static_cast<VectorPy*>(obj);
 
-    VectorPy::PointerType this_ptr = reinterpret_cast<VectorPy::PointerType>(_pcTwinPointer);
-    VectorPy::PointerType vect_ptr = reinterpret_cast<VectorPy::PointerType>(vec->_pcTwinPointer);
+    VectorPy::PointerType this_ptr = getVectorPtr();
+    VectorPy::PointerType vect_ptr = vec->getVectorPtr();
 
     Base::Vector3d v = (*this_ptr) + (*vect_ptr);
     return new VectorPy(v);
@@ -315,12 +294,12 @@ PyObject*  VectorPy::sub(PyObject *args)
 {
     PyObject *obj;
     if (!PyArg_ParseTuple(args, "O!", &(VectorPy::Type), &obj))
-        return 0;
+        return nullptr;
 
     VectorPy* vec = static_cast<VectorPy*>(obj);
 
-    VectorPy::PointerType this_ptr = reinterpret_cast<VectorPy::PointerType>(_pcTwinPointer);
-    VectorPy::PointerType vect_ptr = reinterpret_cast<VectorPy::PointerType>(vec->_pcTwinPointer);
+    VectorPy::PointerType this_ptr = getVectorPtr();
+    VectorPy::PointerType vect_ptr = vec->getVectorPtr();
 
     Base::Vector3d v = (*this_ptr) - (*vect_ptr);
     return new VectorPy(v);
@@ -329,9 +308,9 @@ PyObject*  VectorPy::sub(PyObject *args)
 PyObject*  VectorPy::negative(PyObject *args)
 {
     if (!PyArg_ParseTuple(args, ""))
-        return 0;
+        return nullptr;
 
-    VectorPy::PointerType this_ptr = reinterpret_cast<VectorPy::PointerType>(_pcTwinPointer);
+    VectorPy::PointerType this_ptr = getVectorPtr();
     Base::Vector3d v = -(*this_ptr);
     return new VectorPy(v);
 }
@@ -343,11 +322,11 @@ PyObject* VectorPy::richCompare(PyObject *v, PyObject *w, int op)
         Vector3d v1 = static_cast<VectorPy*>(v)->value();
         Vector3d v2 = static_cast<VectorPy*>(w)->value();
 
-        PyObject *res=0;
+        PyObject *res=nullptr;
         if (op != Py_EQ && op != Py_NE) {
             PyErr_SetString(PyExc_TypeError,
             "no ordering relation is defined for Vector");
-            return 0;
+            return nullptr;
         }
         else if (op == Py_EQ) {
             res = (v1 == v2) ? Py_True : Py_False;
@@ -372,12 +351,12 @@ PyObject*  VectorPy::isEqual(PyObject *args)
     PyObject *obj;
     double tolerance=0;
     if (!PyArg_ParseTuple(args, "O!d", &(VectorPy::Type), &obj, &tolerance))
-        return 0;
+        return nullptr;
 
     VectorPy* vec = static_cast<VectorPy*>(obj);
 
-    VectorPy::PointerType this_ptr = reinterpret_cast<VectorPy::PointerType>(_pcTwinPointer);
-    VectorPy::PointerType vect_ptr = reinterpret_cast<VectorPy::PointerType>(vec->_pcTwinPointer);
+    VectorPy::PointerType this_ptr = getVectorPtr();
+    VectorPy::PointerType vect_ptr = vec->getVectorPtr();
 
     Py::Boolean eq((*this_ptr).IsEqual(*vect_ptr, tolerance));
     return Py::new_reference_to(eq);
@@ -387,8 +366,8 @@ PyObject*  VectorPy::scale(PyObject *args)
 {
     double factorX, factorY, factorZ;
     if (!PyArg_ParseTuple(args, "ddd", &factorX, &factorY, &factorZ))
-        return 0;
-    VectorPy::PointerType ptr = reinterpret_cast<VectorPy::PointerType>(_pcTwinPointer);
+        return nullptr;
+    VectorPy::PointerType ptr = getVectorPtr();
     ptr->Scale(factorX, factorY, factorZ);
 
     return Py::new_reference_to(this);
@@ -398,8 +377,8 @@ PyObject*  VectorPy::multiply(PyObject *args)
 {
     double factor;
     if (!PyArg_ParseTuple(args, "d", &factor))
-        return 0;
-    VectorPy::PointerType ptr = reinterpret_cast<VectorPy::PointerType>(_pcTwinPointer);
+        return nullptr;
+    VectorPy::PointerType ptr = getVectorPtr();
     ptr->Scale(factor, factor, factor);
 
     return Py::new_reference_to(this);
@@ -409,12 +388,12 @@ PyObject*  VectorPy::dot(PyObject *args)
 {
     PyObject *obj;
     if (!PyArg_ParseTuple(args, "O!", &(VectorPy::Type), &obj))
-        return 0;
+        return nullptr;
 
     VectorPy* vec = static_cast<VectorPy*>(obj);
 
-    VectorPy::PointerType this_ptr = reinterpret_cast<VectorPy::PointerType>(_pcTwinPointer);
-    VectorPy::PointerType vect_ptr = reinterpret_cast<VectorPy::PointerType>(vec->_pcTwinPointer);
+    VectorPy::PointerType this_ptr = getVectorPtr();
+    VectorPy::PointerType vect_ptr = vec->getVectorPtr();
 
     Py::Float mult((*this_ptr) * (*vect_ptr));
     return Py::new_reference_to(mult);
@@ -424,12 +403,12 @@ PyObject*  VectorPy::cross(PyObject *args)
 {
     PyObject *obj;
     if (!PyArg_ParseTuple(args, "O!", &(VectorPy::Type), &obj))
-        return 0;
+        return nullptr;
 
     VectorPy* vec = static_cast<VectorPy*>(obj);
 
-    VectorPy::PointerType this_ptr = reinterpret_cast<VectorPy::PointerType>(_pcTwinPointer);
-    VectorPy::PointerType vect_ptr = reinterpret_cast<VectorPy::PointerType>(vec->_pcTwinPointer);
+    VectorPy::PointerType this_ptr = getVectorPtr();
+    VectorPy::PointerType vect_ptr = vec->getVectorPtr();
 
     Base::Vector3d v = (*this_ptr) % (*vect_ptr);
     return new VectorPy(v);
@@ -439,22 +418,22 @@ PyObject*  VectorPy::isOnLineSegment(PyObject *args)
 {
     PyObject *start, *end;
     if (!PyArg_ParseTuple(args, "OO",&start, &end))
-        return 0;
+        return nullptr;
     if (!PyObject_TypeCheck(start, &(VectorPy::Type))) {
         PyErr_SetString(PyExc_TypeError, "First arg must be Vector");
-        return 0;
+        return nullptr;
     }
     if (!PyObject_TypeCheck(end, &(VectorPy::Type))) {
         PyErr_SetString(PyExc_TypeError, "Second arg must be Vector");
-        return 0;
+        return nullptr;
     }
 
     VectorPy* start_vec = static_cast<VectorPy*>(start);
     VectorPy* end_vec = static_cast<VectorPy*>(end);
 
-    VectorPy::PointerType this_ptr = reinterpret_cast<VectorPy::PointerType>(_pcTwinPointer);
-    VectorPy::PointerType start_ptr = reinterpret_cast<VectorPy::PointerType>(start_vec->_pcTwinPointer);
-    VectorPy::PointerType end_ptr = reinterpret_cast<VectorPy::PointerType>(end_vec->_pcTwinPointer);
+    VectorPy::PointerType this_ptr = getVectorPtr();
+    VectorPy::PointerType start_ptr = start_vec->getVectorPtr();
+    VectorPy::PointerType end_ptr = end_vec->getVectorPtr();
 
     Py::Boolean result = this_ptr->IsOnLineSegment(*start_ptr, *end_ptr);
 
@@ -465,12 +444,12 @@ PyObject*  VectorPy::getAngle(PyObject *args)
 {
     PyObject *obj;
     if (!PyArg_ParseTuple(args, "O!", &(VectorPy::Type), &obj))
-        return 0;
+        return nullptr;
 
     VectorPy* vec = static_cast<VectorPy*>(obj);
 
-    VectorPy::PointerType this_ptr = reinterpret_cast<VectorPy::PointerType>(_pcTwinPointer);
-    VectorPy::PointerType vect_ptr = reinterpret_cast<VectorPy::PointerType>(vec->_pcTwinPointer);
+    VectorPy::PointerType this_ptr = getVectorPtr();
+    VectorPy::PointerType vect_ptr = vec->getVectorPtr();
 
     Py::Float angle(this_ptr->GetAngle(*vect_ptr));
     return Py::new_reference_to(angle);
@@ -479,11 +458,11 @@ PyObject*  VectorPy::getAngle(PyObject *args)
 PyObject*  VectorPy::normalize(PyObject *args)
 {
     if (!PyArg_ParseTuple(args, ""))
-        return 0;
-    VectorPy::PointerType ptr = reinterpret_cast<VectorPy::PointerType>(_pcTwinPointer);
+        return nullptr;
+    VectorPy::PointerType ptr = getVectorPtr();
     if (ptr->Length() < Vector3d::epsilon()) {
-        PyErr_SetString(Base::BaseExceptionFreeCADError, "Cannot normalize null vector");
-        return 0;
+        PyErr_SetString(Base::PyExc_FC_GeneralError, "Cannot normalize null vector");
+        return nullptr;
     }
 
     ptr->Normalize();
@@ -495,22 +474,22 @@ PyObject*  VectorPy::projectToLine(PyObject *args)
 {
     PyObject *base, *line;
     if (!PyArg_ParseTuple(args, "OO",&base, &line))
-        return 0;
+        return nullptr;
     if (!PyObject_TypeCheck(base, &(VectorPy::Type))) {
         PyErr_SetString(PyExc_TypeError, "First arg must be Vector");
-        return 0;
+        return nullptr;
     }
     if (!PyObject_TypeCheck(line, &(VectorPy::Type))) {
         PyErr_SetString(PyExc_TypeError, "Second arg must be Vector");
-        return 0;
+        return nullptr;
     }
 
     VectorPy* base_vec = static_cast<VectorPy*>(base);
     VectorPy* line_vec = static_cast<VectorPy*>(line);
 
-    VectorPy::PointerType this_ptr = reinterpret_cast<VectorPy::PointerType>(_pcTwinPointer);
-    VectorPy::PointerType base_ptr = reinterpret_cast<VectorPy::PointerType>(base_vec->_pcTwinPointer);
-    VectorPy::PointerType line_ptr = reinterpret_cast<VectorPy::PointerType>(line_vec->_pcTwinPointer);
+    VectorPy::PointerType this_ptr = getVectorPtr();
+    VectorPy::PointerType base_ptr = base_vec->getVectorPtr();
+    VectorPy::PointerType line_ptr = line_vec->getVectorPtr();
 
     this_ptr->ProjectToLine(*base_ptr, *line_ptr);
 
@@ -521,22 +500,22 @@ PyObject*  VectorPy::projectToPlane(PyObject *args)
 {
     PyObject *base, *line;
     if (!PyArg_ParseTuple(args, "OO",&base, &line))
-        return 0;
+        return nullptr;
     if (!PyObject_TypeCheck(base, &(VectorPy::Type))) {
         PyErr_SetString(PyExc_TypeError, "First arg must be Vector");
-        return 0;
+        return nullptr;
     }
     if (!PyObject_TypeCheck(line, &(VectorPy::Type))) {
         PyErr_SetString(PyExc_TypeError, "Second arg must be Vector");
-        return 0;
+        return nullptr;
     }
 
     VectorPy* base_vec = static_cast<VectorPy*>(base);
     VectorPy* line_vec = static_cast<VectorPy*>(line);
 
-    VectorPy::PointerType this_ptr = reinterpret_cast<VectorPy::PointerType>(_pcTwinPointer);
-    VectorPy::PointerType base_ptr = reinterpret_cast<VectorPy::PointerType>(base_vec->_pcTwinPointer);
-    VectorPy::PointerType line_ptr = reinterpret_cast<VectorPy::PointerType>(line_vec->_pcTwinPointer);
+    VectorPy::PointerType this_ptr = getVectorPtr();
+    VectorPy::PointerType base_ptr = base_vec->getVectorPtr();
+    VectorPy::PointerType line_ptr = line_vec->getVectorPtr();
 
     this_ptr->ProjectToPlane(*base_ptr, *line_ptr);
 
@@ -547,11 +526,11 @@ PyObject*  VectorPy::distanceToPoint(PyObject *args)
 {
     PyObject *pnt;
     if (!PyArg_ParseTuple(args, "O!",&(VectorPy::Type),&pnt))
-        return 0;
+        return nullptr;
 
     VectorPy* base_vec = static_cast<VectorPy*>(pnt);
-    VectorPy::PointerType this_ptr = reinterpret_cast<VectorPy::PointerType>(_pcTwinPointer);
-    VectorPy::PointerType base_ptr = reinterpret_cast<VectorPy::PointerType>(base_vec->_pcTwinPointer);
+    VectorPy::PointerType this_ptr = getVectorPtr();
+    VectorPy::PointerType base_ptr = base_vec->getVectorPtr();
 
     Py::Float dist(Base::Distance(*this_ptr, *base_ptr));
     return Py::new_reference_to(dist);
@@ -561,22 +540,22 @@ PyObject*  VectorPy::distanceToLine(PyObject *args)
 {
     PyObject *base, *line;
     if (!PyArg_ParseTuple(args, "OO",&base, &line))
-        return 0;
+        return nullptr;
     if (!PyObject_TypeCheck(base, &(VectorPy::Type))) {
         PyErr_SetString(PyExc_TypeError, "First arg must be Vector");
-        return 0;
+        return nullptr;
     }
     if (!PyObject_TypeCheck(line, &(VectorPy::Type))) {
         PyErr_SetString(PyExc_TypeError, "Second arg must be Vector");
-        return 0;
+        return nullptr;
     }
 
     VectorPy* base_vec = static_cast<VectorPy*>(base);
     VectorPy* line_vec = static_cast<VectorPy*>(line);
 
-    VectorPy::PointerType this_ptr = reinterpret_cast<VectorPy::PointerType>(_pcTwinPointer);
-    VectorPy::PointerType base_ptr = reinterpret_cast<VectorPy::PointerType>(base_vec->_pcTwinPointer);
-    VectorPy::PointerType line_ptr = reinterpret_cast<VectorPy::PointerType>(line_vec->_pcTwinPointer);
+    VectorPy::PointerType this_ptr = getVectorPtr();
+    VectorPy::PointerType base_ptr = base_vec->getVectorPtr();
+    VectorPy::PointerType line_ptr = line_vec->getVectorPtr();
 
     Py::Float dist(this_ptr->DistanceToLine(*base_ptr, *line_ptr));
     return Py::new_reference_to(dist);
@@ -586,22 +565,22 @@ PyObject*  VectorPy::distanceToLineSegment(PyObject *args)
 {
     PyObject *base, *line;
     if (!PyArg_ParseTuple(args, "OO",&base, &line))
-        return 0;
+        return nullptr;
     if (!PyObject_TypeCheck(base, &(VectorPy::Type))) {
         PyErr_SetString(PyExc_TypeError, "First arg must be Vector");
-        return 0;
+        return nullptr;
     }
     if (!PyObject_TypeCheck(line, &(VectorPy::Type))) {
         PyErr_SetString(PyExc_TypeError, "Second arg must be Vector");
-        return 0;
+        return nullptr;
     }
 
     VectorPy* base_vec = static_cast<VectorPy*>(base);
     VectorPy* line_vec = static_cast<VectorPy*>(line);
 
-    VectorPy::PointerType this_ptr = reinterpret_cast<VectorPy::PointerType>(_pcTwinPointer);
-    VectorPy::PointerType base_ptr = reinterpret_cast<VectorPy::PointerType>(base_vec->_pcTwinPointer);
-    VectorPy::PointerType line_ptr = reinterpret_cast<VectorPy::PointerType>(line_vec->_pcTwinPointer);
+    VectorPy::PointerType this_ptr = getVectorPtr();
+    VectorPy::PointerType base_ptr = base_vec->getVectorPtr();
+    VectorPy::PointerType line_ptr = line_vec->getVectorPtr();
 
     Vector3d v = this_ptr->DistanceToLineSegment(*base_ptr, *line_ptr);
     return new VectorPy(v);
@@ -611,86 +590,86 @@ PyObject*  VectorPy::distanceToPlane(PyObject *args)
 {
     PyObject *base, *line;
     if (!PyArg_ParseTuple(args, "OO",&base, &line))
-        return 0;
+        return nullptr;
     if (!PyObject_TypeCheck(base, &(VectorPy::Type))) {
         PyErr_SetString(PyExc_TypeError, "First arg must be Vector");
-        return 0;
+        return nullptr;
     }
     if (!PyObject_TypeCheck(line, &(VectorPy::Type))) {
         PyErr_SetString(PyExc_TypeError, "Second arg must be Vector");
-        return 0;
+        return nullptr;
     }
 
     VectorPy* base_vec = static_cast<VectorPy*>(base);
     VectorPy* line_vec = static_cast<VectorPy*>(line);
 
-    VectorPy::PointerType this_ptr = reinterpret_cast<VectorPy::PointerType>(_pcTwinPointer);
-    VectorPy::PointerType base_ptr = reinterpret_cast<VectorPy::PointerType>(base_vec->_pcTwinPointer);
-    VectorPy::PointerType line_ptr = reinterpret_cast<VectorPy::PointerType>(line_vec->_pcTwinPointer);
+    VectorPy::PointerType this_ptr = getVectorPtr();
+    VectorPy::PointerType base_ptr = base_vec->getVectorPtr();
+    VectorPy::PointerType line_ptr = line_vec->getVectorPtr();
 
     Py::Float dist(this_ptr->DistanceToPlane(*base_ptr, *line_ptr));
     return Py::new_reference_to(dist);
 }
 
-Py::Float VectorPy::getLength(void) const
+Py::Float VectorPy::getLength() const
 {
-    VectorPy::PointerType ptr = reinterpret_cast<VectorPy::PointerType>(_pcTwinPointer);
+    VectorPy::PointerType ptr = getVectorPtr();
     return Py::Float(ptr->Length());
 }
 
 void  VectorPy::setLength(Py::Float arg)
 {
-    VectorPy::PointerType ptr = reinterpret_cast<VectorPy::PointerType>(_pcTwinPointer);
+    VectorPy::PointerType ptr = getVectorPtr();
     double len = ptr->Length();
     if (len < Vector3d::epsilon()) {
         throw Py::RuntimeError(std::string("Cannot set length of null vector"));
     }
 
-    double val = (double)arg/len;
+    double val = static_cast<double>(arg)/len;
     ptr->x *= val;
     ptr->y *= val;
     ptr->z *= val;
 }
 
-Py::Float VectorPy::getx(void) const
+Py::Float VectorPy::getx() const
 {
-    VectorPy::PointerType ptr = reinterpret_cast<VectorPy::PointerType>(_pcTwinPointer);
+    VectorPy::PointerType ptr = getVectorPtr();
     return Py::Float(ptr->x);
 }
 
 void  VectorPy::setx(Py::Float arg)
 {
-    VectorPy::PointerType ptr = reinterpret_cast<VectorPy::PointerType>(_pcTwinPointer);
-    ptr->x = (double)arg;
+    VectorPy::PointerType ptr = getVectorPtr();
+    ptr->x = static_cast<double>(arg);
 }
 
-Py::Float VectorPy::gety(void) const
+Py::Float VectorPy::gety() const
 {
-    VectorPy::PointerType ptr = reinterpret_cast<VectorPy::PointerType>(_pcTwinPointer);
+    VectorPy::PointerType ptr = getVectorPtr();
     return Py::Float(ptr->y);
 }
 
 void  VectorPy::sety(Py::Float arg)
 {
-    VectorPy::PointerType ptr = reinterpret_cast<VectorPy::PointerType>(_pcTwinPointer);
-    ptr->y = (double)arg;
+    VectorPy::PointerType ptr = getVectorPtr();
+    ptr->y = static_cast<double>(arg);
 }
 
-Py::Float VectorPy::getz(void) const
+Py::Float VectorPy::getz() const
 {
-    VectorPy::PointerType ptr = reinterpret_cast<VectorPy::PointerType>(_pcTwinPointer);
+    VectorPy::PointerType ptr = getVectorPtr();
     return Py::Float(ptr->z);
 }
 
 void  VectorPy::setz(Py::Float arg)
 {
-    VectorPy::PointerType ptr = reinterpret_cast<VectorPy::PointerType>(_pcTwinPointer);
-    ptr->z = (double)arg;
+    VectorPy::PointerType ptr = getVectorPtr();
+    ptr->z = static_cast<double>(arg);
 }
 
 PyObject *VectorPy::getCustomAttributes(const char* /*attr*/) const
 {
-    return 0;
+    return nullptr;
 }
 
 int VectorPy::setCustomAttributes(const char* /*attr*/, PyObject* /*obj*/)
@@ -712,15 +691,15 @@ PyObject * VectorPy::number_divide_handler (PyObject* self, PyObject* other)
         if (PyObject_TypeCheck(other, &(VectorPy::Type))) {
             PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for /: '%s' and '%s'",
                          Py_TYPE(self)->tp_name, Py_TYPE(other)->tp_name);
-            return 0;
+            return nullptr;
         }
 
         Base::Vector3d vec = static_cast<VectorPy*>(self) ->value();
         double div = PyFloat_AsDouble(other);
-        if (div == 0) {
+        if (div == 0.0) {
             PyErr_Format(PyExc_ZeroDivisionError, "'%s' division by zero",
                          Py_TYPE(self)->tp_name);
-            return 0;
+            return nullptr;
         }
 
         vec /= div;
@@ -729,7 +708,7 @@ PyObject * VectorPy::number_divide_handler (PyObject* self, PyObject* other)
 
     PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for /: '%s' and '%s'",
                  Py_TYPE(self)->tp_name, Py_TYPE(other)->tp_name);
-    return 0;
+    return nullptr;
 }
 
 PyObject * VectorPy::number_remainder_handler (PyObject* self, PyObject* other)
@@ -744,21 +723,21 @@ PyObject * VectorPy::number_remainder_handler (PyObject* self, PyObject* other)
 
     PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %%: '%s' and '%s'",
                  Py_TYPE(self)->tp_name, Py_TYPE(other)->tp_name);
-    return 0;
+    return nullptr;
 }
 
 PyObject * VectorPy::number_divmod_handler (PyObject* self, PyObject* other)
 {
     PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for divmod(): '%s' and '%s'",
                  Py_TYPE(self)->tp_name, Py_TYPE(other)->tp_name);
-    return 0;
+    return nullptr;
 }
 
 PyObject * VectorPy::number_power_handler (PyObject* self, PyObject* other, PyObject* /*arg*/)
 {
     PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for ** or pow(): '%s' and '%s'",
                  Py_TYPE(self)->tp_name, Py_TYPE(other)->tp_name);
-    return 0;
+    return nullptr;
 }
 
 PyObject * VectorPy::number_negative_handler (PyObject* self)
@@ -770,7 +749,7 @@ PyObject * VectorPy::number_negative_handler (PyObject* self)
 
     PyErr_Format(PyExc_TypeError, "bad operand type for unary -: '%s'",
                  Py_TYPE(self)->tp_name);
-    return 0;
+    return nullptr;
 }
 
 PyObject * VectorPy::number_positive_handler (PyObject* self)
@@ -782,7 +761,7 @@ PyObject * VectorPy::number_positive_handler (PyObject* self)
 
     PyErr_Format(PyExc_TypeError, "bad operand type for unary +: '%s'",
                  Py_TYPE(self)->tp_name);
-    return 0;
+    return nullptr;
 }
 
 PyObject * VectorPy::number_absolute_handler (PyObject* self)
@@ -797,7 +776,7 @@ PyObject * VectorPy::number_absolute_handler (PyObject* self)
 
     PyErr_Format(PyExc_TypeError, "bad operand type for abs(): '%s'",
                  Py_TYPE(self)->tp_name);
-    return 0;
+    return nullptr;
 }
 
 int VectorPy::number_nonzero_handler (PyObject* /*self*/)
@@ -809,84 +788,54 @@ PyObject * VectorPy::number_invert_handler (PyObject* self)
 {
     PyErr_Format(PyExc_TypeError, "bad operand type for unary ~: '%s'",
                  Py_TYPE(self)->tp_name);
-    return 0;
+    return nullptr;
 }
 
 PyObject * VectorPy::number_lshift_handler (PyObject* self, PyObject* other)
 {
     PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for <<: '%s' and '%s'",
                  Py_TYPE(self)->tp_name, Py_TYPE(other)->tp_name);
-    return 0;
+    return nullptr;
 }
 
 PyObject * VectorPy::number_rshift_handler (PyObject* self, PyObject* other)
 {
     PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for >>: '%s' and '%s'",
                  Py_TYPE(self)->tp_name, Py_TYPE(other)->tp_name);
-    return 0;
+    return nullptr;
 }
 
 PyObject * VectorPy::number_and_handler (PyObject* self, PyObject* other)
 {
     PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for &: '%s' and '%s'",
                  Py_TYPE(self)->tp_name, Py_TYPE(other)->tp_name);
-    return 0;
+    return nullptr;
 }
 
 PyObject * VectorPy::number_xor_handler (PyObject* self, PyObject* other)
 {
     PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for ^: '%s' and '%s'",
                  Py_TYPE(self)->tp_name, Py_TYPE(other)->tp_name);
-    return 0;
+    return nullptr;
 }
 
 PyObject * VectorPy::number_or_handler (PyObject* self, PyObject* other)
 {
     PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for |: '%s' and '%s'",
                  Py_TYPE(self)->tp_name, Py_TYPE(other)->tp_name);
-    return 0;
+    return nullptr;
 }
 
-#if PY_MAJOR_VERSION < 3
-int VectorPy::number_coerce_handler (PyObject ** /*self*/, PyObject ** /*other*/)
-{
-    return 1;
-}
-#endif
-
 PyObject * VectorPy::number_int_handler (PyObject* self)
 {
     PyErr_Format(PyExc_TypeError, "int() argument must be a string or a number, not '%s'",
                  Py_TYPE(self)->tp_name);
-    return 0;
+    return nullptr;
 }
 
-#if PY_MAJOR_VERSION < 3
-PyObject * VectorPy::number_long_handler (PyObject* self)
-{
-    PyErr_Format(PyExc_TypeError, "long() argument must be a string or a number, not '%s'",
-                 Py_TYPE(self)->tp_name);
-    return 0;
-}
-#endif
-
 PyObject * VectorPy::number_float_handler (PyObject* self)
 {
     PyErr_Format(PyExc_TypeError, "float() argument must be a string or a number, not '%s'",
                  Py_TYPE(self)->tp_name);
-    return 0;
+    return nullptr;
 }
-
-#if PY_MAJOR_VERSION < 3
-PyObject * VectorPy::number_oct_handler (PyObject* /*self*/)
-{
-    PyErr_SetString(PyExc_TypeError, "oct() argument can't be converted to oct");
-    return 0;
-}
-
-PyObject * VectorPy::number_hex_handler (PyObject* /*self*/)
-{
-    PyErr_SetString(PyExc_TypeError, "hex() argument can't be converted to hex");
-    return 0;
-}
-#endif
