@@ -36,8 +36,11 @@ namespace Base {
 class BaseExport ViewProjMethod
 {
 public:
-    virtual ~ViewProjMethod(){}
-    virtual bool isValid() const { return true; }
+    ViewProjMethod(const ViewProjMethod&) = default;
+    ViewProjMethod& operator= (const ViewProjMethod&) = default;
+    virtual ~ViewProjMethod() = default;
+
+    virtual bool isValid() const;
     /** Convert 3D point to 2D projection plane */
     virtual Vector3f operator()(const Vector3f &rclPt) const = 0;
     /** Convert 3D point to 2D projection plane */
@@ -47,9 +50,9 @@ public:
     /** Convert a 2D point on the projection plane in 3D space */
     virtual Vector3d inverse (const Vector3d &rclPt) const = 0;
     /** Calculate the projection (+ mapping) matrix */
-    virtual Matrix4D getProjectionMatrix (void) const = 0;
+    virtual Matrix4D getProjectionMatrix () const = 0;
     /** Calculate the composed projection matrix */
-    Matrix4D getComposedProjectionMatrix (void) const;
+    Matrix4D getComposedProjectionMatrix () const;
     /** Apply an additional transformation to the input points */
     void setTransform(const Base::Matrix4D&);
     const Base::Matrix4D& getTransform() const {
@@ -74,14 +77,13 @@ class BaseExport ViewProjMatrix : public ViewProjMethod
 {
 public:
     ViewProjMatrix (const Matrix4D &rclMtx);
-    virtual ~ViewProjMatrix();
 
     Vector3f operator()(const Vector3f &rclPt) const;
     Vector3d operator()(const Vector3d &rclPt) const;
     Vector3f inverse (const Vector3f &rclPt) const;
     Vector3d inverse (const Vector3d &rclPt) const;
 
-    Matrix4D getProjectionMatrix (void) const;
+    Matrix4D getProjectionMatrix () const;
 
 protected:
     bool isOrthographic;
@@ -98,14 +100,13 @@ class BaseExport ViewOrthoProjMatrix : public ViewProjMethod
 {
 public:
     ViewOrthoProjMatrix (const Matrix4D &rclMtx);
-    virtual ~ViewOrthoProjMatrix();
 
     Vector3f operator()(const Vector3f &rclPt) const;
     Vector3d operator()(const Vector3d &rclPt) const;
     Vector3f inverse (const Vector3f &rclPt) const;
     Vector3d inverse (const Vector3d &rclPt) const;
 
-    Matrix4D getProjectionMatrix (void) const;
+    Matrix4D getProjectionMatrix () const;
 
 protected:
     Matrix4D _clMtx, _clMtxInv;
