@@ -295,7 +295,7 @@ PythonType &PythonType::supportSequenceType()
         sequence_table->sq_repeat = sequence_repeat_handler;
         sequence_table->sq_item = sequence_item_handler;
 
-        sequence_table->sq_ass_item = sequence_ass_item_handler;    // BAS setup seperately?
+        sequence_table->sq_ass_item = sequence_ass_item_handler;    // BAS setup separately?
         // QQQ sq_inplace_concat
         // QQQ sq_inplace_repeat
     }
@@ -311,7 +311,7 @@ PythonType &PythonType::supportMappingType()
         table->tp_as_mapping = mapping_table;
         mapping_table->mp_length = mapping_length_handler;
         mapping_table->mp_subscript = mapping_subscript_handler;
-        mapping_table->mp_ass_subscript = mapping_ass_subscript_handler;    // BAS setup seperately?
+        mapping_table->mp_ass_subscript = mapping_ass_subscript_handler;    // BAS setup separately?
     }
     return *this;
 }
