@@ -25,8 +25,8 @@
 #define APPLICATION_H
 
 #include <QPixmap>
+#include <map>
 #include <string>
-#include <vector>
 
 #define  putpix()
 
@@ -43,6 +43,7 @@ class MacroManager;
 class MDIView;
 class MainWindow;
 class MenuItem;
+class PreferencePackManager;
 class ViewProvider;
 class ViewProviderDocumentObject;
 
@@ -74,11 +75,11 @@ public:
     /** @name methods for View handling */
     //@{
     /// send Messages to the active view
-    bool sendMsgToActiveView(const char* pMsg, const char** ppReturn=0);
+    bool sendMsgToActiveView(const char* pMsg, const char** ppReturn=nullptr);
     /// send Messages test to the active view
     bool sendHasMsgToActiveView(const char* pMsg);
     /// send Messages to the focused view
-    bool sendMsgToFocusView(const char* pMsg, const char** ppReturn=0);
+    bool sendMsgToFocusView(const char* pMsg, const char** ppReturn=nullptr);
     /// send Messages test to the focused view
     bool sendHasMsgToFocusView(const char* pMsg);
     /// Attach a view (get called by the FCView constructor)
@@ -88,9 +89,9 @@ public:
     /// get called if a view gets activated, this manage the whole activation scheme
     void viewActivated(Gui::MDIView* pcView);
     /// call update to all documents and all views (costly!)
-    void onUpdate(void);
+    void onUpdate();
     /// call update to all views of the active document
-    void updateActive(void);
+    void updateActive();
     /// call update to all command actions
     void updateActions(bool delay = false);
     //@}
@@ -133,6 +134,8 @@ public:
     boost::signals2::signal<void (const Gui::ViewProviderDocumentObject&)> signalInEdit;
     /// signal on leaving edit mode
     boost::signals2::signal<void (const Gui::ViewProviderDocumentObject&)> signalResetEdit;
+    /// signal on changing user edit mode
+    boost::signals2::signal<void (int)> signalUserEditModeChanged;
     //@}
 
     /** @name methods for Document handling */
@@ -157,11 +160,11 @@ public:
     /// message when a GuiDocument is about to vanish
     void onLastWindowClosed(Gui::Document* pcDoc);
     /// Getter for the active document
-    Gui::Document* activeDocument(void) const;
+    Gui::Document* activeDocument() const;
     /// Set the active document
     void setActiveDocument(Gui::Document* pcDocument);
     /// Getter for the editing document
-    Gui::Document* editDocument(void) const;
+    Gui::Document* editDocument() const;
     Gui::MDIView* editViewOfNode(SoNode *node) const;
     /// Set editing document, which will reset editing of all other document
     void setEditDocument(Gui::Document* pcDocument);
@@ -174,7 +177,7 @@ public:
     */
     Gui::Document* getDocument(const App::Document* pDoc) const;
     /// Getter for the active view of the active document or null
-    Gui::MDIView* activeView(void) const;
+    Gui::MDIView* activeView() const;
     /// Activate a view of the given type of the active document
     void activateView(const Base::Type&, bool create=false);
     /// Shows the associated view provider of the given object
@@ -186,7 +189,7 @@ public:
     //@}
 
     /// true when the application shutting down
-    bool isClosing(void);
+    bool isClosing();
     void checkForPreviousCrashes();
 
     /** @name workbench handling */
@@ -196,7 +199,7 @@ public:
     QPixmap workbenchIcon(const QString&) const;
     QString workbenchToolTip(const QString&) const;
     QString workbenchMenuText(const QString&) const;
-    QStringList workbenches(void) const;
+    QStringList workbenches() const;
     void setupContextMenu(const char* recipient, MenuItem*) const;
     //@}
 
@@ -209,24 +212,48 @@ public:
     /** @name User Commands */
     //@{
     /// Get macro manager
-    Gui::MacroManager *macroManager(void);
+    Gui::MacroManager *macroManager();
     /// Reference to the command manager
-    Gui::CommandManager &commandManager(void);
+    Gui::CommandManager &commandManager();
     /// helper which create the commands
     void createStandardOperations();
     //@}
 
+    Gui::PreferencePackManager* prefPackManager();
+
     /** @name Init, Destruct an Access methods */
     //@{
-    /// some kind of singelton
+    /// some kind of singleton
     static Application* Instance;
-    static void initApplication(void);
-    static void initTypes(void);
-    static void initOpenInventor(void);
-    static void runInitGuiScript(void);
-    static void runApplication(void);
+    static void initApplication();
+    static void initTypes();
+    static void initOpenInventor();
+    static void runInitGuiScript();
+    static void runApplication();
     void tryClose( QCloseEvent * e );
     //@}
+    
+    /** @name User edit mode */
+    //@{
+protected:
+    // the below std::map is a translation of 'EditMode' enum in ViewProvider.h
+    // to add a new edit mode, it should first be added there
+    // this is only used for GUI user interaction (menu, toolbar, Python API)
+    const std::map <int, std::string> userEditModes {
+        {0, QT_TRANSLATE_NOOP("EditMode", "Default")},
+        {1, QT_TRANSLATE_NOOP("EditMode", "Transform")},
+        {2, QT_TRANSLATE_NOOP("EditMode", "Cutting")},
+        {3, QT_TRANSLATE_NOOP("EditMode", "Color")}
+    };
+    int userEditMode = userEditModes.begin()->first;
+
+public:
+    std::map <int, std::string> listUserEditModes() const { return userEditModes; }
+    int getUserEditMode(const std::string &mode = "") const;
+    std::string getUserEditModeName(int mode = -1) const;
+    bool setUserEditMode(int mode);
+    bool setUserEditMode(const std::string &mode);
+    //@}
 
 public:
     //---------------------------------------------------------------------
@@ -293,6 +320,10 @@ public:
 
     static PyObject* sAddDocObserver           (PyObject *self,PyObject *args);
     static PyObject* sRemoveDocObserver        (PyObject *self,PyObject *args);
+    
+    static PyObject* sListUserEditModes        (PyObject *self,PyObject *args);
+    static PyObject* sGetUserEditMode          (PyObject *self,PyObject *args);
+    static PyObject* sSetUserEditMode          (PyObject *self,PyObject *args);
 
     static PyMethodDef    Methods[];
 
