@@ -24,13 +24,10 @@
 #ifndef GUI_COMMAND_H
 #define GUI_COMMAND_H
 
-
 #include <list>
-#include <map>
-#include <string>
-#include <vector>
 
 #include <Base/Type.h>
+#include <Gui/Application.h>
 
 /** @defgroup CommandMacros Helper macros for running commands through Python interpreter */
 //@{
@@ -179,8 +176,8 @@
     auto __obj = _obj;\
     if(__obj && __obj->getNameInDocument()) {\
         Gui::Command::doCommand(Gui::Command::Gui,\
-            "Gui.ActiveDocument.setEdit(App.getDocument('%s').getObject('%s'))",\
-            __obj->getDocument()->getName(), __obj->getNameInDocument());\
+            "Gui.ActiveDocument.setEdit(App.getDocument('%s').getObject('%s'), %i)",\
+            __obj->getDocument()->getName(), __obj->getNameInDocument(), Gui::Application::Instance->getUserEditMode());\
     }\
 }while(0)
 
@@ -216,15 +213,15 @@ class SelectionSingleton;
 class MDIView;
 
 
-void CreateStdCommands(void);
-void CreateDocCommands(void);
-void CreateFeatCommands(void);
-void CreateMacroCommands(void);
-void CreateViewStdCommands(void);
-void CreateWindowStdCommands(void);
-void CreateStructureCommands(void);
-void CreateTestCommands(void);
-void CreateLinkCommands(void);
+void CreateStdCommands();
+void CreateDocCommands();
+void CreateFeatCommands();
+void CreateMacroCommands();
+void CreateViewStdCommands();
+void CreateWindowStdCommands();
+void CreateStructureCommands();
+void CreateTestCommands();
+void CreateLinkCommands();
 
 
 /** The CommandBase class
@@ -235,8 +232,8 @@ void CreateLinkCommands(void);
 class GuiExport CommandBase
 {
 protected:
-    CommandBase(const char* sMenu, const char* sToolTip=0, const char* sWhat=0,
-                const char* sStatus=0, const char* sPixmap=0, const char* sAccel=0);
+    CommandBase(const char* sMenu, const char* sToolTip=nullptr, const char* sWhat=nullptr,
+                const char* sStatus=nullptr, const char* sPixmap=nullptr, const char* sAccel=nullptr);
     virtual ~CommandBase();
 
 public:
@@ -249,7 +246,7 @@ public:
     //@{
 protected:
     /// Creates the used Action when adding to a widget. The default implementation does nothing.
-    virtual Action * createAction(void);
+    virtual Action * createAction();
 
 public:
     /// Reassigns QAction stuff after the language has changed.
@@ -326,10 +323,11 @@ protected:
     /// Methods which gets called when activated, needs to be reimplemented!
     virtual void activated(int iMsg)=0;
     /// Creates the used Action
-    virtual Action * createAction(void);
+    virtual Action * createAction();
     /// Applies the menu text, tool and status tip to the passed action object
     void applyCommandData(const char* context, Action* );
     const char* keySequenceToAccel(int) const;
+    void printConflictingAccelerators() const;
     //@}
 
 public:
@@ -338,11 +336,13 @@ public:
     /// CommandManager is a friend
     friend class CommandManager;
     /// Override this method if your Cmd is not always active
-    virtual bool isActive(void){return true;}
+    virtual bool isActive(){return true;}
     /// Get somtile called to check the state of the command
-    void testActive(void);
+    void testActive();
     /// Enables or disables the command
     void setEnabled(bool);
+    /// (Re)Create the text for the tooltip (for example, when the shortcut is changed)
+    void recreateTooltip(const char* context, Action*);
     /// Command trigger source
     enum TriggerSource {
         /// No external trigger, e.g. invoked through Python
@@ -372,52 +372,52 @@ public:
     /** @name Helper methods to get important classes */
     //@{
     /// Get pointer to the Application Window
-    static Application*  getGuiApplication(void);
+    static Application*  getGuiApplication();
     /// Get a reference to the selection
-    static Gui::SelectionSingleton&  getSelection(void);
+    static Gui::SelectionSingleton&  getSelection();
     /// Get pointer to the active gui document
-    Gui::Document*  getActiveGuiDocument(void) const;
+    Gui::Document*  getActiveGuiDocument() const;
     /** Get pointer to the named or active App document
      *  Returns a pointer to the named document or the active
      *  document when no name is given. NULL is returned
      *  when the name does not exist or no document is active!
      */
-    App::Document*  getDocument(const char* Name=0) const;
+    App::Document*  getDocument(const char* Name=nullptr) const;
     /// checks if the active view is of a special type or derived
     bool isViewOfType(Base::Type t) const;
     /// returns the named feature or the active one from the active document or NULL
     App::DocumentObject*  getObject(const char* Name) const;
     /// returns a python command string to retrieve an object from a document
-    static std::string getObjectCmd(const char *Name, const App::Document *doc=0,
-            const char *prefix=0, const char *postfix=0, bool gui=false);
+    static std::string getObjectCmd(const char *Name, const App::Document *doc=nullptr,
+            const char *prefix=nullptr, const char *postfix=nullptr, bool gui=false);
     /// returns a python command string to retrieve the given object
     static std::string getObjectCmd(const App::DocumentObject *obj,
-            const char *prefix=0, const char *postfix=0, bool gui=false);
+            const char *prefix=nullptr, const char *postfix=nullptr, bool gui=false);
     /** Get unique Feature name from the active document
      *
      *  @param BaseName: the base name
      *  @param obj: if not zero, then request the unique name in the document of
      *  the given object.
      */
-    std::string getUniqueObjectName(const char *BaseName, const App::DocumentObject *obj=0) const;
+    std::string getUniqueObjectName(const char *BaseName, const App::DocumentObject *obj=nullptr) const;
     //@}
 
     /** @name Helper methods for the Undo/Redo and Update handling */
     //@{
     /// Open a new Undo transaction on the active document
-    static void openCommand(const char* sName=0);
+    static void openCommand(const char* sName=nullptr);
     /// Commit the Undo transaction on the active document
-    static void commitCommand(void);
+    static void commitCommand();
     /// Abort the Undo transaction on the active document
-    static void abortCommand(void);
+    static void abortCommand();
     /// Check if an Undo transaction is open on the active document
-    static bool hasPendingCommand(void);
+    static bool hasPendingCommand();
     /// Updates the (active) document (propagate changes)
-    static void updateActive(void);
+    static void updateActive();
     /// Updates the (all or listed) documents (propagate changes)
     static void updateAll(std::list<Gui::Document*> cList);
     /// Checks if the active object of the active document is valid
-    static bool isActiveObjectValid(void);
+    static bool isActiveObjectValid();
     /// Translate command
     void languageChange();
     /// Updates the QAction with respect to the passed mode.
@@ -450,7 +450,7 @@ public:
      *
      * @sa Command::_doCommand()
      */
-#ifdef FC_OS_WIN32
+#ifdef _MSC_VER
 #define doCommand(_type,...) _doCommand(__FILE__,__LINE__,_type,##__VA_ARGS__)
 #else
 #define doCommand(...) _doCommand(__FILE__,__LINE__,__VA_ARGS__)
@@ -539,17 +539,17 @@ public:
     /** @name Helper methods to generate help pages */
     //@{
     /// returns the begin of a online help page
-    const char * beginCmdHelp(void);
+    const char * beginCmdHelp();
     /// returns the end of a online help page
-    const char * endCmdHelp(void);
+    const char * endCmdHelp();
     /// Get the help URL
-    virtual const char* getHelpUrl(void) const { return sHelpUrl; }
+    virtual const char* getHelpUrl() const { return sHelpUrl; }
     //@}
 
     /** @name Helper methods for the Active tests */
     //@{
     /// true when there is a document
-    bool hasActiveDocument(void) const;
+    bool hasActiveDocument() const;
     /// true when there is a document and a Feature with Name
     bool hasObject(const char* Name);
     //@}
@@ -557,13 +557,14 @@ public:
     /** @name checking of internal state */
     //@{
     /// returns the name to which the command belongs
-    const char* getAppModuleName(void) const {return sAppModule;}
+    const char* getAppModuleName() const {return sAppModule;}
     void setAppModuleName(const char*);
     /// Get the command name
     const char* getName() const { return sName; }
     /// Get the name of the grouping of the command
     const char* getGroupName() const { return sGroup; }
     void setGroupName(const char*);
+    QString translatedGroupName() const;
     //@}
 
 
@@ -584,6 +585,9 @@ public:
     };
     friend class LogDisabler;
 
+private:
+    void _invoke(int, bool disablelog);
+
 protected:
     enum CmdType {
         AlterDoc       = 1,  /**< Command change the Document */
@@ -630,7 +634,7 @@ public:
      * @param reg: whether to register the command with CommandManager
      * @return Return the command index.
      */
-    int addCommand(Command *cmd = 0, bool reg=true);
+    int addCommand(Command *cmd = nullptr, bool reg=true);
     /** Add child command
      * @param cmd: child command name.
      * @return Return the found command, or NULL if not found.
@@ -639,7 +643,7 @@ public:
 
 protected:
     virtual void activated(int iMsg);
-    virtual Gui::Action * createAction(void);
+    virtual Gui::Action * createAction();
     virtual void languageChange();
 
     void setup(Action *);
@@ -669,11 +673,11 @@ protected:
     /// Method which gets called when activated
     virtual void activated(int iMsg);
     /// if the command is not always active
-    virtual bool isActive(void);
+    virtual bool isActive();
     /// Get the help URL
-    const char* getHelpUrl(void) const;
+    const char* getHelpUrl() const;
     /// Creates the used Action
-    virtual Action * createAction(void);
+    virtual Action * createAction();
     //@}
 
 public:
@@ -720,11 +724,11 @@ protected:
     /// Method which gets called when activated
     virtual void activated(int iMsg);
     /// if the command is not always active
-    virtual bool isActive(void);
+    virtual bool isActive();
     /// Get the help URL
-    const char* getHelpUrl(void) const;
+    const char* getHelpUrl() const;
     /// Creates the used Action
-    virtual Action * createAction(void);
+    virtual Action * createAction();
     //@}
 
 public:
@@ -775,7 +779,7 @@ protected:
     /// Method which get called when activated
     void activated(int iMsg);
     /// Creates the used Action
-    Action * createAction(void);
+    Action * createAction();
     //@}
 
 public:
@@ -841,7 +845,7 @@ public:
      *  of a special app module use GetModuleCommands()
      *  @see Command
      */
-    std::vector <Command*> getAllCommands(void) const;
+    std::vector <Command*> getAllCommands() const;
 
     /** Returns all commands of a group
      *  delivers a vector of all commands in the given group.
@@ -862,11 +866,26 @@ public:
     /// method is OBSOLETE use GetModuleCommands() or GetAllCommands()
     const std::map<std::string, Command*>& getCommands() const { return _sCommands; }
     /// get frequently called by the AppWnd to check the commands are active.
-    void testActive(void);
+    void testActive();
 
     void addCommandMode(const char* sContext, const char* sName);
     void updateCommands(const char* sContext, int mode);
 
+    /** 
+     * Returns a pointer to a conflicting command, or nullptr if there is no conflict.
+     * In the case of multiple conflicts, only the first is returned. 
+     * \param accel The accelerator to check
+     * \param ignore (optional) A command to ignore matches with
+     */
+    const Command* checkAcceleratorForConflicts(const char* accel, const Command *ignore = nullptr) const;
+
+    /**
+     * Returns the first available command name for a new macro (e.g. starting from 1,
+     * examines the existing user preferences for Std_Macro_%1 and returns the lowest
+     * available numbered string).
+     */
+    std::string newMacroName() const;
+
 private:
     /// Destroys all commands in the manager and empties the list.
     void clearCommands();
