@@ -23,59 +23,48 @@
 
 #include "PreCompiled.h"
 #ifndef _PreComp_
+# include <Inventor/nodes/SoCamera.h>
 # include <QApplication>
 # include <QClipboard>
 # include <QDateTime>
-# include <QEventLoop>
-# include <QFileDialog>
-# include <QLabel>
 # include <QTextStream>
-# include <QStatusBar>
-# include <QPointer>
-# include <QProcess>
-# include <sstream>
-# include <Inventor/nodes/SoCamera.h>
+# include <QTreeWidgetItem> 
 #endif
-#include <algorithm>
 
 #include <boost/regex.hpp>
 #include <boost/algorithm/string/replace.hpp>
 
-#include <Base/Exception.h>
-#include <Base/FileInfo.h>
-#include <Base/Interpreter.h>
-#include <Base/Sequencer.h>
-#include <Base/Tools.h>
-#include <Base/Console.h>
 #include <App/AutoTransaction.h>
 #include <App/Document.h>
-#include <App/DocumentObjectGroup.h>
 #include <App/DocumentObject.h>
+#include <App/Expression.h>
 #include <App/GeoFeature.h>
-#include <App/Origin.h>
+#include <Base/Exception.h>
+#include <Base/FileInfo.h>
+#include <Base/Stream.h>
+#include <Base/Tools.h>
 
 #include "Action.h"
 #include "Application.h"
-#include "Document.h"
+#include "BitmapFactory.h"
 #include "Command.h"
 #include "Control.h"
 #include "FileDialog.h"
 #include "MainWindow.h"
-#include "BitmapFactory.h"
 #include "Selection.h"
+#include "DlgObjectSelection.h"
 #include "DlgProjectInformationImp.h"
 #include "DlgProjectUtility.h"
-#include "Transform.h"
-#include "Placement.h"
+#include "GraphvizView.h"
 #include "ManualAlignment.h"
-#include "WaitCursor.h"
-#include "ViewProvider.h"
-#include <Gui/View3DInventor.h>
-#include <Gui/View3DInventorViewer.h>
 #include "MergeDocuments.h"
 #include "NavigationStyle.h"
-#include "GraphvizView.h"
-#include "DlgObjectSelection.h"
+#include "Placement.h"
+#include "Transform.h"
+#include "View3DInventor.h"
+#include "View3DInventorViewer.h"
+#include "ViewProvider.h"
+#include "WaitCursor.h"
 
 FC_LOG_LEVEL_INIT("Command", false)
 
@@ -92,7 +81,7 @@ StdCmdOpen::StdCmdOpen()
   : Command("Std_Open")
 {
     // setting the
-    sGroup        = QT_TR_NOOP("File");
+    sGroup        = "File";
     sMenuText     = QT_TR_NOOP("&Open...");
     sToolTipText  = QT_TR_NOOP("Open a document or import files");
     sWhatsThis    = "Std_Open";
@@ -183,7 +172,7 @@ StdCmdImport::StdCmdImport()
   : Command("Std_Import")
 {
     // setting the
-    sGroup        = QT_TR_NOOP("File");
+    sGroup        = "File";
     sMenuText     = QT_TR_NOOP("&Import...");
     sToolTipText  = QT_TR_NOOP("Import a file in the active document");
     sWhatsThis    = "Std_Import";
@@ -253,7 +242,7 @@ void StdCmdImport::activated(int iMsg)
     }
 }
 
-bool StdCmdImport::isActive(void)
+bool StdCmdImport::isActive()
 {
     return (getActiveGuiDocument() ? true : false);
 }
@@ -269,7 +258,7 @@ StdCmdExport::StdCmdExport()
   : Command("Std_Export")
 {
     // setting the
-    sGroup        = QT_TR_NOOP("File");
+    sGroup        = "File";
     sMenuText     = QT_TR_NOOP("&Export...");
     sToolTipText  = QT_TR_NOOP("Export an object in the active document");
     sWhatsThis    = "Std_Export";
@@ -501,7 +490,7 @@ void StdCmdExport::activated(int iMsg)
     }
 }
 
-bool StdCmdExport::isActive(void)
+bool StdCmdExport::isActive()
 {
     return (getActiveGuiDocument() ? true : false);
 }
@@ -516,7 +505,7 @@ StdCmdMergeProjects::StdCmdMergeProjects()
   : Command("Std_MergeProjects")
 {
     sAppModule    = "File";
-    sGroup        = QT_TR_NOOP("File");
+    sGroup        = "File";
     sMenuText     = QT_TR_NOOP("Merge project...");
     sToolTipText  = QT_TR_NOOP("Merge project");
     sWhatsThis    = "Std_MergeProjects";
@@ -554,7 +543,7 @@ void StdCmdMergeProjects::activated(int iMsg)
     }
 }
 
-bool StdCmdMergeProjects::isActive(void)
+bool StdCmdMergeProjects::isActive()
 {
     return this->hasActiveDocument();
 }
@@ -569,7 +558,7 @@ StdCmdDependencyGraph::StdCmdDependencyGraph()
   : Command("Std_DependencyGraph")
 {
     // setting the
-    sGroup        = QT_TR_NOOP("Tools");
+    sGroup        = "Tools";
     sMenuText     = QT_TR_NOOP("Dependency graph...");
     sToolTipText  = QT_TR_NOOP("Show the dependency graph of the objects in the active document");
     sStatusTip    = QT_TR_NOOP("Show the dependency graph of the objects in the active document");
@@ -587,7 +576,7 @@ void StdCmdDependencyGraph::activated(int iMsg)
     getMainWindow()->addWindow(view);
 }
 
-bool StdCmdDependencyGraph::isActive(void)
+bool StdCmdDependencyGraph::isActive()
 {
     return (getActiveGuiDocument() ? true : false);
 }
@@ -601,7 +590,7 @@ DEF_STD_CMD(StdCmdNew)
 StdCmdNew::StdCmdNew()
   :Command("Std_New")
 {
-    sGroup        = QT_TR_NOOP("File");
+    sGroup        = "File";
     sMenuText     = QT_TR_NOOP("&New");
     sToolTipText  = QT_TR_NOOP("Create a new empty document");
     sWhatsThis    = "Std_New";
@@ -632,7 +621,7 @@ DEF_STD_CMD_A(StdCmdSave)
 StdCmdSave::StdCmdSave()
   :Command("Std_Save")
 {
-  sGroup        = QT_TR_NOOP("File");
+  sGroup        = "File";
   sMenuText     = QT_TR_NOOP("&Save");
   sToolTipText  = QT_TR_NOOP("Save the active document");
   sWhatsThis    = "Std_Save";
@@ -654,7 +643,7 @@ void StdCmdSave::activated(int iMsg)
     doCommand(Command::Gui,"Gui.SendMsgToActiveView(\"Save\")");
 }
 
-bool StdCmdSave::isActive(void)
+bool StdCmdSave::isActive()
 {
 #if 0
   if( getActiveGuiDocument() )
@@ -672,14 +661,12 @@ DEF_STD_CMD_A(StdCmdSaveAs)
 StdCmdSaveAs::StdCmdSaveAs()
   :Command("Std_SaveAs")
 {
-  sGroup        = QT_TR_NOOP("File");
+  sGroup        = "File";
   sMenuText     = QT_TR_NOOP("Save &As...");
   sToolTipText  = QT_TR_NOOP("Save the active document under a new file name");
   sWhatsThis    = "Std_SaveAs";
   sStatusTip    = QT_TR_NOOP("Save the active document under a new file name");
-#if QT_VERSION >= 0x040200
   sPixmap       = "document-save-as";
-#endif
   sAccel        = keySequenceToAccel(QKeySequence::SaveAs);
   eType         = 0;
 }
@@ -696,7 +683,7 @@ void StdCmdSaveAs::activated(int iMsg)
     doCommand(Command::Gui,"Gui.SendMsgToActiveView(\"SaveAs\")");
 }
 
-bool StdCmdSaveAs::isActive(void)
+bool StdCmdSaveAs::isActive()
 {
 #if 0
   if( getActiveGuiDocument() )
@@ -714,7 +701,7 @@ DEF_STD_CMD_A(StdCmdSaveCopy)
 StdCmdSaveCopy::StdCmdSaveCopy()
   :Command("Std_SaveCopy")
 {
-  sGroup        = QT_TR_NOOP("File");
+  sGroup        = "File";
   sMenuText     = QT_TR_NOOP("Save a &Copy...");
   sToolTipText  = QT_TR_NOOP("Save a copy of the active document under a new file name");
   sWhatsThis    = "Std_SaveCopy";
@@ -734,7 +721,7 @@ void StdCmdSaveCopy::activated(int iMsg)
     doCommand(Command::Gui,"Gui.SendMsgToActiveView(\"SaveCopy\")");
 }
 
-bool StdCmdSaveCopy::isActive(void)
+bool StdCmdSaveCopy::isActive()
 {
   return ( getActiveGuiDocument() ? true : false );
 }
@@ -747,7 +734,7 @@ DEF_STD_CMD_A(StdCmdSaveAll)
 StdCmdSaveAll::StdCmdSaveAll()
   :Command("Std_SaveAll")
 {
-  sGroup        = QT_TR_NOOP("File");
+  sGroup        = "File";
   sMenuText     = QT_TR_NOOP("Save All");
   sToolTipText  = QT_TR_NOOP("Save all opened document");
   sWhatsThis    = "Std_SaveAll";
@@ -761,7 +748,7 @@ void StdCmdSaveAll::activated(int iMsg)
     Gui::Document::saveAll();
 }
 
-bool StdCmdSaveAll::isActive(void)
+bool StdCmdSaveAll::isActive()
 {
   return ( getActiveGuiDocument() ? true : false );
 }
@@ -775,7 +762,7 @@ DEF_STD_CMD_A(StdCmdRevert)
 StdCmdRevert::StdCmdRevert()
   :Command("Std_Revert")
 {
-    sGroup        = QT_TR_NOOP("File");
+    sGroup        = "File";
     sMenuText     = QT_TR_NOOP("Revert");
     sToolTipText  = QT_TR_NOOP("Reverts to the saved version of this file");
     sWhatsThis    = "Std_Revert";
@@ -799,7 +786,7 @@ void StdCmdRevert::activated(int iMsg)
         doCommand(Command::App,"App.ActiveDocument.restore()");
 }
 
-bool StdCmdRevert::isActive(void)
+bool StdCmdRevert::isActive()
 {
   return ( getActiveGuiDocument() ? true : false );
 }
@@ -814,14 +801,12 @@ StdCmdProjectInfo::StdCmdProjectInfo()
   :Command("Std_ProjectInfo")
 {
   // setting the
-  sGroup        = QT_TR_NOOP("File");
+  sGroup        = "File";
   sMenuText     = QT_TR_NOOP("Project i&nformation...");
   sToolTipText  = QT_TR_NOOP("Show details of the currently active project");
   sWhatsThis    = "Std_ProjectInfo";
   sStatusTip    = QT_TR_NOOP("Show details of the currently active project");
-#if QT_VERSION >= 0x040200
   sPixmap       = "document-properties";
-#endif
 }
 
 void StdCmdProjectInfo::activated(int iMsg)
@@ -831,7 +816,7 @@ void StdCmdProjectInfo::activated(int iMsg)
     dlg.exec();
 }
 
-bool StdCmdProjectInfo::isActive(void)
+bool StdCmdProjectInfo::isActive()
 {
   return ( getActiveGuiDocument() ? true : false );
 }
@@ -846,7 +831,7 @@ StdCmdProjectUtil::StdCmdProjectUtil()
   :Command("Std_ProjectUtil")
 {
     // setting the
-    sGroup        = QT_TR_NOOP("Tools");
+    sGroup        = "Tools";
     sWhatsThis    = "Std_ProjectUtil";
     sMenuText     = QT_TR_NOOP("Project utility...");
     sToolTipText  = QT_TR_NOOP("Utility to extract or create project files");
@@ -861,7 +846,7 @@ void StdCmdProjectUtil::activated(int iMsg)
     dlg.exec();
 }
 
-bool StdCmdProjectUtil::isActive(void)
+bool StdCmdProjectUtil::isActive()
 {
     return true;
 }
@@ -874,7 +859,7 @@ DEF_STD_CMD_A(StdCmdPrint)
 StdCmdPrint::StdCmdPrint()
   :Command("Std_Print")
 {
-    sGroup        = QT_TR_NOOP("File");
+    sGroup        = "File";
     sMenuText     = QT_TR_NOOP("&Print...");
     sToolTipText  = QT_TR_NOOP("Print the document");
     sWhatsThis    = "Std_Print";
@@ -893,7 +878,7 @@ void StdCmdPrint::activated(int iMsg)
     }
 }
 
-bool StdCmdPrint::isActive(void)
+bool StdCmdPrint::isActive()
 {
     return getGuiApplication()->sendHasMsgToActiveView("Print");
 }
@@ -906,7 +891,7 @@ DEF_STD_CMD_A(StdCmdPrintPreview)
 StdCmdPrintPreview::StdCmdPrintPreview()
   :Command("Std_PrintPreview")
 {
-    sGroup        = QT_TR_NOOP("File");
+    sGroup        = "File";
     sMenuText     = QT_TR_NOOP("&Print preview...");
     sToolTipText  = QT_TR_NOOP("Print the document");
     sWhatsThis    = "Std_PrintPreview";
@@ -923,7 +908,7 @@ void StdCmdPrintPreview::activated(int iMsg)
     }
 }
 
-bool StdCmdPrintPreview::isActive(void)
+bool StdCmdPrintPreview::isActive()
 {
     return getGuiApplication()->sendHasMsgToActiveView("PrintPreview");
 }
@@ -936,7 +921,7 @@ DEF_STD_CMD_A(StdCmdPrintPdf)
 StdCmdPrintPdf::StdCmdPrintPdf()
   :Command("Std_PrintPdf")
 {
-    sGroup        = QT_TR_NOOP("File");
+    sGroup        = "File";
     sMenuText     = QT_TR_NOOP("&Export PDF...");
     sToolTipText  = QT_TR_NOOP("Export the document as PDF");
     sWhatsThis    = "Std_PrintPdf";
@@ -954,7 +939,7 @@ void StdCmdPrintPdf::activated(int iMsg)
     }
 }
 
-bool StdCmdPrintPdf::isActive(void)
+bool StdCmdPrintPdf::isActive()
 {
     return getGuiApplication()->sendHasMsgToActiveView("PrintPdf");
 }
@@ -968,15 +953,13 @@ DEF_STD_CMD(StdCmdQuit)
 StdCmdQuit::StdCmdQuit()
   :Command("Std_Quit")
 {
-  sGroup        = QT_TR_NOOP("File");
+  sGroup        = "File";
   sMenuText     = QT_TR_NOOP("E&xit");
   sToolTipText  = QT_TR_NOOP("Quits the application");
   sWhatsThis    = "Std_Quit";
   sStatusTip    = QT_TR_NOOP("Quits the application");
-#if QT_VERSION >= 0x040200
   sPixmap       = "application-exit";
-#endif
-  sAccel        = "Alt+F4";
+  sAccel        = keySequenceToAccel(QKeySequence::Quit);
   eType         = NoTransaction;
 }
 
@@ -996,7 +979,7 @@ DEF_STD_CMD_AC(StdCmdUndo)
 StdCmdUndo::StdCmdUndo()
   :Command("Std_Undo")
 {
-  sGroup        = QT_TR_NOOP("Edit");
+  sGroup        = "Edit";
   sMenuText     = QT_TR_NOOP("&Undo");
   sToolTipText  = QT_TR_NOOP("Undo exactly one action");
   sWhatsThis    = "Std_Undo";
@@ -1013,20 +996,20 @@ void StdCmdUndo::activated(int iMsg)
     getGuiApplication()->sendMsgToActiveView("Undo");
 }
 
-bool StdCmdUndo::isActive(void)
+bool StdCmdUndo::isActive()
 {
   return getGuiApplication()->sendHasMsgToActiveView("Undo");
 }
 
-Action * StdCmdUndo::createAction(void)
+Action * StdCmdUndo::createAction()
 {
     Action *pcAction;
 
     pcAction = new UndoAction(this,getMainWindow());
-    pcAction->setShortcut(QString::fromLatin1(sAccel));
+    pcAction->setShortcut(QString::fromLatin1(getAccel()));
     applyCommandData(this->className(), pcAction);
-    if (sPixmap)
-        pcAction->setIcon(Gui::BitmapFactory().iconFromTheme(sPixmap));
+    if (getPixmap())
+        pcAction->setIcon(Gui::BitmapFactory().iconFromTheme(getPixmap()));
 
     return pcAction;
 }
@@ -1040,7 +1023,7 @@ DEF_STD_CMD_AC(StdCmdRedo)
 StdCmdRedo::StdCmdRedo()
   :Command("Std_Redo")
 {
-  sGroup        = QT_TR_NOOP("Edit");
+  sGroup        = "Edit";
   sMenuText     = QT_TR_NOOP("&Redo");
   sToolTipText  = QT_TR_NOOP("Redoes a previously undone action");
   sWhatsThis    = "Std_Redo";
@@ -1057,20 +1040,20 @@ void StdCmdRedo::activated(int iMsg)
     getGuiApplication()->sendMsgToActiveView("Redo");
 }
 
-bool StdCmdRedo::isActive(void)
+bool StdCmdRedo::isActive()
 {
   return getGuiApplication()->sendHasMsgToActiveView("Redo");
 }
 
-Action * StdCmdRedo::createAction(void)
+Action * StdCmdRedo::createAction()
 {
     Action *pcAction;
 
     pcAction = new RedoAction(this,getMainWindow());
-    pcAction->setShortcut(QString::fromLatin1(sAccel));
+    pcAction->setShortcut(QString::fromLatin1(getAccel()));
     applyCommandData(this->className(), pcAction);
-    if (sPixmap)
-        pcAction->setIcon(Gui::BitmapFactory().iconFromTheme(sPixmap));
+    if (getPixmap())
+        pcAction->setIcon(Gui::BitmapFactory().iconFromTheme(getPixmap()));
 
     return pcAction;
 }
@@ -1083,7 +1066,7 @@ DEF_STD_CMD_A(StdCmdCut)
 StdCmdCut::StdCmdCut()
   : Command("Std_Cut")
 {
-    sGroup        = QT_TR_NOOP("Edit");
+    sGroup        = "Edit";
     sMenuText     = QT_TR_NOOP("&Cut");
     sToolTipText  = QT_TR_NOOP("Cut out");
     sWhatsThis    = "Std_Cut";
@@ -1098,7 +1081,7 @@ void StdCmdCut::activated(int iMsg)
     getGuiApplication()->sendMsgToActiveView("Cut");
 }
 
-bool StdCmdCut::isActive(void)
+bool StdCmdCut::isActive()
 {
     return getGuiApplication()->sendHasMsgToActiveView("Cut");
 }
@@ -1111,7 +1094,7 @@ DEF_STD_CMD_A(StdCmdCopy)
 StdCmdCopy::StdCmdCopy()
   : Command("Std_Copy")
 {
-    sGroup        = QT_TR_NOOP("Edit");
+    sGroup        = "Edit";
     sMenuText     = QT_TR_NOOP("C&opy");
     sToolTipText  = QT_TR_NOOP("Copy operation");
     sWhatsThis    = "Std_Copy";
@@ -1131,7 +1114,7 @@ void StdCmdCopy::activated(int iMsg)
     }
 }
 
-bool StdCmdCopy::isActive(void)
+bool StdCmdCopy::isActive()
 {
     if (getGuiApplication()->sendHasMsgToFocusView("Copy"))
         return true;
@@ -1146,7 +1129,7 @@ DEF_STD_CMD_A(StdCmdPaste)
 StdCmdPaste::StdCmdPaste()
   : Command("Std_Paste")
 {
-    sGroup        = QT_TR_NOOP("Edit");
+    sGroup        = "Edit";
     sMenuText     = QT_TR_NOOP("&Paste");
     sToolTipText  = QT_TR_NOOP("Paste operation");
     sWhatsThis    = "Std_Paste";
@@ -1169,13 +1152,14 @@ void StdCmdPaste::activated(int iMsg)
     }
 }
 
-bool StdCmdPaste::isActive(void)
+bool StdCmdPaste::isActive()
 {
     if (getGuiApplication()->sendHasMsgToFocusView("Paste"))
         return true;
     QClipboard* cb = QApplication::clipboard();
     const QMimeData* mime = cb->mimeData();
-    if (!mime) return false;
+    if (!mime)
+        return false;
     return getMainWindow()->canInsertFromMimeData(mime);
 }
 
@@ -1185,7 +1169,7 @@ StdCmdDuplicateSelection::StdCmdDuplicateSelection()
   :Command("Std_DuplicateSelection")
 {
     sAppModule    = "Edit";
-    sGroup        = QT_TR_NOOP("Edit");
+    sGroup        = "Edit";
     sMenuText     = QT_TR_NOOP("Duplicate selection");
     sToolTipText  = QT_TR_NOOP("Put duplicates of the selected objects to the active document");
     sWhatsThis    = "Std_DuplicateSelection";
@@ -1259,7 +1243,7 @@ void StdCmdDuplicateSelection::activated(int iMsg)
     fi.deleteFile();
 }
 
-bool StdCmdDuplicateSelection::isActive(void)
+bool StdCmdDuplicateSelection::isActive()
 {
     return Gui::Selection().hasSelection();
 }
@@ -1273,14 +1257,12 @@ DEF_STD_CMD_A(StdCmdSelectAll)
 StdCmdSelectAll::StdCmdSelectAll()
   : Command("Std_SelectAll")
 {
-    sGroup        = QT_TR_NOOP("Edit");
+    sGroup        = "Edit";
     sMenuText     = QT_TR_NOOP("Select &All");
     sToolTipText  = QT_TR_NOOP("Select all");
     sWhatsThis    = "Std_SelectAll";
     sStatusTip    = QT_TR_NOOP("Select all");
-#if QT_VERSION >= 0x040200
     sPixmap       = "edit-select-all";
-#endif
     //sAccel        = "Ctrl+A"; // superseeds shortcuts for text edits
 }
 
@@ -1293,9 +1275,9 @@ void StdCmdSelectAll::activated(int iMsg)
     rSel.setSelection(doc->getName(), objs);
 }
 
-bool StdCmdSelectAll::isActive(void)
+bool StdCmdSelectAll::isActive()
 {
-    return App::GetApplication().getActiveDocument() != 0;
+    return App::GetApplication().getActiveDocument() != nullptr;
 }
 
 //===========================================================================
@@ -1306,14 +1288,12 @@ DEF_STD_CMD_A(StdCmdDelete)
 StdCmdDelete::StdCmdDelete()
   :Command("Std_Delete")
 {
-  sGroup        = QT_TR_NOOP("Edit");
+  sGroup        = "Edit";
   sMenuText     = QT_TR_NOOP("&Delete");
   sToolTipText  = QT_TR_NOOP("Deletes the selected objects");
   sWhatsThis    = "Std_Delete";
   sStatusTip    = QT_TR_NOOP("Deletes the selected objects");
-#if QT_VERSION >= 0x040200
   sPixmap       = "edit-delete";
-#endif
   sAccel        = keySequenceToAccel(QKeySequence::Delete);
   eType         = ForEdit;
 }
@@ -1334,7 +1314,7 @@ void StdCmdDelete::activated(int iMsg)
 
         Gui::getMainWindow()->setUpdatesEnabled(false);
         auto editDoc = Application::Instance->editDocument();
-        ViewProviderDocumentObject *vpedit = 0;
+        ViewProviderDocumentObject *vpedit = nullptr;
         if(editDoc)
             vpedit = dynamic_cast<ViewProviderDocumentObject*>(editDoc->getInEdit());
         if(vpedit) {
@@ -1433,8 +1413,8 @@ void StdCmdDelete::activated(int iMsg)
                     if (vp) {
                         // ask the ViewProvider if it wants to do some clean up
                         if (vp->onDelete(sel.getSubNames())) {
-                            FCMD_OBJ_DOC_CMD(obj,"removeObject('" << obj->getNameInDocument() << "')");
                             docs.insert(obj->getDocument());
+                            FCMD_OBJ_DOC_CMD(obj,"removeObject('" << obj->getNameInDocument() << "')");
                         }
                     }
                 }
@@ -1468,7 +1448,7 @@ void StdCmdDelete::activated(int iMsg)
     Gui::getMainWindow()->update();
 }
 
-bool StdCmdDelete::isActive(void)
+bool StdCmdDelete::isActive()
 {
     return Selection().getCompleteSelection().size() > 0;
 }
@@ -1481,7 +1461,7 @@ DEF_STD_CMD_A(StdCmdRefresh)
 StdCmdRefresh::StdCmdRefresh()
   : Command("Std_Refresh")
 {
-    sGroup        = QT_TR_NOOP("Edit");
+    sGroup        = "Edit";
     sMenuText     = QT_TR_NOOP("&Refresh");
     sToolTipText  = QT_TR_NOOP("Recomputes the current active document");
     sWhatsThis    = "Std_Refresh";
@@ -1522,7 +1502,7 @@ void StdCmdRefresh::activated(int iMsg)
     }
 }
 
-bool StdCmdRefresh::isActive(void)
+bool StdCmdRefresh::isActive()
 {
     return this->getDocument() && this->getDocument()->mustExecute();
 }
@@ -1535,7 +1515,7 @@ DEF_STD_CMD_A(StdCmdTransform)
 StdCmdTransform::StdCmdTransform()
   : Command("Std_Transform")
 {
-    sGroup        = QT_TR_NOOP("Edit");
+    sGroup        = "Edit";
     sMenuText     = QT_TR_NOOP("Transform...");
     sToolTipText  = QT_TR_NOOP("Transform the geometry of selected objects");
     sStatusTip    = QT_TR_NOOP("Transform the geometry of selected objects");
@@ -1548,9 +1528,9 @@ void StdCmdTransform::activated(int iMsg)
     Gui::Control().showDialog(new Gui::Dialog::TaskTransform());
 }
 
-bool StdCmdTransform::isActive(void)
+bool StdCmdTransform::isActive()
 {
-    return (Gui::Control().activeDialog()==0);
+    return (Gui::Control().activeDialog()==nullptr);
 }
 
 //===========================================================================
@@ -1561,7 +1541,7 @@ DEF_STD_CMD_A(StdCmdPlacement)
 StdCmdPlacement::StdCmdPlacement()
   : Command("Std_Placement")
 {
-    sGroup        = QT_TR_NOOP("Edit");
+    sGroup        = "Edit";
     sMenuText     = QT_TR_NOOP("Placement...");
     sToolTipText  = QT_TR_NOOP("Place the selected objects");
     sStatusTip    = QT_TR_NOOP("Place the selected objects");
@@ -1582,9 +1562,9 @@ void StdCmdPlacement::activated(int iMsg)
     Gui::Control().showDialog(plm);
 }
 
-bool StdCmdPlacement::isActive(void)
+bool StdCmdPlacement::isActive()
 {
-    return (Gui::Control().activeDialog()==0);
+    return Gui::Selection().countObjectsOfType(App::GeoFeature::getClassTypeId()) >= 1;
 }
 
 //===========================================================================
@@ -1595,11 +1575,12 @@ DEF_STD_CMD_A(StdCmdTransformManip)
 StdCmdTransformManip::StdCmdTransformManip()
   : Command("Std_TransformManip")
 {
-    sGroup        = QT_TR_NOOP("Edit");
+    sGroup        = "Edit";
     sMenuText     = QT_TR_NOOP("Transform");
     sToolTipText  = QT_TR_NOOP("Transform the selected object in the 3d view");
     sStatusTip    = QT_TR_NOOP("Transform the selected object in the 3d view");
     sWhatsThis    = "Std_TransformManip";
+    sPixmap       = "Std_TransformManip";
 }
 
 void StdCmdTransformManip::activated(int iMsg)
@@ -1615,7 +1596,7 @@ void StdCmdTransformManip::activated(int iMsg)
         getActiveGuiDocument()->setEdit(vp, Gui::ViewProvider::Transform);
 }
 
-bool StdCmdTransformManip::isActive(void)
+bool StdCmdTransformManip::isActive()
 {
     return Gui::Selection().countObjectsOfType(App::GeoFeature::getClassTypeId()) == 1;
 }
@@ -1628,7 +1609,7 @@ DEF_STD_CMD_A(StdCmdAlignment)
 StdCmdAlignment::StdCmdAlignment()
   : Command("Std_Alignment")
 {
-    sGroup        = QT_TR_NOOP("Edit");
+    sGroup        = "Edit";
     sMenuText     = QT_TR_NOOP("Alignment...");
     sToolTipText  = QT_TR_NOOP("Align the selected objects");
     sStatusTip    = QT_TR_NOOP("Align the selected objects");
@@ -1683,7 +1664,7 @@ void StdCmdAlignment::activated(int iMsg)
     Gui::Selection().clearSelection();
 }
 
-bool StdCmdAlignment::isActive(void)
+bool StdCmdAlignment::isActive()
 {
     if (ManualAlignment::hasInstance())
         return false;
@@ -1698,15 +1679,13 @@ DEF_STD_CMD_A(StdCmdEdit)
 StdCmdEdit::StdCmdEdit()
   : Command("Std_Edit")
 {
-    sGroup        = QT_TR_NOOP("Edit");
+    sGroup        = "Edit";
     sMenuText     = QT_TR_NOOP("Toggle &Edit mode");
     sToolTipText  = QT_TR_NOOP("Toggles the selected object's edit mode");
     sWhatsThis    = "Std_Edit";
     sStatusTip    = QT_TR_NOOP("Activates or Deactivates the selected object's edit mode");
     sAccel        = "";
-#if QT_VERSION >= 0x040200
     sPixmap       = "edit-edit";
-#endif
     eType         = ForEdit;
 }
 
@@ -1727,9 +1706,9 @@ void StdCmdEdit::activated(int iMsg)
     }
 }
 
-bool StdCmdEdit::isActive(void)
+bool StdCmdEdit::isActive()
 {
-    return (Selection().getCompleteSelection().size() > 0) || (Gui::Control().activeDialog() != 0);
+    return (Selection().getCompleteSelection().size() > 0) || (Gui::Control().activeDialog() != nullptr);
 }
 
 //======================================================================
@@ -1744,7 +1723,7 @@ public:
                        , pcActionCopyActive(nullptr)
                        , pcActionPaste(nullptr)
     {
-        sGroup        = QT_TR_NOOP("Edit");
+        sGroup        = "Edit";
         sMenuText     = QT_TR_NOOP("Expression actions");
         sToolTipText  = QT_TR_NOOP("Expression actions");
         sWhatsThis    = "Std_Expressions";
@@ -1784,7 +1763,7 @@ protected:
         copyExpressions(objs);
     }
 
-    virtual Gui::Action * createAction(void) {
+    virtual Gui::Action * createAction() {
         ActionGroup* pcAction = new ActionGroup(this, getMainWindow());
         pcAction->setDropDownMenu(true);
         applyCommandData(this->className(), pcAction);
@@ -1953,7 +1932,7 @@ protected:
 
 namespace Gui {
 
-void CreateDocCommands(void)
+void CreateDocCommands()
 {
     CommandManager &rcCmdMgr = Application::Instance->commandManager();
 
