@@ -20,31 +20,29 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
-#ifndef _PreComp_
-#endif
 
 #include "Command.h"
 #include "Application.h"
-#include "MainWindow.h"
 #include "DlgMacroExecuteImp.h"
 #include "DlgMacroRecordImp.h"
 #include "Macro.h"
+#include "MainWindow.h"
 #include "PythonDebugger.h"
 
+
 using namespace Gui;
 
 
 //===========================================================================
 // Std_DlgMacroRecord
 //===========================================================================
-DEF_STD_CMD_A(StdCmdDlgMacroRecord);
+DEF_STD_CMD_A(StdCmdDlgMacroRecord)
 
 StdCmdDlgMacroRecord::StdCmdDlgMacroRecord()
   : Command("Std_DlgMacroRecord")
 {
-    sGroup        = QT_TR_NOOP("Macro");
+    sGroup        = "Macro";
     sMenuText     = QT_TR_NOOP("&Macro recording ...");
     sToolTipText  = QT_TR_NOOP("Opens a dialog to record a macro");
     sWhatsThis    = "Std_DlgMacroRecord";
@@ -55,12 +53,12 @@ StdCmdDlgMacroRecord::StdCmdDlgMacroRecord()
 
 void StdCmdDlgMacroRecord::activated(int iMsg)
 {
-    Q_UNUSED(iMsg); 
+    Q_UNUSED(iMsg);
     Gui::Dialog::DlgMacroRecordImp cDlg(getMainWindow());
     cDlg.exec();
 }
 
-bool StdCmdDlgMacroRecord::isActive(void)
+bool StdCmdDlgMacroRecord::isActive()
 {
     return ! (getGuiApplication()->macroManager()->isOpen());
 }
@@ -68,12 +66,12 @@ bool StdCmdDlgMacroRecord::isActive(void)
 //===========================================================================
 // Std_MacroStopRecord
 //===========================================================================
-DEF_STD_CMD_A(StdCmdMacroStopRecord);
+DEF_STD_CMD_A(StdCmdMacroStopRecord)
 
 StdCmdMacroStopRecord::StdCmdMacroStopRecord()
   : Command("Std_MacroStopRecord")
 {
-    sGroup        = QT_TR_NOOP("Macro");
+    sGroup        = "Macro";
     sMenuText     = QT_TR_NOOP("S&top macro recording");
     sToolTipText  = QT_TR_NOOP("Stop the macro recording session");
     sWhatsThis    = "Std_MacroStopRecord";
@@ -84,11 +82,11 @@ StdCmdMacroStopRecord::StdCmdMacroStopRecord()
 
 void StdCmdMacroStopRecord::activated(int iMsg)
 {
-    Q_UNUSED(iMsg); 
+    Q_UNUSED(iMsg);
     getGuiApplication()->macroManager()->commit();
 }
 
-bool StdCmdMacroStopRecord::isActive(void)
+bool StdCmdMacroStopRecord::isActive()
 {
     return getGuiApplication()->macroManager()->isOpen();
 }
@@ -96,12 +94,12 @@ bool StdCmdMacroStopRecord::isActive(void)
 //===========================================================================
 // Std_DlgMacroExecute
 //===========================================================================
-DEF_STD_CMD_A(StdCmdDlgMacroExecute);
+DEF_STD_CMD_A(StdCmdDlgMacroExecute)
 
 StdCmdDlgMacroExecute::StdCmdDlgMacroExecute()
   : Command("Std_DlgMacroExecute")
 {
-    sGroup        = QT_TR_NOOP("Macro");
+    sGroup        = "Macro";
     sMenuText     = QT_TR_NOOP("Macros ...");
     sToolTipText  = QT_TR_NOOP("Opens a dialog to let you execute a recorded macro");
     sWhatsThis    = "Std_DlgMacroExecute";
@@ -112,12 +110,12 @@ StdCmdDlgMacroExecute::StdCmdDlgMacroExecute()
 
 void StdCmdDlgMacroExecute::activated(int iMsg)
 {
-    Q_UNUSED(iMsg); 
+    Q_UNUSED(iMsg);
     Gui::Dialog::DlgMacroExecuteImp cDlg(getMainWindow());
     cDlg.exec();
 }
 
-bool StdCmdDlgMacroExecute::isActive(void)
+bool StdCmdDlgMacroExecute::isActive()
 {
     return ! (getGuiApplication()->macroManager()->isOpen());
 }
@@ -125,12 +123,12 @@ bool StdCmdDlgMacroExecute::isActive(void)
 //===========================================================================
 // Std_DlgMacroExecuteDirect
 //===========================================================================
-DEF_STD_CMD_A(StdCmdDlgMacroExecuteDirect);
+DEF_STD_CMD_A(StdCmdDlgMacroExecuteDirect)
 
 StdCmdDlgMacroExecuteDirect::StdCmdDlgMacroExecuteDirect()
   : Command("Std_DlgMacroExecuteDirect")
 {
-    sGroup        = QT_TR_NOOP("Macro");
+    sGroup        = "Macro";
     sMenuText     = QT_TR_NOOP("Execute macro");
     sToolTipText  = QT_TR_NOOP("Execute the macro in the editor");
     sWhatsThis    = "Std_DlgMacroExecuteDirect";
@@ -142,21 +140,46 @@ StdCmdDlgMacroExecuteDirect::StdCmdDlgMacroExecuteDirect()
 
 void StdCmdDlgMacroExecuteDirect::activated(int iMsg)
 {
-    Q_UNUSED(iMsg); 
+    Q_UNUSED(iMsg);
     doCommand(Command::Gui,"Gui.SendMsgToActiveView(\"Run\")");
 }
 
-bool StdCmdDlgMacroExecuteDirect::isActive(void)
+bool StdCmdDlgMacroExecuteDirect::isActive()
 {
     return getGuiApplication()->sendHasMsgToActiveView("Run");
 }
 
-DEF_STD_CMD_A(StdCmdMacroStartDebug);
+DEF_STD_CMD_A(StdCmdMacroAttachDebugger)
+
+StdCmdMacroAttachDebugger::StdCmdMacroAttachDebugger()
+  : Command("Std_MacroAttachDebugger")
+{
+    sGroup        = "Macro";
+    sMenuText     = QT_TR_NOOP("Attach to remote debugger...");
+    sToolTipText  = QT_TR_NOOP("Attach to a remotely running debugger");
+    sWhatsThis    = "Std_MacroAttachDebugger";
+    sStatusTip    = QT_TR_NOOP("Attach to a remotely running debugger");
+    eType         = 0;
+}
+
+void StdCmdMacroAttachDebugger::activated(int iMsg)
+{
+    Q_UNUSED(iMsg);
+    doCommand(Gui, "from freecad.gui import RemoteDebugger\n"
+                   "RemoteDebugger.attachToRemoteDebugger()");
+}
+
+bool StdCmdMacroAttachDebugger::isActive()
+{
+    return true;
+}
+
+DEF_STD_CMD_A(StdCmdMacroStartDebug)
 
 StdCmdMacroStartDebug::StdCmdMacroStartDebug()
   : Command("Std_MacroStartDebug")
 {
-    sGroup        = QT_TR_NOOP("Macro");
+    sGroup        = "Macro";
     sMenuText     = QT_TR_NOOP("Debug macro");
     sToolTipText  = QT_TR_NOOP("Start debugging of macro");
     sWhatsThis    = "Std_MacroStartDebug";
@@ -168,7 +191,7 @@ StdCmdMacroStartDebug::StdCmdMacroStartDebug()
 
 void StdCmdMacroStartDebug::activated(int iMsg)
 {
-    Q_UNUSED(iMsg); 
+    Q_UNUSED(iMsg);
     PythonDebugger* dbg = Application::Instance->macroManager()->debugger();
     if (!dbg->isRunning())
         doCommand(Command::Gui,"Gui.SendMsgToActiveView(\"StartDebug\")");
@@ -176,17 +199,17 @@ void StdCmdMacroStartDebug::activated(int iMsg)
         dbg->stepRun();
 }
 
-bool StdCmdMacroStartDebug::isActive(void)
+bool StdCmdMacroStartDebug::isActive()
 {
     return getGuiApplication()->sendHasMsgToActiveView("StartDebug");
 }
 
-DEF_STD_CMD_A(StdCmdMacroStopDebug);
+DEF_STD_CMD_A(StdCmdMacroStopDebug)
 
 StdCmdMacroStopDebug::StdCmdMacroStopDebug()
   : Command("Std_MacroStopDebug")
 {
-    sGroup        = QT_TR_NOOP("Macro");
+    sGroup        = "Macro";
     sMenuText     = QT_TR_NOOP("Stop debugging");
     sToolTipText  = QT_TR_NOOP("Stop debugging of macro");
     sWhatsThis    = "Std_MacroStopDebug";
@@ -198,105 +221,106 @@ StdCmdMacroStopDebug::StdCmdMacroStopDebug()
 
 void StdCmdMacroStopDebug::activated(int iMsg)
 {
-    Q_UNUSED(iMsg); 
+    Q_UNUSED(iMsg);
     Application::Instance->macroManager()->debugger()->tryStop();
 }
 
-bool StdCmdMacroStopDebug::isActive(void)
+bool StdCmdMacroStopDebug::isActive()
 {
     static PythonDebugger* dbg = Application::Instance->macroManager()->debugger();
     return dbg->isRunning();
 }
 
-DEF_STD_CMD_A(StdCmdMacroStepOver);
+DEF_STD_CMD_A(StdCmdMacroStepOver)
 
 StdCmdMacroStepOver::StdCmdMacroStepOver()
   : Command("Std_MacroStepOver")
 {
-    sGroup        = QT_TR_NOOP("Macro");
+    sGroup        = "Macro";
     sMenuText     = QT_TR_NOOP("Step over");
     sToolTipText  = QT_TR_NOOP("Step over");
     sWhatsThis    = "Std_MacroStepOver";
     sStatusTip    = QT_TR_NOOP("Step over");
-    sPixmap       = 0;
+    sPixmap       = nullptr;
     sAccel        = "F10";
     eType         = 0;
 }
 
 void StdCmdMacroStepOver::activated(int iMsg)
 {
-    Q_UNUSED(iMsg); 
+    Q_UNUSED(iMsg);
     Application::Instance->macroManager()->debugger()->stepOver();
 }
 
-bool StdCmdMacroStepOver::isActive(void)
+bool StdCmdMacroStepOver::isActive()
 {
     static PythonDebugger* dbg = Application::Instance->macroManager()->debugger();
     return dbg->isRunning();
 }
 
-DEF_STD_CMD_A(StdCmdMacroStepInto);
+DEF_STD_CMD_A(StdCmdMacroStepInto)
 
 StdCmdMacroStepInto::StdCmdMacroStepInto()
   : Command("Std_MacroStepInto")
 {
-    sGroup        = QT_TR_NOOP("Macro");
+    sGroup        = "Macro";
     sMenuText     = QT_TR_NOOP("Step into");
     sToolTipText  = QT_TR_NOOP("Step into");
     //sWhatsThis    = "Std_MacroStepOver";
     sStatusTip    = QT_TR_NOOP("Step into");
-    sPixmap       = 0;
+    sPixmap       = nullptr;
     sAccel        = "F11";
     eType         = 0;
 }
 
 void StdCmdMacroStepInto::activated(int iMsg)
 {
-    Q_UNUSED(iMsg); 
+    Q_UNUSED(iMsg);
     Application::Instance->macroManager()->debugger()->stepInto();
 }
 
-bool StdCmdMacroStepInto::isActive(void)
+bool StdCmdMacroStepInto::isActive()
 {
     static PythonDebugger* dbg = Application::Instance->macroManager()->debugger();
     return dbg->isRunning();
 }
 
-DEF_STD_CMD_A(StdCmdToggleBreakpoint);
+DEF_STD_CMD_A(StdCmdToggleBreakpoint)
 
 StdCmdToggleBreakpoint::StdCmdToggleBreakpoint()
   : Command("Std_ToggleBreakpoint")
 {
-    sGroup        = QT_TR_NOOP("Macro");
+    sGroup        = "Macro";
     sMenuText     = QT_TR_NOOP("Toggle breakpoint");
     sToolTipText  = QT_TR_NOOP("Toggle breakpoint");
     sWhatsThis    = "Std_ToggleBreakpoint";
     sStatusTip    = QT_TR_NOOP("Toggle breakpoint");
-    sPixmap       = 0;
+    sPixmap       = nullptr;
     sAccel        = "F9";
     eType         = 0;
 }
 
 void StdCmdToggleBreakpoint::activated(int iMsg)
 {
-    Q_UNUSED(iMsg); 
+    Q_UNUSED(iMsg);
     doCommand(Command::Gui,"Gui.SendMsgToActiveView(\"ToggleBreakpoint\")");
 }
 
-bool StdCmdToggleBreakpoint::isActive(void)
+bool StdCmdToggleBreakpoint::isActive()
 {
     return getGuiApplication()->sendHasMsgToActiveView("ToggleBreakpoint");
 }
 
 namespace Gui {
 
-void CreateMacroCommands(void)
+void CreateMacroCommands()
 {
     CommandManager &rcCmdMgr = Application::Instance->commandManager();
     rcCmdMgr.addCommand(new StdCmdDlgMacroRecord());
     rcCmdMgr.addCommand(new StdCmdMacroStopRecord());
     rcCmdMgr.addCommand(new StdCmdDlgMacroExecute());
     rcCmdMgr.addCommand(new StdCmdDlgMacroExecuteDirect());
+    rcCmdMgr.addCommand(new StdCmdMacroAttachDebugger());
     rcCmdMgr.addCommand(new StdCmdMacroStartDebug());
     rcCmdMgr.addCommand(new StdCmdMacroStopDebug());
     rcCmdMgr.addCommand(new StdCmdMacroStepOver());
