@@ -20,51 +20,39 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 #ifndef _PreComp_
 # include <QApplication>
 # include <QMessageBox>
-# include <QSharedPointer>
 # include <QWhatsThis>
-#if QT_VERSION >= 0x040200
-# include <QDesktopServices>
-# include <QUrl>
-#endif
 #endif
 
-#include <boost/scoped_ptr.hpp>
-
+#include <App/Document.h>
 #include <Base/Exception.h>
-#include <Base/FileInfo.h>
 #include <Base/Interpreter.h>
 #include <Base/Sequencer.h>
-#include <App/Document.h>
-#include "Action.h"
-#include "Application.h"
-#include "Document.h"
-#include "Splashscreen.h"
-#include "Command.h"
-#include "MainWindow.h"
-#include "WhatsThis.h"
-#include "DlgUndoRedo.h"
-#include "BitmapFactory.h"
-#include "View.h"
 
+#include "Action.h"
+#include "BitmapFactory.h"
+#include "Command.h"
+#include "DlgCustomizeImp.h"
 #include "DlgParameterImp.h"
 #include "DlgPreferencesImp.h"
-#include "DlgCustomizeImp.h"
-#include "Widgets.h"
-#include "OnlineDocumentation.h"
-#include "GuiConsole.h"
-#include "WorkbenchManager.h"
-#include "Workbench.h"
-#include "Selection.h"
 #include "DlgUnitsCalculatorImp.h"
+#include "GuiConsole.h"
+#include "MainWindow.h"
+#include "OnlineDocumentation.h"
+#include "Selection.h"
+#include "Splashscreen.h"
+#include "WhatsThis.h"
+#include "Workbench.h"
+#include "WorkbenchManager.h"
+
 
 using Base::Console;
 using Base::Sequencer;
 using namespace Gui;
+namespace bp = boost::placeholders;
 
 
 //===========================================================================
@@ -76,7 +64,7 @@ DEF_STD_CMD_AC(StdCmdWorkbench)
 StdCmdWorkbench::StdCmdWorkbench()
   : Command("Std_Workbench")
 {
-    sGroup        = QT_TR_NOOP("View");
+    sGroup        = "View";
     sMenuText     = QT_TR_NOOP("Workbench");
     sToolTipText  = QT_TR_NOOP("Switch between workbenches");
     sWhatsThis    = "Std_Workbench";
@@ -114,20 +102,20 @@ void StdCmdWorkbench::activated(int i)
     }
 }
 
-bool StdCmdWorkbench::isActive(void)
+bool StdCmdWorkbench::isActive()
 {
     return true;
 }
 
-Action * StdCmdWorkbench::createAction(void)
+Action * StdCmdWorkbench::createAction()
 {
     Action *pcAction;
 
     pcAction = new WorkbenchGroup(this,getMainWindow());
-    pcAction->setShortcut(QString::fromLatin1(sAccel));
+    pcAction->setShortcut(QString::fromLatin1(getAccel()));
     applyCommandData(this->className(), pcAction);
-    if (sPixmap)
-        pcAction->setIcon(Gui::BitmapFactory().iconFromTheme(sPixmap));
+    if (getPixmap())
+        pcAction->setIcon(Gui::BitmapFactory().iconFromTheme(getPixmap()));
 
     return pcAction;
 }
@@ -141,7 +129,7 @@ DEF_STD_CMD_C(StdCmdRecentFiles)
 StdCmdRecentFiles::StdCmdRecentFiles()
   :Command("Std_RecentFiles")
 {
-    sGroup        = QT_TR_NOOP("File");
+    sGroup        = "File";
     sMenuText     = QT_TR_NOOP("Recent files");
     sToolTipText  = QT_TR_NOOP("Recent file list");
     sWhatsThis    = "Std_RecentFiles";
@@ -164,7 +152,7 @@ void StdCmdRecentFiles::activated(int iMsg)
 /**
  * Creates the QAction object containing the recent files.
  */
-Action * StdCmdRecentFiles::createAction(void)
+Action * StdCmdRecentFiles::createAction()
 {
     RecentFilesAction* pcAction = new RecentFilesAction(this, getMainWindow());
     pcAction->setObjectName(QLatin1String("recentFiles"));
@@ -182,7 +170,7 @@ DEF_STD_CMD_C(StdCmdRecentMacros)
 StdCmdRecentMacros::StdCmdRecentMacros()
   :Command("Std_RecentMacros")
 {
-    sGroup        = QT_TR_NOOP("Macro");
+    sGroup        = "Macro";
     sMenuText     = QT_TR_NOOP("Recent macros");
     sToolTipText  = QT_TR_NOOP("Recent macro list");
     sWhatsThis    = "Std_RecentMacros";
@@ -204,7 +192,7 @@ void StdCmdRecentMacros::activated(int iMsg)
 /**
  * Creates the QAction object containing the recent macros.
  */
-Action * StdCmdRecentMacros::createAction(void)
+Action * StdCmdRecentMacros::createAction()
 {
     RecentMacrosAction* pcAction = new RecentMacrosAction(this, getMainWindow());
     pcAction->setObjectName(QLatin1String("recentMacros"));
@@ -222,7 +210,7 @@ DEF_STD_CMD_ACL(StdCmdAbout)
 StdCmdAbout::StdCmdAbout()
   :Command("Std_About")
 {
-    sGroup        = QT_TR_NOOP("Help");
+    sGroup        = "Help";
     sMenuText     = QT_TR_NOOP("&About %1");
     sToolTipText  = QT_TR_NOOP("About %1");
     sWhatsThis    = "Std_About";
@@ -230,28 +218,23 @@ StdCmdAbout::StdCmdAbout()
     eType         = 0;
 }
 
-Action * StdCmdAbout::createAction(void)
+Action * StdCmdAbout::createAction()
 {
     Action *pcAction;
 
     QString exe = qApp->applicationName();
     pcAction = new Action(this,getMainWindow());
     pcAction->setText(QCoreApplication::translate(
-        this->className(), sMenuText).arg(exe));
+        this->className(), getMenuText()).arg(exe));
     pcAction->setToolTip(QCoreApplication::translate(
-        this->className(), sToolTipText).arg(exe));
+        this->className(), getToolTipText()).arg(exe));
     pcAction->setStatusTip(QCoreApplication::translate(
-        this->className(), sStatusTip).arg(exe));
-    pcAction->setWhatsThis(QLatin1String(sWhatsThis));
+        this->className(), getStatusTip()).arg(exe));
+    pcAction->setWhatsThis(QLatin1String(getWhatsThis()));
     pcAction->setIcon(QApplication::windowIcon());
-    pcAction->setShortcut(QString::fromLatin1(sAccel));
-#if QT_VERSION > 0x050000
+    pcAction->setShortcut(QString::fromLatin1(getAccel()));
     // Needs to have AboutRole set to avoid duplicates if adding the about action more than once on macOS
     pcAction->setMenuRole(QAction::AboutRole);
-#else
-    // With Qt 4.8, having AboutRole set causes it to disappear when readding it: issue #0001485
-    pcAction->setMenuRole(QAction::ApplicationSpecificRole);
-#endif
     return pcAction;
 }
 
@@ -276,12 +259,12 @@ void StdCmdAbout::languageChange()
     if (_pcAction) {
         QString exe = qApp->applicationName();
         _pcAction->setText(QCoreApplication::translate(
-            this->className(), sMenuText).arg(exe));
+            this->className(), getMenuText()).arg(exe));
         _pcAction->setToolTip(QCoreApplication::translate(
-            this->className(), sToolTipText).arg(exe));
+            this->className(), getToolTipText()).arg(exe));
         _pcAction->setStatusTip(QCoreApplication::translate(
-            this->className(), sStatusTip).arg(exe));
-        _pcAction->setWhatsThis(QLatin1String(sWhatsThis));
+            this->className(), getStatusTip()).arg(exe));
+        _pcAction->setWhatsThis(QLatin1String(getWhatsThis()));
     }
 }
 
@@ -293,7 +276,7 @@ DEF_STD_CMD(StdCmdAboutQt)
 StdCmdAboutQt::StdCmdAboutQt()
   :Command("Std_AboutQt")
 {
-  sGroup        = QT_TR_NOOP("Help");
+  sGroup        = "Help";
   sMenuText     = QT_TR_NOOP("About &Qt");
   sToolTipText  = QT_TR_NOOP("About Qt");
   sWhatsThis    = "Std_AboutQt";
@@ -315,7 +298,7 @@ DEF_STD_CMD(StdCmdWhatsThis)
 StdCmdWhatsThis::StdCmdWhatsThis()
   :Command("Std_WhatsThis")
 {
-    sGroup        = QT_TR_NOOP("Help");
+    sGroup        = "Help";
     sMenuText     = QT_TR_NOOP("&What's This?");
     sToolTipText  = QT_TR_NOOP("What's This");
     sWhatsThis    = "Std_WhatsThis";
@@ -339,7 +322,7 @@ DEF_STD_CMD(StdCmdDlgParameter)
 StdCmdDlgParameter::StdCmdDlgParameter()
   :Command("Std_DlgParameter")
 {
-  sGroup        = QT_TR_NOOP("Tools");
+  sGroup        = "Tools";
   sMenuText     = QT_TR_NOOP("E&dit parameters ...");
   sToolTipText  = QT_TR_NOOP("Opens a Dialog to edit the parameters");
   sWhatsThis    = "Std_DlgParameter";
@@ -364,7 +347,7 @@ DEF_STD_CMD_C(StdCmdDlgPreferences)
 StdCmdDlgPreferences::StdCmdDlgPreferences()
   :Command("Std_DlgPreferences")
 {
-    sGroup        = QT_TR_NOOP("Tools");
+    sGroup        = "Tools";
     sMenuText     = QT_TR_NOOP("&Preferences ...");
     sToolTipText  = QT_TR_NOOP("Opens a Dialog to edit the preferences");
     sWhatsThis    = "Std_DlgPreferences";
@@ -373,7 +356,7 @@ StdCmdDlgPreferences::StdCmdDlgPreferences()
     eType         = 0;
 }
 
-Action * StdCmdDlgPreferences::createAction(void)
+Action * StdCmdDlgPreferences::createAction()
 {
     Action *pcAction = Command::createAction();
     pcAction->setMenuRole(QAction::PreferencesRole);
@@ -396,7 +379,7 @@ DEF_STD_CMD(StdCmdDlgCustomize)
 StdCmdDlgCustomize::StdCmdDlgCustomize()
   :Command("Std_DlgCustomize")
 {
-    sGroup        = QT_TR_NOOP("Tools");
+    sGroup        = "Tools";
     sMenuText     = QT_TR_NOOP("Cu&stomize...");
     sToolTipText  = QT_TR_NOOP("Customize toolbars and command bars");
     sWhatsThis    = "Std_DlgCustomize";
@@ -408,7 +391,7 @@ StdCmdDlgCustomize::StdCmdDlgCustomize()
 void StdCmdDlgCustomize::activated(int iMsg)
 {
     Q_UNUSED(iMsg);
-    static QPointer<QDialog> dlg = 0;
+    static QPointer<QDialog> dlg = nullptr;
     if (!dlg)
         dlg = new Gui::Dialog::DlgCustomizeImp(getMainWindow());
     dlg->setAttribute(Qt::WA_DeleteOnClose);
@@ -423,7 +406,7 @@ DEF_STD_CMD(StdCmdCommandLine)
 StdCmdCommandLine::StdCmdCommandLine()
   :Command("Std_CommandLine")
 {
-    sGroup        = QT_TR_NOOP("Tools");
+    sGroup        = "Tools";
     sMenuText     = QT_TR_NOOP("Start command &line...");
     sToolTipText  = QT_TR_NOOP("Opens the command line in the console");
     sWhatsThis    = "Std_CommandLine";
@@ -471,7 +454,7 @@ DEF_STD_CMD(StdCmdOnlineHelp)
 StdCmdOnlineHelp::StdCmdOnlineHelp()
   :Command("Std_OnlineHelp")
 {
-    sGroup        = QT_TR_NOOP("Help");
+    sGroup        = "Help";
     sMenuText     = QT_TR_NOOP("Help");
     sToolTipText  = QT_TR_NOOP("Show help to the application");
     sWhatsThis    = "Std_OnlineHelp";
@@ -496,7 +479,7 @@ DEF_STD_CMD(StdCmdOnlineHelpWebsite)
 StdCmdOnlineHelpWebsite::StdCmdOnlineHelpWebsite()
   :Command("Std_OnlineHelpWebsite")
 {
-    sGroup        = QT_TR_NOOP("Help");
+    sGroup        = "Help";
     sMenuText     = QT_TR_NOOP("Help Website");
     sToolTipText  = QT_TR_NOOP("The website where the help is maintained");
     sWhatsThis    = "Std_OnlineHelpWebsite";
@@ -507,7 +490,7 @@ StdCmdOnlineHelpWebsite::StdCmdOnlineHelpWebsite()
 void StdCmdOnlineHelpWebsite::activated(int iMsg)
 {
     Q_UNUSED(iMsg);
-    std::string defaulturl = QCoreApplication::translate(this->className(),"http://www.freecadweb.org/wiki/Online_Help_Toc").toStdString();
+    std::string defaulturl = QCoreApplication::translate(this->className(),"https://wiki.freecad.org/Online_Help_Toc").toStdString();
     ParameterGrp::handle hURLGrp = App::GetApplication().GetParameterGroupByPath("User parameter:BaseApp/Preferences/Websites");
     std::string url = hURLGrp->GetASCII("OnlineHelp", defaulturl.c_str());
     hURLGrp->SetASCII("OnlineHelp", url.c_str());
@@ -523,7 +506,7 @@ DEF_STD_CMD(StdCmdFreeCADDonation)
 StdCmdFreeCADDonation::StdCmdFreeCADDonation()
   :Command("Std_FreeCADDonation")
 {
-    sGroup        = QT_TR_NOOP("Help");
+    sGroup        = "Help";
     sMenuText     = QT_TR_NOOP("Donate");
     sToolTipText  = QT_TR_NOOP("Donate to FreeCAD development");
     sWhatsThis    = "Std_FreeCADDonation";
@@ -534,9 +517,9 @@ StdCmdFreeCADDonation::StdCmdFreeCADDonation()
 
 void StdCmdFreeCADDonation::activated(int iMsg)
 {
-    Q_UNUSED(iMsg); 
+    Q_UNUSED(iMsg);
     ParameterGrp::handle hURLGrp = App::GetApplication().GetParameterGroupByPath("User parameter:BaseApp/Preferences/Websites");
-    std::string url = hURLGrp->GetASCII("DonatePage", "https://wiki.freecadweb.org/Donate");
+    std::string url = hURLGrp->GetASCII("DonatePage", "https://wiki.freecad.org/Donate");
     hURLGrp->SetASCII("DonatePage", url.c_str());
     OpenURLInBrowser(url.c_str());
 }
@@ -550,7 +533,7 @@ DEF_STD_CMD(StdCmdFreeCADWebsite)
 StdCmdFreeCADWebsite::StdCmdFreeCADWebsite()
   :Command("Std_FreeCADWebsite")
 {
-    sGroup        = QT_TR_NOOP("Help");
+    sGroup        = "Help";
     sMenuText     = QT_TR_NOOP("FreeCAD Website");
     sToolTipText  = QT_TR_NOOP("The FreeCAD website");
     sWhatsThis    = "Std_FreeCADWebsite";
@@ -562,7 +545,7 @@ StdCmdFreeCADWebsite::StdCmdFreeCADWebsite()
 void StdCmdFreeCADWebsite::activated(int iMsg)
 {
     Q_UNUSED(iMsg);
-    std::string defaulturl = QCoreApplication::translate(this->className(),"http://www.freecadweb.org").toStdString();
+    std::string defaulturl = QCoreApplication::translate(this->className(),"https://www.freecad.org").toStdString();
     ParameterGrp::handle hURLGrp = App::GetApplication().GetParameterGroupByPath("User parameter:BaseApp/Preferences/Websites");
     std::string url = hURLGrp->GetASCII("WebPage", defaulturl.c_str());
     hURLGrp->SetASCII("WebPage", url.c_str());
@@ -578,7 +561,7 @@ DEF_STD_CMD(StdCmdFreeCADUserHub)
 StdCmdFreeCADUserHub::StdCmdFreeCADUserHub()
   :Command("Std_FreeCADUserHub")
 {
-    sGroup        = QT_TR_NOOP("Help");
+    sGroup        = "Help";
     sMenuText     = QT_TR_NOOP("Users documentation");
     sToolTipText  = QT_TR_NOOP("Documentation for users on the FreeCAD website");
     sWhatsThis    = "Std_FreeCADUserHub";
@@ -590,7 +573,7 @@ StdCmdFreeCADUserHub::StdCmdFreeCADUserHub()
 void StdCmdFreeCADUserHub::activated(int iMsg)
 {
     Q_UNUSED(iMsg);
-    std::string defaulturl = QCoreApplication::translate(this->className(),"http://www.freecadweb.org/wiki/User_hub").toStdString();
+    std::string defaulturl = QCoreApplication::translate(this->className(),"https://wiki.freecad.org/User_hub").toStdString();
     ParameterGrp::handle hURLGrp = App::GetApplication().GetParameterGroupByPath("User parameter:BaseApp/Preferences/Websites");
     std::string url = hURLGrp->GetASCII("Documentation", defaulturl.c_str());
     hURLGrp->SetASCII("Documentation", url.c_str());
@@ -606,7 +589,7 @@ DEF_STD_CMD(StdCmdFreeCADPowerUserHub)
 StdCmdFreeCADPowerUserHub::StdCmdFreeCADPowerUserHub()
   :Command("Std_FreeCADPowerUserHub")
 {
-    sGroup        = QT_TR_NOOP("Help");
+    sGroup        = "Help";
     sMenuText     = QT_TR_NOOP("Python scripting documentation");
     sToolTipText  = QT_TR_NOOP("Python scripting documentation on the FreeCAD website");
     sWhatsThis    = "Std_FreeCADPowerUserHub";
@@ -618,7 +601,7 @@ StdCmdFreeCADPowerUserHub::StdCmdFreeCADPowerUserHub()
 void StdCmdFreeCADPowerUserHub::activated(int iMsg)
 {
     Q_UNUSED(iMsg);
-    std::string defaulturl = QCoreApplication::translate(this->className(),"http://www.freecadweb.org/wiki/Power_users_hub").toStdString();
+    std::string defaulturl = QCoreApplication::translate(this->className(),"https://wiki.freecad.org/Power_users_hub").toStdString();
     ParameterGrp::handle hURLGrp = App::GetApplication().GetParameterGroupByPath("User parameter:BaseApp/Preferences/Websites");
     std::string url = hURLGrp->GetASCII("PowerUsers", defaulturl.c_str());
     hURLGrp->SetASCII("PowerUsers", url.c_str());
@@ -634,7 +617,7 @@ DEF_STD_CMD(StdCmdFreeCADForum)
 StdCmdFreeCADForum::StdCmdFreeCADForum()
   :Command("Std_FreeCADForum")
 {
-    sGroup        = QT_TR_NOOP("Help");
+    sGroup        = "Help";
     sMenuText     = QT_TR_NOOP("FreeCAD Forum");
     sToolTipText  = QT_TR_NOOP("The FreeCAD forum, where you can find help from other users");
     sWhatsThis    = "Std_FreeCADForum";
@@ -646,7 +629,7 @@ StdCmdFreeCADForum::StdCmdFreeCADForum()
 void StdCmdFreeCADForum::activated(int iMsg)
 {
     Q_UNUSED(iMsg);
-    std::string defaulturl = QCoreApplication::translate(this->className(),"http://forum.freecadweb.org").toStdString();
+    std::string defaulturl = QCoreApplication::translate(this->className(),"https://forum.freecad.org").toStdString();
     ParameterGrp::handle hURLGrp = App::GetApplication().GetParameterGroupByPath("User parameter:BaseApp/Preferences/Websites");
     std::string url = hURLGrp->GetASCII("UserForum", defaulturl.c_str());
     hURLGrp->SetASCII("UserForum", url.c_str());
@@ -662,7 +645,7 @@ DEF_STD_CMD(StdCmdFreeCADFAQ)
 StdCmdFreeCADFAQ::StdCmdFreeCADFAQ()
   :Command("Std_FreeCADFAQ")
 {
-    sGroup        = QT_TR_NOOP("Help");
+    sGroup        = "Help";
     sMenuText     = QT_TR_NOOP("FreeCAD FAQ");
     sToolTipText  = QT_TR_NOOP("Frequently Asked Questions on the FreeCAD website");
     sWhatsThis    = "Std_FreeCADFAQ";
@@ -674,7 +657,7 @@ StdCmdFreeCADFAQ::StdCmdFreeCADFAQ()
 void StdCmdFreeCADFAQ::activated(int iMsg)
 {
     Q_UNUSED(iMsg);
-    std::string defaulturl = QCoreApplication::translate(this->className(),"http://www.freecadweb.org/wiki/FAQ").toStdString();
+    std::string defaulturl = QCoreApplication::translate(this->className(),"https://wiki.freecad.org/Frequently_asked_questions").toStdString();
     ParameterGrp::handle hURLGrp = App::GetApplication().GetParameterGroupByPath("User parameter:BaseApp/Preferences/Websites");
     std::string url = hURLGrp->GetASCII("FAQ", defaulturl.c_str());
     hURLGrp->SetASCII("FAQ", url.c_str());
@@ -690,7 +673,7 @@ DEF_STD_CMD(StdCmdPythonWebsite)
 StdCmdPythonWebsite::StdCmdPythonWebsite()
   :Command("Std_PythonWebsite")
 {
-    sGroup        = QT_TR_NOOP("Help");
+    sGroup        = "Help";
     sMenuText     = QT_TR_NOOP("Python Website");
     sToolTipText  = QT_TR_NOOP("The official Python website");
     sWhatsThis    = "Std_PythonWebsite";
@@ -702,9 +685,38 @@ StdCmdPythonWebsite::StdCmdPythonWebsite()
 void StdCmdPythonWebsite::activated(int iMsg)
 {
     Q_UNUSED(iMsg);
-    OpenURLInBrowser("http://python.org");
+    OpenURLInBrowser("https://www.python.org");
 }
 
+
+//===========================================================================
+// Std_ReportBug
+//===========================================================================
+
+DEF_STD_CMD(StdCmdReportBug)
+
+StdCmdReportBug::StdCmdReportBug()
+  :Command("Std_ReportBug")
+{
+    sGroup        = "Help";
+    sMenuText     = QT_TR_NOOP("Report a bug");
+    sToolTipText  = QT_TR_NOOP("Report a bug or suggest a feature");
+    sWhatsThis    = "Std_ReportBug";
+    sStatusTip    = QT_TR_NOOP("Report a bug or suggest a feature");
+    sPixmap       = "internet-web-browser";
+    eType         = 0;
+}
+
+void StdCmdReportBug::activated(int iMsg)
+{
+    Q_UNUSED(iMsg);
+    ParameterGrp::handle hURLGrp = App::GetApplication().GetParameterGroupByPath("User parameter:BaseApp/Preferences/Websites");
+    std::string url = hURLGrp->GetASCII("IssuesPage", "https://github.com/FreeCAD/FreeCAD/issues");
+    hURLGrp->SetASCII("IssuesPage", url.c_str());
+    OpenURLInBrowser(url.c_str());
+}
+
+
 //===========================================================================
 // Std_MeasurementSimple
 //===========================================================================
@@ -714,7 +726,7 @@ DEF_STD_CMD(StdCmdMeasurementSimple)
 StdCmdMeasurementSimple::StdCmdMeasurementSimple()
   :Command("Std_MeasurementSimple")
 {
-    sGroup        = QT_TR_NOOP("Tools");
+    sGroup        = "Tools";
     sMenuText     = QT_TR_NOOP("Measure distance");
     sToolTipText  = QT_TR_NOOP("Measures distance between two selected objects");
     sWhatsThis    = "Std_MeasurementSimple";
@@ -771,7 +783,7 @@ DEF_STD_CMD_A(StdCmdTextDocument)
 StdCmdTextDocument::StdCmdTextDocument()
   :Command("Std_TextDocument")
 {
-    sGroup        = QT_TR_NOOP("Tools");
+    sGroup        = "Tools";
     sMenuText     = QT_TR_NOOP("Add text document");
     sToolTipText  = QT_TR_NOOP("Add text document to active document");
     sWhatsThis    = "Std_TextDocument";
@@ -791,7 +803,7 @@ void StdCmdTextDocument::activated(int iMsg)
     commitCommand();
 }
 
-bool StdCmdTextDocument::isActive(void)
+bool StdCmdTextDocument::isActive()
 {
     return hasActiveDocument();
 }
@@ -804,7 +816,7 @@ DEF_STD_CMD(StdCmdUnitsCalculator)
 StdCmdUnitsCalculator::StdCmdUnitsCalculator()
   : Command("Std_UnitsCalculator")
 {
-    sGroup        = QT_TR_NOOP("Tools");
+    sGroup        = "Tools";
     sMenuText     = QT_TR_NOOP("&Units calculator...");
     sToolTipText  = QT_TR_NOOP("Start the units calculator");
     sWhatsThis    = "Std_UnitsCalculator";
@@ -820,9 +832,110 @@ void StdCmdUnitsCalculator::activated(int iMsg)
     dlg->show();
 }
 
+//===========================================================================
+// StdCmdUserEditMode
+//===========================================================================
+class StdCmdUserEditMode : public Gui::Command
+{
+public:
+    StdCmdUserEditMode();
+    virtual ~StdCmdUserEditMode(){}
+    virtual void languageChange();
+    virtual const char* className() const {return "StdCmdUserEditMode";}
+    void updateIcon(int mode);
+protected:
+    virtual void activated(int iMsg);
+    virtual bool isActive();
+    virtual Gui::Action * createAction();
+};
+
+StdCmdUserEditMode::StdCmdUserEditMode()
+  : Command("Std_UserEditMode")
+{
+    sGroup        = "Edit";
+    sMenuText     = QT_TR_NOOP("Edit mode");
+    sToolTipText  = QT_TR_NOOP("Defines behavior when editing an object from tree");
+    sStatusTip    = QT_TR_NOOP("Defines behavior when editing an object from tree");
+    sWhatsThis    = "Std_UserEditMode";
+    sPixmap       = "Std_UserEditModeDefault";
+    eType         = ForEdit;
+
+    this->getGuiApplication()->signalUserEditModeChanged.connect(boost::bind(&StdCmdUserEditMode::updateIcon, this, bp::_1));
+}
+
+Gui::Action * StdCmdUserEditMode::createAction()
+{
+    Gui::ActionGroup* pcAction = new Gui::ActionGroup(this, Gui::getMainWindow());
+    pcAction->setDropDownMenu(true);
+    pcAction->setIsMode(true);
+    applyCommandData(this->className(), pcAction);
+
+    for (auto const &uem : Gui::Application::Instance->listUserEditModes()) {
+        QAction* act = pcAction->addAction(QString());
+        auto modeName = QString::fromStdString(uem.second);
+        act->setCheckable(true);
+        act->setIcon(BitmapFactory().iconFromTheme(qPrintable(QString::fromLatin1("Std_UserEditMode")+modeName)));
+        act->setObjectName(QString::fromLatin1("Std_UserEditMode")+modeName);
+        act->setWhatsThis(QString::fromLatin1(getWhatsThis()));
+
+        if (uem.first == 0) {
+            pcAction->setIcon(act->icon());
+            act->setChecked(true);
+        }
+    }
+
+    _pcAction = pcAction;
+
+    int lastMode = App::GetApplication().GetParameterGroupByPath("User parameter:BaseApp/Preferences/General")->
+        GetInt("UserEditMode", 0);
+    Gui::Application::Instance->setUserEditMode(lastMode);
+
+    languageChange();
+    return pcAction;
+}
+
+void StdCmdUserEditMode::languageChange()
+{
+    Command::languageChange();
+
+    if (!_pcAction)
+        return;
+    Gui::ActionGroup* pcAction = qobject_cast<Gui::ActionGroup*>(_pcAction);
+    QList<QAction*> a = pcAction->actions();
+
+    for (int i = 0 ; i < a.count() ; i++) {
+        auto modeName = QString::fromStdString(Gui::Application::Instance->getUserEditModeName(i));
+        a[i]->setText(QCoreApplication::translate(
+        "EditMode", qPrintable(modeName)));
+        a[i]->setToolTip(QCoreApplication::translate(
+        "EditMode", qPrintable(modeName+QString::fromLatin1(" mode"))));
+    }
+}
+
+void StdCmdUserEditMode::updateIcon(int mode)
+{
+    Gui::ActionGroup *actionGroup = dynamic_cast<Gui::ActionGroup *>(_pcAction);
+    if (!actionGroup)
+        return;
+
+    actionGroup->setCheckedAction(mode);
+}
+
+void StdCmdUserEditMode::activated(int iMsg)
+{
+    App::GetApplication().GetParameterGroupByPath("User parameter:BaseApp/Preferences/General")->
+            SetInt("UserEditMode", iMsg);
+    Gui::Application::Instance->setUserEditMode(iMsg);
+}
+
+bool StdCmdUserEditMode::isActive()
+{
+    return true;
+}
+
 namespace Gui {
 
-void CreateStdCommands(void)
+void CreateStdCommands()
 {
     CommandManager &rcCmdMgr = Application::Instance->commandManager();
 
@@ -847,8 +960,10 @@ void CreateStdCommands(void)
     rcCmdMgr.addCommand(new StdCmdFreeCADForum());
     rcCmdMgr.addCommand(new StdCmdFreeCADFAQ());
     rcCmdMgr.addCommand(new StdCmdPythonWebsite());
+    rcCmdMgr.addCommand(new StdCmdReportBug());
     rcCmdMgr.addCommand(new StdCmdTextDocument());
     rcCmdMgr.addCommand(new StdCmdUnitsCalculator());
+    rcCmdMgr.addCommand(new StdCmdUserEditMode());
     //rcCmdMgr.addCommand(new StdCmdMeasurementSimple());
     //rcCmdMgr.addCommand(new StdCmdDownloadOnlineHelp());
     //rcCmdMgr.addCommand(new StdCmdDescription());
