@@ -28,31 +28,29 @@
 # include <QFileDialog>
 # include <QMutex>
 # include <QMutexLocker>
-# include <QThread>
-# include <QTimer>
 # include <QMdiArea>
 # include <QMdiSubWindow>
-# include <QWaitCondition>
-# include <QTranslator>
 # include <QRunnable>
+# include <QThread>
 # include <QThreadPool>
+# include <QTimer>
+# include <QTranslator>
+# include <QWaitCondition>
 #endif
 
 #include <Base/Console.h>
+#include <Base/Sequencer.h>
+
+#include "CommandT.h"
 #include "Application.h"
+#include "Command.h"
 #include "MainWindow.h"
 #include "MDIView.h"
-#include "Command.h"
-#include "CommandT.h"
 #include "Language/Translator.h"
 
-#include "ProgressBar.h"
-
 
 using namespace Gui;
 
-//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-
 //===========================================================================
 // Std_TestQM
 //===========================================================================
@@ -134,7 +132,7 @@ void FCCmdTest1::activated(int iMsg)
     Q_UNUSED(iMsg);
 }
 
-bool FCCmdTest1::isActive(void)
+bool FCCmdTest1::isActive()
 {
     //return (GetActiveOCCDocument()!=NULL);
     return true;
@@ -162,9 +160,9 @@ void FCCmdTest2::activated(int iMsg)
     Q_UNUSED(iMsg);
 }
 
-bool FCCmdTest2::isActive(void)
+bool FCCmdTest2::isActive()
 {
-    return (getDocument()!=NULL);
+    return (getDocument()!=nullptr);
 }
 
 //===========================================================================
@@ -187,13 +185,14 @@ void FCCmdTest3::activated(int iMsg)
 {
     Q_UNUSED(iMsg);
     App::Document *pcDoc = getDocument();
-    if (!pcDoc) return;
+    if (!pcDoc)
+        return;
 }
 
 
-bool FCCmdTest3::isActive(void)
+bool FCCmdTest3::isActive()
 {
-    return (getDocument()!=NULL);
+    return (getDocument()!=nullptr);
 }
 
 //===========================================================================
@@ -217,13 +216,14 @@ void FCCmdTest4::activated(int iMsg)
 {
     Q_UNUSED(iMsg);
     App::Document *pcDoc = getDocument();
-    if(!pcDoc) return;
+    if(!pcDoc)
+        return;
 }
 
 
-bool FCCmdTest4::isActive(void)
+bool FCCmdTest4::isActive()
 {
-    return (getDocument()!=NULL);
+    return (getDocument()!=nullptr);
 }
 
 //===========================================================================
@@ -246,12 +246,13 @@ void FCCmdTest5::activated(int iMsg)
 {
     Q_UNUSED(iMsg);
     App::Document *pcDoc = getDocument();
-    if(!pcDoc) return;
+    if(!pcDoc)
+        return;
 }
 
-bool FCCmdTest5::isActive(void)
+bool FCCmdTest5::isActive()
 {
-  return (getDocument()!=NULL);
+  return (getDocument()!=nullptr);
 }
 
 
@@ -275,12 +276,13 @@ void FCCmdTest6::activated(int iMsg)
 {
     Q_UNUSED(iMsg);
     App::Document *pcDoc = getDocument();
-    if(!pcDoc) return;
+    if(!pcDoc)
+        return;
 }
 
-bool FCCmdTest6::isActive(void)
+bool FCCmdTest6::isActive()
 {
-    return (getDocument()!=NULL);
+    return (getDocument()!=nullptr);
 }
 
 //===========================================================================
@@ -303,7 +305,8 @@ void CmdTestCmdFuncs::activated(int iMsg)
     Q_UNUSED(iMsg);
     App::Document *doc = getDocument();
     auto obj = doc->addObject("App::Annotation", "obj");
-    if (!obj) return;
+    if (!obj)
+        return;
 
     std::string objName = obj->getNameInDocument();
 
@@ -327,9 +330,9 @@ void CmdTestCmdFuncs::activated(int iMsg)
     Gui::copyVisualT(objName.c_str(), "DisplayMode", objName.c_str());
 }
 
-bool CmdTestCmdFuncs::isActive(void)
+bool CmdTestCmdFuncs::isActive()
 {
-    return (getDocument()!=NULL);
+    return (getDocument()!=nullptr);
 }
 
 //===========================================================================
@@ -369,7 +372,7 @@ void CmdTestProgress1::activated(int iMsg)
     }
 }
 
-bool CmdTestProgress1::isActive(void)
+bool CmdTestProgress1::isActive()
 {
     return (!Base::Sequencer().isRunning());
 }
@@ -412,7 +415,7 @@ void CmdTestProgress2::activated(int iMsg)
     }
 }
 
-bool CmdTestProgress2::isActive(void)
+bool CmdTestProgress2::isActive()
 {
     return ( !Base::Sequencer().isRunning() );
 }
@@ -482,7 +485,7 @@ void CmdTestProgress3::activated(int iMsg)
     }
 }
 
-bool CmdTestProgress3::isActive(void)
+bool CmdTestProgress3::isActive()
 {
     return ( !Base::Sequencer().isRunning() );
 }
@@ -519,7 +522,7 @@ void CmdTestProgress4::activated(int iMsg)
             QWaitCondition().wait(&mutex, 5);
             if (i == 45) {
                 delete seq;
-                seq = 0;
+                seq = nullptr;
             }
             if (seq) {
                 seq->next(false);
@@ -537,7 +540,7 @@ void CmdTestProgress4::activated(int iMsg)
     }
 }
 
-bool CmdTestProgress4::isActive(void)
+bool CmdTestProgress4::isActive()
 {
     return (!Base::Sequencer().isRunning());
 }
@@ -617,7 +620,7 @@ void CmdTestProgress5::activated(int iMsg)
     thr3->start();
 }
 
-bool CmdTestProgress5::isActive(void)
+bool CmdTestProgress5::isActive()
 {
     return (!Base::Sequencer().isRunning());
 }
@@ -644,7 +647,7 @@ void CmdTestMDI1::activated(int iMsg)
     getMainWindow()->removeWindow(mdi);
 }
 
-bool CmdTestMDI1::isActive(void)
+bool CmdTestMDI1::isActive()
 {
     return getMainWindow()->activeWindow();
 }
@@ -672,7 +675,7 @@ void CmdTestMDI2::activated(int iMsg)
     }
 }
 
-bool CmdTestMDI2::isActive(void)
+bool CmdTestMDI2::isActive()
 {
     return getMainWindow()->activeWindow();
 }
@@ -694,13 +697,13 @@ void CmdTestMDI3::activated(int iMsg)
     Q_UNUSED(iMsg);
     MDIView* mdi = getMainWindow()->activeWindow();
     getMainWindow()->removeWindow(mdi);
-    mdi->setParent(0, Qt::Window | Qt::WindowTitleHint |
+    mdi->setParent(nullptr, Qt::Window | Qt::WindowTitleHint |
                    Qt::WindowSystemMenuHint |
                    Qt::WindowMinMaxButtonsHint);
     mdi->show();
 }
 
-bool CmdTestMDI3::isActive(void)
+bool CmdTestMDI3::isActive()
 {
     return getMainWindow()->activeWindow();
 }
@@ -710,7 +713,7 @@ DEF_STD_CMD(CmdTestConsoleOutput)
 CmdTestConsoleOutput::CmdTestConsoleOutput()
   : Command("Std_TestConsoleOutput")
 {
-    sGroup      = QT_TR_NOOP("Standard-Test");
+    sGroup      = "Standard-Test";
     sMenuText   = QT_TR_NOOP("Test console output");
     sToolTipText= QT_TR_NOOP("Test console output");
     sStatusTip  = QT_TR_NOOP("Test console output");
@@ -808,7 +811,7 @@ void CmdTestConsoleOutput::activated(int iMsg)
 
 namespace Gui {
 
-void CreateTestCommands(void)
+void CreateTestCommands()
 {
     CommandManager &rcCmdMgr = Application::Instance->commandManager();
 
