@@ -367,16 +367,17 @@ Action * StdCmdToolBarMenu::createAction()
 
 class FilterStatusBar : public QObject
 {
-//    Q_OBJECT
+    //    Q_OBJECT
 
 public:
-    FilterStatusBar(Action * action):QObject(action) {this->action = action;}
-//    virtual ~FilterStatusBar() {}
+    FilterStatusBar(Action* action) :QObject(action) { this->action = action; }
+    //    virtual ~FilterStatusBar() {}
 protected:
-    Action * action;
-    bool eventFilter(QObject *obj, QEvent *event)
+    Action* action;
+    bool eventFilter(QObject* obj, QEvent* event) override
     {
-        if (getMainWindow()->findChild<QStatusBar *>() != nullptr && obj == getMainWindow()->statusBar() && ((event->type() == QEvent::Hide) || (event->type() == QEvent::Show))) {
+        if (getMainWindow() && getMainWindow()->findChild<QStatusBar*>() && obj == getMainWindow()->statusBar() &&
+            ((event->type() == QEvent::Hide) || (event->type() == QEvent::Show))) {
             this->action->setChecked(getMainWindow()->statusBar()->isVisible());
         }
         return false;
