@@ -25,43 +25,35 @@
 #include <boost_bind_bind.hpp>
 #include <boost/graph/topological_sort.hpp>
 #include <boost_graph_reverse_graph.hpp>
-
-#include <QApplication>
-#include <QString>
-#include <QGraphicsTextItem>
-#include <QGraphicsEllipseItem>
-#include <QGraphicsPixmapItem>
-#include <QGraphicsRectItem>
-#include <QGraphicsSceneHoverEvent>
-#include <QGraphicsProxyWidget>
-#include <QPen>
+#include <memory>
 #include <QBrush>
 #include <QColor>
-#include <QPainter>
+#include <QGraphicsPixmapItem>
+#include <QGraphicsProxyWidget>
+#include <QGraphicsSceneContextMenuEvent>
+#include <QGraphicsSceneMouseEvent>
 #include <QKeyEvent>
 #include <QMenu>
+#include <QPainter>
+#include <QPen>
+#include <QString>
 #include <QTimer>
 #endif
 
-#include <QAbstractEventDispatcher>
-
-#include <deque>
-#include <memory>
-
-#include <unordered_set>
-
-#include <Base/TimeInfo.h>
 #include <Base/Console.h>
+#include <Base/TimeInfo.h>
+#include <App/Document.h>
 #include <Gui/Application.h>
-#include <Gui/Document.h>
-#include <Gui/ViewProviderDocumentObject.h>
-#include <Gui/Selection.h>
 #include <Gui/BitmapFactory.h>
-#include <Gui/MenuManager.h>
+#include <Gui/Document.h>
 #include <Gui/MainWindow.h>
+#include <Gui/MenuManager.h>
+#include <Gui/Selection.h>
+#include <Gui/ViewProviderDocumentObject.h>
 
 #include "DAGModel.h"
 
+
 using namespace Gui;
 using namespace DAG;
 namespace bp = boost::placeholders;
@@ -302,7 +294,7 @@ void Model::slotDeleteObject(const ViewProviderDocumentObject &VPDObjectIn)
 void Model::slotChangeObject(const ViewProviderDocumentObject &VPDObjectIn, const App::Property& propertyIn)
 {
   std::string name("Empty Name");
-  if (propertyIn.getName()) //getName can return 0.
+  if (propertyIn.hasName())
     name = propertyIn.getName();
   assert(!name.empty());
   
@@ -383,7 +375,7 @@ void Model::selectionChanged(const SelectionChanges& msg)
     }
   };
   
-  //lamda for clearing selections.
+  //lambda for clearing selections.
   auto clearSelection = [this, highlightConnectorOff]()
   {
     BGL_FORALL_VERTICES(currentVertex, *theGraph, Graph)
@@ -395,7 +387,7 @@ void Model::selectionChanged(const SelectionChanges& msg)
     }
   };
   
-  //lamda for getting rectangle.
+  //lambda for getting rectangle.
   auto getRectangle = [this](const char *in)
   {
     assert(in);
