@@ -40,7 +40,7 @@ class DlgActivateWindowImp : public QDialog
     Q_OBJECT
 
 public:
-    DlgActivateWindowImp(QWidget* parent = 0, Qt::WindowFlags fl = Qt::WindowFlags());
+    DlgActivateWindowImp(QWidget* parent = nullptr, Qt::WindowFlags fl = Qt::WindowFlags());
     ~DlgActivateWindowImp();
 
 protected:
