@@ -24,10 +24,9 @@
 #ifndef GUI_DIALOG_DLGMACRORECORDIMP_H
 #define GUI_DIALOG_DLGMACRORECORDIMP_H
 
-#include "Window.h"
 #include <QDialog>
 #include <memory>
-
+#include "Window.h"
 
 namespace Gui {
 class MacroManager;
@@ -43,7 +42,7 @@ class DlgMacroRecordImp : public QDialog, public Gui::WindowParameter
     Q_OBJECT
 
 public:
-    DlgMacroRecordImp( QWidget* parent = 0, Qt::WindowFlags fl = Qt::WindowFlags() );
+    DlgMacroRecordImp( QWidget* parent = nullptr, Qt::WindowFlags fl = Qt::WindowFlags() );
     virtual ~DlgMacroRecordImp();
 
 protected Q_SLOTS:
