@@ -20,7 +20,6 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 #ifndef _PreComp_
 # include <sstream>
@@ -33,19 +32,18 @@
 # include <QTreeWidget>
 #endif
 
-#include "ui_DlgParameter.h"
+#include <App/Application.h>
+#include <Base/Exception.h>
+#include <Base/Parameter.h>
+
 #include "DlgParameterImp.h"
+#include "ui_DlgParameter.h"
+#include "BitmapFactory.h"
 #include "DlgParameterFind.h"
 #include "DlgInputDialogImp.h"
-#include "BitmapFactory.h"
 #include "FileDialog.h"
 #include "SpinBox.h"
 
-#include <Base/Parameter.h>
-#include <Base/Exception.h>
-#include <App/Application.h>
-
-
 
 using namespace Gui::Dialog;
 
@@ -70,25 +68,19 @@ DlgParameterImp::DlgParameterImp( QWidget* parent,  Qt::WindowFlags fl )
     paramGroup = new ParameterGroup(ui->splitter3);
     paramGroup->setHeaderLabels(groupLabels);
     paramGroup->setRootIsDecorated(false);
-#if QT_VERSION >= 0x050000
     paramGroup->setSortingEnabled(true);
     paramGroup->sortByColumn(0, Qt::AscendingOrder);
     paramGroup->header()->setProperty("showSortIndicator", QVariant(true));
-#endif
 
     QStringList valueLabels;
     valueLabels << tr( "Name" ) << tr( "Type" ) << tr( "Value" );
     paramValue = new ParameterValue(ui->splitter3);
     paramValue->setHeaderLabels(valueLabels);
     paramValue->setRootIsDecorated(false);
-#if QT_VERSION >= 0x050000
     paramValue->header()->setSectionResizeMode(0, QHeaderView::Stretch);
     paramValue->setSortingEnabled(true);
     paramValue->sortByColumn(0, Qt::AscendingOrder);
     paramValue->header()->setProperty("showSortIndicator", QVariant(true));
-#else
-    paramValue->header()->setResizeMode(0, QHeaderView::Stretch);
-#endif
 
     QSizePolicy policy = paramValue->sizePolicy();
     policy.setHorizontalStretch(3);
@@ -126,11 +118,7 @@ DlgParameterImp::DlgParameterImp( QWidget* parent,  Qt::WindowFlags fl )
     boldFont.setBold(true);
     defaultColor = paramGroup->topLevelItem(0)->foreground(0);
 
-    // set a placeholder text to inform the user
-    // (QLineEdit has no placeholderText property in Qt4)
-#if QT_VERSION >= 0x050200
     ui->findGroupLE->setPlaceholderText(tr("Search Group"));
-#endif
 }
 
 /**
@@ -238,7 +226,6 @@ void DlgParameterImp::changeEvent(QEvent *e)
 
 void DlgParameterImp::on_checkSort_toggled(bool on)
 {
-#if QT_VERSION >= 0x050000
     paramGroup->setSortingEnabled(on);
     paramGroup->sortByColumn(0, Qt::AscendingOrder);
     paramGroup->header()->setProperty("showSortIndicator", QVariant(on));
@@ -246,9 +233,6 @@ void DlgParameterImp::on_checkSort_toggled(bool on)
     paramValue->setSortingEnabled(on);
     paramValue->sortByColumn(0, Qt::AscendingOrder);
     paramValue->header()->setProperty("showSortIndicator", QVariant(on));
-#else
-    Q_UNUSED(on)
-#endif
 }
 
 void DlgParameterImp::on_closeButton_clicked()
@@ -402,7 +386,7 @@ void DlgParameterImp::onChangeParameterSet(int itemPos)
     QStringList paths = path.split(QLatin1String("."), QString::SkipEmptyParts);
 #endif
 
-    QTreeWidgetItem* parent = 0;
+    QTreeWidgetItem* parent = nullptr;
     for (int index=0; index < paramGroup->topLevelItemCount() && !paths.empty(); index++) {
         QTreeWidgetItem* child = paramGroup->topLevelItem(index);
         if (child->text(0) == paths.front()) {
@@ -414,7 +398,7 @@ void DlgParameterImp::onChangeParameterSet(int itemPos)
     while (parent && !paths.empty()) {
         parent->setExpanded(true);
         QTreeWidgetItem* item = parent;
-        parent = 0;
+        parent = nullptr;
         for (int index=0; index < item->childCount(); index++) {
             QTreeWidgetItem* child = item->child(index);
             if (child->text(0) == paths.front()) {
@@ -733,16 +717,12 @@ void ParameterValue::keyPressEvent (QKeyEvent* event)
 
 void ParameterValue::resizeEvent(QResizeEvent* event)
 {
-#if QT_VERSION >= 0x050000
     QHeaderView* hv = header();
     hv->setSectionResizeMode(QHeaderView::Stretch);
-#endif
 
     QTreeWidget::resizeEvent(event);
 
-#if QT_VERSION >= 0x050000
     hv->setSectionResizeMode(QHeaderView::Interactive);
-#endif
 }
 
 void ParameterValue::onChangeSelectedItem(QTreeWidgetItem* item, int col)
@@ -957,7 +937,7 @@ ParameterGroupItem::~ParameterGroupItem()
     _hcGrp->ClearObserver();
 }
 
-void ParameterGroupItem::fillUp(void)
+void ParameterGroupItem::fillUp()
 {
     // filling up groups
     std::vector<Base::Reference<ParameterGrp> > vhcParamGrp = _hcGrp->GetGroups();
