@@ -44,20 +44,37 @@ class DlgSettingsColorGradientImp : public QDialog
     Q_OBJECT
 
 public:
-    DlgSettingsColorGradientImp( QWidget* parent = 0, Qt::WindowFlags fl = Qt::WindowFlags() );
+    DlgSettingsColorGradientImp(const App::ColorGradient& cg,
+                                QWidget* parent = nullptr,
+                                Qt::WindowFlags fl = Qt::WindowFlags());
     ~DlgSettingsColorGradientImp();
 
     void accept();
 
+    /** @name Color profile */
+    //@{
+    App::ColorGradientProfile getProfile() const;
+    void setProfile(const App::ColorGradientProfile& pro);
+    //@}
+    /** @name Parameter range and scale */
+    //@{
+    void setNumberOfDecimals(int, float fMin, float fMax);
+    int numberOfDecimals() const;
+    //@}
+
+private:
+    void setupConnections();
+
     /** @name Color model */
     //@{
-    void setColorModel( App::ColorGradient::TColorModel tModel);
-    App::ColorGradient::TColorModel colorModel() const;
+    void setColorModelNames(const std::vector<std::string>&);
+    void setColorModel(std::size_t tModel);
+    std::size_t colorModel() const;
     //@}
     /** @name Color style */
     //@{
-    void setColorStyle( App::ColorGradient::TStyle tStyle );
-    App::ColorGradient::TStyle colorStyle() const;
+    void setColorStyle( App::ColorBarStyle tStyle );
+    App::ColorBarStyle colorStyle() const;
     //@}
     /** @name Display mode */
     //@{
@@ -68,18 +85,18 @@ public:
     //@}
     /** @name Parameter range and scale */
     //@{
-    void setRange( float fMin, float fMax );
-    void getRange( float& fMin, float& fMax) const;
+    void setRange(float fMin, float fMax);
+    void getRange(float& fMin, float& fMax) const;
     void setNumberOfLabels(int);
     int numberOfLabels() const;
-    void setNumberOfDecimals(int);
-    int numberOfDecimals() const;
     //@}
 
+Q_SIGNALS:
+    void colorModelChanged();
+
 private:
+    QDoubleValidator* validator;
     std::unique_ptr<Ui_DlgSettingsColorGradient> ui;
-    QDoubleValidator* fMaxVal;
-    QDoubleValidator* fMinVal;
 };
 
 } // namespace Dialog
