@@ -42,7 +42,7 @@ class DlgUnitsCalculator : public QDialog
     Q_OBJECT
 
 public:
-    DlgUnitsCalculator(QWidget* parent = 0, Qt::WindowFlags fl = Qt::WindowFlags());
+    DlgUnitsCalculator(QWidget* parent = nullptr, Qt::WindowFlags fl = Qt::WindowFlags());
     ~DlgUnitsCalculator();
 
 protected:
@@ -56,8 +56,8 @@ protected Q_SLOTS:
     void on_comboBoxScheme_activated(int);
     void on_spinBoxDecimals_valueChanged(int);
 
-    void copy(void);
-    void returnPressed(void);
+    void copy();
+    void returnPressed();
 
     void parseError(const QString& errorText);
 
