@@ -20,28 +20,26 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 
 #ifndef _PreComp_
 # include <QApplication>
-# include <algorithm>
-# include <boost/signals2.hpp>
-# include <boost/bind.hpp>
+# include <QFont>
 #endif
 
-#include <boost/unordered_set.hpp>
+#include <App/Document.h>
+#include <App/DocumentObject.h>
+#include <App/PropertyLinks.h>
 
 #include "DocumentModel.h"
 #include "Application.h"
 #include "BitmapFactory.h"
 #include "Document.h"
 #include "ViewProviderDocumentObject.h"
-#include <App/Document.h>
-#include <App/DocumentObject.h>
-#include <App/PropertyLinks.h>
+
 
 using namespace Gui;
+namespace bp = boost::placeholders;
 
 namespace Gui {
     // forward declaration
@@ -83,12 +81,12 @@ namespace Gui {
         { return childItems.count(); }
         virtual QVariant data(int role) const
         {
-            Q_UNUSED(role); 
+            Q_UNUSED(role);
             return QVariant();
         }
         virtual bool setData (const QVariant & value, int role)
         {
-            Q_UNUSED(value); 
+            Q_UNUSED(value);
             if (role == Qt::EditRole) {
                 return true;
             }
@@ -105,7 +103,7 @@ namespace Gui {
         { qDeleteAll(childItems); childItems.clear(); }
 
     protected:
-        DocumentModelIndex() : parentItem(0) {}
+        DocumentModelIndex() : parentItem(nullptr) {}
         DocumentModelIndex *parentItem;
         QList<DocumentModelIndex*> childItems;
     };
@@ -206,7 +204,7 @@ namespace Gui {
 
     // ------------------------------------------------------------------------
 
-    QIcon* DocumentIndex::documentIcon = 0;
+    QIcon* DocumentIndex::documentIcon = nullptr;
 
     void DocumentIndex::addToDocument(ViewProviderIndex* vp)
     {
@@ -298,7 +296,7 @@ namespace Gui {
             ViewProviderIndex* c = static_cast<ViewProviderIndex*>(*it)->clone();
             copy->appendChild(c);
         }
-        return copy; 
+        return copy;
     }
 
     void ViewProviderIndex::findViewProviders(const ViewProviderDocumentObject& vp,
@@ -337,10 +335,10 @@ namespace Gui {
 
     // ------------------------------------------------------------------------
 
-    TYPESYSTEM_SOURCE_ABSTRACT(Gui::DocumentModelIndex, Base::BaseClass);
-    TYPESYSTEM_SOURCE_ABSTRACT(Gui::ApplicationIndex,Gui::DocumentModelIndex);
-    TYPESYSTEM_SOURCE_ABSTRACT(Gui::DocumentIndex, Gui::DocumentModelIndex);
-    TYPESYSTEM_SOURCE_ABSTRACT(Gui::ViewProviderIndex, Gui::DocumentModelIndex);
+    TYPESYSTEM_SOURCE_ABSTRACT(Gui::DocumentModelIndex, Base::BaseClass)
+    TYPESYSTEM_SOURCE_ABSTRACT(Gui::ApplicationIndex,Gui::DocumentModelIndex)
+    TYPESYSTEM_SOURCE_ABSTRACT(Gui::DocumentIndex, Gui::DocumentModelIndex)
+    TYPESYSTEM_SOURCE_ABSTRACT(Gui::ViewProviderIndex, Gui::DocumentModelIndex)
 
     struct DocumentModelP
     {
@@ -367,27 +365,27 @@ DocumentModel::DocumentModel(QObject* parent)
     }
 
     // Setup connections
-    Application::Instance->signalNewDocument.connect(boost::bind(&DocumentModel::slotNewDocument, this, _1));
-    Application::Instance->signalDeleteDocument.connect(boost::bind(&DocumentModel::slotDeleteDocument, this, _1));
-    Application::Instance->signalRenameDocument.connect(boost::bind(&DocumentModel::slotRenameDocument, this, _1));
-    Application::Instance->signalActiveDocument.connect(boost::bind(&DocumentModel::slotActiveDocument, this, _1));
-    Application::Instance->signalRelabelDocument.connect(boost::bind(&DocumentModel::slotRelabelDocument, this, _1));
+    Application::Instance->signalNewDocument.connect(boost::bind(&DocumentModel::slotNewDocument, this, bp::_1));
+    Application::Instance->signalDeleteDocument.connect(boost::bind(&DocumentModel::slotDeleteDocument, this, bp::_1));
+    Application::Instance->signalRenameDocument.connect(boost::bind(&DocumentModel::slotRenameDocument, this, bp::_1));
+    Application::Instance->signalActiveDocument.connect(boost::bind(&DocumentModel::slotActiveDocument, this, bp::_1));
+    Application::Instance->signalRelabelDocument.connect(boost::bind(&DocumentModel::slotRelabelDocument, this, bp::_1));
 }
 
 DocumentModel::~DocumentModel()
 {
-    delete d; d = 0;
+    delete d; d = nullptr;
 }
 
 void DocumentModel::slotNewDocument(const Gui::Document& Doc)
 {
-    Doc.signalNewObject.connect(boost::bind(&DocumentModel::slotNewObject, this, _1));
-    Doc.signalDeletedObject.connect(boost::bind(&DocumentModel::slotDeleteObject, this, _1));
-    Doc.signalChangedObject.connect(boost::bind(&DocumentModel::slotChangeObject, this, _1, _2));
-    Doc.signalRelabelObject.connect(boost::bind(&DocumentModel::slotRenameObject, this, _1));
-    Doc.signalActivatedObject.connect(boost::bind(&DocumentModel::slotActiveObject, this, _1));
-    Doc.signalInEdit.connect(boost::bind(&DocumentModel::slotInEdit, this, _1));
-    Doc.signalResetEdit.connect(boost::bind(&DocumentModel::slotResetEdit, this, _1));
+    Doc.signalNewObject.connect(boost::bind(&DocumentModel::slotNewObject, this, bp::_1));
+    Doc.signalDeletedObject.connect(boost::bind(&DocumentModel::slotDeleteObject, this, bp::_1));
+    Doc.signalChangedObject.connect(boost::bind(&DocumentModel::slotChangeObject, this, bp::_1, bp::_2));
+    Doc.signalRelabelObject.connect(boost::bind(&DocumentModel::slotRenameObject, this, bp::_1));
+    Doc.signalActivatedObject.connect(boost::bind(&DocumentModel::slotActiveObject, this, bp::_1));
+    Doc.signalInEdit.connect(boost::bind(&DocumentModel::slotInEdit, this, bp::_1));
+    Doc.signalResetEdit.connect(boost::bind(&DocumentModel::slotResetEdit, this, bp::_1));
 
     QModelIndex parent = createIndex(0,0,d->rootItem);
     int count_docs = d->rootItem->childCount();
@@ -411,7 +409,7 @@ void DocumentModel::slotDeleteDocument(const Gui::Document& Doc)
 
 void DocumentModel::slotRenameDocument(const Gui::Document& Doc)
 {
-    Q_UNUSED(Doc); 
+    Q_UNUSED(Doc);
     // do nothing here
 }
 
@@ -436,12 +434,12 @@ void DocumentModel::slotActiveDocument(const Gui::Document& /*Doc*/)
 
 void DocumentModel::slotInEdit(const Gui::ViewProviderDocumentObject& v)
 {
-    Q_UNUSED(v); 
+    Q_UNUSED(v);
 }
 
 void DocumentModel::slotResetEdit(const Gui::ViewProviderDocumentObject& v)
 {
-    Q_UNUSED(v); 
+    Q_UNUSED(v);
 }
 
 void DocumentModel::slotNewObject(const Gui::ViewProviderDocumentObject& obj)
@@ -550,13 +548,13 @@ void DocumentModel::slotChangeObject(const Gui::ViewProviderDocumentObject& obj,
 
 void DocumentModel::slotRenameObject(const Gui::ViewProviderDocumentObject& obj)
 {
-    Q_UNUSED(obj); 
+    Q_UNUSED(obj);
     // renaming of objects not supported at the moment
 }
 
 void DocumentModel::slotActiveObject(const Gui::ViewProviderDocumentObject& obj)
 {
-    Q_UNUSED(obj); 
+    Q_UNUSED(obj);
     // do nothing here because this is automatically done by calling
     // ViewProviderIndex::data()
 }
@@ -564,15 +562,15 @@ void DocumentModel::slotActiveObject(const Gui::ViewProviderDocumentObject& obj)
 const Document* DocumentModel::getDocument(const QModelIndex& index) const
 {
     if (!index.isValid())
-        return 0;
-    Base::BaseClass* item = 0;
+        return nullptr;
+    Base::BaseClass* item = nullptr;
     item = static_cast<Base::BaseClass*>(index.internalPointer());
     if (item->getTypeId() == DocumentIndex::getClassTypeId()) {
         const Gui::Document& d = static_cast<DocumentIndex*>(item)->d;
         return (&d);
     }
 
-    return 0;
+    return nullptr;
 }
 
 bool DocumentModel::isPropertyLink(const App::Property& prop) const
@@ -627,13 +625,13 @@ Qt::ItemFlags DocumentModel::flags(const QModelIndex &index) const
     //    return Qt::ItemIsEnabled;
     //return QAbstractItemModel::flags(index);
     if (!index.isValid())
-        return 0;
+        return Qt::ItemFlags();
     return static_cast<DocumentModelIndex*>(index.internalPointer())->flags();
 }
 
 QModelIndex DocumentModel::index (int row, int column, const QModelIndex & parent) const
 {
-    DocumentModelIndex* item = 0;
+    DocumentModelIndex* item = nullptr;
     if (!parent.isValid())
         item = d->rootItem;
     else
@@ -647,7 +645,7 @@ QModelIndex DocumentModel::parent (const QModelIndex & index) const
 {
     if (!index.isValid() || index.internalPointer() == d->rootItem)
         return QModelIndex();
-    DocumentModelIndex* item = 0;
+    DocumentModelIndex* item = nullptr;
     item = static_cast<DocumentModelIndex*>(index.internalPointer());
     DocumentModelIndex* parent = item->parent();
     return createIndex(parent->row(), 0, parent);
@@ -657,14 +655,14 @@ int DocumentModel::rowCount (const QModelIndex & parent) const
 {
     if (!parent.isValid())
         return 1; // the root item
-    DocumentModelIndex* item = 0;
+    DocumentModelIndex* item = nullptr;
     item = static_cast<DocumentModelIndex*>(parent.internalPointer());
     return item->childCount();
 }
 
 QVariant DocumentModel::headerData (int section, Qt::Orientation orientation, int role) const
 {
-    Q_UNUSED(section); 
+    Q_UNUSED(section);
     if (orientation == Qt::Horizontal) {
         if (role != Qt::DisplayRole)
             return QVariant();
