@@ -20,20 +20,16 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 
-#ifndef _PreComp_
-# include <boost_bind_bind.hpp>
-#endif
+#include <Base/Interpreter.h>
 
 #include "Application.h"
 #include "Document.h"
+#include "DocumentObserverPython.h"
 #include "ViewProvider.h"
 #include "ViewProviderDocumentObject.h"
-#include "DocumentObserverPython.h"
-#include <Base/Interpreter.h>
-#include <Base/Console.h>
+
 
 using namespace Gui;
 namespace bp = boost::placeholders;
@@ -47,7 +43,7 @@ void DocumentObserverPython::addObserver(const Py::Object& obj)
 
 void DocumentObserverPython::removeObserver(const Py::Object& obj)
 {
-    DocumentObserverPython* obs=0;
+    DocumentObserverPython* obs=nullptr;
     for (std::vector<DocumentObserverPython*>::iterator it =
         _instances.begin(); it != _instances.end(); ++it) {
         if ((*it)->inst == obj) {
