@@ -20,10 +20,9 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
-#include <stdio.h>
-#include <cmath>
+#include <cstdio>
+#include <iostream>
 
 #include <QByteArray>
 #include <QDockWidget>
@@ -33,24 +32,20 @@
 #include <QMetaEnum>
 #include <QSettings>
 #include <QFileIconProvider>
-#if QT_VERSION < 0x050000
-#include <QWebSettings>
-#endif
-#if QT_VERSION >= 0x050000
 #include <QUrlQuery>
-#endif
 
-#include "DownloadItem.h"
 #include "DownloadManager.h"
 #include "ui_DownloadManager.h"
 #include "DockWindowManager.h"
+#include "DownloadItem.h"
 #include "MainWindow.h"
 
+
 using namespace Gui::Dialog;
 
 /* TRANSLATOR Gui::Dialog::DownloadManager */
 
-DownloadManager* DownloadManager::self = 0;
+DownloadManager* DownloadManager::self = nullptr;
 
 DownloadManager* DownloadManager::getInstance()
 {
@@ -63,7 +58,7 @@ DownloadManager::DownloadManager(QWidget *parent)
     : QDialog(parent)
     , m_autoSaver(new AutoSaver(this))
     , m_manager(new NetworkAccessManager(this))
-    , m_iconProvider(0)
+    , m_iconProvider(nullptr)
     , m_removePolicy(Never)
     , ui(new Ui_DownloadManager())
 {
@@ -95,7 +90,7 @@ DownloadManager::~DownloadManager()
     if (m_iconProvider)
         delete m_iconProvider;
     delete ui;
-    self = 0;
+    self = nullptr;
 }
 
 void DownloadManager::closeEvent(QCloseEvent* e)
@@ -117,7 +112,6 @@ QUrl DownloadManager::redirectUrl(const QUrl& url) const
 {
     QUrl redirectUrl = url;
     if (url.host() == QLatin1String("www.dropbox.com")) {
-#if QT_VERSION >= 0x050000
         QUrlQuery urlQuery(url);
         QList< QPair<QString, QString> > query = urlQuery.queryItems();
         for (QList< QPair<QString, QString> >::iterator it = query.begin(); it != query.end(); ++it) {
@@ -134,22 +128,6 @@ QUrl DownloadManager::redirectUrl(const QUrl& url) const
             }
         }
         redirectUrl.setQuery(urlQuery);
-#else
-        QList< QPair<QString, QString> > query = url.queryItems();
-        for (QList< QPair<QString, QString> >::iterator it = query.begin(); it != query.end(); ++it) {
-            if (it->first == QLatin1String("dl")) {
-                if (it->second == QLatin1String("0\r\n")) {
-                    redirectUrl.removeQueryItem(QLatin1String("dl"));
-                    redirectUrl.addQueryItem(QLatin1String("dl"), QLatin1String("1\r\n"));
-                }
-                else if (it->second == QLatin1String("0")) {
-                    redirectUrl.removeQueryItem(QLatin1String("dl"));
-                    redirectUrl.addQueryItem(QLatin1String("dl"), QLatin1String("1"));
-                }
-                break;
-            }
-        }
-#endif
     }
     else {
         // When the url comes from drag and drop it may end with CR+LF. This may cause problems
@@ -217,13 +195,6 @@ void DownloadManager::updateRow()
     ui->downloadsView->setRowHeight(row, item->minimumSizeHint().height());
 
     bool remove = false;
-#if QT_VERSION < 0x050000
-    QWebSettings *globalSettings = QWebSettings::globalSettings();
-    if (!item->downloading()
-        && globalSettings->testAttribute(QWebSettings::PrivateBrowsingEnabled))
-        remove = true;
-#endif
-
     if (item->downloadedSuccessfully()
         && removePolicy() == DownloadManager::SuccessFullDownload) {
         remove = true;
@@ -293,7 +264,7 @@ void DownloadManager::load()
         QString fileName = settings.value(key + QLatin1String("location")).toString();
         bool done = settings.value(key + QLatin1String("done"), true).toBool();
         if (!url.isEmpty() && !fileName.isEmpty()) {
-            DownloadItem *item = new DownloadItem(0, false, this);
+            DownloadItem *item = new DownloadItem(nullptr, false, this);
             item->m_output.setFileName(fileName);
             item->fileNameLabel->setText(QFileInfo(item->m_output.fileName()).fileName());
             item->m_url = url;
@@ -317,7 +288,7 @@ void DownloadManager::cleanup()
     updateItemCount();
     if (m_downloads.isEmpty() && m_iconProvider) {
         delete m_iconProvider;
-        m_iconProvider = 0;
+        m_iconProvider = nullptr;
     }
     m_autoSaver->changeOccurred();
 }
