@@ -23,42 +23,46 @@
 
 #include "PreCompiled.h"
 #ifndef _PreComp_
-# include <QAbstractTextDocumentLayout>
 # include <QApplication>
+# include <QCheckBox>
 # include <QClipboard>
 # include <QDateTime>
 # include <QHBoxLayout>
+# include <QVBoxLayout>
+# include <QLineEdit>
 # include <QMessageBox>
-# include <QPainter>
 # include <QPrinter>
 # include <QPrintDialog>
-# include <QScrollBar>
 # include <QPlainTextEdit>
 # include <QPrintPreviewDialog>
-# include <QTextBlock>
+# include <QSpacerItem>
+# include <QStyle>
 # include <QTextCodec>
+# include <QTextCursor>
+# include <QTextDocument>
 # include <QTextStream>
 # include <QTimer>
+# include <QToolButton>
 #endif
 
 #include "EditorView.h"
 #include "Application.h"
-#include "BitmapFactory.h"
 #include "FileDialog.h"
 #include "Macro.h"
 #include "MainWindow.h"
-#include "PythonDebugger.h"
 #include "PythonEditor.h"
 
+#include <Base/Exception.h>
 #include <Base/Interpreter.h>
 #include <Base/Parameter.h>
-#include <Base/Exception.h>
+
 
 using namespace Gui;
 namespace Gui {
 class EditorViewP {
 public:
     QPlainTextEdit* textEdit;
+    SearchBar* searchBar;
     QString fileName;
     EditorView::DisplayName displayName;
     QTimer*  activityTimer;
@@ -74,12 +78,14 @@ public:
 
 /* TRANSLATOR Gui::EditorView */
 
+TYPESYSTEM_SOURCE_ABSTRACT(Gui::EditorView, Gui::MDIView)
+
 /**
  *  Constructs a EditorView which is a child of 'parent', with the
  *  name 'name'.
  */
 EditorView::EditorView(QPlainTextEdit* editor, QWidget* parent)
-    : MDIView(0,parent,Qt::WindowFlags()), WindowParameter( "Editor" )
+    : MDIView(nullptr,parent,Qt::WindowFlags()), WindowParameter( "Editor" )
 {
     d = new EditorViewP;
     d->lock = false;
@@ -90,19 +96,29 @@ EditorView::EditorView(QPlainTextEdit* editor, QWidget* parent)
     d->textEdit = editor;
     d->textEdit->setLineWrapMode(QPlainTextEdit::NoWrap);
 
+    d->searchBar = new SearchBar();
+    d->searchBar->setEditor(editor);
+
     // update editor actions on request
     Gui::MainWindow* mw = Gui::getMainWindow();
     connect(editor, SIGNAL(undoAvailable(bool)), mw, SLOT(updateEditorActions()));
     connect(editor, SIGNAL(redoAvailable(bool)), mw, SLOT(updateEditorActions()));
     connect(editor, SIGNAL(copyAvailable(bool)), mw, SLOT(updateEditorActions()));
 
+    connect(editor, SIGNAL(showSearchBar()), d->searchBar, SLOT(activate()));
+    connect(editor, SIGNAL(findNext()), d->searchBar, SLOT(findNext()));
+    connect(editor, SIGNAL(findPrevious()), d->searchBar, SLOT(findPrevious()));
+
     // Create the layout containing the workspace and a tab bar
     QFrame* hbox = new QFrame(this);
-    hbox->setFrameStyle(QFrame::StyledPanel | QFrame::Sunken);
-    QHBoxLayout* layout = new QHBoxLayout();
+    hbox->setFrameShape(QFrame::StyledPanel);
+    hbox->setFrameShadow(QFrame::Sunken);
+    QVBoxLayout* layout = new QVBoxLayout();
     layout->setMargin(1);
     layout->addWidget(d->textEdit);
+    layout->addWidget(d->searchBar);
     d->textEdit->setParent(hbox);
+    d->searchBar->setParent(hbox);
     hbox->setLayout(layout);
     setCentralWidget(hbox);
 
@@ -295,7 +311,7 @@ bool EditorView::onHasMsg(const char* pMsg) const
 }
 
 /** Checking on close state. */
-bool EditorView::canClose(void)
+bool EditorView::canClose()
 {
     if ( !d->textEdit->document()->isModified() )
         return true;
@@ -325,7 +341,7 @@ void EditorView::setDisplayName(EditorView::DisplayName type)
 /**
  * Saves the content of the editor to a file specified by the appearing file dialog.
  */
-bool EditorView::saveAs(void)
+bool EditorView::saveAs()
 {
     QString fn = FileDialog::getSaveFileName(this, QObject::tr("Save Macro"),
         QString(), QString::fromLatin1("%1 (*.FCMacro);;Python (*.py)").arg(tr("FreeCAD macro")));
@@ -366,7 +382,7 @@ bool EditorView::open(const QString& fileName)
  * Copies the selected text to the clipboard and deletes it from the text edit.
  * If there is no selected text nothing happens.
  */
-void EditorView::cut(void)
+void EditorView::cut()
 {
     d->textEdit->cut();
 }
@@ -374,7 +390,7 @@ void EditorView::cut(void)
 /**
  * Copies any selected text to the clipboard.
  */
-void EditorView::copy(void)
+void EditorView::copy()
 {
     d->textEdit->copy();
 }
@@ -383,7 +399,7 @@ void EditorView::copy(void)
  * Pastes the text from the clipboard into the text edit at the current cursor position.
  * If there is no text in the clipboard nothing happens.
  */
-void EditorView::paste(void)
+void EditorView::paste()
 {
     d->textEdit->paste();
 }
@@ -392,7 +408,7 @@ void EditorView::paste(void)
  * Undoes the last operation.
  * If there is no operation to undo, i.e. there is no undo step in the undo/redo history, nothing happens.
  */
-void EditorView::undo(void)
+void EditorView::undo()
 {
     d->lock = true;
     if (!d->undos.isEmpty()) {
@@ -407,7 +423,7 @@ void EditorView::undo(void)
  * Redoes the last operation.
  * If there is no operation to undo, i.e. there is no undo step in the undo/redo history, nothing happens.
  */
-void EditorView::redo(void)
+void EditorView::redo()
 {
     d->lock = true;
     if (!d->redos.isEmpty()) {
@@ -568,6 +584,8 @@ void EditorView::focusInEvent (QFocusEvent *)
 
 // ---------------------------------------------------------
 
+TYPESYSTEM_SOURCE_ABSTRACT(Gui::PythonEditorView, Gui::EditorView)
+
 PythonEditorView::PythonEditorView(PythonEditor* editor, QWidget* parent)
   : EditorView(editor, parent), _pye(editor)
 {
@@ -605,9 +623,12 @@ bool PythonEditorView::onMsg(const char* pMsg,const char** ppReturn)
  */
 bool PythonEditorView::onHasMsg(const char* pMsg) const
 {
-    if (strcmp(pMsg,"Run")==0)  return true;
-    if (strcmp(pMsg,"StartDebug")==0)  return true;
-    if (strcmp(pMsg,"ToggleBreakpoint")==0)  return true;
+    if (strcmp(pMsg,"Run")==0)
+        return true;
+    if (strcmp(pMsg,"StartDebug")==0)
+        return true;
+    if (strcmp(pMsg,"ToggleBreakpoint")==0)
+        return true;
     return EditorView::onHasMsg(pMsg);
 }
 
@@ -618,7 +639,7 @@ void PythonEditorView::executeScript()
 {
     // always save the macro when it is modified
     if (EditorView::onHasMsg("Save"))
-        EditorView::onMsg("Save", 0);
+        EditorView::onMsg("Save", nullptr);
     try {
         Application::Instance->macroManager()->run(Gui::MacroManager::File,fileName().toUtf8());
     }
@@ -650,4 +671,180 @@ void PythonEditorView::hideDebugMarker()
     _pye->hideDebugMarker();
 }
 
+// ----------------------------------------------------------------------------
+
+SearchBar::SearchBar(QWidget* parent)
+    : QWidget(parent)
+    , textEditor(nullptr)
+{
+    horizontalLayout = new QHBoxLayout(this);
+    horizontalLayout->setSpacing(3);
+
+    closeButton = new QToolButton(this);
+    closeButton->setIcon(style()->standardIcon(QStyle::SP_DialogCloseButton));
+    closeButton->setAutoRaise(true);
+    connect(closeButton, &QToolButton::clicked, this, &SearchBar::deactivate);
+
+    horizontalLayout->addWidget(closeButton);
+
+    searchText = new QLineEdit(this);
+    searchText->setClearButtonEnabled(true);
+    horizontalLayout->addWidget(searchText);
+    connect(searchText, &QLineEdit::returnPressed, this, &SearchBar::findNext);
+    connect(searchText, &QLineEdit::textChanged, this, &SearchBar::findCurrent);
+    connect(searchText, &QLineEdit::textChanged, this, &SearchBar::updateButtons);
+
+    prevButton = new QToolButton(this);
+    prevButton->setIcon(style()->standardIcon(QStyle::SP_ArrowBack));
+    prevButton->setAutoRaise(true);
+    prevButton->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
+    horizontalLayout->addWidget(prevButton);
+    connect(prevButton, &QToolButton::clicked, this, &SearchBar::findPrevious);
+
+    nextButton = new QToolButton(this);
+    nextButton->setIcon(style()->standardIcon(QStyle::SP_ArrowForward));
+    nextButton->setAutoRaise(true);
+    nextButton->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
+    horizontalLayout->addWidget(nextButton);
+    connect(nextButton, &QToolButton::clicked, this, &SearchBar::findNext);
+
+    matchCase = new QCheckBox(this);
+    horizontalLayout->addWidget(matchCase);
+    connect(matchCase, &QCheckBox::toggled, this, &SearchBar::findCurrent);
+
+    matchWord = new QCheckBox(this);
+    horizontalLayout->addWidget(matchWord);
+    connect(matchWord, &QCheckBox::toggled, this, &SearchBar::findCurrent);
+
+    horizontalSpacer = new QSpacerItem(192, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);
+    horizontalLayout->addItem(horizontalSpacer);
+
+    retranslateUi();
+
+    setMinimumWidth(minimumSizeHint().width());
+    updateButtons();
+    hide();
+}
+
+void SearchBar::setEditor(QPlainTextEdit* textEdit)
+{
+    textEditor = textEdit;
+}
+
+void SearchBar::keyPressEvent(QKeyEvent* event)
+{
+    if (event->key() == Qt::Key_Escape) {
+        hide();
+        return;
+    }
+
+    QWidget::keyPressEvent(event);
+}
+
+void SearchBar::retranslateUi()
+{
+    prevButton->setText(tr("Previous"));
+    nextButton->setText(tr("Next"));
+    matchCase->setText(tr("Case sensitive"));
+    matchWord->setText(tr("Whole words"));
+}
+
+void SearchBar::activate()
+{
+    show();
+    searchText->selectAll();
+    searchText->setFocus(Qt::ShortcutFocusReason);
+}
+
+void SearchBar::deactivate()
+{
+    if (textEditor)
+        textEditor->setFocus();
+    hide();
+}
+
+void SearchBar::findPrevious()
+{
+    findText(true, false, searchText->text());
+}
+
+void SearchBar::findNext()
+{
+    findText(true, true, searchText->text());
+}
+
+void SearchBar::findCurrent()
+{
+    findText(false, true, searchText->text());
+}
+
+void SearchBar::findText(bool skip, bool next, const QString& str)
+{
+    if (!textEditor)
+        return;
+
+    QTextCursor cursor = textEditor->textCursor();
+    QTextDocument *doc = textEditor->document();
+    if (!doc || cursor.isNull())
+        return;
+
+    if (cursor.hasSelection())
+        cursor.setPosition((skip && next) ? cursor.position() : cursor.anchor());
+
+    bool found = true;
+    QTextCursor newCursor = cursor;
+    if (!str.isEmpty()) {
+        QTextDocument::FindFlags options;
+        if (!next)
+            options |= QTextDocument::FindBackward;
+        if (matchCase->isChecked())
+            options |= QTextDocument::FindCaseSensitively;
+        if (matchWord->isChecked())
+            options |= QTextDocument::FindWholeWords;
+
+        newCursor = doc->find(str, cursor, options);
+        if (newCursor.isNull()) {
+            QTextCursor ac(doc);
+            ac.movePosition(options & QTextDocument::FindBackward ? QTextCursor::End : QTextCursor::Start);
+            newCursor = doc->find(str, ac, options);
+            if (newCursor.isNull()) {
+                found = false;
+                newCursor = cursor;
+            }
+        }
+    }
+
+    if (!isVisible())
+        show();
+
+    textEditor->setTextCursor(newCursor);
+
+    QString styleSheet;
+    if (!found) {
+        styleSheet = QString::fromLatin1(
+            " QLineEdit {\n"
+            "     background-color: rgb(221,144,161);\n"
+            " }\n"
+        );
+    }
+
+    searchText->setStyleSheet(styleSheet);
+}
+
+void SearchBar::updateButtons()
+{
+    bool empty = searchText->text().isEmpty();
+    prevButton->setDisabled(empty);
+    nextButton->setDisabled(empty);
+}
+
+void SearchBar::changeEvent(QEvent* event)
+{
+    if (event->type() == QEvent::LanguageChange) {
+        retranslateUi();
+    }
+
+    QWidget::changeEvent(event);
+}
+
 #include "moc_EditorView.cpp"
