@@ -28,8 +28,13 @@
 #include "Window.h"
 
 QT_BEGIN_NAMESPACE
+class QLineEdit;
 class QPlainTextEdit;
 class QPrinter;
+class QHBoxLayout;
+class QToolButton;
+class QCheckBox;
+class QSpacerItem;
 QT_END_NAMESPACE
 
 namespace Gui {
@@ -45,6 +50,8 @@ class GuiExport EditorView : public MDIView, public WindowParameter
 {
     Q_OBJECT
 
+    TYPESYSTEM_HEADER();
+
 public:
     enum DisplayName {
         FullName,
@@ -59,13 +66,13 @@ public:
     void setDisplayName(DisplayName);
     void OnChange(Base::Subject<const char*> &rCaller,const char* rcReason);
 
-    const char *getName(void) const {return "EditorView";}
-    void onUpdate(void){}
+    const char *getName() const {return "EditorView";}
+    void onUpdate(){}
 
     bool onMsg(const char* pMsg,const char** ppReturn);
     bool onHasMsg(const char* pMsg) const;
 
-    bool canClose(void);
+    bool canClose();
 
     /** @name Standard actions of the editor */
     //@{
@@ -114,6 +121,8 @@ class GuiExport PythonEditorView : public EditorView
 {
     Q_OBJECT
 
+    TYPESYSTEM_HEADER();
+
 public:
     PythonEditorView(PythonEditor* editor, QWidget* parent);
     ~PythonEditorView();
@@ -132,6 +141,43 @@ private:
     PythonEditor* _pye;
 };
 
+class SearchBar : public QWidget
+{
+    Q_OBJECT
+
+public:
+    SearchBar(QWidget* parent = nullptr);
+
+    void setEditor(QPlainTextEdit *textEdit);
+
+protected:
+    void keyPressEvent(QKeyEvent*);
+    void changeEvent(QEvent*);
+
+public Q_SLOTS:
+    void activate();
+    void deactivate();
+    void findPrevious();
+    void findNext();
+    void findCurrent();
+
+private:
+    void retranslateUi();
+    void findText(bool skip, bool next, const QString& str);
+    void updateButtons();
+
+private:
+    QPlainTextEdit* textEditor;
+    QHBoxLayout* horizontalLayout;
+    QSpacerItem* horizontalSpacer;
+    QToolButton* closeButton;
+    QLineEdit* searchText;
+    QToolButton* prevButton;
+    QToolButton* nextButton;
+    QCheckBox* matchCase;
+    QCheckBox* matchWord;
+};
+
 } // namespace Gui
 
 #endif // GUI_EDITORVIEW_H
