@@ -23,29 +23,26 @@
 #include "PreCompiled.h"
 
 #ifndef _PreComp_
-#include <QContextMenuEvent>
-#include <QStandardItem>
-#include <QStandardItemModel>
-#include <QLineEdit>
-#include <QAbstractItemView>
-#include <QMenu>
-#include <QTextBlock>
+# include <boost/algorithm/string/predicate.hpp>
+# include <QAbstractItemView>
+# include <QContextMenuEvent>
+# include <QLineEdit>
+# include <QMenu>
+# include <QTextBlock>
 #endif
 
-#include <boost/algorithm/string/predicate.hpp>
-
-#include <Base/Tools.h>
-#include <Base/Console.h>
 #include <App/Application.h>
 #include <App/Document.h>
 #include <App/DocumentObject.h>
-#include <App/DocumentObserver.h>
-#include <App/ObjectIdentifier.h>
-#include "ExpressionCompleter.h"
 #include <App/ExpressionParser.h>
-#include <App/PropertyLinks.h>
+#include <App/ObjectIdentifier.h>
+#include <Base/Tools.h>
+#include <CXX/Extensions.hxx>
 
-FC_LOG_LEVEL_INIT("Completer",true,true)
+#include "ExpressionCompleter.h"
+
+
+FC_LOG_LEVEL_INIT("Completer", true, true)
 
 Q_DECLARE_METATYPE(App::ObjectIdentifier)
 
@@ -54,22 +51,21 @@ using namespace Gui;
 
 class ExpressionCompleterModel: public QAbstractItemModel {
 public:
-    ExpressionCompleterModel(QObject *parent, const App::DocumentObject *obj, bool noProperty)
+    ExpressionCompleterModel(QObject *parent, bool noProperty)
         :QAbstractItemModel(parent), noProperty(noProperty)
     {
-        setDocumentObject(obj);
     }
 
     void setNoProperty(bool enabled) {
         noProperty = enabled;
     }
 
-    void setDocumentObject(const App::DocumentObject *obj) {
+    void setDocumentObject(const App::DocumentObject *obj, bool checkInList) {
         beginResetModel();
         if(obj) {
             currentDoc = obj->getDocument()->getName();
             currentObj = obj->getNameInDocument();
-            if(!noProperty)
+            if(!noProperty && checkInList)
                 inList = obj->getInListEx(true);
         } else {
             currentDoc.clear();
@@ -147,7 +143,7 @@ public:
             return QVariant();
         QVariant v;
         Info info = getInfo(index);
-        _data(info,index.row(),&v,0,role==Qt::UserRole);
+        _data(info,index.row(),&v,nullptr,role==Qt::UserRole);
         FC_TRACE(info.d.doc << "," << info.d.obj << "," << index.row()
                 << ": " << v.toString().toUtf8().constData());
         return v;
@@ -160,10 +156,10 @@ public:
         int docSize = (int)docs.size()*2;
         int objSize = 0;
         int propSize = 0;
-        std::vector<App::Property*> props;
-        App::Document *doc = 0;
-        App::DocumentObject *obj = 0;
-        App::Property *prop = 0;
+        std::vector<std::pair<const char*, App::Property*> > props;
+        App::Document *doc = nullptr;
+        App::DocumentObject *obj = nullptr;
+        const char *propName = nullptr;
         if(idx>=0 && idx<docSize)
             doc = docs[idx/2];
         else {
@@ -185,13 +181,13 @@ public:
                     idx -= objSize;
                     if(info.d.doc<0)
                         row = idx;
-                    cobj->getPropertyList(props);
+                    cobj->getPropertyNamedList(props);
                     propSize = (int)props.size();
                     if(idx >= propSize)
                         return;
                     if(idx>=0) {
                         obj = cobj;
-                        prop = props[idx];
+                        propName = props[idx].first;
                     }
                 }
             }
@@ -201,8 +197,8 @@ public:
                 *count = docSize + objSize + propSize;
             if(idx>=0 && v) {
                 QString res;
-                if(prop)
-                    res = QString::fromLatin1(prop->getName());
+                if(propName)
+                    res = QString::fromLatin1(propName);
                 else if(obj) {
                     if(idx & 1)
                         res = QString::fromUtf8(quote(obj->Label.getStrValue()).c_str());
@@ -249,18 +245,18 @@ public:
 
         if(noProperty)
             return;
-        if(!prop) {
+        if(!propName) {
             idx = row;
-            obj->getPropertyList(props);
+            obj->getPropertyNamedList(props);
             propSize = (int)props.size();
             if(idx<0 || idx>=propSize)
                 return;
-            prop = props[idx];
+            propName = props[idx].first;
             if(count)
                 *count = propSize;
         }
-        if(v)
-            *v = QString::fromLatin1(prop->getName());
+        if(v) 
+            *v = QString::fromLatin1(propName);
         return;
     }
 
@@ -317,7 +313,7 @@ public:
                 return 0;
         }
         int count = 0;
-        _data(info,row,0,&count);
+        _data(info,row,nullptr,&count);
         FC_TRACE(info.d.doc << "," << info.d.obj << "," << row << " row count " << count);
         return count;
     }
@@ -340,9 +336,10 @@ private:
  * @param parent Parent object owning the completer.
  */
 
-ExpressionCompleter::ExpressionCompleter(const App::DocumentObject * currentDocObj,
-        QObject *parent, bool noProperty)
-    : QCompleter(parent), currentObj(currentDocObj), noProperty(noProperty)
+ExpressionCompleter::ExpressionCompleter(const App::DocumentObject * currentDocObj, 
+        QObject *parent, bool noProperty, bool checkInList)
+    : QCompleter(parent), currentObj(currentDocObj)
+    , noProperty(noProperty), checkInList(checkInList)
 {
     setCaseSensitivity(Qt::CaseInsensitive);
 }
@@ -351,18 +348,21 @@ void ExpressionCompleter::init() {
     if(model())
         return;
 
-    setModel(new ExpressionCompleterModel(this,currentObj.getObject(),noProperty));
+    auto m = new ExpressionCompleterModel(this,noProperty);
+    m->setDocumentObject(currentObj.getObject(),checkInList);
+    setModel(m);
 }
 
-void ExpressionCompleter::setDocumentObject(const App::DocumentObject *obj) {
+void ExpressionCompleter::setDocumentObject(const App::DocumentObject *obj, bool _checkInList) {
     if(!obj || !obj->getNameInDocument())
         currentObj = App::DocumentObjectT();
     else
         currentObj = obj;
     setCompletionPrefix(QString());
+    checkInList = _checkInList;
     auto m = model();
     if(m)
-        static_cast<ExpressionCompleterModel*>(m)->setDocumentObject(obj);
+        static_cast<ExpressionCompleterModel*>(m)->setDocumentObject(obj, checkInList);
 }
 
 void ExpressionCompleter::setNoProperty(bool enabled) {
@@ -372,10 +372,6 @@ void ExpressionCompleter::setNoProperty(bool enabled) {
         static_cast<ExpressionCompleterModel*>(m)->setNoProperty(enabled);
 }
 
-void ExpressionCompleter::setRequireLeadingEqualSign(bool enabled) {
-    requireLeadingEqualSign = enabled;
-}
-
 QString ExpressionCompleter::pathFromIndex ( const QModelIndex & index ) const
 {
     auto m = model();
@@ -454,22 +450,15 @@ void ExpressionCompleter::slotUpdate(const QString & prefix, int pos)
 {
     init();
 
-    using namespace boost::tuples;
     std::string completionPrefix;
 
     // Compute start; if prefix starts with =, start parsing from offset 1.
     int start = (prefix.size() > 0 && prefix.at(0) == QChar::fromLatin1('=')) ? 1 : 0;
 
-    if (requireLeadingEqualSign && start != 1) {
-        if (auto p = popup())
-            p->setVisible(false);
-        return;
-    }
-
     std::string expression = Base::Tools::toStdString(prefix.mid(start));
 
     // Tokenize prefix
-    std::vector<boost::tuple<int, int, std::string> > tokens = ExpressionParser::tokenize(expression);
+    std::vector<std::tuple<int, int, std::string> > tokens = ExpressionParser::tokenize(expression);
 
     // No tokens
     if (tokens.size() == 0) {
@@ -499,7 +488,7 @@ void ExpressionCompleter::slotUpdate(const QString & prefix, int pos)
         trim = prefixEnd - pos;
 
     // Extract last tokens that can be rebuilt to a variable
-    ssize_t i = static_cast<ssize_t>(tokens.size()) - 1;
+    long i = static_cast<long>(tokens.size()) - 1;
 
     // First, check if we have unclosing string starting from the end
     bool stringing = false;
@@ -526,7 +515,7 @@ void ExpressionCompleter::slotUpdate(const QString & prefix, int pos)
     }
 
     if(!stringing) {
-        i = static_cast<ssize_t>(tokens.size()) - 1;
+        i = static_cast<long>(tokens.size()) - 1;
         for(;i>=0;--i) {
             int token = get<0>(tokens[i]);
             if (token != '.' && token != '#' &&
@@ -540,13 +529,13 @@ void ExpressionCompleter::slotUpdate(const QString & prefix, int pos)
     }
 
     // Set prefix start for use when replacing later
-    if (i == static_cast<ssize_t>(tokens.size()))
+    if (i == static_cast<long>(tokens.size()))
         prefixStart = prefixEnd;
     else
         prefixStart = start + get<1>(tokens[i]);
 
     // Build prefix from tokens
-    while (i < static_cast<ssize_t>(tokens.size())) {
+    while (i < static_cast<long>(tokens.size())) {
         completionPrefix += get<2>(tokens[i]);
         ++i;
     }
@@ -565,32 +554,35 @@ void ExpressionCompleter::slotUpdate(const QString & prefix, int pos)
     }
 }
 
-ExpressionLineEdit::ExpressionLineEdit(QWidget *parent, bool noProperty, bool requireLeadingEqualSign)
+ExpressionLineEdit::ExpressionLineEdit(QWidget *parent, bool noProperty, char checkPrefix, bool checkInList)
     : QLineEdit(parent)
     , completer(nullptr)
     , block(true)
     , noProperty(noProperty)
     , exactMatch(false)
-    , requireLeadingEqualSign(requireLeadingEqualSign)
+    , checkInList(checkInList)
+    , checkPrefix(checkPrefix)
 {
     connect(this, SIGNAL(textEdited(const QString&)), this, SLOT(slotTextChanged(const QString&)));
 }
 
-void ExpressionLineEdit::setDocumentObject(const App::DocumentObject * currentDocObj)
+void ExpressionLineEdit::setPrefix(char prefix) {
+    checkPrefix = prefix;
+}
+
+void ExpressionLineEdit::setDocumentObject(const App::DocumentObject * currentDocObj, bool _checkInList)
 {
+    checkInList = _checkInList;
     if (completer) {
-        completer->setDocumentObject(currentDocObj);
+        completer->setDocumentObject(currentDocObj, checkInList);
         return;
     }
-    if (currentDocObj != 0) {
-        completer = new ExpressionCompleter(currentDocObj, this, noProperty);
+    if (currentDocObj != nullptr) {
+        completer = new ExpressionCompleter(currentDocObj, this, noProperty, checkInList);
         completer->setWidget(this);
         completer->setCaseSensitivity(Qt::CaseInsensitive);
-        completer->setRequireLeadingEqualSign(requireLeadingEqualSign);
-#if QT_VERSION>=QT_VERSION_CHECK(5,2,0)
         if (!exactMatch)
             completer->setFilterMode(Qt::MatchContains);
-#endif
         connect(completer, SIGNAL(activated(QString)), this, SLOT(slotCompleteText(QString)));
         connect(completer, SIGNAL(highlighted(QString)), this, SLOT(slotCompleteText(QString)));
         connect(this, SIGNAL(textChanged2(QString,int)), completer, SLOT(slotUpdate(QString,int)));
@@ -605,10 +597,9 @@ void ExpressionLineEdit::setNoProperty(bool enabled) {
 
 void ExpressionLineEdit::setExactMatch(bool enabled) {
     exactMatch = enabled;
-#if QT_VERSION>=QT_VERSION_CHECK(5,2,0)
     if (completer)
         completer->setFilterMode(exactMatch ? Qt::MatchStartsWith : Qt::MatchContains);
-#endif
+
 }
 
 bool ExpressionLineEdit::completerActive() const
@@ -625,6 +616,8 @@ void ExpressionLineEdit::hideCompleter()
 void ExpressionLineEdit::slotTextChanged(const QString & text)
 {
     if (!block) {
+        if(!text.size() || (checkPrefix && text[0]!=QLatin1Char(checkPrefix)))
+            return;
         Q_EMIT textChanged2(text,cursorPosition());
     }
 }
@@ -650,7 +643,6 @@ void ExpressionLineEdit::keyPressEvent(QKeyEvent *e) {
 
 void ExpressionLineEdit::contextMenuEvent(QContextMenuEvent *event)
 {
-#if QT_VERSION >= QT_VERSION_CHECK(5,2,0)
     QMenu *menu = createStandardContextMenu();
     menu->addSeparator();
     QAction* match = menu->addAction(tr("Exact match"));
@@ -671,9 +663,6 @@ void ExpressionLineEdit::contextMenuEvent(QContextMenuEvent *event)
     }
 
     delete menu;
-#else
-    QLineEdit::contextMenuEvent(event);
-#endif
 }
 
 
@@ -690,10 +679,8 @@ ExpressionTextEdit::ExpressionTextEdit(QWidget *parent)
 
 void ExpressionTextEdit::setExactMatch(bool enabled) {
     exactMatch = enabled;
-#if QT_VERSION>=QT_VERSION_CHECK(5,2,0)
     if (completer)
         completer->setFilterMode(exactMatch ? Qt::MatchStartsWith : Qt::MatchContains);
-#endif
 }
 
 void ExpressionTextEdit::setDocumentObject(const App::DocumentObject * currentDocObj)
@@ -705,10 +692,8 @@ void ExpressionTextEdit::setDocumentObject(const App::DocumentObject * currentDo
 
     if (currentDocObj != nullptr) {
         completer = new ExpressionCompleter(currentDocObj, this);
-#if QT_VERSION>=QT_VERSION_CHECK(5,2,0)
         if (!exactMatch)
             completer->setFilterMode(Qt::MatchContains);
-#endif
         completer->setWidget(this);
         completer->setCaseSensitivity(Qt::CaseInsensitive);
         connect(completer, SIGNAL(activated(QString)), this, SLOT(slotCompleteText(QString)));
@@ -757,7 +742,6 @@ void ExpressionTextEdit::keyPressEvent(QKeyEvent *e) {
 
 void ExpressionTextEdit::contextMenuEvent(QContextMenuEvent *event)
 {
-#if QT_VERSION >= QT_VERSION_CHECK(5,2,0)
     QMenu *menu = createStandardContextMenu();
     menu->addSeparator();
     QAction* match = menu->addAction(tr("Exact match"));
@@ -778,9 +762,6 @@ void ExpressionTextEdit::contextMenuEvent(QContextMenuEvent *event)
     }
 
     delete menu;
-#else
-    QPlainTextEdit::contextMenuEvent(event);
-#endif
 }
 
 ///////////////////////////////////////////////////////////////////////
