@@ -92,6 +92,27 @@ void FileDialog::onSelectedFilter(const QString& /*filter*/)
     }
 }
 
+QList<QUrl> FileDialog::fetchSidebarUrls()
+{
+    QStringList list;
+    list << QStandardPaths::writableLocation(QStandardPaths::DesktopLocation);
+    list << QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation);
+    list << QStandardPaths::writableLocation(QStandardPaths::HomeLocation);
+    list << QStandardPaths::writableLocation(QStandardPaths::PicturesLocation);
+    list << getWorkingDirectory();
+    list << restoreLocation();
+    list << QDir::currentPath();
+
+    QList<QUrl> urls;
+    for (const auto& it : list) {
+        if (QFileInfo::exists(it)) {
+            urls << QUrl::fromLocalFile(it);
+        }
+    }
+
+    return urls;
+}
+
 bool FileDialog::hasSuffix(const QString& ext) const
 {
     QRegExp rx(QString::fromLatin1("\\*.(%1)\\W").arg(ext));
@@ -181,18 +202,9 @@ QString FileDialog::getSaveFileName (QWidget * parent, const QString & caption,
     // before showing the file dialog.
     QString file;
     if (DialogOptions::dontUseNativeFileDialog()) {
-        QList<QUrl> urls;
+        QList<QUrl> urls = fetchSidebarUrls();
 
         options |= QFileDialog::DontUseNativeDialog;
-        urls << QUrl::fromLocalFile(QStandardPaths::writableLocation(QStandardPaths::DesktopLocation));
-        urls << QUrl::fromLocalFile(QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation));
-        urls << QUrl::fromLocalFile(QStandardPaths::writableLocation(QStandardPaths::HomeLocation));
-        urls << QUrl::fromLocalFile(QStandardPaths::writableLocation(QStandardPaths::MusicLocation));
-        urls << QUrl::fromLocalFile(QStandardPaths::writableLocation(QStandardPaths::PicturesLocation));
-        urls << QUrl::fromLocalFile(QStandardPaths::writableLocation(QStandardPaths::MoviesLocation));
-        urls << QUrl::fromLocalFile(getWorkingDirectory());
-        urls << QUrl::fromLocalFile(restoreLocation());
-        urls << QUrl::fromLocalFile(QDir::currentPath());
 
         FileDialog dlg(parent);
         dlg.setWindowTitle(windowTitle);
@@ -263,18 +275,9 @@ QString FileDialog::getOpenFileName(QWidget * parent, const QString & caption, c
 
     QString file;
     if (DialogOptions::dontUseNativeFileDialog()) {
-        QList<QUrl> urls;
+        QList<QUrl> urls = fetchSidebarUrls();
 
         options |= QFileDialog::DontUseNativeDialog;
-        urls << QUrl::fromLocalFile(QStandardPaths::writableLocation(QStandardPaths::DesktopLocation));
-        urls << QUrl::fromLocalFile(QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation));
-        urls << QUrl::fromLocalFile(QStandardPaths::writableLocation(QStandardPaths::HomeLocation));
-        urls << QUrl::fromLocalFile(QStandardPaths::writableLocation(QStandardPaths::MusicLocation));
-        urls << QUrl::fromLocalFile(QStandardPaths::writableLocation(QStandardPaths::PicturesLocation));
-        urls << QUrl::fromLocalFile(QStandardPaths::writableLocation(QStandardPaths::MoviesLocation));
-        urls << QUrl::fromLocalFile(getWorkingDirectory());
-        urls << QUrl::fromLocalFile(restoreLocation());
-        urls << QUrl::fromLocalFile(QDir::currentPath());
 
         FileDialog dlg(parent);
         dlg.setWindowTitle(windowTitle);
@@ -324,18 +327,9 @@ QStringList FileDialog::getOpenFileNames (QWidget * parent, const QString & capt
 
     QStringList files;
     if (DialogOptions::dontUseNativeFileDialog()) {
-        QList<QUrl> urls;
+        QList<QUrl> urls = fetchSidebarUrls();
 
         options |= QFileDialog::DontUseNativeDialog;
-        urls << QUrl::fromLocalFile(QStandardPaths::writableLocation(QStandardPaths::DesktopLocation));
-        urls << QUrl::fromLocalFile(QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation));
-        urls << QUrl::fromLocalFile(QStandardPaths::writableLocation(QStandardPaths::HomeLocation));
-        urls << QUrl::fromLocalFile(QStandardPaths::writableLocation(QStandardPaths::MusicLocation));
-        urls << QUrl::fromLocalFile(QStandardPaths::writableLocation(QStandardPaths::PicturesLocation));
-        urls << QUrl::fromLocalFile(QStandardPaths::writableLocation(QStandardPaths::MoviesLocation));
-        urls << QUrl::fromLocalFile(getWorkingDirectory());
-        urls << QUrl::fromLocalFile(restoreLocation());
-        urls << QUrl::fromLocalFile(QDir::currentPath());
 
         FileDialog dlg(parent);
         dlg.setWindowTitle(windowTitle);
