@@ -53,7 +53,7 @@
  * So, to avoid entering Tilt mode, the style implements its own tap-and-hold
  * detection, and a special Pan state for the state machine - StickyPanState.
  *
- * This style wasn't tested with space mouse during development (I don't have one).
+ * This style wasn't tested with spacemouse during development (I don't have one).
  *
  * See also GestureNavigationStyle-state-machine-diagram.docx for a crude
  * diagram of the state machine.
@@ -62,28 +62,28 @@
 
 #include "PreCompiled.h"
 #ifndef _PreComp_
-# include <Inventor/actions/SoRayPickAction.h>
-# include <Inventor/SoPickedPoint.h>
 # include <Inventor/SoFullPath.h>
+# include <Inventor/SoPickedPoint.h>
+# include <Inventor/actions/SoRayPickAction.h>
 # include <Inventor/draggers/SoDragger.h>
 # include <QApplication>
 #endif
 
-#include "GestureNavigationStyle.h"
-
-#include <App/Application.h>
-#include <Base/Console.h>
-#include "View3DInventorViewer.h"
-#include "Application.h"
-#include "SoTouchEvents.h"
-
 #include <QTapAndHoldGesture>
 
-#include <boost/statechart/state_machine.hpp>
-#include <boost/statechart/simple_state.hpp>
-#include <boost/statechart/state.hpp>
+#include <App/Application.h>
+#include <Base/Interpreter.h>
+#include <Base/Console.h>
+
+#include "GestureNavigationStyle.h"
+#include "Application.h"
+#include "SoTouchEvents.h"
+#include "View3DInventorViewer.h"
+
 #include <boost/statechart/custom_reaction.hpp>
-#include <boost/mpl/list.hpp>
+#include <boost/statechart/state_machine.hpp>
+#include <boost/statechart/state.hpp>
+
 
 namespace sc = boost::statechart;
 #define NS Gui::GestureNavigationStyle
@@ -93,7 +93,7 @@ namespace Gui {
 class NS::Event : public sc::event<NS::Event>
 {
 public:
-    Event():inventor_event(nullptr), flags(new Flags){}
+    Event():inventor_event(nullptr), modifiers{}, flags(new Flags){}
     virtual ~Event(){}
 
     void log() const {
@@ -869,7 +869,9 @@ SbBool GestureNavigationStyle::processSoEvent(const SoEvent* const ev)
     // Events when in "ready-to-seek" mode are ignored, except those
     // which influence the seek mode itself -- these are handled further
     // up the inheritance hierarchy.
-    if (this->isSeekMode()) { return superclass::processSoEvent(ev); }
+    if (this->isSeekMode()) {
+        return superclass::processSoEvent(ev);
+    }
     // Switch off viewing mode (Bug #0000911)
     if (!this->isSeekMode()&& !this->isAnimating() && this->isViewing() )
         this->setViewing(false); // by default disable viewing mode to render the scene
@@ -887,7 +889,8 @@ SbBool GestureNavigationStyle::processSoEvent(const SoEvent* const ev)
     // give the nodes in the foreground root the chance to handle events (e.g color bar)
     if (!viewer->isEditing()) {
         bool processed = handleEventInForeground(ev);
-        if (processed) return true;
+        if (processed)
+            return true;
     }
 
     if (   (smev.isRelease(1) && this->button1down == false)
@@ -918,9 +921,8 @@ SbBool GestureNavigationStyle::processSoEvent(const SoEvent* const ev)
         //whatever else, we don't track
         }
     }
-    this->ctrldown = ev->wasCtrlDown();
-    this->shiftdown = ev->wasShiftDown();
-    this->altdown = ev->wasAltDown();
+
+    syncModifierKeys(ev);
 
     smev.modifiers =
         (this->button1down ? NS::Event::BUTTON1DOWN : 0) |
@@ -1010,7 +1012,7 @@ void GestureNavigationStyle::onSetRotationCenter(SbVec2s cursor){
     SbBool ret = NavigationStyle::lookAtPoint(cursor);
     if(!ret){
         this->interactiveCountDec(); //this was in original gesture nav. Not sure what is it needed for --DeepSOIC
-        Base::Console().Warning(
+        Base::Console().Log(
             "No object under cursor! Can't set new center of rotation.\n");
     }
 
