@@ -20,37 +20,34 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 
 #ifndef _PreComp_
 # include <QApplication>
 # include <QFile>
+# include <QGraphicsScene>
+# include <QGraphicsSvgItem>
+# include <QGraphicsView>
+# include <QMessageBox>
+# include <QMouseEvent>
 # include <QPrinter>
 # include <QPrintDialog>
 # include <QPrintPreviewDialog>
 # include <QProcess>
 # include <QSvgRenderer>
-# include <QGraphicsSvgItem>
-# include <QMessageBox>
-# include <QMouseEvent>
-# include <QGraphicsScene>
-# include <QGraphicsView>
 # include <QScrollBar>
 # include <QThread>
-# include <QProcess>
-# include <boost_bind_bind.hpp>
 #endif
-#include "GraphicsViewZoom.h"
-#include "FileDialog.h"
 
-
-#include "GraphvizView.h"
-#include "Application.h"
-#include "MainWindow.h"
 #include <App/Application.h>
 #include <App/Document.h>
 
+#include "GraphvizView.h"
+#include "GraphicsViewZoom.h"
+#include "FileDialog.h"
+#include "MainWindow.h"
+
+
 using namespace Gui;
 namespace bp = boost::placeholders;
 
@@ -67,21 +64,15 @@ namespace Gui {
 class GraphvizWorker : public QThread {
     Q_OBJECT
 public:
-    GraphvizWorker(QObject * parent = 0)
+    GraphvizWorker(QObject * parent = nullptr)
         : QThread(parent)
     {
-#if QT_VERSION < 0x050000
-        dotProc.moveToThread(this);
-        unflattenProc.moveToThread(this);
-#endif
     }
 
     virtual ~GraphvizWorker()
     {
-#if QT_VERSION >= 0x050000
         dotProc.moveToThread(this);
         unflattenProc.moveToThread(this);
-#endif
     }
 
     void setData(const QByteArray & data)
@@ -90,7 +81,6 @@ public:
     }
 
     void startThread() {
-#if QT_VERSION >= 0x050000
         // This doesn't actually run a thread but calls the function
         // directly in the main thread.
         // This is needed because embedding a QProcess into a QThread
@@ -98,9 +88,6 @@ public:
         run();
         // Can't use the finished() signal of QThread
         emitFinished();
-#else
-        start();
-#endif
     }
 
     void run() {
@@ -239,7 +226,7 @@ void GraphvizGraphicsView::mouseReleaseEvent(QMouseEvent* e)
 /* TRANSLATOR Gui::GraphvizView */
 
 GraphvizView::GraphvizView(App::Document & _doc, QWidget* parent)
-  : MDIView(0, parent)
+  : MDIView(nullptr, parent)
   , doc(_doc)
   , nPending(0)
 {
@@ -268,9 +255,7 @@ GraphvizView::GraphvizView(App::Document & _doc, QWidget* parent)
 
     // Create worker thread
     thread = new GraphvizWorker(this);
-#if QT_VERSION >= 0x050000
     connect(thread, SIGNAL(emitFinished()), this, SLOT(done()));
-#endif
     connect(thread, SIGNAL(finished()), this, SLOT(done()));
     connect(thread, SIGNAL(error()), this, SLOT(error()));
     connect(thread, SIGNAL(svgFileRead(const QByteArray &)), this, SLOT(svgFileRead(const QByteArray &)));
@@ -533,11 +518,7 @@ bool GraphvizView::onHasMsg(const char* pMsg) const
 void GraphvizView::print(QPrinter* printer)
 {
     QPainter p(printer);
-#if QT_VERSION >= 0x050300
     QRect rect = printer->pageLayout().paintRectPixels(printer->resolution());
-#else
-    QRect rect = printer->pageRect();
-#endif
     view->scene()->render(&p, rect);
     //QByteArray buffer = exportGraph(QString::fromLatin1("svg"));
     //QSvgRenderer svg(buffer);
@@ -549,11 +530,7 @@ void GraphvizView::print()
 {
     QPrinter printer(QPrinter::HighResolution);
     printer.setFullPage(true);
-#if QT_VERSION >= 0x050300
     printer.setPageOrientation(QPageLayout::Landscape);
-#else
-    printer.setOrientation(QPrinter::Landscape);
-#endif
     QPrintDialog dlg(&printer, this);
     if (dlg.exec() == QDialog::Accepted) {
         print(&printer);
@@ -583,11 +560,7 @@ void GraphvizView::printPreview()
 {
     QPrinter printer(QPrinter::HighResolution);
     printer.setFullPage(true);
-#if QT_VERSION >= 0x050300
     printer.setPageOrientation(QPageLayout::Landscape);
-#else
-    printer.setOrientation(QPrinter::Landscape);
-#endif
 
     QPrintPreviewDialog dlg(&printer, this);
     connect(&dlg, SIGNAL(paintRequested (QPrinter *)),
