@@ -20,14 +20,13 @@
  *                                                                         *
  ***************************************************************************/
 
-
-
 #ifndef GUIAPPLICATIONNATIVEEVENTAWARE_H
 #define GUIAPPLICATIONNATIVEEVENTAWARE_H
 
 #include <QApplication>
 #include <vector>
 
+
 class QMainWindow;
 
 namespace Gui
@@ -54,9 +53,6 @@ namespace Gui
       #if defined(_USE_3DCONNEXION_SDK) || defined(SPNAV_FOUND)
         GuiNativeEvent *nativeEvent;
       #endif
-      #if defined(SPNAV_FOUND) && defined(SPNAV_USE_X11) && QT_VERSION < 0x050000
-        bool x11EventFilter(XEvent *event) override final;
-      #endif
     }; // end class GUIApplicationNativeEventAware
 } // end namespace Gui
 
