@@ -20,7 +20,6 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #ifndef __InventorAll__
 #define __InventorAll__
 
@@ -30,59 +29,92 @@
 #else
 #include <GL/gl.h>
 #endif
+
 #include <Inventor/C/basic.h>
+#include <Inventor/SbBSPTree.h>
 #include <Inventor/SbBox.h>
+#include <Inventor/SbBox2f.h>
 #include <Inventor/SbClip.h>
 #include <Inventor/SbColor.h>
+#include <Inventor/SbLine.h>
+#include <Inventor/SbLinear.h>
+#include <Inventor/SbRotation.h>
+#include <Inventor/SbSphere.h>
+#include <Inventor/SbTesselator.h>
+#include <Inventor/SbVec2s.h>
+#include <Inventor/SbViewportRegion.h>
 #include <Inventor/SoDB.h>
+#include <Inventor/SoEventManager.h>
+#include <Inventor/SoFullPath.h>
 #include <Inventor/SoInput.h>
 #include <Inventor/SoInteraction.h>
-#include <Inventor/SbLinear.h>
 #include <Inventor/SoOffscreenRenderer.h>
 #include <Inventor/SoPickedPoint.h>
 #include <Inventor/SoPrimitiveVertex.h>
-#include <Inventor/SbTesselator.h>
-#include <Inventor/SbViewportRegion.h>
-#include <Inventor/SoEventManager.h>
+#include <Inventor/SoRenderManager.h>
+#include <Inventor/actions/SoAction.h>
 #include <Inventor/actions/SoBoxHighlightRenderAction.h>
+#include <Inventor/actions/SoCallbackAction.h>
 #include <Inventor/actions/SoGetBoundingBoxAction.h>
 #include <Inventor/actions/SoGetMatrixAction.h>
 #include <Inventor/actions/SoGetPrimitiveCountAction.h>
 #include <Inventor/actions/SoGLRenderAction.h>
 #include <Inventor/actions/SoHandleEventAction.h>
 #include <Inventor/actions/SoLineHighlightRenderAction.h>
+#include <Inventor/actions/SoPickAction.h>
 #include <Inventor/actions/SoRayPickAction.h>
 #include <Inventor/actions/SoSearchAction.h>
 #include <Inventor/actions/SoToVRML2Action.h>
 #include <Inventor/actions/SoWriteAction.h>
+#include <Inventor/annex/HardCopy/SoVectorizeAction.h>
 #include <Inventor/annex/HardCopy/SoVectorizePSAction.h>
 #include <Inventor/annex/HardCopy/SoVectorOutput.h>
 #include <Inventor/bundles/SoMaterialBundle.h>
 #include <Inventor/bundles/SoTextureCoordinateBundle.h>
 #include <Inventor/caches/SoNormalCache.h>
+#include <Inventor/details/SoDetail.h>
 #include <Inventor/details/SoFaceDetail.h>
 #include <Inventor/details/SoLineDetail.h>
 #include <Inventor/details/SoPointDetail.h>
-#include <Inventor/draggers/SoDragger.h>
-#include <Inventor/draggers/SoTransformerDragger.h>
-#include <Inventor/draggers/SoTrackballDragger.h>
 #include <Inventor/draggers/SoCenterballDragger.h>
+#include <Inventor/draggers/SoDragger.h>
+#include <Inventor/draggers/SoTrackballDragger.h>
+#include <Inventor/draggers/SoTransformerDragger.h>
+#include <Inventor/elements/SoCacheElement.h>
+#include <Inventor/elements/SoComplexityElement.h>
+#include <Inventor/elements/SoComplexityTypeElement.h>
 #include <Inventor/elements/SoCoordinateElement.h>
 #include <Inventor/elements/SoCreaseAngleElement.h>
+#include <Inventor/elements/SoDrawStyleElement.h>
+#include <Inventor/elements/SoFontNameElement.h>
+#include <Inventor/elements/SoFontSizeElement.h>
 #include <Inventor/elements/SoGLCacheContextElement.h>
 #include <Inventor/elements/SoGLCoordinateElement.h>
+#include <Inventor/elements/SoLazyElement.h>
+#include <Inventor/elements/SoLightModelElement.h>
+#include <Inventor/elements/SoLineWidthElement.h>
+#include <Inventor/elements/SoMaterialBindingElement.h>
+#include <Inventor/elements/SoModelMatrixElement.h>
 #include <Inventor/elements/SoNormalBindingElement.h>
 #include <Inventor/elements/SoNormalElement.h>
+#include <Inventor/elements/SoOverrideElement.h>
+#include <Inventor/elements/SoProfileCoordinateElement.h>
+#include <Inventor/elements/SoProfileElement.h>
+#include <Inventor/elements/SoProjectionMatrixElement.h>
 #include <Inventor/elements/SoReplacedElement.h>
+#include <Inventor/elements/SoShapeStyleElement.h>
+#include <Inventor/elements/SoSwitchElement.h>
+#include <Inventor/elements/SoTextureEnabledElement.h>
+#include <Inventor/elements/SoUnitsElement.h>
+#include <Inventor/elements/SoViewingMatrixElement.h>
 #include <Inventor/elements/SoViewportRegionElement.h>
 #include <Inventor/elements/SoViewVolumeElement.h>
-#include <Inventor/elements/SoModelMatrixElement.h>
-#include <Inventor/elements/SoTextureEnabledElement.h>
-#include <Inventor/elements/SoShapeStyleElement.h>
+#include <Inventor/elements/SoWindowElement.h>
 #include <Inventor/engines/SoComposeVec3f.h>
 #include <Inventor/engines/SoComposeRotationFromTo.h>
 #include <Inventor/engines/SoComposeRotation.h>
 #include <Inventor/errors/SoDebugError.h>
+#include <Inventor/errors/SoError.h>
 #include <Inventor/errors/SoReadError.h>
 #include <Inventor/events/SoEvent.h>
 #include <Inventor/events/SoKeyboardEvent.h>
@@ -91,15 +123,26 @@
 #include <Inventor/events/SoMouseButtonEvent.h>
 #include <Inventor/events/SoSpaceballButtonEvent.h>
 #include <Inventor/fields/SoMFColor.h>
+#include <Inventor/fields/SoMFNode.h>
+#include <Inventor/fields/SoSFBool.h>
+#include <Inventor/fields/SoSFColor.h>
+#include <Inventor/fields/SoSFDouble.h>
+#include <Inventor/fields/SoSFFloat.h>
+#include <Inventor/fields/SoSFInt32.h>
+#include <Inventor/fields/SoSFNode.h>
+#include <Inventor/fields/SoSFRotation.h>
 #include <Inventor/fields/SoSFVec3f.h>
 #include <Inventor/manips/SoCenterballManip.h>
 #include <Inventor/manips/SoClipPlaneManip.h>
 #include <Inventor/manips/SoTransformerManip.h>
+#include <Inventor/misc/SoChildList.h>
+#include <Inventor/misc/SoState.h>
 #include <Inventor/nodes/SoAnnotation.h>
 #include <Inventor/nodes/SoAntiSquish.h>
 #include <Inventor/nodes/SoAsciiText.h>
 #include <Inventor/nodes/SoBaseColor.h>
 #include <Inventor/nodes/SoCallback.h>
+#include <Inventor/nodes/SoCamera.h>
 #include <Inventor/nodes/SoComplexity.h>
 #include <Inventor/nodes/SoCone.h>
 #include <Inventor/nodes/SoCoordinate3.h>
@@ -127,7 +170,9 @@
 #include <Inventor/nodes/SoMaterialBinding.h>
 #include <Inventor/nodes/SoMatrixTransform.h>
 #include <Inventor/nodes/SoMultipleCopy.h>
+#include <Inventor/nodes/SoNode.h>
 #include <Inventor/nodes/SoNormal.h>
+#include <Inventor/nodes/SoNormalBinding.h>
 #include <Inventor/nodes/SoNurbsSurface.h>
 #include <Inventor/nodes/SoOrthographicCamera.h>
 #include <Inventor/nodes/SoPerspectiveCamera.h>
@@ -145,6 +190,7 @@
 #include <Inventor/nodes/SoShape.h>
 #include <Inventor/nodes/SoShapeHints.h>
 #include <Inventor/nodes/SoSphere.h>
+#include <Inventor/nodes/SoSubNode.h>
 #include <Inventor/nodes/SoSurroundScale.h>
 #include <Inventor/nodes/SoSwitch.h>
 #include <Inventor/nodes/SoText2.h>
@@ -152,15 +198,24 @@
 #include <Inventor/nodes/SoTexture3.h>
 #include <Inventor/nodes/SoTextureCoordinate3.h>
 #include <Inventor/nodes/SoTransform.h>
+#include <Inventor/nodes/SoTransformation.h>
 #include <Inventor/nodes/SoTranslation.h>
 #include <Inventor/nodes/SoTransparencyType.h>
 #include <Inventor/nodekits/SoShapeKit.h>
 #include <Inventor/manips/SoTransformBoxManip.h>
+#include <Inventor/projectors/SbLineProjector.h>
+#include <Inventor/projectors/SbPlaneProjector.h>
 #include <Inventor/projectors/SbSpherePlaneProjector.h>
 #include <Inventor/projectors/SbSphereSheetProjector.h>
+#include <Inventor/sensors/SoFieldSensor.h>
+#include <Inventor/sensors/SoIdleSensor.h>
 #include <Inventor/sensors/SoNodeSensor.h>
 #include <Inventor/sensors/SoTimerSensor.h>
 #include <Inventor/system/inttypes.h>
+#include <Inventor/threads/SbStorage.h>
 #include <Inventor/VRMLnodes/SoVRMLGroup.h>
-
+#include <Inventor/VRMLnodes/SoVRMLIndexedFaceSet.h>
+#include <Inventor/VRMLnodes/SoVRMLNormal.h>
+#include <Inventor/VRMLnodes/SoVRMLParent.h>
+#include <Inventor/VRMLnodes/SoVRMLShape.h>
 #endif
