@@ -23,96 +23,70 @@
 
 #include "PreCompiled.h"
 #ifndef _PreComp_
-# include <algorithm>
 # include <QApplication>
-# include <QThread>
-# include <QBuffer>
 # include <QByteArray>
 # include <QCheckBox>
 # include <QClipboard>
-# include <QMimeData>
 # include <QCloseEvent>
 # include <QContextMenuEvent>
 # include <QDesktopServices>
-# include <QDesktopWidget>
 # include <QDockWidget>
 # include <QFontMetrics>
 # include <QKeySequence>
 # include <QLabel>
 # include <QMdiSubWindow>
+# include <QMenu>
 # include <QMessageBox>
+# include <QMimeData>
 # include <QPainter>
+# include <QScreen>
 # include <QSettings>
 # include <QSignalMapper>
 # include <QStatusBar>
+# include <QThread>
 # include <QTimer>
 # include <QToolBar>
-#if QT_VERSION >= 0x050000
 # include <QUrlQuery>
-#endif
 # include <QWhatsThis>
+# include <QPushButton>
 #endif
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
-# include <QScreen>
-#endif
-
-// FreeCAD Base header
+#include <App/Application.h>
+#include <App/Document.h>
+#include <App/DocumentObject.h>
+#include <App/DocumentObjectGroup.h>
 #include <Base/Parameter.h>
 #include <Base/Exception.h>
 #include <Base/FileInfo.h>
 #include <Base/Interpreter.h>
-#include <Base/Persistence.h>
 #include <Base/Stream.h>
-#include <Base/Reader.h>
-#include <Base/Writer.h>
-#include <App/Application.h>
-#include <App/DocumentObject.h>
-#include <App/DocumentObjectGroup.h>
+#include <DAGView/DAGView.h>
+#include <TaskView/TaskView.h>
 
 #include "MainWindow.h"
-#include "Application.h"
-#include "Assistant.h"
-#include "DownloadManager.h"
-#include "WaitCursor.h"
-#include "FileDialog.h"
-
 #include "Action.h"
+#include "Assistant.h"
+#include "BitmapFactory.h"
+#include "ComboView.h"
 #include "Command.h"
-
-#include "ToolBoxManager.h"
 #include "DockWindowManager.h"
+#include "DownloadManager.h"
+#include "FileDialog.h"
+#include "MenuManager.h"
+#include "ProgressBar.h"
+#include "PropertyView.h"
+#include "PythonConsole.h"
+#include "ReportView.h"
+#include "SelectionView.h"
+#include "Splashscreen.h"
 #include "ToolBarManager.h"
+#include "ToolBoxManager.h"
+#include "Tree.h"
+#include "WaitCursor.h"
 #include "WorkbenchManager.h"
 #include "Workbench.h"
 
-#include "Window.h"
-#include "View.h"
-#include "Macro.h"
-#include "ProgressBar.h"
 
-#include "WidgetFactory.h"
-#include "BitmapFactory.h"
-#include "Splashscreen.h"
-
-#include "Tree.h"
-#include "PropertyView.h"
-#include "SelectionView.h"
-#include "MenuManager.h"
-//#include "ToolBox.h"
-#include "ReportView.h"
-#include "ComboView.h"
-#include "PythonConsole.h"
-#include "TaskView/TaskView.h"
-#include "DAGView/DAGView.h"
-
-#include "DlgUndoRedo.h"
-#include "DlgOnlineHelpImp.h"
-
-#include "Language/Translator.h"
-#include "GuiInitScript.h"
-
-#include "Document.h"
 #include "MergeDocuments.h"
 #include "ViewProviderExtern.h"
 
@@ -135,7 +109,7 @@ using namespace Gui::DockWnd;
 using namespace std;
 
 
-MainWindow* MainWindow::instance = 0L;
+MainWindow* MainWindow::instance = nullptr;
 
 namespace Gui {
 
@@ -176,7 +150,6 @@ struct MainWindowP
     QTimer* actionTimer;
     QTimer* statusTimer;
     QTimer* activityTimer;
-    QTimer* visibleTimer;
     QMdiArea* mdiArea;
     QPointer<MDIView> activeView;
     QSignalMapper* windowMapper;
@@ -193,14 +166,11 @@ struct MainWindowP
 class MDITabbar : public QTabBar
 {
 public:
-    MDITabbar( QWidget * parent = 0 ) : QTabBar(parent)
+    MDITabbar( QWidget * parent = nullptr ) : QTabBar(parent)
     {
         menu = new QMenu(this);
-        // For Qt 4.2.x the tabs might be very wide
-#if QT_VERSION >= 0x040200
         setDrawBase(false);
         setSizePolicy(QSizePolicy::Maximum, QSizePolicy::Fixed);
-#endif
     }
 
     ~MDITabbar()
@@ -283,8 +253,8 @@ MainWindow::MainWindow(QWidget * parent, Qt::WindowFlags f)
   : QMainWindow( parent, f/*WDestructiveClose*/ )
 {
     d = new MainWindowP;
-    d->splashscreen = 0;
-    d->activeView = 0;
+    d->splashscreen = nullptr;
+    d->activeView = nullptr;
     d->whatsthis = false;
     d->assistant = new Assistant();
 
@@ -293,31 +263,20 @@ MainWindow::MainWindow(QWidget * parent, Qt::WindowFlags f)
 
     // support for grouped dragging of dockwidgets
     // https://woboq.com/blog/qdockwidget-changes-in-56.html
-#if QT_VERSION >= 0x050600
     setDockOptions(dockOptions() | QMainWindow::GroupedDragging);
-#endif
 
     // Create the layout containing the workspace and a tab bar
     d->mdiArea = new QMdiArea();
     // Movable tabs
-#if QT_VERSION >= 0x040800
     d->mdiArea->setTabsMovable(true);
-#endif
-#if QT_VERSION >= 0x040500
     d->mdiArea->setTabPosition(QTabWidget::South);
     d->mdiArea->setViewMode(QMdiArea::TabbedView);
     QTabBar* tab = d->mdiArea->findChild<QTabBar*>();
     if (tab) {
-        // 0000636: Two documents close
-#if QT_VERSION < 0x040800
-        connect(tab, SIGNAL(tabCloseRequested(int)),
-                this, SLOT(tabCloseRequested(int)));
-#endif
         tab->setTabsClosable(true);
         // The tabs might be very wide
         tab->setExpanding(false);
     }
-#endif
     d->mdiArea->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
     d->mdiArea->setHorizontalScrollBarPolicy(Qt::ScrollBarAsNeeded);
     d->mdiArea->setOption(QMdiArea::DontMaximizeSubWindowOnActivation, false);
@@ -360,12 +319,6 @@ MainWindow::MainWindow(QWidget * parent, Qt::WindowFlags f)
     QClipboard *clipbd = QApplication::clipboard();
     connect(clipbd, SIGNAL(dataChanged()), this, SLOT(updateEditorActions()));
 
-    // show main window timer
-    d->visibleTimer = new QTimer(this);
-    d->visibleTimer->setObjectName(QString::fromLatin1("visibleTimer"));
-    connect(d->visibleTimer, SIGNAL(timeout()),this, SLOT(showMainWindow()));
-    d->visibleTimer->setSingleShot(true);
-
     d->windowMapper = new QSignalMapper(this);
 
     // connection between workspace, window menu and tab bar
@@ -407,7 +360,7 @@ MainWindow::MainWindow(QWidget * parent, Qt::WindowFlags f)
         group->SetBool("Enabled", enabled); //ensure entry exists.
         if (enabled) {
             treeView = true;
-            TreeDockWidget* tree = new TreeDockWidget(0, this);
+            TreeDockWidget* tree = new TreeDockWidget(nullptr, this);
             tree->setObjectName
                 (QString::fromLatin1(QT_TRANSLATE_NOOP("QDockWidget","Tree view")));
             tree->setMinimumWidth(210);
@@ -428,7 +381,7 @@ MainWindow::MainWindow(QWidget * parent, Qt::WindowFlags f)
         group->SetBool("Enabled", enabled); //ensure entry exists.
         if (enabled) {
             propertyView = true;
-            PropertyDockView* pcPropView = new PropertyDockView(0, this);
+            PropertyDockView* pcPropView = new PropertyDockView(nullptr, this);
             pcPropView->setObjectName
                 (QString::fromLatin1(QT_TRANSLATE_NOOP("QDockWidget","Property view")));
             pcPropView->setMinimumWidth(210);
@@ -438,7 +391,7 @@ MainWindow::MainWindow(QWidget * parent, Qt::WindowFlags f)
 
     // Selection view
     if (hiddenDockWindows.find("Std_SelectionView") == std::string::npos) {
-        SelectionView* pcSelectionView = new SelectionView(0, this);
+        SelectionView* pcSelectionView = new SelectionView(nullptr, this);
         pcSelectionView->setObjectName
             (QString::fromLatin1(QT_TRANSLATE_NOOP("QDockWidget","Selection view")));
         pcSelectionView->setMinimumWidth(210);
@@ -454,21 +407,12 @@ MainWindow::MainWindow(QWidget * parent, Qt::WindowFlags f)
             enable = group->GetBool("Enabled", true);
         }
 
-        ComboView* pcComboView = new ComboView(enable, 0, this);
+        ComboView* pcComboView = new ComboView(enable, nullptr, this);
         pcComboView->setObjectName(QString::fromLatin1(QT_TRANSLATE_NOOP("QDockWidget","Combo View")));
         pcComboView->setMinimumWidth(150);
         pDockMgr->registerDockWindow("Std_ComboView", pcComboView);
     }
 
-#if QT_VERSION < 0x040500
-    // Report view
-    if (hiddenDockWindows.find("Std_ReportView") == std::string::npos) {
-        Gui::DockWnd::ReportView* pcReport = new Gui::DockWnd::ReportView(this);
-        pcReport->setObjectName
-            (QString::fromLatin1(QT_TRANSLATE_NOOP("QDockWidget","Report view")));
-        pDockMgr->registerDockWindow("Std_ReportView", pcReport);
-    }
-#else
     // Report view (must be created before PythonConsole!)
     if (hiddenDockWindows.find("Std_ReportView") == std::string::npos) {
         ReportOutput* pcReport = new ReportOutput(this);
@@ -483,15 +427,6 @@ MainWindow::MainWindow(QWidget * parent, Qt::WindowFlags f)
     // Python console
     if (hiddenDockWindows.find("Std_PythonView") == std::string::npos) {
         PythonConsole* pcPython = new PythonConsole(this);
-        ParameterGrp::handle hGrp = App::GetApplication().GetUserParameter().
-            GetGroup("BaseApp")->GetGroup("Preferences")->GetGroup("General");
-
-        if (hGrp->GetBool("PythonWordWrap", true)) {
-          pcPython->setWordWrapMode(QTextOption::WrapAtWordBoundaryOrAnywhere);
-        } else {
-          pcPython->setWordWrapMode(QTextOption::NoWrap);
-        }
-
         pcPython->setWindowIcon(Gui::BitmapFactory().iconFromTheme("applications-python"));
         pcPython->setObjectName
             (QString::fromLatin1(QT_TRANSLATE_NOOP("QDockWidget","Python console")));
@@ -541,7 +476,6 @@ MainWindow::MainWindow(QWidget * parent, Qt::WindowFlags f)
         connect(result, SIGNAL(currentChanged(int)), l, SLOT(tabChanged()));
         l->unusedTabBars << result;
     }
-#endif
 #endif
 
     // accept drops on the window, get handled in dropEvent, dragEnterEvent
@@ -553,7 +487,7 @@ MainWindow::~MainWindow()
 {
     delete d->status;
     delete d;
-    instance = 0;
+    instance = nullptr;
 }
 
 MainWindow* MainWindow::getInstance()
@@ -647,15 +581,15 @@ int MainWindow::confirmSave(const char *docName, QWidget *parent, bool addCheckb
         discardBtn->setShortcut(QKeySequence::mnemonic(text));
     }
 
-    int res = 0;
+    int res = ConfirmSaveResult::Cancel;
     box.adjustSize(); // Silence warnings from Qt on Windows
     switch (box.exec())
     {
     case QMessageBox::Save:
-        res = checkBox.isChecked()?2:1;
+        res = checkBox.isChecked()?ConfirmSaveResult::SaveAll:ConfirmSaveResult::Save;
         break;
     case QMessageBox::Discard:
-        res = checkBox.isChecked()?-2:-1;
+        res = checkBox.isChecked()?ConfirmSaveResult::DiscardAll:ConfirmSaveResult::Discard;
         break;
     }
     if(addCheckbox && res)
@@ -667,40 +601,62 @@ bool MainWindow::closeAllDocuments (bool close)
 {
     auto docs = App::GetApplication().getDocuments();
     try {
-        docs = App::Document::getDependentDocuments(docs,true);
-    }catch(Base::Exception &e) {
+        docs = App::Document::getDependentDocuments(docs, true);
+    }
+    catch(Base::Exception &e) {
         e.ReportException();
     }
+
     bool checkModify = true;
     bool saveAll = false;
-    for(auto doc : docs) {
+    int failedSaves = 0;
+
+    for (auto doc : docs) {
         auto gdoc = Application::Instance->getDocument(doc);
-        if(!gdoc)
+        if (!gdoc)
             continue;
-        if(!gdoc->canClose(false))
+        if (!gdoc->canClose(false))
             return false;
-        if(!gdoc->isModified()
+        if (!gdoc->isModified()
                 || doc->testStatus(App::Document::PartialDoc)
                 || doc->testStatus(App::Document::TempDoc))
             continue;
         bool save = saveAll;
-        if(!save && checkModify) {
-            int res = confirmSave(doc->Label.getStrValue().c_str(),this,docs.size()>1);
-            if(res==0)
+        if (!save && checkModify) {
+            int res = confirmSave(doc->Label.getStrValue().c_str(), this, docs.size()>1);
+            switch (res)
+            {
+            case ConfirmSaveResult::Cancel:
                 return false;
-            if(res>0) {
+            case ConfirmSaveResult::SaveAll:
+                saveAll = true;
+                /* FALLTHRU */
+            case ConfirmSaveResult::Save:
                 save = true;
-                if(res==2)
-                    saveAll = true;
-            } else if(res==-2)
+                break;
+            case ConfirmSaveResult::DiscardAll:
                 checkModify = false;
+            }
         }
-        if(save && !gdoc->save())
+
+        if (save && !gdoc->save())
+            failedSaves++;
+    }
+
+    if (failedSaves > 0) {
+        int ret = QMessageBox::question(
+            getMainWindow(),
+            QObject::tr("%1 Document(s) not saved").arg(QString::number(failedSaves)),
+            QObject::tr("Some documents could not be saved. Do you want to cancel closing?"),
+            QMessageBox::Discard | QMessageBox::Cancel,
+            QMessageBox::Discard);
+        if (ret == QMessageBox::Cancel)
             return false;
     }
-    if(close)
+
+    if (close)
         App::GetApplication().closeAllDocuments();
-    // d->mdiArea->closeAllSubWindows();
+
     return true;
 }
 
@@ -737,14 +693,33 @@ void MainWindow::whatsThis()
 
 void MainWindow::showDocumentation(const QString& help)
 {
-    QUrl url(help);
-    if (url.scheme().isEmpty()) {
-        QString page;
-        page = QString::fromUtf8("%1.html").arg(help);
-        d->assistant->showDocumentation(page);
+    Base::PyGILStateLocker lock;
+    PyObject* module = PyImport_ImportModule("Help");
+    if (module) {
+        Py_DECREF(module);
+        Gui::Command::addModule(Gui::Command::Gui,"Help");
+        Gui::Command::doCommand(Gui::Command::Gui,"Help.show(\"%s\")", help.toStdString().c_str());
     }
     else {
-        QDesktopServices::openUrl(url);
+        PyErr_Clear();
+        QUrl url(help);
+        if (url.scheme().isEmpty()) {
+            QMessageBox msgBox(getMainWindow());
+            msgBox.setWindowTitle(tr("Help addon needed!"));
+            msgBox.setText(tr("The Help system of %1 is now handled by the \"Help\" addon. "
+               "It can easily be installed via the Addons Manager").arg(QString(qApp->applicationName())));
+            QAbstractButton* pButtonAddonMgr = msgBox.addButton(tr("Open Addon Manager"), QMessageBox::YesRole);
+            msgBox.addButton(QMessageBox::Ok);
+            msgBox.exec();
+            if (msgBox.clickedButton() == pButtonAddonMgr) {
+                ParameterGrp::handle hGrp = App::GetApplication().GetParameterGroupByPath("User parameter:BaseApp/Preferences/Addons");
+                hGrp->SetASCII("SelectedAddon", "Help");
+                Gui::Command::doCommand(Gui::Command::Gui,"Gui.runCommand('Std_AddonMgr',0)");
+            }
+        }
+        else {
+            QDesktopServices::openUrl(url);
+        }
     }
 }
 
@@ -891,6 +866,7 @@ bool MainWindow::eventFilter(QObject* o, QEvent* e)
                 QApplication::sendEvent(this, &e);
             }
             static_cast<QWidget *>(o)->setAttribute(Qt::WA_OutsideWSRange);
+            o->deleteLater();
             return true;
         }
         if (o->inherits("QWhatsThat") && e->type() == QEvent::Hide) {
@@ -988,7 +964,7 @@ void MainWindow::removeWindow(Gui::MDIView* view, bool close)
     //
     auto subwindow = qobject_cast<QMdiSubWindow*>(parent);
     if(subwindow && d->mdiArea->subWindowList().contains(subwindow)) {
-        subwindow->setParent(0);
+        subwindow->setParent(nullptr);
 
         assert(!d->mdiArea->subWindowList().contains(subwindow));
         // d->mdiArea->removeSubWindow(parent);
@@ -1039,7 +1015,8 @@ void MainWindow::setActiveWindow(MDIView* view)
 
 void MainWindow::onWindowActivated(QMdiSubWindow* w)
 {
-    if (!w) return;
+    if (!w)
+        return;
     MDIView* view = dynamic_cast<MDIView*>(w->widget());
 
     ParameterGrp::handle hGrp = App::GetApplication().GetParameterGroupByPath("User parameter:BaseApp/Preferences/View");
@@ -1165,7 +1142,7 @@ QList<QWidget*> MainWindow::windows(QMdiArea::WindowOrder order) const
     return mdis;
 }
 
-MDIView* MainWindow::activeWindow(void) const
+MDIView* MainWindow::activeWindow() const
 {
     // each activated window notifies this main window when it is activated
     return d->activeView;
@@ -1193,10 +1170,22 @@ void MainWindow::closeEvent (QCloseEvent * e)
             (*it)->hide();
             (*it)->deleteLater();
         }
+
+        if (Workbench* wb = WorkbenchManager::instance()->active())
+            wb->removeTaskWatcher();
+
+        /*emit*/ mainWindowClosed();
         d->activityTimer->stop();
-        saveWindowSettings();
+
+        // https://forum.freecadweb.org/viewtopic.php?f=8&t=67748
+        // When the session manager jumps in it can happen that the closeEvent()
+        // function is triggered twice and for the second call the main window might be
+        // invisible. In this case the window settings shouldn't be saved.
+        if (isVisible())
+            saveWindowSettings();
+
         delete d->assistant;
-        d->assistant = 0;
+        d->assistant = nullptr;
 
         // See createMimeDataFromSelection
         QVariant prop = this->property("x-documentobject-file");
@@ -1206,7 +1195,6 @@ void MainWindow::closeEvent (QCloseEvent * e)
                 fi.deleteFile();
         }
 
-        /*emit*/ mainWindowClosed();
         if (this->property("QuitOnClosed").isValid()) {
             QApplication::closeAllWindows();
             qApp->quit(); // stop the event loop
@@ -1214,32 +1202,16 @@ void MainWindow::closeEvent (QCloseEvent * e)
     }
 }
 
-void MainWindow::showEvent(QShowEvent  * /*e*/)
+void MainWindow::showEvent(QShowEvent* e)
 {
-    // needed for logging
     std::clog << "Show main window" << std::endl;
-    d->visibleTimer->start(15000);
+    QMainWindow::showEvent(e);
 }
 
-void MainWindow::hideEvent(QHideEvent  * /*e*/)
+void MainWindow::hideEvent(QHideEvent* e)
 {
-    // needed for logging
     std::clog << "Hide main window" << std::endl;
-    d->visibleTimer->stop();
-}
-
-void MainWindow::showMainWindow()
-{
-    // Under certain circumstances it can happen that at startup the main window
-    // appears for a short moment and disappears immediately. The workaround
-    // starts a timer to check for the visibility of the main window and call
-    // ShowWindow() if needed.
-    // So far, this phenomena only appeared with Qt4.1.4
-#if defined(Q_OS_WIN) && (QT_VERSION == 0x040104)
-    WId id = this->winId();
-    ShowWindow(id, SW_SHOW);
-    std::cout << "Force to show main window" << std::endl;
-#endif
+    QMainWindow::hideEvent(e);
 }
 
 void MainWindow::processMessages(const QList<QByteArray> & msg)
@@ -1304,6 +1276,8 @@ void MainWindow::delayedStartup()
     if (hGrp->GetBool("CreateNewDoc", false)) {
         if (App::GetApplication().getDocuments().size()==0){
             App::GetApplication().newDocument();
+            Gui::Command::doCommand(Gui::Command::Gui,
+                "Gui.activeDocument().activeView().viewDefaultOrientation()");
         }
     }
 
@@ -1392,12 +1366,12 @@ void MainWindow::switchToTopLevelMode()
 {
     QList<QDockWidget*> dw = this->findChildren<QDockWidget*>();
     for (QList<QDockWidget*>::Iterator it = dw.begin(); it != dw.end(); ++it) {
-        (*it)->setParent(0, Qt::Window);
+        (*it)->setParent(nullptr, Qt::Window);
         (*it)->show();
     }
     QList<QWidget*> mdi = getMainWindow()->windows();
     for (QList<QWidget*>::Iterator it = mdi.begin(); it != mdi.end(); ++it) {
-        (*it)->setParent(0, Qt::Window);
+        (*it)->setParent(nullptr, Qt::Window);
         (*it)->show();
     }
 }
@@ -1422,11 +1396,7 @@ void MainWindow::loadWindowSettings()
     QString qtver = QString::fromLatin1("Qt%1.%2").arg(major).arg(minor);
     QSettings config(vendor, application);
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
     QRect rect = QApplication::primaryScreen()->availableGeometry();
-#else
-    QRect rect = QApplication::desktop()->availableGeometry();
-#endif
     int maxHeight = rect.height();
     int maxWidth = rect.width();
 
@@ -1480,7 +1450,7 @@ void MainWindow::saveWindowSettings()
     ToolBarManager::getInstance()->saveState();
 }
 
-void MainWindow::startSplasher(void)
+void MainWindow::startSplasher()
 {
     // startup splasher
     // when running in verbose mode no splasher
@@ -1494,19 +1464,45 @@ void MainWindow::startSplasher(void)
             d->splashscreen->show();
         }
         else
-            d->splashscreen = 0;
+            d->splashscreen = nullptr;
     }
 }
 
-void MainWindow::stopSplasher(void)
+void MainWindow::stopSplasher()
 {
     if (d->splashscreen) {
         d->splashscreen->finish(this);
         delete d->splashscreen;
-        d->splashscreen = 0;
+        d->splashscreen = nullptr;
     }
 }
 
+QPixmap MainWindow::aboutImage() const
+{
+    // See if we have a custom About screen image set
+    QPixmap about_image;
+    QFileInfo fi(QString::fromLatin1("images:about_image.png"));
+    if (fi.isFile() && fi.exists())
+        about_image.load(fi.filePath(), "PNG");
+
+    std::string about_path = App::Application::Config()["AboutImage"];
+    if (!about_path.empty() && about_image.isNull()) {
+        QString path = QString::fromUtf8(about_path.c_str());
+        if (QDir(path).isRelative()) {
+            QString home = QString::fromStdString(App::Application::getHomePath());
+            path = QFileInfo(QDir(home), path).absoluteFilePath();
+        }
+        about_image.load(path);
+
+        // Now try the icon paths
+        if (about_image.isNull()) {
+            about_image = Gui::BitmapFactory().pixmap(about_path.c_str());
+        }
+    }
+
+    return about_image;
+}
+
 QPixmap MainWindow::splashImage() const
 {
     // search in the UserAppData dir as very first
@@ -1520,7 +1516,7 @@ QPixmap MainWindow::splashImage() const
     if (splash_image.isNull()) {
         QString path = QString::fromUtf8(splash_path.c_str());
         if (QDir(path).isRelative()) {
-            QString home = QString::fromUtf8(App::GetApplication().getHomePath());
+            QString home = QString::fromStdString(App::Application::getHomePath());
             path = QFileInfo(QDir(home), path).absoluteFilePath();
         }
 
@@ -1529,7 +1525,15 @@ QPixmap MainWindow::splashImage() const
 
     // now try the icon paths
     if (splash_image.isNull()) {
-        splash_image = Gui::BitmapFactory().pixmap(splash_path.c_str());
+        if (qApp->devicePixelRatio() > 1.0) {
+            // For HiDPI screens, we have a double-resolution version of the splash image
+            splash_path += "2x";
+            splash_image = Gui::BitmapFactory().pixmap(splash_path.c_str());
+            splash_image.setDevicePixelRatio(2.0);
+        }
+        else {
+            splash_image = Gui::BitmapFactory().pixmap(splash_path.c_str());
+        }
     }
 
     // include application name and version number
@@ -1538,7 +1542,8 @@ QPixmap MainWindow::splashImage() const
         QString title = qApp->applicationName();
         QString major   = QString::fromLatin1(App::Application::Config()["BuildVersionMajor"].c_str());
         QString minor   = QString::fromLatin1(App::Application::Config()["BuildVersionMinor"].c_str());
-        QString version = QString::fromLatin1("%1.%2").arg(major, minor);
+        QString point   = QString::fromLatin1(App::Application::Config()["BuildVersionPoint"].c_str());
+        QString version = QString::fromLatin1("%1.%2.%3").arg(major, minor, point);
         QString position, fontFamily;
 
         std::map<std::string,std::string>::const_iterator te = App::Application::Config().find("SplashInfoExeName");
@@ -1563,14 +1568,14 @@ QPixmap MainWindow::splashImage() const
         }
 
         QFont fontExe = painter.font();
-        fontExe.setPointSize(20);
+        fontExe.setPointSizeF(20.0);
         QFontMetrics metricExe(fontExe);
         int l = QtTools::horizontalAdvance(metricExe, title);
         int w = splash_image.width();
         int h = splash_image.height();
 
         QFont fontVer = painter.font();
-        fontVer.setPointSize(12);
+        fontVer.setPointSizeF(12.0);
         QFontMetrics metricVer(fontVer);
         int v = QtTools::horizontalAdvance(metricVer, version);
 
@@ -1652,16 +1657,16 @@ QMimeData * MainWindow::createMimeDataFromSelection () const
             sel.push_back(s.pObject);
     }
     if(sel.empty())
-        return 0;
+        return nullptr;
 
     auto all = App::Document::getDependencyList(sel);
     if (all.size() > sel.size()) {
         DlgObjectSelection dlg(sel,getMainWindow());
         if(dlg.exec()!=QDialog::Accepted)
-            return 0;
+            return nullptr;
         sel = dlg.getSelections();
         if(sel.empty())
-            return 0;
+            return nullptr;
     }
 
     std::vector<App::Document*> unsaved;
@@ -1670,7 +1675,7 @@ QMimeData * MainWindow::createMimeDataFromSelection () const
         QMessageBox::critical(getMainWindow(), tr("Unsaved document"),
             tr("The exported object contains external link. Please save the document"
                 "at least once before exporting."));
-        return 0;
+        return nullptr;
     }
 
     unsigned int memsize=1000; // ~ for the meta-information
@@ -1771,7 +1776,7 @@ void MainWindow::insertFromMimeData (const QMimeData * mimeData)
 
         doc->openTransaction("Paste");
         Base::ByteArrayIStreambuf buf(res);
-        std::istream in(0);
+        std::istream in(nullptr);
         in.rdbuf(&buf);
         MergeDocuments mimeView(doc);
         std::vector<App::DocumentObject*> newObj = mimeView.importObjects(in);
@@ -1849,15 +1854,10 @@ void MainWindow::loadUrls(App::Document* doc, const QList<QUrl>& urls)
 //#ifndef QT_NO_OPENSSL
         else if (it->scheme().toLower() == QLatin1String("https")) {
             QUrl url = *it;
-#if QT_VERSION >= 0x050000
             QUrlQuery urlq(url);
             if (urlq.hasQueryItem(QLatin1String("sid"))) {
                 urlq.removeAllQueryItems(QLatin1String("sid"));
                 url.setQuery(urlq);
-#else
-            if (it->hasEncodedQueryItem(QByteArray("sid"))) {
-                url.removeEncodedQueryItem(QByteArray("sid"));
-#endif
                 url.setScheme(QLatin1String("http"));
             }
             Gui::Dialog::DownloadManager* dm = Gui::Dialog::DownloadManager::getInstance();
