@@ -28,10 +28,8 @@
 #include <Base/BoundBox.h>
 #include <Base/Placement.h>
 #include <Base/Vector3D.h>
-#include <Gui/Application.h>
 #include <Gui/Document.h>
 #include <Gui/ViewProviderDocumentObject.h>
-#include <boost_signals2.hpp>
 
 class SbVec3f;
 class SoPickedPoint;
