@@ -20,18 +20,16 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #ifndef MOUSESELECTION_H
 #define MOUSESELECTION_H
 
 #include <bitset>
 #include <vector>
-#include <Inventor/SbLinear.h>
-#include <Inventor/SbVec2f.h>
 #include <QCursor>
 #include <Gui/GLPainter.h>
 #include <Gui/Namespace.h>
 
+
 // forwards
 class QMouseEvent;
 class QWheelEvent;
@@ -60,13 +58,13 @@ public:
     enum { Continue=0, Restart=1, Finish=2, Cancel=3, Ignore=4 };
 
     AbstractMouseSelection();
-    virtual ~AbstractMouseSelection(void) {}
+    virtual ~AbstractMouseSelection() {}
     /// implement this in derived classes
     virtual void initialize() = 0;
     /// implement this in derived classes
-    virtual void terminate() = 0;
+    virtual void terminate(bool abort = false) = 0;
     void grabMouseModel(Gui::View3DInventorViewer*);
-    void releaseMouseModel(void);
+    void releaseMouseModel(bool abort = false);
     const std::vector<SbVec2s>& getPositions() const {
         return _clPoly;
     }
@@ -134,7 +132,7 @@ public:
     void setColor(float r, float g, float b, float a = 1.0);
 
     virtual void initialize();
-    virtual void terminate();
+    virtual void terminate(bool abort = false);
 
 protected:
     virtual int mouseButtonEvent(const SoMouseButtonEvent* const e, const QPoint& pos);
@@ -213,7 +211,7 @@ public:
     void setColor(float r, float g, float b, float a = 1.0);
 
     virtual void initialize();
-    virtual void terminate();
+    virtual void terminate(bool abort = false);
 
 protected:
     virtual int mouseButtonEvent(const SoMouseButtonEvent* const e, const QPoint& pos);
@@ -253,7 +251,7 @@ class GuiExport BoxZoomSelection : public RubberbandSelection
 public:
     BoxZoomSelection();
     ~BoxZoomSelection();
-    void terminate();
+    void terminate(bool abort = false);
 };
 
 } // namespace Gui
