@@ -20,30 +20,34 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 #ifndef _PreComp_
-# include <algorithm>
-# include <cfloat>
-# include "InventorAll.h"
+# include <Inventor/SbViewportRegion.h>
+# include <Inventor/SoPickedPoint.h>
+# include <Inventor/actions/SoGetBoundingBoxAction.h>
+# include <Inventor/errors/SoDebugError.h>
+# include <Inventor/nodes/SoSeparator.h>
+# include <Inventor/nodes/SoCamera.h>
+# include <Inventor/nodes/SoOrthographicCamera.h>
+# include <Inventor/nodes/SoPerspectiveCamera.h>
+# include <Inventor/projectors/SbSphereSheetProjector.h>
 # include <QAction>
 # include <QActionGroup>
 # include <QApplication>
 # include <QByteArray>
 # include <QCursor>
-# include <QList>
 # include <QMenu>
-# include <QMetaObject>
-# include <QRegExp>
 #endif
 
 #include <App/Application.h>
+
 #include "NavigationStyle.h"
-#include "View3DInventorViewer.h"
 #include "Application.h"
 #include "MenuManager.h"
 #include "MouseSelection.h"
 #include "SoMouseWheelEvent.h"
+#include "View3DInventorViewer.h"
+
 
 using namespace Gui;
 
@@ -64,7 +68,7 @@ struct NavigationStyleP {
     {
         this->animationsteps = 0;
         this->animationdelta = 0;
-        this->animsensor = 0;
+        this->animsensor = nullptr;
         this->sensitivity = 2.0f;
         this->resetcursorpos = false;
         this->rotationCenterFound = false;
@@ -173,7 +177,7 @@ const Base::Type& NavigationStyleEvent::style() const
 
 TYPESYSTEM_SOURCE_ABSTRACT(Gui::NavigationStyle,Base::BaseClass)
 
-NavigationStyle::NavigationStyle() : viewer(0), mouseSelection(0)
+NavigationStyle::NavigationStyle() : viewer(nullptr), mouseSelection(nullptr)
 {
     PRIVATE(this) = new NavigationStyleP();
     PRIVATE(this)->animsensor = new SoTimerSensor(NavigationStyleP::viewAnimationCB, this);
@@ -261,17 +265,17 @@ void NavigationStyle::finalize()
     delete[] this->log.time;
 }
 
-void NavigationStyle::interactiveCountInc(void)
+void NavigationStyle::interactiveCountInc()
 {
     viewer->interactiveCountInc();
 }
 
-void NavigationStyle::interactiveCountDec(void)
+void NavigationStyle::interactiveCountDec()
 {
     viewer->interactiveCountDec();
 }
 
-int NavigationStyle::getInteractiveCount(void) const
+int NavigationStyle::getInteractiveCount() const
 {
     return viewer->getInteractiveCount();
 }
@@ -288,7 +292,7 @@ NavigationStyle::OrbitStyle NavigationStyle::getOrbitStyle() const
     return NavigationStyle::OrbitStyle(projector->getOrbitStyle());
 }
 
-SbBool NavigationStyle::isViewing(void) const
+SbBool NavigationStyle::isViewing() const
 {
     return viewer->isViewing();
 }
@@ -298,7 +302,7 @@ void NavigationStyle::setViewing(SbBool enable)
     viewer->setViewing(enable);
 }
 
-SbBool NavigationStyle::isSeekMode(void) const
+SbBool NavigationStyle::isSeekMode() const
 {
     return viewer->isSeekMode();
 }
@@ -321,7 +325,8 @@ void NavigationStyle::seekToPoint(const SbVec3f& scenepos)
 SbBool NavigationStyle::lookAtPoint(const SbVec2s screenpos)
 {
     SoCamera* cam = viewer->getSoRenderManager()->getCamera();
-    if (cam == 0) return false;
+    if (cam == nullptr)
+        return false;
 
     SoRayPickAction rpaction(viewer->getSoRenderManager()->getViewportRegion());
     rpaction.setPoint(screenpos);
@@ -343,7 +348,8 @@ SbBool NavigationStyle::lookAtPoint(const SbVec2s screenpos)
 void NavigationStyle::lookAtPoint(const SbVec3f& pos)
 {
     SoCamera* cam = viewer->getSoRenderManager()->getCamera();
-    if (cam == 0) return;
+    if (cam == nullptr)
+        return;
     PRIVATE(this)->rotationCenterFound = false;
 
     // Find global coordinates of focal point.
@@ -401,7 +407,8 @@ void NavigationStyle::lookAtPoint(const SbVec3f& pos)
 void NavigationStyle::setCameraOrientation(const SbRotation& rot, SbBool moveToCenter)
 {
     SoCamera* cam = viewer->getSoRenderManager()->getCamera();
-    if (cam == 0) return;
+    if (cam == nullptr)
+        return;
 
     // Find global coordinates of focal point.
     SbVec3f direction;
@@ -480,7 +487,8 @@ void NavigationStyleP::viewAnimationCB(void * data, SoSensor * sensor)
         SbRotation slerp = SbRotation::slerp(that->spinRotation, PRIVATE(that)->endRotation, step);
         SbVec3f focalpoint = (1.0f-step)*PRIVATE(that)->focal1 + step*PRIVATE(that)->focal2;
         SoCamera* cam = that->viewer->getSoRenderManager()->getCamera();
-        if (!cam) return; // no camera
+        if (!cam) // no camera
+            return;
 
         SbVec3f direction;
         cam->orientation.setValue(slerp);
@@ -504,7 +512,8 @@ void NavigationStyleP::viewAnimationCB(void * data, SoSensor * sensor)
 void NavigationStyle::boxZoom(const SbBox2s& box)
 {
     SoCamera* cam = viewer->getSoRenderManager()->getCamera();
-    if (!cam) return; // no camera
+    if (!cam) // no camera
+        return;
     const SbViewportRegion & vp = viewer->getSoRenderManager()->getViewportRegion();
     SbViewVolume vv = cam->getViewVolume(vp.getViewportAspectRatio());
 
@@ -547,7 +556,8 @@ void NavigationStyle::viewAll()
     SoGetBoundingBoxAction action(viewer->getSoRenderManager()->getViewportRegion());
     action.apply(viewer->getSceneGraph());
     SbBox3f box = action.getBoundingBox();
-    if (box.isEmpty()) return;
+    if (box.isEmpty())
+        return;
 
 #if 0
     // check whether the box is very wide or tall, if not do nothing
@@ -560,7 +570,8 @@ void NavigationStyle::viewAll()
 #endif
 
     SoCamera* cam = viewer->getSoRenderManager()->getCamera();
-    if (!cam) return;
+    if (!cam)
+        return;
 
     SbViewVolume  vol = cam->getViewVolume();
     if (vol.ulf == vol.llf)
@@ -611,7 +622,8 @@ void NavigationStyle::viewAll()
  */
 void NavigationStyle::reorientCamera(SoCamera * cam, const SbRotation & rot)
 {
-    if (cam == NULL) return;
+    if (cam == nullptr)
+        return;
 
     // Find global coordinates of focal point.
     SbVec3f direction;
@@ -630,8 +642,10 @@ void NavigationStyle::reorientCamera(SoCamera * cam, const SbRotation & rot)
 void NavigationStyle::panCamera(SoCamera * cam, float aspectratio, const SbPlane & panplane,
                                 const SbVec2f & currpos, const SbVec2f & prevpos)
 {
-    if (cam == NULL) return; // can happen for empty scenegraph
-    if (currpos == prevpos) return; // useless invocation
+    if (cam == nullptr) // can happen for empty scenegraph
+        return;
+    if (currpos == prevpos) // useless invocation
+        return;
 
 
     // Find projection points for the last and current mouse coordinates.
@@ -659,7 +673,7 @@ void NavigationStyle::pan(SoCamera* camera)
     // The plane we're projecting the mouse coordinates to get 3D
     // coordinates should stay the same during the whole pan
     // operation, so we should calculate this value here.
-    if (camera == NULL) { // can happen for empty scenegraph
+    if (camera == nullptr) { // can happen for empty scenegraph
         this->panningplane = SbPlane(SbVec3f(0, 0, 1), 0);
     }
     else {
@@ -689,7 +703,8 @@ void NavigationStyle::panToCenter(const SbPlane & pplane, const SbVec2f & currpo
  */
 void NavigationStyle::zoom(SoCamera * cam, float diffvalue)
 {
-    if (cam == NULL) return; // can happen for empty scenegraph
+    if (cam == nullptr) // can happen for empty scenegraph
+        return;
     SoType t = cam->getTypeId();
     SbName tname = t.getName();
 
@@ -870,7 +885,7 @@ void NavigationStyle::setRotationCenter(const SbVec3f& cnt)
 SbVec3f NavigationStyle::getFocalPoint() const
 {
     SoCamera* cam = viewer->getSoRenderManager()->getCamera();
-    if (cam == 0)
+    if (cam == nullptr)
         return SbVec3f(0,0,0);
 
     // Find global coordinates of focal point.
@@ -886,8 +901,9 @@ SbVec3f NavigationStyle::getFocalPoint() const
  */
 void NavigationStyle::spin(const SbVec2f & pointerpos)
 {
-    if (this->log.historysize < 2) return;
-    assert(this->spinprojector != NULL);
+    if (this->log.historysize < 2)
+        return;
+    assert(this->spinprojector != nullptr);
 
     const SbViewportRegion & vp = viewer->getSoRenderManager()->getViewportRegion();
     SbVec2s glsize(vp.getViewportSizePixels());
@@ -965,7 +981,7 @@ void NavigationStyle::spin(const SbVec2f & pointerpos)
  * \param prevpos  previous normalized position of mouse pointer
  */
 void NavigationStyle::spin_simplified(SoCamera* cam, SbVec2f curpos, SbVec2f prevpos){
-    assert(this->spinprojector != NULL);
+    assert(this->spinprojector != nullptr);
 
     // 0000333: Turntable camera rotation
     SbMatrix mat;
@@ -1046,7 +1062,8 @@ void NavigationStyle::saveCursorPosition(const SoEvent * const ev)
         float ratio = vp.getViewportAspectRatio();
 
         SoCamera* cam = viewer->getSoRenderManager()->getCamera();
-        if (!cam) return; // no camera
+        if (!cam) // no camera
+            return;
         SbViewVolume vv = cam->getViewVolume(ratio);
 
         SbLine line;
@@ -1065,7 +1082,8 @@ void NavigationStyle::saveCursorPosition(const SoEvent * const ev)
         float ratio = vp.getViewportAspectRatio();
 
         SoCamera* cam = viewer->getSoRenderManager()->getCamera();
-        if (!cam) return; // no camera
+        if (!cam) // no camera
+            return;
 
         SoGetBoundingBoxAction action(viewer->getSoRenderManager()->getViewportRegion());
         action.apply(viewer->getSceneGraph());
@@ -1163,7 +1181,7 @@ NavigationStyle::setAnimationEnabled(const SbBool enable)
 */
 
 SbBool
-NavigationStyle::isAnimationEnabled(void) const
+NavigationStyle::isAnimationEnabled() const
 {
     return this->spinanimatingallowed;
 }
@@ -1172,7 +1190,7 @@ NavigationStyle::isAnimationEnabled(void) const
   Query if the model in the viewer is currently in spinning mode after
   a user drag.
 */
-SbBool NavigationStyle::isAnimating(void) const
+SbBool NavigationStyle::isAnimating() const
 {
     return this->currentmode == NavigationStyle::SPINNING;
 }
@@ -1183,7 +1201,8 @@ SbBool NavigationStyle::isAnimating(void) const
  */
 void NavigationStyle::startAnimating(const SbVec3f& axis, float velocity)
 {
-    if (!isAnimationEnabled()) return;
+    if (!isAnimationEnabled())
+        return;
 
     this->prevRedrawTime = SbTime::getTimeOfDay();
     this->spinincrement = SbRotation::identity();
@@ -1195,7 +1214,7 @@ void NavigationStyle::startAnimating(const SbVec3f& axis, float velocity)
     this->spinRotation = rot;
 }
 
-void NavigationStyle::stopAnimating(void)
+void NavigationStyle::stopAnimating()
 {
     if (this->currentmode != NavigationStyle::SPINNING) {
         return;
@@ -1305,13 +1324,23 @@ void NavigationStyle::startSelection(NavigationStyle::SelectionMode mode)
         mouseSelection->grabMouseModel(viewer);
 }
 
+void NavigationStyle::abortSelection()
+{
+    pcPolygon.clear();
+    if (mouseSelection) {
+        mouseSelection->releaseMouseModel(true);
+        delete mouseSelection;
+        mouseSelection = nullptr;
+    }
+}
+
 void NavigationStyle::stopSelection()
 {
     pcPolygon.clear();
     if (mouseSelection) {
         mouseSelection->releaseMouseModel();
         delete mouseSelection;
-        mouseSelection = 0;
+        mouseSelection = nullptr;
     }
 }
 
@@ -1357,17 +1386,34 @@ void NavigationStyle::addToLog(const SbVec2s pos, const SbTime time)
 
 // This method "clears" the mouse location log, used for spin
 // animation calculations.
-void NavigationStyle::clearLog(void)
+void NavigationStyle::clearLog()
 {
     this->log.historysize = 0;
 }
 
+void NavigationStyle::syncModifierKeys(const SoEvent * const ev)
+{
+    // Mismatches in state of the modifier keys happens if the user
+    // presses or releases them outside the viewer window.
+    if (this->ctrldown != ev->wasCtrlDown()) {
+        this->ctrldown = ev->wasCtrlDown();
+    }
+    if (this->shiftdown != ev->wasShiftDown()) {
+        this->shiftdown = ev->wasShiftDown();
+    }
+    if (this->altdown != ev->wasAltDown()) {
+        this->altdown = ev->wasAltDown();
+    }
+}
+
 // The viewer is a state machine, and all changes to the current state
 // are made through this call.
 void NavigationStyle::setViewingMode(const ViewerMode newmode)
 {
     const ViewerMode oldmode = this->currentmode;
-    if (newmode == oldmode) { return; }
+    if (newmode == oldmode) {
+        return;
+    }
 
     switch (newmode) {
     case DRAGGING:
@@ -1436,14 +1482,14 @@ SbBool NavigationStyle::processEvent(const SoEvent * const ev)
             pcPolygon = mouseSelection->getPositions();
             selectedRole = mouseSelection->selectedRole();
             delete mouseSelection;
-            mouseSelection = 0;
+            mouseSelection = nullptr;
             syncWithEvent(ev);
             return NavigationStyle::processSoEvent(ev);
         }
         else if (hd==AbstractMouseSelection::Cancel) {
             pcPolygon.clear();
             delete mouseSelection;
-            mouseSelection = 0;
+            mouseSelection = nullptr;
             syncWithEvent(ev);
             return NavigationStyle::processSoEvent(ev);
         }
@@ -1470,27 +1516,22 @@ SbBool NavigationStyle::processEvent(const SoEvent * const ev)
 
 SbBool NavigationStyle::processSoEvent(const SoEvent * const ev)
 {
-    const SbViewportRegion & vp = viewer->getSoRenderManager()->getViewportRegion();
-    const SbVec2s size(vp.getViewportSizePixels());
-    const SbVec2s pos(ev->getPosition());
-    const SbVec2f posn((float) pos[0] / (float) std::max((int)(size[0] - 1), 1),
-                       (float) pos[1] / (float) std::max((int)(size[1] - 1), 1));
     bool processed = false;
+    bool offeredtoViewerEventBase = false;
 
     //handle mouse wheel zoom
-    if(ev->isOfType(SoMouseWheelEvent::getClassTypeId())){
-        doZoom(
-            viewer->getSoRenderManager()->getCamera(),
-            static_cast<const SoMouseWheelEvent*>(ev)->getDelta(),
-            posn
-        );
-        processed = true;
+    if (ev->isOfType(SoMouseWheelEvent::getClassTypeId())) {
+        const SoMouseWheelEvent * const event = static_cast<const SoMouseWheelEvent *>(ev);
+        processed = processWheelEvent(event);
+        viewer->processSoEventBase(ev);
+        offeredtoViewerEventBase = true;
     }
 
-    if (! processed)
-        return viewer->processSoEventBase(ev);
-    else
-        return processed;
+    if (!processed && !offeredtoViewerEventBase) {
+        processed = viewer->processSoEventBase(ev);
+    }
+
+    return processed;
 }
 
 void NavigationStyle::syncWithEvent(const SoEvent * const ev)
@@ -1498,21 +1539,15 @@ void NavigationStyle::syncWithEvent(const SoEvent * const ev)
     // Events when in "ready-to-seek" mode are ignored, except those
     // which influence the seek mode itself -- these are handled further
     // up the inheritance hierarchy.
-    if (this->isSeekMode()) { return; }
+    if (this->isSeekMode()) {
+        return;
+    }
 
     const SoType type(ev->getTypeId());
 
     // Mismatches in state of the modifier keys happens if the user
     // presses or releases them outside the viewer window.
-    if (this->ctrldown != ev->wasCtrlDown()) {
-        this->ctrldown = ev->wasCtrlDown();
-    }
-    if (this->shiftdown != ev->wasShiftDown()) {
-        this->shiftdown = ev->wasShiftDown();
-    }
-    if (this->altdown != ev->wasAltDown()) {
-        this->altdown = ev->wasAltDown();
-    }
+    syncModifierKeys(ev);
 
     // Keyboard handling
     if (type.isDerivedFrom(SoKeyboardEvent::getClassTypeId())) {
@@ -1590,12 +1625,111 @@ SbBool NavigationStyle::processMotionEvent(const SoMotion3Event * const ev)
     return true;
 }
 
+SbBool NavigationStyle::processKeyboardEvent(const SoKeyboardEvent * const event)
+{
+    SbBool processed = false;
+    const SbBool press = event->getState() == SoButtonEvent::DOWN ? true : false;
+    switch (event->getKey()) {
+    case SoKeyboardEvent::LEFT_CONTROL:
+    case SoKeyboardEvent::RIGHT_CONTROL:
+        this->ctrldown = press;
+        break;
+    case SoKeyboardEvent::LEFT_SHIFT:
+    case SoKeyboardEvent::RIGHT_SHIFT:
+        this->shiftdown = press;
+        break;
+    case SoKeyboardEvent::LEFT_ALT:
+    case SoKeyboardEvent::RIGHT_ALT:
+        this->altdown = press;
+        break;
+    case SoKeyboardEvent::H:
+        processed = true;
+        viewer->saveHomePosition();
+        break;
+    case SoKeyboardEvent::R:
+        processed = true;
+        viewer->resetToHomePosition();
+        break;
+    case SoKeyboardEvent::S:
+    case SoKeyboardEvent::HOME:
+    case SoKeyboardEvent::LEFT_ARROW:
+    case SoKeyboardEvent::UP_ARROW:
+    case SoKeyboardEvent::RIGHT_ARROW:
+    case SoKeyboardEvent::DOWN_ARROW:
+        if (!this->isViewing())
+            this->setViewing(true);
+        break;
+    case SoKeyboardEvent::PAGE_UP:
+    {
+        processed = true;
+        const SbVec2f posn = normalizePixelPos(event->getPosition());
+        doZoom(viewer->getSoRenderManager()->getCamera(), getDelta(), posn);
+        break;
+    }
+    case SoKeyboardEvent::PAGE_DOWN:
+    {
+        processed = true;
+        const SbVec2f posn = normalizePixelPos(event->getPosition());
+        doZoom(viewer->getSoRenderManager()->getCamera(), -getDelta(), posn);
+        break;
+    }
+    default:
+        break;
+    }
+
+    return processed;
+}
+
+SbBool NavigationStyle::processClickEvent(const SoMouseButtonEvent * const event)
+{
+    // issue #0002433: avoid to swallow the UP event if down the
+    // scene graph somewhere a dialog gets opened
+    SbBool processed = false;
+    const SbBool press = event->getState() == SoButtonEvent::DOWN ? true : false;
+    if (press) {
+        SbTime tmp = (event->getTime() - mouseDownConsumedEvent.getTime());
+        float dci = (float)QApplication::doubleClickInterval()/1000.0f;
+        // a double-click?
+        if (tmp.getValue() < dci) {
+            mouseDownConsumedEvent = *event;
+            mouseDownConsumedEvent.setTime(event->getTime());
+            processed = true;
+        }
+        else {
+            mouseDownConsumedEvent.setTime(event->getTime());
+            // 'ANY' is used to mark that we don't know yet if it will
+            // be a double-click event.
+            mouseDownConsumedEvent.setButton(SoMouseButtonEvent::ANY);
+        }
+    }
+    else if (!press) {
+        if (mouseDownConsumedEvent.getButton() == SoMouseButtonEvent::BUTTON1) {
+            // now handle the postponed event
+            NavigationStyle::processSoEvent(&mouseDownConsumedEvent);
+            mouseDownConsumedEvent.setButton(SoMouseButtonEvent::ANY);
+        }
+    }
+
+    return processed;
+}
+
+SbBool NavigationStyle::processWheelEvent(const SoMouseWheelEvent * const event)
+{
+    const SbVec2s pos(event->getPosition());
+    const SbVec2f posn = normalizePixelPos(pos);
+
+    //handle mouse wheel zoom
+    doZoom(viewer->getSoRenderManager()->getCamera(),
+           event->getDelta(), posn);
+    return true;
+}
+
 void NavigationStyle::setPopupMenuEnabled(const SbBool on)
 {
     this->menuenabled = on;
 }
 
-SbBool NavigationStyle::isPopupMenuEnabled(void) const
+SbBool NavigationStyle::isPopupMenuEnabled() const
 {
     return this->menuenabled;
 }
