@@ -24,23 +24,23 @@
 #include "PreCompiled.h"
 
 #ifndef _PreComp_
-# include <qapplication.h>
-# include <qdir.h>
-# include <qfileinfo.h>
-# include <qlineedit.h>
-# include <qmessagebox.h>
-# include <qtimer.h>
+# include <QApplication>
+# include <QDir>
+# include <QFileInfo>
+# include <QMessageBox>
+# include <QTimer>
 #endif
 
+#include <App/Application.h>
+#include <Base/Console.h>
+
 #include "NetworkRetriever.h"
 #include "Action.h"
 #include "BitmapFactory.h"
+#include "FileDialog.h"
 #include "MainWindow.h"
 #include "ui_DlgAuthorization.h"
-#include "FileDialog.h"
 
-#include <App/Application.h>
-#include <Base/Console.h>
 
 using namespace Gui;
 using namespace Gui::Dialog;
@@ -374,12 +374,8 @@ void NetworkRetriever::wgetFinished(int exitCode, QProcess::ExitStatus status)
 bool NetworkRetriever::testWget()
 {
     QProcess proc;
-#if QT_VERSION > 0x050000
     proc.setProgram(QString::fromLatin1("wget"));
     proc.start();
-#else
-    proc.start(QString::fromLatin1("wget"));
-#endif
     bool ok = proc.state() == QProcess::Running;
     proc.kill();
     proc.waitForFinished();
@@ -391,7 +387,7 @@ bool NetworkRetriever::testWget()
 StdCmdDownloadOnlineHelp::StdCmdDownloadOnlineHelp( QObject * parent)
   : QObject(parent), Command("Std_DownloadOnlineHelp")
 {
-    sGroup        = QT_TR_NOOP("Help");
+    sGroup        ="Help";
     sMenuText     = QT_TR_NOOP("Download online help");
     sToolTipText  = QT_TR_NOOP("Download %1's online help");
     sWhatsThis    = "Std_DownloadOnlineHelp";
@@ -418,22 +414,22 @@ StdCmdDownloadOnlineHelp::~StdCmdDownloadOnlineHelp()
     delete wget;
 }
 
-Action * StdCmdDownloadOnlineHelp::createAction(void)
+Action * StdCmdDownloadOnlineHelp::createAction()
 {
     Action *pcAction;
 
-    QString exe = QString::fromLatin1(App::GetApplication().getExecutableName());
+    QString exe = QString::fromStdString(App::Application::getExecutableName());
     pcAction = new Action(this,getMainWindow());
     pcAction->setText(QCoreApplication::translate(
-        this->className(), sMenuText));
+        this->className(), getMenuText()));
     pcAction->setToolTip(QCoreApplication::translate(
-        this->className(), sToolTipText).arg(exe));
+        this->className(), getToolTipText()).arg(exe));
     pcAction->setStatusTip(QCoreApplication::translate(
-        this->className(), sStatusTip).arg(exe));
+        this->className(), getStatusTip()).arg(exe));
     pcAction->setWhatsThis(QCoreApplication::translate(
-        this->className(), sWhatsThis).arg(exe));
-    pcAction->setIcon(Gui::BitmapFactory().pixmap(sPixmap));
-    pcAction->setShortcut(QString::fromLatin1(sAccel));
+        this->className(), getWhatsThis()).arg(exe));
+    pcAction->setIcon(Gui::BitmapFactory().pixmap(getPixmap()));
+    pcAction->setShortcut(QString::fromLatin1(getAccel()));
 
     return pcAction;
 }
@@ -441,15 +437,15 @@ Action * StdCmdDownloadOnlineHelp::createAction(void)
 void StdCmdDownloadOnlineHelp::languageChange()
 {
     if (_pcAction) {
-        QString exe = QString::fromLatin1(App::GetApplication().getExecutableName());
+        QString exe = QString::fromStdString(App::Application::getExecutableName());
         _pcAction->setText(QCoreApplication::translate(
-            this->className(), sMenuText));
+            this->className(), getMenuText()));
         _pcAction->setToolTip(QCoreApplication::translate(
-            this->className(), sToolTipText).arg(exe));
+            this->className(), getToolTipText()).arg(exe));
         _pcAction->setStatusTip(QCoreApplication::translate(
-            this->className(), sStatusTip).arg(exe));
+            this->className(), getStatusTip()).arg(exe));
         _pcAction->setWhatsThis(QCoreApplication::translate(
-            this->className(), sWhatsThis).arg(exe));
+            this->className(), getWhatsThis()).arg(exe));
     }
 }
 
@@ -487,7 +483,7 @@ void StdCmdDownloadOnlineHelp::activated(int iMsg)
         bool canStart = false;
 
         // set output directory
-        QString path = QString::fromUtf8(App::GetApplication().getHomePath());
+        QString path = QString::fromStdString(App::Application::getHomePath());
         path += QString::fromLatin1("/doc/");
         ParameterGrp::handle hURLGrp = App::GetApplication().GetParameterGroupByPath("User parameter:BaseApp/Preferences/OnlineHelp");
         path = QString::fromUtf8(hURLGrp->GetASCII( "DownloadLocation", path.toLatin1() ).c_str());
@@ -554,7 +550,7 @@ void StdCmdDownloadOnlineHelp::wgetFinished()
 {
     if (_pcAction)
         _pcAction->setText(QCoreApplication::translate(
-            this->className(), sMenuText));
+            this->className(), getMenuText()));
 }
 
 #include "moc_NetworkRetriever.cpp"
