@@ -20,17 +20,17 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #ifndef GUI_PROGRESSDIALOG_H
 #define GUI_PROGRESSDIALOG_H
 
 #include <Base/Sequencer.h>
 #include <QProgressDialog>
 #ifdef QT_WINEXTRAS_LIB
-#include <QWinTaskbarProgress>
 #include <QWinTaskbarButton>
+#include <QWinTaskbarProgress>
 #endif
 
+
 namespace Gui {
 
 struct SequencerDialogPrivate;
@@ -83,7 +83,7 @@ class ProgressDialog : public QProgressDialog
 
 public:
     /** Construction */
-    ProgressDialog (SequencerDialog* s, QWidget * parent=0);
+    ProgressDialog (SequencerDialog* s, QWidget * parent=nullptr);
     /** Destruction */
     ~ProgressDialog ();
 
