@@ -20,13 +20,17 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
+#ifndef _PreComp_
+# include <QVBoxLayout>
+#endif
+
+#include <Base/Console.h>
 
 #include "PropertyPage.h"
 #include "PrefWidgets.h"
-#include "WidgetFactory.h"
-#include <Base/Console.h>
+#include "UiLoader.h"
+
 
 using namespace Gui::Dialog;
 
@@ -113,12 +117,10 @@ void PreferencePage::changeEvent(QEvent *e)
 // ----------------------------------------------------------------
 
 PreferenceUiForm::PreferenceUiForm(const QString& fn, QWidget* parent)
-  : PreferencePage(parent), form(0)
+  : PreferencePage(parent), form(nullptr)
 {
     UiLoader loader;
-#if QT_VERSION >= 0x040500
     loader.setLanguageChangeEnabled(true);
-#endif
     loader.setWorkingDirectory(QFileInfo(fn).absolutePath());
     QFile file(fn);
     if (file.open(QFile::ReadOnly))
@@ -146,7 +148,7 @@ void PreferenceUiForm::changeEvent(QEvent *e)
 }
 
 template <typename PW>
-void PreferenceUiForm::loadPrefWidgets(void)
+void PreferenceUiForm::loadPrefWidgets()
 {
     QList<PW> pw = form->findChildren<PW>();
     for (typename QList<PW>::iterator it = pw.begin(); it != pw.end(); ++it)
@@ -154,7 +156,7 @@ void PreferenceUiForm::loadPrefWidgets(void)
 }
 
 template <typename PW>
-void PreferenceUiForm::savePrefWidgets(void)
+void PreferenceUiForm::savePrefWidgets()
 {
     QList<PW> pw = form->findChildren<PW>();
     for (typename QList<PW>::iterator it = pw.begin(); it != pw.end(); ++it)
@@ -170,6 +172,7 @@ void PreferenceUiForm::loadSettings()
     loadPrefWidgets<Gui::PrefSpinBox        *>();
     loadPrefWidgets<Gui::PrefDoubleSpinBox  *>();
     loadPrefWidgets<Gui::PrefLineEdit       *>();
+    loadPrefWidgets<Gui::PrefTextEdit       *>();
     loadPrefWidgets<Gui::PrefFileChooser    *>();
     loadPrefWidgets<Gui::PrefComboBox       *>();
     loadPrefWidgets<Gui::PrefFontBox        *>();
@@ -178,6 +181,7 @@ void PreferenceUiForm::loadSettings()
     loadPrefWidgets<Gui::PrefSlider         *>();
     loadPrefWidgets<Gui::PrefColorButton    *>();
     loadPrefWidgets<Gui::PrefUnitSpinBox    *>();
+    loadPrefWidgets<Gui::PrefQuantitySpinBox*>();
 }
 
 void PreferenceUiForm::saveSettings()
@@ -189,6 +193,7 @@ void PreferenceUiForm::saveSettings()
     savePrefWidgets<Gui::PrefSpinBox        *>();
     savePrefWidgets<Gui::PrefDoubleSpinBox  *>();
     savePrefWidgets<Gui::PrefLineEdit       *>();
+    savePrefWidgets<Gui::PrefTextEdit       *>();
     savePrefWidgets<Gui::PrefFileChooser    *>();
     savePrefWidgets<Gui::PrefComboBox       *>();
     savePrefWidgets<Gui::PrefFontBox        *>();
@@ -197,6 +202,7 @@ void PreferenceUiForm::saveSettings()
     savePrefWidgets<Gui::PrefSlider         *>();
     savePrefWidgets<Gui::PrefColorButton    *>();
     savePrefWidgets<Gui::PrefUnitSpinBox    *>();
+    savePrefWidgets<Gui::PrefQuantitySpinBox*>();
 }
 
 // ----------------------------------------------------------------
