@@ -20,39 +20,29 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 #ifndef _PreComp_
-# include <QGridLayout>
-# include <QHeaderView>
 # include <QEvent>
+# include <QGridLayout>
 # include <QTimer>
-# include <boost_bind_bind.hpp>
 #endif
 
-
-/// Here the FreeCAD includes sorted by Base,App,Gui......
-#include <Base/Parameter.h>
-#include <App/PropertyStandard.h>
-#include <App/PropertyGeo.h>
-#include <App/PropertyLinks.h>
-#include <App/PropertyContainer.h>
-#include <App/DocumentObject.h>
 #include <App/Document.h>
-#include <Base/Console.h>
+#include <App/DocumentObject.h>
+#include <Base/Parameter.h>
 
 #include "PropertyView.h"
 #include "Application.h"
-#include "MainWindow.h"
 #include "Document.h"
-#include "BitmapFactory.h"
-#include "ViewProvider.h"
-#include "ViewProviderDocumentObject.h"
+#include "MainWindow.h"
+#include "SelectionObject.h"
 #include "Tree.h"
 #include "ViewParams.h"
-
+#include "ViewProvider.h"
+#include "ViewProviderDocumentObject.h"
 #include "propertyeditor/PropertyEditor.h"
 
+
 using namespace std;
 using namespace Gui;
 using namespace Gui::DockWnd;
@@ -76,7 +66,7 @@ static ParameterGrp::handle _GetParam() {
  * in two tabs.
  */
 PropertyView::PropertyView(QWidget *parent)
-  : QWidget(parent),SelectionObserver(false,0)
+  : QWidget(parent), SelectionObserver(false, ResolveMode::NoResolve)
 {
     QGridLayout* pLayout = new QGridLayout( this );
     pLayout->setSpacing(0);
@@ -111,7 +101,7 @@ PropertyView::PropertyView(QWidget *parent)
 
     this->connectPropData =
     App::GetApplication().signalChangedObject.connect(boost::bind
-        (&PropertyView::slotChangePropertyData, this, bp::_1, bp::_2));
+        (&PropertyView::slotChangePropertyData, this, bp::_2));
     this->connectPropView =
     Gui::Application::Instance->signalChangedObject.connect(boost::bind
         (&PropertyView::slotChangePropertyView, this, bp::_1, bp::_2));
@@ -142,6 +132,8 @@ PropertyView::PropertyView(QWidget *parent)
     this->connectDelObject =
         App::GetApplication().signalDeletedObject.connect(
                 boost::bind(&PropertyView::slotDeletedObject, this, bp::_1));
+    this->connectChangedDocument = App::GetApplication().signalChangedDocument.connect(
+            boost::bind(&PropertyView::slotChangePropertyData, this, bp::_2));
 }
 
 PropertyView::~PropertyView()
@@ -157,6 +149,7 @@ PropertyView::~PropertyView()
     this->connectDelDocument.disconnect();
     this->connectDelObject.disconnect();
     this->connectDelViewObject.disconnect();
+    this->connectChangedDocument.disconnect();
 }
 
 static bool _ShowAll;
@@ -169,8 +162,11 @@ void PropertyView::setShowAll(bool enable) {
     if(_ShowAll != enable) {
         _ShowAll = enable;
         for(auto view : getMainWindow()->findChildren<PropertyView*>()) {
-            if(view->isVisible())
+            if(view->isVisible()) {
+                view->propertyEditorData->buildUp();
+                view->propertyEditorView->buildUp();
                 view->onTimer();
+            }
         }
     }
 }
@@ -187,7 +183,7 @@ void PropertyView::hideEvent(QHideEvent *ev) {
 
 void PropertyView::showEvent(QShowEvent *ev) {
     this->attachSelection();
-    this->timer->start(100);
+    this->timer->start(ViewParams::instance()->getPropertyViewTimer());
     QWidget::showEvent(ev);
 }
 
@@ -209,14 +205,20 @@ void PropertyView::slotRollback() {
     clearPropertyItemSelection();
 }
 
-void PropertyView::slotChangePropertyData(const App::DocumentObject&, const App::Property& prop)
+void PropertyView::slotChangePropertyData(const App::Property& prop)
 {
-    propertyEditorData->updateProperty(prop);
+    if (propertyEditorData->propOwners.count(prop.getContainer())) {
+        propertyEditorData->updateProperty(prop);
+        timer->start(ViewParams::instance()->getPropertyViewTimer());
+    }
 }
 
 void PropertyView::slotChangePropertyView(const Gui::ViewProvider&, const App::Property& prop)
 {
-    propertyEditorView->updateProperty(prop);
+    if (propertyEditorView->propOwners.count(prop.getContainer())) {
+        propertyEditorView->updateProperty(prop);
+        timer->start(ViewParams::instance()->getPropertyViewTimer());
+    }
 }
 
 bool PropertyView::isPropertyHidden(const App::Property *prop) {
@@ -229,10 +231,11 @@ void PropertyView::slotAppendDynamicProperty(const App::Property& prop)
     if (isPropertyHidden(&prop))
         return;
 
-    if (propertyEditorData->appendProperty(prop)
-            || propertyEditorView->appendProperty(prop))
+    App::PropertyContainer* parent = prop.getContainer();
+    if (propertyEditorData->propOwners.count(parent)
+            || propertyEditorView->propOwners.count(parent))
     {
-        timer->start(100);
+        timer->start(ViewParams::instance()->getPropertyViewTimer());
     }
 }
 
@@ -243,34 +246,17 @@ void PropertyView::slotRemoveDynamicProperty(const App::Property& prop)
         propertyEditorData->removeProperty(prop);
     else if(propertyEditorView->propOwners.count(parent))
         propertyEditorView->removeProperty(prop);
+    else
+        return;
+    timer->start(ViewParams::instance()->getPropertyViewTimer());
 }
 
 void PropertyView::slotChangePropertyEditor(const App::Document &, const App::Property& prop)
 {
     App::PropertyContainer* parent = prop.getContainer();
-    Gui::PropertyEditor::PropertyEditor* editor = nullptr;
-
-    if (parent && propertyEditorData->propOwners.count(parent))
-        editor = propertyEditorData;
-    else if (parent && propertyEditorView->propOwners.count(parent))
-        editor = propertyEditorView;
-    else
-        return;
-
-    if(showAll() || isPropertyHidden(&prop)) {
-        editor->updateEditorMode(prop);
-        return;
-    }
-    for(auto &v : editor->propList) {
-        for(auto p : v.second)
-            if(p == &prop) {
-                editor->updateEditorMode(prop);
-                return;
-            }
-    }
-    // The property is not in the list, probably because it is hidden before.
-    // So perform a full update.
-    timer->start(50);
+    if (propertyEditorData->propOwners.count(parent)
+            || propertyEditorView->propOwners.count(parent))
+        timer->start(ViewParams::instance()->getPropertyViewTimer());
 }
 
 void PropertyView::slotDeleteDocument(const Gui::Document &doc) {
@@ -278,7 +264,7 @@ void PropertyView::slotDeleteDocument(const Gui::Document &doc) {
         propertyEditorView->buildUp();
         propertyEditorData->buildUp();
         clearPropertyItemSelection();
-        timer->start(50);
+        timer->start(ViewParams::instance()->getPropertyViewTimer());
     }
 }
 
@@ -287,7 +273,7 @@ void PropertyView::slotDeletedViewObject(const Gui::ViewProvider &vp) {
         propertyEditorView->buildUp();
         propertyEditorData->buildUp();
         clearPropertyItemSelection();
-        timer->start(50);
+        timer->start(ViewParams::instance()->getPropertyViewTimer());
     }
 }
 
@@ -296,7 +282,7 @@ void PropertyView::slotDeletedObject(const App::DocumentObject &obj) {
         propertyEditorView->buildUp();
         propertyEditorData->buildUp();
         clearPropertyItemSelection();
-        timer->start(50);
+        timer->start(ViewParams::instance()->getPropertyViewTimer());
     }
 }
 
@@ -312,7 +298,7 @@ void PropertyView::checkEnable(const char *doc) {
     }
     // check if at least one selected object is part of the active document
     setEnabled(!Selection().hasSelection()
-            || Selection().hasSelection(doc,false));
+            || Selection().hasSelection(doc, ResolveMode::NoResolve));
 }
 
 struct PropertyView::PropInfo
@@ -341,23 +327,28 @@ void PropertyView::onSelectionChanged(const SelectionChanges& msg)
         return;
 
     // clear the properties.
-    timer->start(50);
+    timer->start(ViewParams::instance()->getPropertyViewTimer());
 }
 
 void PropertyView::onTimer() {
 
-    propertyEditorData->buildUp();
-    propertyEditorView->buildUp();
-    clearPropertyItemSelection();
     timer->stop();
 
-    if(!this->isConnectionAttached())
+    if(!this->isSelectionAttached()) {
+        propertyEditorData->buildUp();
+        propertyEditorView->buildUp();
+        clearPropertyItemSelection();
         return;
+    }
 
     if(!Gui::Selection().hasSelection()) {
         auto gdoc = TreeWidget::selectedDocument();
-        if(!gdoc || !gdoc->getDocument())
+        if(!gdoc || !gdoc->getDocument()) {
+            propertyEditorData->buildUp();
+            propertyEditorView->buildUp();
+            clearPropertyItemSelection();
             return;
+        }
 
         PropertyModel::PropertyList docProps;
 
@@ -378,7 +369,7 @@ void PropertyView::onTimer() {
     std::vector<PropInfo> propDataMap;
     std::vector<PropInfo> propViewMap;
     bool checkLink = true;
-    ViewProviderDocumentObject *vpLast = 0;
+    ViewProviderDocumentObject *vpLast = nullptr;
     auto sels = Gui::Selection().getSelectionEx("*");
     for(auto &sel : sels) {
         App::DocumentObject *ob = sel.getObject();
