@@ -20,15 +20,12 @@
  *                                                                         *
  ***************************************************************************/
 
-
-
 #ifndef GUI_DOCKWND_PROPERTYVIEW_H
 #define GUI_DOCKWND_PROPERTYVIEW_H
 
-
 #include "DockWindow.h"
 #include "Selection.h"
-#include <boost_signals2.hpp>
+
 
 class QPixmap;
 class QTabWidget;
@@ -59,7 +56,7 @@ class PropertyView : public QWidget, public Gui::SelectionObserver
     Q_OBJECT
 
 public:
-    PropertyView(QWidget *parent=0);
+    PropertyView(QWidget *parent=nullptr);
     virtual ~PropertyView();
 
     Gui::PropertyEditor::PropertyEditor* propertyEditorView;
@@ -81,7 +78,7 @@ protected:
 
 private:
     void onSelectionChanged(const SelectionChanges& msg) override;
-    void slotChangePropertyData(const App::DocumentObject&, const App::Property&);
+    void slotChangePropertyData(const App::Property&);
     void slotChangePropertyView(const Gui::ViewProvider&, const App::Property&);
     void slotAppendDynamicProperty(const App::Property&);
     void slotRemoveDynamicProperty(const App::Property&);
@@ -92,7 +89,7 @@ private:
     void slotDeletedViewObject(const Gui::ViewProvider&);
     void slotDeletedObject(const App::DocumentObject&);
 
-    void checkEnable(const char *doc = 0);
+    void checkEnable(const char *doc = nullptr);
 
 private:
     struct PropInfo;
@@ -109,6 +106,7 @@ private:
     Connection connectDelDocument;
     Connection connectDelObject;
     Connection connectDelViewObject;
+    Connection connectChangedDocument;
     QTabWidget* tabs;
     QTimer* timer;
 };
@@ -122,7 +120,7 @@ class PropertyDockView : public Gui::DockWindow
     Q_OBJECT
 
 public:
-    PropertyDockView(Gui::Document*  pcDocument, QWidget *parent=0);
+    PropertyDockView(Gui::Document*  pcDocument, QWidget *parent=nullptr);
     virtual ~PropertyDockView();
 };
 
