@@ -20,40 +20,31 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 #ifndef _PreComp_
 # include <QApplication>
 # include <QClipboard>
 # include <QDockWidget>
-# include <QGridLayout>
-# include <QHBoxLayout>
 # include <QKeyEvent>
 # include <QMenu>
 # include <QMessageBox>
-# include <QPushButton>
-# include <QSpacerItem>
+# include <QMimeData>
 # include <QTextCursor>
 # include <QTextDocumentFragment>
 # include <QTextStream>
 # include <QUrl>
-# include <QMimeData>
 #endif
 
+#include <Base/Interpreter.h>
+
 #include "PythonConsole.h"
 #include "PythonConsolePy.h"
-#include "CallTips.h"
 #include "Application.h"
-#include "Action.h"
-#include "Command.h"
-#include "DlgEditorImp.h"
+#include "CallTips.h"
 #include "FileDialog.h"
 #include "MainWindow.h"
 #include "Tools.h"
 
-#include <Base/Interpreter.h>
-#include <Base/Exception.h>
-#include <CXX/Exception.hxx>
 
 using namespace Gui;
 
@@ -97,15 +88,16 @@ struct PythonConsoleP
     QStringList statements;
     bool interactive;
     QMap<QString, QColor> colormap; // Color map
+    ParameterGrp::handle hGrpSettings;
     PythonConsoleP()
     {
         type = Normal;
-        _stdoutPy = 0;
-        _stderrPy = 0;
-        _stdinPy = 0;
-        _stdin = 0;
-        interpreter = 0;
-        callTipsList = 0;
+        _stdoutPy = nullptr;
+        _stderrPy = nullptr;
+        _stdinPy = nullptr;
+        _stdin = nullptr;
+        interpreter = nullptr;
+        callTipsList = nullptr;
         interactive = false;
         historyFile = QString::fromUtf8((App::Application::getUserAppDataDir() + "PythonHistory.log").c_str());
         colormap[QLatin1String("Text")] = Qt::black;
@@ -171,17 +163,9 @@ void InteractiveInterpreter::setPrompt()
     Base::PyGILStateLocker lock;
     d->sysmodule = PyImport_ImportModule("sys");
     if (!PyObject_HasAttrString(d->sysmodule, "ps1"))
-#if PY_MAJOR_VERSION >= 3
         PyObject_SetAttrString(d->sysmodule, "ps1", PyUnicode_FromString(">>> "));
-#else
-        PyObject_SetAttrString(d->sysmodule, "ps1", PyString_FromString(">>> "));
-#endif
     if (!PyObject_HasAttrString(d->sysmodule, "ps2"))
-#if PY_MAJOR_VERSION >= 3
         PyObject_SetAttrString(d->sysmodule, "ps2", PyUnicode_FromString("... "));
-#else
-        PyObject_SetAttrString(d->sysmodule, "ps2", PyString_FromString("... "));
-#endif
 }
 
 /**
@@ -206,8 +190,8 @@ PyObject* InteractiveInterpreter::compile(const char* source) const
     PyObject* eval = PyObject_CallObject(func,args);  // must decref later
 #endif
 
-    Py_DECREF(args);
-    Py_DECREF(func);
+    Py_XDECREF(args);
+    Py_XDECREF(func);
 
     if (eval){
         return eval;
@@ -217,7 +201,7 @@ PyObject* InteractiveInterpreter::compile(const char* source) const
     }
 
     // can never happen
-    return 0;
+    return nullptr;
 }
 
 /**
@@ -289,7 +273,7 @@ bool InteractiveInterpreter::runSource(const char* source) const
         // message we don't need.
         PyObject *errobj, *errdata, *errtraceback;
         PyErr_Fetch(&errobj, &errdata, &errtraceback);
-        PyErr_Restore(errobj, errdata, 0);
+        PyErr_Restore(errobj, errdata, nullptr);
         // print error message
         if (PyErr_Occurred()) PyErr_Print();
             return false;
@@ -316,18 +300,14 @@ void InteractiveInterpreter::runCode(PyCodeObject* code) const
     Base::PyGILStateLocker lock;
     PyObject *module, *dict, *presult;           /* "exec code in d, d" */
     module = PyImport_AddModule("__main__");     /* get module, init python */
-    if (module == NULL)
+    if (module == nullptr)
         throw Base::PyException();                 /* not incref'd */
     dict = PyModule_GetDict(module);             /* get dict namespace */
-    if (dict == NULL)
+    if (dict == nullptr)
         throw Base::PyException();                 /* not incref'd */
 
     // It seems that the return value is always 'None' or Null
-#if PY_MAJOR_VERSION >= 3
     presult = PyEval_EvalCode((PyObject*)code, dict, dict); /* run compiled bytecode */
-#else
-    presult = PyEval_EvalCode(code, dict, dict); /* run compiled bytecode */
-#endif
     Py_XDECREF(code);                            /* decref the code object */
     if (!presult) {
         if (PyErr_ExceptionMatches(PyExc_SystemExit)) {
@@ -359,11 +339,7 @@ void InteractiveInterpreter::runCode(PyCodeObject* code) const
                     }
 
                     std::string err = str.str();
-#if PY_MAJOR_VERSION >= 3
                     errdata = PyUnicode_FromString(err.c_str());
-#else
-                    errdata = PyString_FromString(err.c_str());
-#endif
                 }
             }
             PyErr_Restore(errobj, errdata, errtraceback);
@@ -380,11 +356,10 @@ void InteractiveInterpreter::runCode(PyCodeObject* code) const
  */
 bool InteractiveInterpreter::push(const char* line)
 {
-    d->buffer.append(QString::fromLatin1(line));
+    d->buffer.append(QString::fromUtf8(line));
     QString source = d->buffer.join(QLatin1String("\n"));
     try {
-        // Source is already UTF-8, so we can use toLatin1()
-        bool more = runSource(source.toLatin1());
+        bool more = runSource(source.toUtf8());
         if (!more)
             d->buffer.clear();
         return more;
@@ -402,7 +377,7 @@ bool InteractiveInterpreter::push(const char* line)
     return false;
 }
 
-bool InteractiveInterpreter::hasPendingInput( void ) const
+bool InteractiveInterpreter::hasPendingInput( ) const
 {
     return (!d->buffer.isEmpty());
 }
@@ -428,7 +403,7 @@ void InteractiveInterpreter::clearBuffer()
  *  Constructs a PythonConsole which is a child of 'parent'.
  */
 PythonConsole::PythonConsole(QWidget *parent)
-  : TextEdit(parent), WindowParameter( "Editor" ), _sourceDrain(NULL)
+  : TextEdit(parent), WindowParameter( "Editor" ), _sourceDrain(nullptr)
 {
     d = new PythonConsoleP();
     d->interactive = false;
@@ -447,7 +422,8 @@ PythonConsole::PythonConsole(QWidget *parent)
 
     // create the window for call tips
     d->callTipsList = new CallTipsList(this);
-    d->callTipsList->setFrameStyle(QFrame::Box|QFrame::Raised);
+    d->callTipsList->setFrameStyle(QFrame::Box);
+    d->callTipsList->setFrameShadow(QFrame::Raised);
     d->callTipsList->setLineWidth(2);
     installEventFilter(d->callTipsList);
     viewport()->installEventFilter(d->callTipsList);
@@ -459,9 +435,13 @@ PythonConsole::PythonConsole(QWidget *parent)
 
     // set colors and font from settings
     ParameterGrp::handle hPrefGrp = getWindowParameter();
-    hPrefGrp->Attach( this );
+    hPrefGrp->Attach(this);
     hPrefGrp->NotifyAll();
 
+    d->hGrpSettings = WindowParameter::getDefaultParameter()->GetGroup("PythonConsole");
+    d->hGrpSettings->Attach(this);
+    d->hGrpSettings->NotifyAll();
+
     // disable undo/redo stuff
     setUndoRedoEnabled( false );
     setAcceptDrops( true );
@@ -474,13 +454,8 @@ PythonConsole::PythonConsole(QWidget *parent)
     d->_stdin  = PySys_GetObject("stdin");
     PySys_SetObject("stdin", d->_stdinPy);
 
-#if PY_MAJOR_VERSION >= 3
     const char* version  = PyUnicode_AsUTF8(PySys_GetObject("version"));
     const char* platform = PyUnicode_AsUTF8(PySys_GetObject("platform"));
-#else
-    const char* version  = PyString_AsString(PySys_GetObject("version"));
-    const char* platform = PyString_AsString(PySys_GetObject("platform"));
-#endif
     d->info = QString::fromLatin1("Python %1 on %2\n"
     "Type 'help', 'copyright', 'credits' or 'license' for more information.")
     .arg(QString::fromLatin1(version), QString::fromLatin1(platform));
@@ -494,7 +469,8 @@ PythonConsole::~PythonConsole()
 {
     saveHistory();
     Base::PyGILStateLocker lock;
-    getWindowParameter()->Detach( this );
+    d->hGrpSettings->Detach(this);
+    getWindowParameter()->Detach(this);
     delete pythonSyntax;
     Py_XDECREF(d->_stdoutPy);
     Py_XDECREF(d->_stderrPy);
@@ -504,23 +480,21 @@ PythonConsole::~PythonConsole()
 }
 
 /** Set new font and colors according to the parameters. */
-void PythonConsole::OnChange( Base::Subject<const char*> &rCaller,const char* sReason )
+void PythonConsole::OnChange(Base::Subject<const char*> &rCaller, const char* sReason )
 {
-    Q_UNUSED(rCaller);
-    ParameterGrp::handle hPrefGrp = getWindowParameter();
+    const auto & rGrp = static_cast<ParameterGrp &>(rCaller);
 
-    bool pythonWordWrap = App::GetApplication().GetUserParameter().
-        GetGroup("BaseApp")->GetGroup("Preferences")->GetGroup("General")->GetBool("PythonWordWrap", true);
-
-    if (pythonWordWrap) {
-      this->setWordWrapMode(QTextOption::WrapAtWordBoundaryOrAnywhere);
-    } else {
-      this->setWordWrapMode(QTextOption::NoWrap);
+    if (strcmp(sReason, "PythonWordWrap") == 0) {
+        bool pythonWordWrap = rGrp.GetBool("PythonWordWrap", true);
+        if (pythonWordWrap)
+            setWordWrapMode(QTextOption::WrapAtWordBoundaryOrAnywhere);
+        else
+            setWordWrapMode(QTextOption::NoWrap);
     }
 
     if (strcmp(sReason, "FontSize") == 0 || strcmp(sReason, "Font") == 0) {
-        int fontSize = hPrefGrp->GetInt("FontSize", 10);
-        QString fontFamily = QString::fromLatin1(hPrefGrp->GetASCII("Font", "Courier").c_str());
+        int fontSize = rGrp.GetInt("FontSize", 10);
+        QString fontFamily = QString::fromLatin1(rGrp.GetASCII("Font", "Courier").c_str());
 
         QFont font(fontFamily, fontSize);
         setFont(font);
@@ -531,18 +505,27 @@ void PythonConsole::OnChange( Base::Subject<const char*> &rCaller,const char* sR
 #else
         setTabStopDistance(width);
 #endif
-    } else {
+    }
+    else {
         QMap<QString, QColor>::ConstIterator it = d->colormap.find(QString::fromLatin1(sReason));
         if (it != d->colormap.end()) {
             QColor color = it.value();
             unsigned int col = (color.red() << 24) | (color.green() << 16) | (color.blue() << 8);
             unsigned long value = static_cast<unsigned long>(col);
-            value = hPrefGrp->GetUnsigned(sReason, value);
+            value = rGrp.GetUnsigned(sReason, value);
             col = static_cast<unsigned int>(value);
             color.setRgb((col>>24)&0xff, (col>>16)&0xff, (col>>8)&0xff);
             pythonSyntax->setColor(QString::fromLatin1(sReason), color);
         }
     }
+
+    if (strcmp(sReason, "PythonBlockCursor") == 0) {
+        bool block = rGrp.GetBool("PythonBlockCursor", false);
+        if (block)
+            setCursorWidth(QFontMetrics(font()).averageCharWidth());
+        else
+            setCursorWidth(1);
+    }
 }
 
 /**
@@ -837,12 +820,11 @@ void PythonConsole::runSource(const QString& line)
         setFocus(); // if focus was lost
     }
     catch (const Base::SystemExitException&) {
-#if PY_MAJOR_VERSION >= 3
         // In Python the exception must be cleared because when the message box below appears
         // callable Python objects can be invoked and due to a failing assert the application
         // will be aborted.
         PyErr_Clear();
-#endif
+
         ParameterGrp::handle hPrefGrp = getWindowParameter();
         bool check = hPrefGrp->GetBool("CheckSystemExit",true);
         int ret = QMessageBox::Yes;
@@ -963,7 +945,7 @@ void PythonConsole::changeEvent(QEvent *e)
 
 void PythonConsole::mouseReleaseEvent( QMouseEvent *e )
 {
-  if (e->button() == Qt::MidButton && e->spontaneous())
+  if (e->button() == Qt::MiddleButton && e->spontaneous())
   {
     // on Linux-like systems the middle mouse button is typically connected to a paste operation
     // which will insert some text at the mouse position
@@ -1100,7 +1082,7 @@ void PythonConsole::insertFromMimeData (const QMimeData * source)
     }
 }
 
-QTextCursor PythonConsole::inputBegin(void) const
+QTextCursor PythonConsole::inputBegin() const
 {
     // construct cursor at begin of input line ...
     QTextCursor inputLineBegin(this->textCursor());
@@ -1273,10 +1255,7 @@ void PythonConsole::contextMenuEvent ( QContextMenuEvent * e )
     QAction *a;
     bool mayPasteHere = cursorBeyond( this->textCursor(), this->inputBegin() );
 
-    ParameterGrp::handle hGrp = App::GetApplication().GetUserParameter().
-        GetGroup("BaseApp")->GetGroup("Preferences")->GetGroup("General");
-
-    a = menu.addAction(tr("&Copy"), this, SLOT(copy()), Qt::CTRL+Qt::Key_C);
+    a = menu.addAction(tr("&Copy"), this, SLOT(copy()), QKeySequence(QString::fromLatin1("CTRL+C")));
     a->setEnabled(textCursor().hasSelection());
 
     a = menu.addAction(tr("&Copy command"), this, SLOT(onCopyCommand()));
@@ -1291,15 +1270,15 @@ void PythonConsole::contextMenuEvent ( QContextMenuEvent * e )
     QAction* saveh = menu.addAction(tr("Save history"));
     saveh->setToolTip(tr("Saves Python history across %1 sessions").arg(qApp->applicationName()));
     saveh->setCheckable(true);
-    saveh->setChecked(hGrp->GetBool("SavePythonHistory", false));
+    saveh->setChecked(d->hGrpSettings->GetBool("SavePythonHistory", false));
 
     menu.addSeparator();
 
-    a = menu.addAction(tr("&Paste"), this, SLOT(paste()), Qt::CTRL+Qt::Key_V);
+    a = menu.addAction(tr("&Paste"), this, SLOT(paste()), QKeySequence(QString::fromLatin1("CTRL+V")));
     const QMimeData *md = QApplication::clipboard()->mimeData();
     a->setEnabled( mayPasteHere && md && canInsertFromMimeData(md));
 
-    a = menu.addAction(tr("Select All"), this, SLOT(selectAll()), Qt::CTRL+Qt::Key_A);
+    a = menu.addAction(tr("Select All"), this, SLOT(selectAll()), QKeySequence(QString::fromLatin1("CTRL+A")));
     a->setEnabled(!document()->isEmpty());
 
     a = menu.addAction(tr("Clear console"), this, SLOT(onClearConsole()));
@@ -1312,25 +1291,13 @@ void PythonConsole::contextMenuEvent ( QContextMenuEvent * e )
     QAction* wrap = menu.addAction(tr("Word wrap"));
     wrap->setCheckable(true);
 
-    if (hGrp->GetBool("PythonWordWrap", true)) {
-        wrap->setChecked(true);
-        this->setWordWrapMode(QTextOption::WrapAtWordBoundaryOrAnywhere);
-    } else {
-        wrap->setChecked(false);
-        this->setWordWrapMode(QTextOption::NoWrap);
-    }
-
+    wrap->setChecked(d->hGrpSettings->GetBool("PythonWordWrap", true));
     QAction* exec = menu.exec(e->globalPos());
     if (exec == wrap) {
-        if (wrap->isChecked()) {
-            this->setWordWrapMode(QTextOption::WrapAtWordBoundaryOrAnywhere);
-            hGrp->SetBool("PythonWordWrap", true);
-        } else {
-            this->setWordWrapMode(QTextOption::NoWrap);
-            hGrp->SetBool("PythonWordWrap", false);
-        }
-    } else if (exec == saveh) {
-        hGrp->SetBool("SavePythonHistory", saveh->isChecked());
+        d->hGrpSettings->SetBool("PythonWordWrap", wrap->isChecked());
+    }
+    else if (exec == saveh) {
+        d->hGrpSettings->SetBool("SavePythonHistory", saveh->isChecked());
     }
 }
 
@@ -1394,7 +1361,7 @@ void PythonConsole::onCopyCommand()
     d->type = PythonConsoleP::Normal;
 }
 
-QString PythonConsole::readline( void )
+QString PythonConsole::readline( )
 {
     QEventLoop loop;
     // output is set to the current prompt which we need to extract
@@ -1408,7 +1375,7 @@ QString PythonConsole::readline( void )
     // application is about to quit
     if (loop.exec() != 0)
       { PyErr_SetInterrupt(); }            //< send SIGINT to python
-    this->_sourceDrain = NULL;             //< disable source drain
+    this->_sourceDrain = nullptr;             //< disable source drain
     return inputBuffer.append(QChar::fromLatin1('\n')); //< pass a newline here, since the readline-caller may need it!
 }
 
@@ -1420,9 +1387,8 @@ void PythonConsole::loadHistory() const
     // only load contents if history is empty, to not overwrite anything
     if (!d->history.isEmpty())
         return;
-    ParameterGrp::handle hGrp = App::GetApplication().GetUserParameter().
-        GetGroup("BaseApp")->GetGroup("Preferences")->GetGroup("General");
-    if (!hGrp->GetBool("SavePythonHistory", false))
+
+    if (!d->hGrpSettings->GetBool("SavePythonHistory", false))
         return;
     QFile f(d->historyFile);
     if (f.open(QIODevice::ReadOnly | QIODevice::Text)) {
@@ -1445,9 +1411,7 @@ void PythonConsole::saveHistory() const
 {
     if (d->history.isEmpty())
         return;
-    ParameterGrp::handle hGrp = App::GetApplication().GetUserParameter().
-        GetGroup("BaseApp")->GetGroup("Preferences")->GetGroup("General");
-    if (!hGrp->GetBool("SavePythonHistory", false))
+    if (!d->hGrpSettings->GetBool("SavePythonHistory", false))
         return;
     QFile f(d->historyFile);
     if (f.open(QIODevice::WriteOnly)) {
@@ -1610,7 +1574,7 @@ const QStringList& ConsoleHistory::values() const
 /**
  * restart resets the history access to the latest item.
  */
-void ConsoleHistory::restart( void )
+void ConsoleHistory::restart( )
 {
     _it = _history.end();
 }
@@ -1620,7 +1584,7 @@ void ConsoleHistory::restart( void )
  * Note: with simply remembering a start index, it does not work to nest scratch regions.
  * However, just replace the index keeping by a stack - in case this is be a concern.
  */
-void ConsoleHistory::markScratch( void )
+void ConsoleHistory::markScratch( )
 {
     _scratchBegin = _history.length();
 }
@@ -1628,7 +1592,7 @@ void ConsoleHistory::markScratch( void )
 /**
  * doScratch removes the tail of the history list, starting from the index marked lately.
  */
-void ConsoleHistory::doScratch( void )
+void ConsoleHistory::doScratch( )
 {
     if (_scratchBegin < _history.length())
     {
