@@ -52,58 +52,45 @@
 #pragma warning(disable : 4267)
 #endif
 
-#include <assert.h>
+#include <cassert>
 
-#include <Quarter/QuarterWidget.h>
-#include <Quarter/eventhandlers/EventFilter.h>
-#include <Quarter/eventhandlers/DragDropHandler.h>
-
-#include <QtCore/QEvent>
-#include <QtCore/QDebug>
-#include <QtCore/QFile>
 #include <QAction>
 #include <QApplication>
+#include <QDebug>
+#include <QEvent>
+#include <QFile>
+#include <QGuiApplication>
+#include <QMetaObject>
+#include <QOpenGLDebugLogger>
+#include <QOpenGLDebugMessage>
 #include <QPaintEvent>
 #include <QResizeEvent>
+#include <QWindow>
 
-#if defined(HAVE_QT5_OPENGL)
-#include <QOpenGLDebugMessage>
-#include <QOpenGLDebugLogger>
-#endif
-
+#include <Inventor/C/basic.h>
 #if COIN_MAJOR_VERSION >= 4
 #include <Inventor/SbByteBuffer.h>
 #endif
 
-#include <Inventor/SbViewportRegion.h>
-#include <Inventor/system/gl.h>
-#include <Inventor/events/SoEvents.h>
-#include <Inventor/nodes/SoNode.h>
-#include <Inventor/nodes/SoCamera.h>
-#include <Inventor/nodes/SoSeparator.h>
-#include <Inventor/nodes/SoDirectionalLight.h>
-#include <Inventor/nodes/SoPerspectiveCamera.h>
 #include <Inventor/SbColor.h>
-#include <Inventor/sensors/SoSensorManager.h>
+#include <Inventor/SbViewportRegion.h>
 #include <Inventor/SoDB.h>
-
-#include <Inventor/SbBasic.h>
-#include <Inventor/SoRenderManager.h>
 #include <Inventor/SoEventManager.h>
+#include <Inventor/SoRenderManager.h>
+#include <Inventor/nodes/SoCamera.h>
+#include <Inventor/nodes/SoDirectionalLight.h>
+#include <Inventor/nodes/SoNode.h>
+#include <Inventor/nodes/SoPerspectiveCamera.h>
+#include <Inventor/nodes/SoSeparator.h>
 #include <Inventor/scxml/ScXML.h>
 #include <Inventor/scxml/SoScXMLStateMachine.h>
 
-#include <ctime>
-
+#include "QuarterWidget.h"
 #include "InteractionMode.h"
-#include "QuarterWidgetP.h"
 #include "QuarterP.h"
-
-#if QT_VERSION >= 0x050000
-#include <QWindow>
-#include <QGuiApplication>
-#include <QMetaObject>
-#endif
+#include "QuarterWidgetP.h"
+#include "eventhandlers/EventFilter.h"
+#include "eventhandlers/DragDropHandler.h"
 
 
 using namespace SIM::Coin3D::Quarter;
@@ -149,12 +136,11 @@ using namespace SIM::Coin3D::Quarter;
 #endif
 
 //We need to avoid buffer swapping when initializing a QPainter on this widget
-#if defined(HAVE_QT5_OPENGL)
 class CustomGLWidget : public QOpenGLWidget {
 public:
     QSurfaceFormat myFormat;
 
-    CustomGLWidget(const QSurfaceFormat& format, QWidget* parent = 0, const QOpenGLWidget* shareWidget = 0, Qt::WindowFlags f = Qt::WindowFlags())
+    CustomGLWidget(const QSurfaceFormat& format, QWidget* parent = nullptr, const QOpenGLWidget* shareWidget = nullptr, Qt::WindowFlags f = Qt::WindowFlags())
      : QOpenGLWidget(parent, f), myFormat(format)
     {
         Q_UNUSED(shareWidget);
@@ -209,13 +195,11 @@ public:
     }
     void aboutToDestroyGLContext()
     {
-#if QT_VERSION >= 0x050900
         // With Qt 5.9 a signal is emitted while the QuarterWidget is being destroyed.
         // At this state its type is a QWidget, not a QuarterWidget any more.
         QuarterWidget* qw = qobject_cast<QuarterWidget*>(parent());
         if (!qw)
             return;
-#endif
         QMetaObject::invokeMethod(parent(), "aboutToDestroyGLContext",
             Qt::DirectConnection,
             QGenericReturnArgument());
@@ -251,16 +235,6 @@ public:
         update(); // fixes flickering on some systems
     }
 };
-#else
-class CustomGLWidget : public QGLWidget {
-public:
-    CustomGLWidget(const QGLFormat& fo, QWidget* parent = 0, const QGLWidget* shareWidget = 0, Qt::WindowFlags f = 0)
-     : QGLWidget(fo, parent, shareWidget, f)
-    {
-         setAutoBufferSwap(false);
-    }
-};
-#endif
 
 /*! constructor */
 QuarterWidget::QuarterWidget(const QtGLFormat & format, QWidget * parent, const QtGLWidget * sharewidget, Qt::WindowFlags f)
@@ -312,7 +286,7 @@ QuarterWidget::constructor(const QtGLFormat & format, const QtGLWidget * sharewi
   PRIVATE(this)->eventfilter = new EventFilter(this);
   PRIVATE(this)->interactionmode = new InteractionMode(this);
 
-  PRIVATE(this)->currentStateMachine = NULL;
+  PRIVATE(this)->currentStateMachine = nullptr;
 
   PRIVATE(this)->headlight = new SoDirectionalLight;
   PRIVATE(this)->headlight->ref();
@@ -344,7 +318,6 @@ QuarterWidget::constructor(const QtGLFormat & format, const QtGLWidget * sharewi
 void
 QuarterWidget::replaceViewport()
 {
-#if defined(HAVE_QT5_OPENGL)
   CustomGLWidget* oldvp = static_cast<CustomGLWidget*>(viewport());
   CustomGLWidget* newvp = new CustomGLWidget(oldvp->myFormat, this);
   PRIVATE(this)->replaceGLWidget(newvp);
@@ -352,7 +325,6 @@ QuarterWidget::replaceViewport()
 
   setAutoFillBackground(false);
   viewport()->setAutoFillBackground(false);
-#endif
 }
 
 void
@@ -368,10 +340,10 @@ QuarterWidget::~QuarterWidget()
     delete PRIVATE(this)->currentStateMachine;
   }
   PRIVATE(this)->headlight->unref();
-  PRIVATE(this)->headlight = NULL;
-  this->setSceneGraph(NULL);
-  this->setSoRenderManager(NULL);
-  this->setSoEventManager(NULL);
+  PRIVATE(this)->headlight = nullptr;
+  this->setSceneGraph(nullptr);
+  this->setSoRenderManager(nullptr);
+  this->setSoEventManager(nullptr);
   delete PRIVATE(this)->eventfilter;
   delete PRIVATE(this);
 }
@@ -422,7 +394,7 @@ QuarterWidget::setHeadlightEnabled(bool onoff)
   Returns true if the headlight is on, false if it is off
 */
 bool
-QuarterWidget::headlightEnabled(void) const
+QuarterWidget::headlightEnabled() const
 {
   return PRIVATE(this)->headlight->on.getValue();
 }
@@ -431,7 +403,7 @@ QuarterWidget::headlightEnabled(void) const
   Returns the light used for the headlight.
 */
 SoDirectionalLight *
-QuarterWidget::getHeadlight(void) const
+QuarterWidget::getHeadlight() const
 {
   return PRIVATE(this)->headlight;
 }
@@ -456,7 +428,7 @@ QuarterWidget::setClearZBuffer(bool onoff)
   Returns true if the z buffer is cleared before rendering.
 */
 bool
-QuarterWidget::clearZBuffer(void) const
+QuarterWidget::clearZBuffer() const
 {
   return PRIVATE(this)->clearzbuffer;
 }
@@ -481,7 +453,7 @@ QuarterWidget::setClearWindow(bool onoff)
   Returns true if the rendering buffer is cleared before rendering.
 */
 bool
-QuarterWidget::clearWindow(void) const
+QuarterWidget::clearWindow() const
 {
   return PRIVATE(this)->clearwindow;
 }
@@ -507,7 +479,7 @@ QuarterWidget::setInteractionModeEnabled(bool onoff)
   Returns true if interaction mode is enabled, false otherwise.
  */
 bool
-QuarterWidget::interactionModeEnabled(void) const
+QuarterWidget::interactionModeEnabled() const
 {
   return PRIVATE(this)->interactionmode->enabled();
 }
@@ -531,7 +503,7 @@ QuarterWidget::setInteractionModeOn(bool onoff)
   Returns true if interaction mode is on.
  */
 bool
-QuarterWidget::interactionModeOn(void) const
+QuarterWidget::interactionModeOn() const
 {
   return PRIVATE(this)->interactionmode->on();
 }
@@ -540,7 +512,7 @@ QuarterWidget::interactionModeOn(void) const
   Returns the Coin cache context id for this widget.
 */
 uint32_t
-QuarterWidget::getCacheContextId(void) const
+QuarterWidget::getCacheContextId() const
 {
   return PRIVATE(this)->getCacheContextId();
 }
@@ -566,7 +538,7 @@ QuarterWidget::setTransparencyType(TransparencyType type)
   \retval The current \ref TransparencyType
 */
 QuarterWidget::TransparencyType
-QuarterWidget::transparencyType(void) const
+QuarterWidget::transparencyType() const
 {
   assert(PRIVATE(this)->sorendermanager);
   SoGLRenderAction * action = PRIVATE(this)->sorendermanager->getGLRenderAction();
@@ -594,7 +566,7 @@ QuarterWidget::setRenderMode(RenderMode mode)
   \retval The current \ref RenderMode
 */
 QuarterWidget::RenderMode
-QuarterWidget::renderMode(void) const
+QuarterWidget::renderMode() const
 {
   assert(PRIVATE(this)->sorendermanager);
   return static_cast<RenderMode>(PRIVATE(this)->sorendermanager->getRenderMode());
@@ -622,7 +594,7 @@ QuarterWidget::setStereoMode(StereoMode mode)
   \retval The current \ref StereoMode
 */
 QuarterWidget::StereoMode
-QuarterWidget::stereoMode(void) const
+QuarterWidget::stereoMode() const
 {
   assert(PRIVATE(this)->sorendermanager);
   return static_cast<StereoMode>(PRIVATE(this)->sorendermanager->getStereoMode());
@@ -640,7 +612,7 @@ the widget is located within, and updated whenever any change occurs, emitting a
  */
 
 qreal
-QuarterWidget::devicePixelRatio(void) const
+QuarterWidget::devicePixelRatio() const
 {
   return PRIVATE(this)->device_pixel_ratio;
 }
@@ -657,11 +629,11 @@ QuarterWidget::setSceneGraph(SoNode * node)
 
   if (PRIVATE(this)->scene) {
     PRIVATE(this)->scene->unref();
-    PRIVATE(this)->scene = NULL;
+    PRIVATE(this)->scene = nullptr;
   }
 
-  SoCamera * camera = NULL;
-  SoSeparator * superscene = NULL;
+  SoCamera * camera = nullptr;
+  SoSeparator * superscene = nullptr;
   bool viewall = false;
 
   if (node) {
@@ -694,7 +666,7 @@ QuarterWidget::setSceneGraph(SoNode * node)
   Returns pointer to root of scene graph
 */
 SoNode *
-QuarterWidget::getSceneGraph(void) const
+QuarterWidget::getSceneGraph() const
 {
   return PRIVATE(this)->scene;
 }
@@ -706,10 +678,10 @@ void
 QuarterWidget::setSoRenderManager(SoRenderManager * manager)
 {
   bool carrydata = false;
-  SoNode * scene = NULL;
-  SoCamera * camera = NULL;
+  SoNode * scene = nullptr;
+  SoCamera * camera = nullptr;
   SbViewportRegion vp;
-  if (PRIVATE(this)->sorendermanager && (manager != NULL)) {
+  if (PRIVATE(this)->sorendermanager && (manager != nullptr)) {
     scene = PRIVATE(this)->sorendermanager->getSceneGraph();
     camera = PRIVATE(this)->sorendermanager->getCamera();
     vp = PRIVATE(this)->sorendermanager->getViewportRegion();
@@ -739,7 +711,7 @@ QuarterWidget::setSoRenderManager(SoRenderManager * manager)
   Returns a pointer to the render manager.
 */
 SoRenderManager *
-QuarterWidget::getSoRenderManager(void) const
+QuarterWidget::getSoRenderManager() const
 {
   return PRIVATE(this)->sorendermanager;
 }
@@ -751,10 +723,10 @@ void
 QuarterWidget::setSoEventManager(SoEventManager * manager)
 {
   bool carrydata = false;
-  SoNode * scene = NULL;
-  SoCamera * camera = NULL;
+  SoNode * scene = nullptr;
+  SoCamera * camera = nullptr;
   SbViewportRegion vp;
-  if (PRIVATE(this)->soeventmanager && (manager != NULL)) {
+  if (PRIVATE(this)->soeventmanager && (manager != nullptr)) {
     scene = PRIVATE(this)->soeventmanager->getSceneGraph();
     camera = PRIVATE(this)->soeventmanager->getCamera();
     vp = PRIVATE(this)->soeventmanager->getViewportRegion();
@@ -784,7 +756,7 @@ QuarterWidget::setSoEventManager(SoEventManager * manager)
   Returns a pointer to the event manager
 */
 SoEventManager *
-QuarterWidget::getSoEventManager(void) const
+QuarterWidget::getSoEventManager() const
 {
   return PRIVATE(this)->soeventmanager;
 }
@@ -793,7 +765,7 @@ QuarterWidget::getSoEventManager(void) const
   Returns a pointer to the event filter
  */
 EventFilter *
-QuarterWidget::getEventFilter(void) const
+QuarterWidget::getEventFilter() const
 {
   return PRIVATE(this)->eventfilter;
 }
@@ -802,7 +774,7 @@ QuarterWidget::getEventFilter(void) const
   Reposition the current camera to display the entire scene
  */
 void
-QuarterWidget::viewAll(void)
+QuarterWidget::viewAll()
 {
   const SbName viewallevent("sim.coin3d.coin.navigation.ViewAll");
   for (int c = 0; c < PRIVATE(this)->soeventmanager->getNumSoScXMLStateMachines(); ++c) {
@@ -820,7 +792,7 @@ QuarterWidget::viewAll(void)
   Camera typically seeks towards what the mouse is pointing at.
 */
 void
-QuarterWidget::seek(void)
+QuarterWidget::seek()
 {
   const SbName seekevent("sim.coin3d.coin.navigation.Seek");
   for (int c = 0; c < PRIVATE(this)->soeventmanager->getNumSoScXMLStateMachines(); ++c) {
@@ -834,11 +806,10 @@ QuarterWidget::seek(void)
 }
 
 bool
-QuarterWidget::updateDevicePixelRatio(void) {
-#if QT_VERSION >= 0x050000
+QuarterWidget::updateDevicePixelRatio() {
     qreal dev_pix_ratio = 1.0;
     QWidget* winwidg = window();
-    QWindow* win = NULL;
+    QWindow* win = nullptr;
     if(winwidg) {
         win = winwidg->windowHandle();
     }
@@ -853,7 +824,6 @@ QuarterWidget::updateDevicePixelRatio(void) {
         emit devicePixelRatioChanged(dev_pix_ratio);
         return true;
     }
-#endif
     return false;
 }
 
@@ -890,18 +860,12 @@ void QuarterWidget::paintEvent(QPaintEvent* event)
     }
 
     if(!initialized) {
-#if !defined(HAVE_QT5_OPENGL)
-        glEnable(GL_DEPTH_TEST);
-#endif
         this->getSoRenderManager()->reinitialize();
         initialized = true;
     }
 
     getSoRenderManager()->activate();
 
-#if !defined(HAVE_QT5_OPENGL)
-    glEnable(GL_DEPTH_TEST);
-#endif
     glMatrixMode(GL_PROJECTION);
 
     QtGLWidget* w = static_cast<QtGLWidget*>(this->viewport());
@@ -934,12 +898,8 @@ void QuarterWidget::paintEvent(QPaintEvent* event)
 
     assert(w->isValid() && "No valid GL context found!");
 
-#if defined(HAVE_QT5_OPENGL)
     // Causes an OpenGL error on resize
     //glDrawBuffer(w->format().swapBehavior() == QSurfaceFormat::DoubleBuffer ? GL_BACK : GL_FRONT);
-#else
-    glDrawBuffer(w->doubleBuffer() ? GL_BACK : GL_FRONT);
-#endif
 
     w->makeCurrent();
     this->actualRedraw();
@@ -951,13 +911,9 @@ void QuarterWidget::paintEvent(QPaintEvent* event)
     inherited::paintEvent(event);
     glPopAttrib();
 
-#if defined(HAVE_QT5_OPENGL)
     // Causes an OpenGL error on resize
     //if (w->format().swapBehavior() == QSurfaceFormat::DoubleBuffer)
     //    w->context()->swapBuffers(w->context()->surface());
-#else
-    if (w->doubleBuffer()) { w->swapBuffers(); }
-#endif
 
     PRIVATE(this)->autoredrawenabled = true;
 
@@ -1029,7 +985,7 @@ bool QuarterWidget::viewportEvent(QEvent* event)
   render manager and render the scene by calling this method.
 */
 void
-QuarterWidget::redraw(void)
+QuarterWidget::redraw()
 {
   // we're triggering the next paintGL(). Set a flag to remember this
   // to avoid that we process the delay queue in paintGL()
@@ -1049,26 +1005,14 @@ QuarterWidget::redraw(void)
   // Note that, the recursive repaint is not infinite due to setting
   // 'processdelayqueue = false' above. However, it does cause annoying
   // flickering, and actually crash on Windows.
-#if 1
   this->viewport()->update();
-#else
-
-// #if QT_VERSION >= 0x050500 && QT_VERSION < 0x050600
-#if 1
-  // With Qt 5.5.x there is a major performance problem
-  this->viewport()->update();
-#else
-  this->viewport()->repaint();
-#endif
-
-#endif
 }
 
 /*!
   Overridden from QGLWidget to render the scenegraph
  */
 void
-QuarterWidget::actualRedraw(void)
+QuarterWidget::actualRedraw()
 {
   PRIVATE(this)->sorendermanager->render(PRIVATE(this)->clearwindow,
                                          PRIVATE(this)->clearzbuffer);
@@ -1120,7 +1064,7 @@ QuarterWidget::setBackgroundColor(const QColor & color)
   rendering the scene.
  */
 QColor
-QuarterWidget::backgroundColor(void) const
+QuarterWidget::backgroundColor() const
 {
   SbColor4f bg = PRIVATE(this)->sorendermanager->getBackgroundColor();
 
@@ -1134,7 +1078,7 @@ QuarterWidget::backgroundColor(void) const
   Returns the context menu used by the widget.
 */
 QMenu *
-QuarterWidget::getContextMenu(void) const
+QuarterWidget::getContextMenu() const
 {
   return PRIVATE(this)->contextMenu();
 }
@@ -1143,7 +1087,7 @@ QuarterWidget::getContextMenu(void) const
   \retval Is context menu enabled?
 */
 bool
-QuarterWidget::contextMenuEnabled(void) const
+QuarterWidget::contextMenuEnabled() const
 {
   return PRIVATE(this)->contextmenuenabled;
 }
@@ -1193,8 +1137,8 @@ void
 QuarterWidget::removeStateMachine(SoScXMLStateMachine * statemachine)
 {
   SoEventManager * em = this->getSoEventManager();
-  statemachine->setSceneGraphRoot(NULL);
-  statemachine->setActiveCamera(NULL);
+  statemachine->setSceneGraphRoot(nullptr);
+  statemachine->setActiveCamera(nullptr);
   em->removeSoScXMLStateMachine(statemachine);
 }
 
@@ -1202,7 +1146,7 @@ QuarterWidget::removeStateMachine(SoScXMLStateMachine * statemachine)
   See \ref QWidget::minimumSizeHint
  */
 QSize
-QuarterWidget::minimumSizeHint(void) const
+QuarterWidget::minimumSizeHint() const
 {
   return QSize(50, 50);
 }
@@ -1213,7 +1157,7 @@ QuarterWidget::minimumSizeHint(void) const
   QuarterWidget, add these actions to the menu.
  */
 QList<QAction *>
-QuarterWidget::transparencyTypeActions(void) const
+QuarterWidget::transparencyTypeActions() const
 {
   return PRIVATE(this)->transparencyTypeActions();
 }
@@ -1224,7 +1168,7 @@ QuarterWidget::transparencyTypeActions(void) const
   QuarterWidget, add these actions to the menu.
  */
 QList<QAction *>
-QuarterWidget::stereoModeActions(void) const
+QuarterWidget::stereoModeActions() const
 {
   return PRIVATE(this)->stereoModeActions();
 }
@@ -1235,7 +1179,7 @@ QuarterWidget::stereoModeActions(void) const
   QuarterWidget, add these actions to the menu.
  */
 QList<QAction *>
-QuarterWidget::renderModeActions(void) const
+QuarterWidget::renderModeActions() const
 {
   return PRIVATE(this)->renderModeActions();
 }
@@ -1257,7 +1201,7 @@ QuarterWidget::renderModeActions(void) const
   Removes any navigationModeFile set.
 */
 void
-QuarterWidget::resetNavigationModeFile(void) {
+QuarterWidget::resetNavigationModeFile() {
   this->setNavigationModeFile(QUrl());
 }
 
@@ -1294,7 +1238,7 @@ QuarterWidget::setNavigationModeFile(const QUrl & url)
     if (PRIVATE(this)->currentStateMachine) {
       this->removeStateMachine(PRIVATE(this)->currentStateMachine);
       delete PRIVATE(this)->currentStateMachine;
-      PRIVATE(this)->currentStateMachine = NULL;
+      PRIVATE(this)->currentStateMachine = nullptr;
       PRIVATE(this)->navigationModeFile = url;
     }
     return;
@@ -1305,7 +1249,7 @@ QuarterWidget::setNavigationModeFile(const QUrl & url)
   }
 
   QByteArray filenametmp = filename.toLocal8Bit();
-  ScXMLStateMachine * stateMachine = NULL;
+  ScXMLStateMachine * stateMachine = nullptr;
 
   if (filenametmp.startsWith("coin:")){
     stateMachine = ScXML::readFile(filenametmp.data());
@@ -1355,9 +1299,7 @@ QuarterWidget::setNavigationModeFile(const QUrl & url)
     //navigation systems? - BFG 20090117
     this->setStateCursor("interact", Qt::ArrowCursor);
     this->setStateCursor("idle", Qt::OpenHandCursor);
-#if QT_VERSION >= 0x040200
     this->setStateCursor("rotate", Qt::ClosedHandCursor);
-#endif
     this->setStateCursor("pan", Qt::SizeAllCursor);
     this->setStateCursor("zoom", Qt::SizeVerCursor);
     this->setStateCursor("dolly", Qt::SizeVerCursor);
@@ -1370,7 +1312,7 @@ QuarterWidget::setNavigationModeFile(const QUrl & url)
   \retval The current navigationModeFile
 */
 const QUrl &
-QuarterWidget::navigationModeFile(void) const
+QuarterWidget::navigationModeFile() const
 {
   return PRIVATE(this)->navigationModeFile;
 }
