@@ -44,7 +44,7 @@ namespace SIM { namespace Coin3D { namespace Quarter {
 class QUARTER_DLL_API Mouse : public InputDevice {
 public:
   Mouse(QuarterWidget* quarter);
-  Mouse(void);
+  Mouse();
   virtual ~Mouse();
 
   virtual const SoEvent * translateEvent(QEvent * event);
