@@ -20,30 +20,29 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 #ifndef _PreComp_
-# include <QGridLayout>
 # include <QApplication>
-# include <QMenu>
 # include <QContextMenuEvent>
+# include <QGridLayout>
+# include <QMenu>
 # include <QTextCursor>
 # include <QTextStream>
 # include <QTime>
-# include <QDockWidget>
-# include <QPointer>
 #endif
 
 #include <Base/Interpreter.h>
+
 #include "ReportView.h"
+#include "Application.h"
+#include "BitmapFactory.h"
+#include "DockWindowManager.h"
 #include "FileDialog.h"
 #include "PythonConsole.h"
 #include "PythonConsolePy.h"
-#include "BitmapFactory.h"
-#include "MainWindow.h"
-#include "Application.h"
 #include "Tools.h"
 
+
 using namespace Gui;
 using namespace Gui::DockWnd;
 
@@ -203,6 +202,58 @@ void ReportHighlighter::setErrorColor( const QColor& col )
     errCol = col;
 }
 
+// ----------------------------------------------------------------------------
+
+namespace Gui {
+class ReportOutputParameter
+{
+public:
+    static bool showOnLogMessage()
+    {
+        return getGroup()->GetBool("checkShowReportViewOnLogMessage", false);
+    }
+    static void toggleShowOnLogMessage()
+    {
+        bool show = showOnLogMessage();
+        getGroup()->SetBool("checkShowReportViewOnLogMessage", !show);
+    }
+    static bool showOnMessage()
+    {
+        return getGroup()->GetBool("checkShowReportViewOnNormalMessage", false);
+    }
+    static void toggleShowOnMessage()
+    {
+        bool show = showOnMessage();
+        getGroup()->SetBool("checkShowReportViewOnNormalMessage", !show);
+    }
+    static bool showOnWarning()
+    {
+        return getGroup()->GetBool("checkShowReportViewOnWarning", false);
+    }
+    static void toggleShowOnWarning()
+    {
+        bool show = showOnWarning();
+        getGroup()->SetBool("checkShowReportViewOnWarning", !show);
+    }
+    static bool showOnError()
+    {
+        return getGroup()->GetBool("checkShowReportViewOnError", true);
+    }
+    static void toggleShowOnError()
+    {
+        bool show = showOnError();
+        getGroup()->SetBool("checkShowReportViewOnError", !show);
+    }
+
+private:
+    static ParameterGrp::handle getGroup()
+    {
+        return App::GetApplication().GetUserParameter().
+                GetGroup("BaseApp")->GetGroup("Preferences")->GetGroup("OutputWindow");
+    }
+};
+}
+
 // ----------------------------------------------------------
 
 /**
@@ -240,24 +291,15 @@ private:
  */
 
 ReportOutputObserver::ReportOutputObserver(ReportOutput *report)
+  : QObject(report)
 {
     this->reportView = report;
 }
 
-void ReportOutputObserver::showReportView(){
+void ReportOutputObserver::showReportView()
+{
     // get the QDockWidget parent of the report view
-    QDockWidget* dw = nullptr;
-    QWidget* par = reportView->parentWidget();
-    while (par) {
-        dw = qobject_cast<QDockWidget*>(par);
-        if (dw)
-            break;
-        par = par->parentWidget();
-    }
-
-    if (dw && !dw->toggleViewAction()->isChecked()) {
-        dw->toggleViewAction()->activate(QAction::Trigger);
-    }
+    DockWindowManager::instance()->activate(reportView);
 }
 
 bool ReportOutputObserver::eventFilter(QObject *obj, QEvent *event)
@@ -265,23 +307,24 @@ bool ReportOutputObserver::eventFilter(QObject *obj, QEvent *event)
     if (event->type() == QEvent::User && obj == reportView.data()) {
         CustomReportEvent* cr = dynamic_cast<CustomReportEvent*>(event);
         if (cr) {
-            ParameterGrp::handle group = App::GetApplication().GetUserParameter().
-                    GetGroup("BaseApp")->GetGroup("Preferences")->GetGroup("OutputWindow");
             ReportHighlighter::Paragraph msgType = cr->messageType();
-            if (msgType == ReportHighlighter::Warning){
-                if (group->GetBool("checkShowReportViewOnWarning", true)) {
+            if (msgType == ReportHighlighter::Warning) {
+                if (ReportOutputParameter::showOnWarning()) {
                     showReportView();
                 }
-            } else if (msgType == ReportHighlighter::Error){
-                if (group->GetBool("checkShowReportViewOnError", true)) {
+            }
+            else if (msgType == ReportHighlighter::Error) {
+                if (ReportOutputParameter::showOnError()) {
                     showReportView();
                 }
-            } else if (msgType == ReportHighlighter::Message){
-                if (group->GetBool("checkShowReportViewOnNormalMessage", false)) {
+            }
+            else if (msgType == ReportHighlighter::Message) {
+                if (ReportOutputParameter::showOnMessage()) {
                     showReportView();
                 }
-            } else if (msgType == ReportHighlighter::LogText){
-                if (group->GetBool("checkShowReportViewOnLogMessage", false)) {
+            }
+            else if (msgType == ReportHighlighter::LogText) {
+                if (ReportOutputParameter::showOnLogMessage()) {
                     showReportView();
                 }
             }
@@ -318,12 +361,12 @@ public:
     {
         if (replace_stdout) {
             Py_DECREF(replace_stdout);
-            replace_stdout = 0;
+            replace_stdout = nullptr;
         }
 
         if (replace_stderr) {
             Py_DECREF(replace_stderr);
-            replace_stderr = 0;
+            replace_stderr = nullptr;
         }
     }
 
@@ -335,15 +378,20 @@ public:
     static bool redirected_stderr;
     static PyObject* default_stderr;
     static PyObject* replace_stderr;
+#ifdef FC_DEBUG
+    long logMessageSize = 0;
+#else
+    long logMessageSize = 2048;
+#endif
 };
 
 bool ReportOutput::Data::redirected_stdout = false;
-PyObject* ReportOutput::Data::default_stdout = 0;
-PyObject* ReportOutput::Data::replace_stdout = 0;
+PyObject* ReportOutput::Data::default_stdout = nullptr;
+PyObject* ReportOutput::Data::replace_stdout = nullptr;
 
 bool ReportOutput::Data::redirected_stderr = false;
-PyObject* ReportOutput::Data::default_stderr = 0;
-PyObject* ReportOutput::Data::replace_stderr = 0;
+PyObject* ReportOutput::Data::default_stderr = nullptr;
+PyObject* ReportOutput::Data::replace_stderr = nullptr;
 
 /* TRANSLATOR Gui::DockWnd::ReportOutput */
 
@@ -368,17 +416,16 @@ ReportOutput::ReportOutput(QWidget* parent)
 
     Base::Console().AttachObserver(this);
     getWindowParameter()->Attach(this);
-
     getWindowParameter()->NotifyAll();
+    // do this explicitly because the keys below might not yet be part of a group
+    getWindowParameter()->Notify("RedirectPythonOutput");
+    getWindowParameter()->Notify("RedirectPythonErrors");
+
     _prefs = WindowParameter::getDefaultParameter()->GetGroup("Editor");
     _prefs->Attach(this);
     _prefs->Notify("FontSize");
 
-#ifdef FC_DEBUG
-    messageSize = _prefs->GetInt("LogMessageSize",0);
-#else
-    messageSize = _prefs->GetInt("LogMessageSize",2048);
-#endif
+    messageSize = _prefs->GetInt("LogMessageSize", d->logMessageSize);
 
     // scroll to bottom at startup to make sure that last appended text is visible
     ensureCursorVisible();
@@ -465,6 +512,17 @@ void ReportOutput::customEvent ( QEvent* ev )
     }
 }
 
+
+bool ReportOutput::event(QEvent* event)
+{
+    if (event && event->type() == QEvent::ShortcutOverride) {
+        QKeyEvent * kevent = static_cast<QKeyEvent*>(event);
+        if (kevent == QKeySequence::Copy)
+            kevent->accept();
+    }
+    return QTextEdit::event(event);
+}
+
 void ReportOutput::changeEvent(QEvent *ev)
 {
     if (ev->type() == QEvent::StyleChange) {
@@ -481,18 +539,16 @@ void ReportOutput::changeEvent(QEvent *ev)
 
 void ReportOutput::contextMenuEvent ( QContextMenuEvent * e )
 {
-    ParameterGrp::handle hGrp = WindowParameter::getDefaultParameter()->GetGroup("OutputWindow");
-    bool bShowOnLog = hGrp->GetBool("checkShowReportViewOnLogMessage",false);
-    bool bShowOnNormal = hGrp->GetBool("checkShowReportViewOnNormalMessage",false);
-    bool bShowOnWarn = hGrp->GetBool("checkShowReportViewOnWarning",true);
-    bool bShowOnError = hGrp->GetBool("checkShowReportViewOnError",true);
+    bool bShowOnLog = ReportOutputParameter::showOnLogMessage();
+    bool bShowOnNormal = ReportOutputParameter::showOnMessage();
+    bool bShowOnWarn = ReportOutputParameter::showOnWarning();
+    bool bShowOnError = ReportOutputParameter::showOnError();
 
-    QMenu* menu = createStandardContextMenu();
-    QAction* first = menu->actions().front();
+    QMenu* menu = new QMenu(this);
     QMenu* optionMenu = new QMenu( menu );
     optionMenu->setTitle(tr("Options"));
-    menu->insertMenu(first, optionMenu);
-    menu->insertSeparator(first);
+    menu->addMenu(optionMenu);
+    menu->addSeparator();
 
     QMenu* displayMenu = new QMenu(optionMenu);
     displayMenu->setTitle(tr("Display message types"));
@@ -515,7 +571,7 @@ void ReportOutput::contextMenuEvent ( QContextMenuEvent * e )
     errAct->setChecked(bErr);
 
     QMenu* showOnMenu = new QMenu (optionMenu);
-    showOnMenu->setTitle(tr("Show report view on"));
+    showOnMenu->setTitle(tr("Show output window on"));
     optionMenu->addMenu(showOnMenu);
 
     QAction* showNormAct = showOnMenu->addAction(tr("Normal messages"), this, SLOT(onToggleShowReportViewOnNormalMessage()));
@@ -549,6 +605,19 @@ void ReportOutput::contextMenuEvent ( QContextMenuEvent * e )
     botAct->setCheckable(true);
     botAct->setChecked(gotoEnd);
 
+    // Use Qt's internal translation of the Copy & Select All commands
+    const char* context = "QWidgetTextControl";
+    QString copyStr = QCoreApplication::translate(context, "&Copy");
+    QAction* copy = menu->addAction(copyStr, this, SLOT(copy()), QKeySequence(QKeySequence::Copy));
+    copy->setEnabled(textCursor().hasSelection());
+    QIcon icon = QIcon::fromTheme(QString::fromLatin1("edit-copy"));
+    if (!icon.isNull())
+        copy->setIcon(icon);
+
+    menu->addSeparator();
+    QString selectStr = QCoreApplication::translate(context, "Select All");
+    menu->addAction(selectStr, this, SLOT(selectAll()), QKeySequence(QKeySequence::SelectAll));
+
     menu->addAction(tr("Clear"), this, SLOT(clear()));
     menu->addSeparator();
     menu->addAction(tr("Save As..."), this, SLOT(onSaveAs()));
@@ -620,26 +689,22 @@ void ReportOutput::onToggleNormalMessage()
 
 void ReportOutput::onToggleShowReportViewOnWarning()
 {
-    bool show = getWindowParameter()->GetBool("checkShowReportViewOnWarning", true);
-    getWindowParameter()->SetBool("checkShowReportViewOnWarning", !show);
+    ReportOutputParameter::toggleShowOnWarning();
 }
 
 void ReportOutput::onToggleShowReportViewOnError()
 {
-    bool show = getWindowParameter()->GetBool("checkShowReportViewOnError", true);
-    getWindowParameter()->SetBool("checkShowReportViewOnError", !show);
+    ReportOutputParameter::toggleShowOnError();
 }
 
 void ReportOutput::onToggleShowReportViewOnNormalMessage()
 {
-    bool show = getWindowParameter()->GetBool("checkShowReportViewOnNormalMessage", false);
-    getWindowParameter()->SetBool("checkShowReportViewOnNormalMessage", !show);
+    ReportOutputParameter::toggleShowOnMessage();
 }
 
 void ReportOutput::onToggleShowReportViewOnLogMessage()
 {
-    bool show = getWindowParameter()->GetBool("checkShowReportViewOnLogMessage", false);
-    getWindowParameter()->SetBool("checkShowReportViewOnLogMessage", !show);
+    ReportOutputParameter::toggleShowOnLogMessage();
 }
 
 void ReportOutput::onToggleRedirectPythonStdout()
@@ -734,12 +799,9 @@ void ReportOutput::OnChange(Base::Subject<const char*> &rCaller, const char * sR
         bool checked = rclGrp.GetBool(sReason, true);
         if (checked != d->redirected_stderr)
             onToggleRedirectPythonStderr();
-    }else if(strcmp(sReason, "LogMessageSize") == 0) {
-#ifdef FC_DEBUG
-        messageSize = rclGrp.GetInt(sReason,0);
-#else
-        messageSize = rclGrp.GetInt(sReason,2048);
-#endif
+    }
+    else if (strcmp(sReason, "LogMessageSize") == 0) {
+        messageSize = rclGrp.GetInt(sReason, d->logMessageSize);
     }
 }
 
