@@ -20,17 +20,16 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #ifndef GUI_DOCKWND_REPORTVIEW_H
 #define GUI_DOCKWND_REPORTVIEW_H
 
+#include <QPointer>
 #include <QTextEdit>
 #include <QSyntaxHighlighter>
-#include <Base/Console.h>
-#include <QPointer>
-#include <QDockWidget>
-#include "DockWindow.h"
+
 #include "Window.h"
+#include <FCGlobal.h>
+
 
 class QTabWidget;
 
@@ -52,7 +51,7 @@ class ReportView : public QWidget
     Q_OBJECT
 
 public:
-    ReportView( QWidget* parent = 0);
+    ReportView( QWidget* parent = nullptr);
     ~ReportView();
 
 protected:
@@ -129,7 +128,7 @@ class GuiExport ReportOutput : public QTextEdit, public WindowParameter, public
     Q_OBJECT
 
 public:
-    ReportOutput(QWidget* parent=0);
+    ReportOutput(QWidget* parent=nullptr);
     virtual ~ReportOutput();
 
     /** Observes its parameter group. */
@@ -138,7 +137,7 @@ public:
     void SendLog(const std::string& msg, Base::LogStyle level) override;
 
     /// returns the name for observer handling
-    const char* Name(void) override {return "ReportOutput";}
+    const char* Name() override {return "ReportOutput";}
 
     /** Restore the default font settings. */
     void restoreFont ();
@@ -159,6 +158,8 @@ protected:
     void changeEvent(QEvent *) override;
     /** Pops up the context menu with some extensions */
     void contextMenuEvent ( QContextMenuEvent* e ) override;
+    /** Handle shortcut override events */
+    bool event(QEvent* event) override;
 
 public Q_SLOTS:
     /** Save the report messages into a file. */
@@ -211,7 +212,7 @@ public:
 
 protected:
     QPointer <ReportOutput> reportView;
-    void showReportView(void);
+    void showReportView();
 };
 
 } // namespace DockWnd
