@@ -21,37 +21,41 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #ifndef GUI_SELECTION_H
 #define GUI_SELECTION_H
 
-// Std. configurations
-
+#include <deque>
+#include <list>
 #include <string>
 #include <vector>
-#include <list>
-#include <map>
-#include <deque>
-#include <boost_signals2.hpp>
 #include <CXX/Objects.hxx>
 
-#include <Base/Observer.h>
-#include <Base/Type.h>
-#include <App/Document.h>
 #include <App/DocumentObject.h>
 #include <App/DocumentObserver.h>
-#include <Gui/SelectionObject.h>
+#include <Base/Observer.h>
+
+#include "SelectionObject.h"
+
 
 namespace App
 {
-  class DocumentObject;
-  class Document;
+    class DocumentObject;
+    class Document;
+    class PropertyLinkSubList;
 }
 
 namespace Gui
 {
 
-    class SelectionFilter;
+enum class ResolveMode {
+    NoResolve,
+    OldStyleElement,
+    NewStyleElement,
+    FollowLink
+};
+
+class SelectionObject;
+class SelectionFilter;
 
 /** Transport the changes of the Selection
  * This class transports closer information what was changed in the
@@ -79,12 +83,19 @@ public:
         RmvPreselectSignal, // to request 3D view to remove preselect
         MovePreselect, // to signal observer the mouse movement when preselect
     };
+    enum class MsgSource {
+        Any = 0,
+        Internal = 1,
+        TreeView = 2
+    };
 
     SelectionChanges(MsgType type = ClrSelection,
-            const char *docName=0, const char *objName=0,
-            const char *subName=0, const char *typeName=0,
-            float x=0, float y=0, float z=0, int subtype=0)
-        : Type(type),SubType(subtype)
+            const char *docName=nullptr, const char *objName=nullptr,
+            const char *subName=nullptr, const char *typeName=nullptr,
+            float x=0, float y=0, float z=0,
+            MsgSource subtype=MsgSource::Any)
+        : Type(type)
+        , SubType(subtype)
         , x(x),y(y),z(z)
         , Object(docName,objName,subName)
     {
@@ -100,8 +111,10 @@ public:
                      const std::string &objName,
                      const std::string &subName,
                      const std::string &typeName = std::string(),
-                     float x=0,float y=0,float z=0, int subtype=0)
-        : Type(type), SubType(subtype)
+                     float x=0,float y=0,float z=0,
+                     MsgSource subtype=MsgSource::Any)
+        : Type(type)
+        , SubType(subtype)
         , x(x),y(y),z(z)
         , Object(docName.c_str(), objName.c_str(), subName.c_str())
         , TypeName(typeName)
@@ -153,7 +166,7 @@ public:
     }
 
     MsgType Type;
-    int SubType;
+    MsgSource SubType;
 
     const char* pDocName;
     const char* pObjectName;
@@ -167,7 +180,7 @@ public:
     std::string TypeName;
 
     // Original selection message in case resolve!=0
-    const SelectionChanges *pOriginalMsg = 0;
+    const SelectionChanges *pOriginalMsg = nullptr;
 };
 
 } //namespace Gui
@@ -216,7 +229,7 @@ public:
      *                 1 resolve sub-object with old style element name
      *                 2 resolve sub-object with new style element name
      */
-    SelectionObserver(bool attach = true, int resolve = 1);
+    SelectionObserver(bool attach = true, ResolveMode resolve = ResolveMode::OldStyleElement);
     /** Constructor
      *
      * @param vp: filtering view object.
@@ -229,12 +242,12 @@ public:
      * Constructs an selection observer that receives only selection event of
      * objects within the same document as the input view object.
      */
-    SelectionObserver(const Gui::ViewProviderDocumentObject *vp, bool attach=true, int resolve=1);
+    SelectionObserver(const Gui::ViewProviderDocumentObject *vp, bool attach=true, ResolveMode resolve = ResolveMode::OldStyleElement);
 
     virtual ~SelectionObserver();
-    bool blockConnection(bool block);
-    bool isConnectionBlocked() const;
-    bool isConnectionAttached() const;
+    bool blockSelection(bool block);
+    bool isSelectionBlocked() const;
+    bool isSelectionAttached() const;
 
     /** Attaches to the selection. */
     void attachSelection();
@@ -250,8 +263,8 @@ private:
     Connection connectSelection;
     std::string filterDocName;
     std::string filterObjName;
-    int resolve;
-    bool blockSelection;
+    ResolveMode resolve;
+    bool blockedSelection;
 };
 
 /**
@@ -266,10 +279,10 @@ class GuiExport SelectionObserverPython : public SelectionObserver
 
 public:
     /// Constructor
-    SelectionObserverPython(const Py::Object& obj, int resolve=1);
+    SelectionObserverPython(const Py::Object& obj, ResolveMode resolve = ResolveMode::OldStyleElement);
     virtual ~SelectionObserverPython();
 
-    static void addObserver(const Py::Object& obj, int resolve=1);
+    static void addObserver(const Py::Object& obj, ResolveMode resolve = ResolveMode::OldStyleElement);
     static void removeObserver(const Py::Object& obj);
 
 private:
@@ -328,7 +341,7 @@ public:
 class GuiExport SelectionGateFilterExternal: public SelectionGate
 {
 public:
-    SelectionGateFilterExternal(const char *docName, const char *objName=0);
+    SelectionGateFilterExternal(const char *docName, const char *objName=nullptr);
     virtual bool allow(App::Document*,App::DocumentObject*, const char*) override;
 private:
     std::string DocName;
@@ -365,10 +378,10 @@ public:
     };
 
     /// Add to selection
-    bool addSelection(const char* pDocName, const char* pObjectName=0, const char* pSubName=0,
-            float x=0, float y=0, float z=0, const std::vector<SelObj> *pickedList = 0, bool clearPreSelect=true);
-    bool addSelection2(const char* pDocName, const char* pObjectName=0, const char* pSubName=0,
-            float x=0, float y=0, float z=0, const std::vector<SelObj> *pickedList = 0)
+    bool addSelection(const char* pDocName, const char* pObjectName=nullptr, const char* pSubName=nullptr,
+            float x=0, float y=0, float z=0, const std::vector<SelObj> *pickedList = nullptr, bool clearPreSelect=true);
+    bool addSelection2(const char* pDocName, const char* pObjectName=nullptr, const char* pSubName=nullptr,
+            float x=0, float y=0, float z=0, const std::vector<SelObj> *pickedList = nullptr)
     {
         return addSelection(pDocName,pObjectName,pSubName,x,y,z,pickedList,false);
     }
@@ -378,37 +391,38 @@ public:
     /// Add to selection with several sub-elements
     bool addSelections(const char* pDocName, const char* pObjectName, const std::vector<std::string>& pSubNames);
     /// Update a selection
-    bool updateSelection(bool show, const char* pDocName, const char* pObjectName=0, const char* pSubName=0);
+    bool updateSelection(bool show, const char* pDocName, const char* pObjectName=nullptr, const char* pSubName=nullptr);
     /// Remove from selection (for internal use)
-    void rmvSelection(const char* pDocName, const char* pObjectName=0, const char* pSubName=0,
-            const std::vector<SelObj> *pickedList = 0);
+    void rmvSelection(const char* pDocName, const char* pObjectName=nullptr, const char* pSubName=nullptr,
+            const std::vector<SelObj> *pickedList = nullptr);
     /// Set the selection for a document
     void setSelection(const char* pDocName, const std::vector<App::DocumentObject*>&);
     /// Clear the selection of document \a pDocName. If the document name is not given the selection of the active document is cleared.
-    void clearSelection(const char* pDocName=0, bool clearPreSelect=true);
+    void clearSelection(const char* pDocName=nullptr, bool clearPreSelect=true);
     /// Clear the selection of all documents
     void clearCompleteSelection(bool clearPreSelect=true);
     /// Check if selected
-    bool isSelected(const char* pDocName, const char* pObjectName=0,
-            const char* pSubName=0, int resolve=1) const;
+    bool isSelected(const char* pDocName, const char* pObjectName=nullptr,
+            const char* pSubName=nullptr, ResolveMode resolve = ResolveMode::OldStyleElement) const;
     /// Check if selected
-    bool isSelected(App::DocumentObject*, const char* pSubName=0, int resolve=1) const;
+    bool isSelected(App::DocumentObject*, const char* pSubName=nullptr, ResolveMode resolve = ResolveMode::OldStyleElement) const;
 
     const char *getSelectedElement(App::DocumentObject*, const char* pSubName) const;
 
     /// set the preselected object (mostly by the 3D view)
     int setPreselect(const char* pDocName, const char* pObjectName,
-            const char* pSubName, float x=0, float y=0, float z=0, int signal=0);
+            const char* pSubName, float x=0, float y=0, float z=0,
+            SelectionChanges::MsgSource signal=SelectionChanges::MsgSource::Any);
     /// remove the present preselection
     void rmvPreselect(bool signal=false);
     /// sets different coords for the preselection
     void setPreselectCoord(float x, float y, float z);
     /// returns the present preselection
-    const SelectionChanges& getPreselection(void) const;
+    const SelectionChanges& getPreselection() const;
     /// add a SelectionGate to control what is selectable
-    void addSelectionGate(Gui::SelectionGate *gate, int resolve = 1);
+    void addSelectionGate(Gui::SelectionGate *gate, ResolveMode resolve = ResolveMode::OldStyleElement);
     /// remove the active SelectionGate
-    void rmvSelectionGate(void);
+    void rmvSelectionGate();
 
     int disableCommandLog();
     int enableCommandLog(bool silent=false);
@@ -423,14 +437,14 @@ public:
      * field
      */
     unsigned int countObjectsOfType(const Base::Type& typeId=App::DocumentObject::getClassTypeId(),
-            const char* pDocName=0, int resolve=1) const;
+            const char* pDocName=nullptr, ResolveMode resolve = ResolveMode::OldStyleElement) const;
 
     /**
      * Does basically the same as the method above unless that it accepts a string literal as first argument.
      * \a typeName must be a registered type, otherwise 0 is returned.
      */
     unsigned int countObjectsOfType(const char* typeName,
-            const char* pDocName=0, int resolve=1) const;
+            const char* pDocName=nullptr, ResolveMode resolve = ResolveMode::OldStyleElement) const;
 
     /** Returns a vector of objects of type \a TypeName selected for the given document name \a pDocName.
      * If no document name is specified the objects from the active document are regarded.
@@ -438,19 +452,19 @@ public:
      * @note The vector reflects the sequence of selection.
      */
     std::vector<App::DocumentObject*> getObjectsOfType(const Base::Type& typeId,
-            const char* pDocName=0, int resolve=1) const;
+            const char* pDocName=nullptr, ResolveMode resolve = ResolveMode::OldStyleElement) const;
 
     /**
      * Does basically the same as the method above unless that it accepts a string literal as first argument.
      * \a typeName must be a registered type otherwise an empty array is returned.
      */
     std::vector<App::DocumentObject*> getObjectsOfType(const char* typeName,
-            const char* pDocName=0, int resolve=1) const;
+            const char* pDocName=nullptr, ResolveMode resolve = ResolveMode::OldStyleElement) const;
     /**
      * A convenience template-based method that returns an array with the correct types already.
      */
     template<typename T> inline std::vector<T*> getObjectsOfType(
-            const char* pDocName=0, int resolve=1) const;
+            const char* pDocName=nullptr, ResolveMode resolve = ResolveMode::OldStyleElement) const;
 
     /// Visible state used by setVisible()
     enum VisibleState {
@@ -491,7 +505,7 @@ public:
      *
      * @return The returned vector reflects the sequence of selection.
      */
-    std::vector<SelObj> getSelection(const char* pDocName=0, int resolve=1, bool single=false) const;
+    std::vector<SelObj> getSelection(const char* pDocName=nullptr, ResolveMode resolve = ResolveMode::OldStyleElement, bool single=false) const;
     /** Returns a vector of selection objects
      *
      * @param pDocName: document name. If no document name is given the objects
@@ -508,8 +522,8 @@ public:
      *
      * @return The returned vector reflects the sequence of selection.
      */
-    std::vector<Gui::SelectionObject> getSelectionEx(const char* pDocName=0,
-            Base::Type typeId=App::DocumentObject::getClassTypeId(),int resolve=1, bool single=false) const;
+    std::vector<Gui::SelectionObject> getSelectionEx(const char* pDocName=nullptr,
+            Base::Type typeId=App::DocumentObject::getClassTypeId(), ResolveMode resolve = ResolveMode::OldStyleElement, bool single=false) const;
 
     /**
      * @brief getAsPropertyLinkSubList fills PropertyLinkSubList with current selection.
@@ -519,7 +533,7 @@ public:
     int getAsPropertyLinkSubList(App::PropertyLinkSubList &prop) const;
 
     /** Returns a vector of all selection objects of all documents. */
-    std::vector<SelObj> getCompleteSelection(int resolve=1) const;
+    std::vector<SelObj> getCompleteSelection(ResolveMode resolve = ResolveMode::OldStyleElement) const;
 
     /// Check if there is any selection
     bool hasSelection() const;
@@ -536,7 +550,7 @@ public:
      * If \c resolve is false, then the match is only done with the top
      * level parent object.
      */
-    bool hasSelection(const char* doc, bool resolve=true) const;
+    bool hasSelection(const char* doc, ResolveMode resolve = ResolveMode::OldStyleElement) const;
 
     /** Check if there is any sub-element selection
      *
@@ -547,13 +561,13 @@ public:
      * then sub-object (i.e. a group child object) selection is also counted
      * even if it selects the whole sub-object.
      */
-    bool hasSubSelection(const char *doc=0, bool subElement=false) const;
+    bool hasSubSelection(const char *doc=nullptr, bool subElement=false) const;
 
     /// Check if there is any pre-selection
     bool hasPreselection() const;
 
     /// Size of selected entities for all documents
-    unsigned int size(void) const {
+    unsigned int size() const {
         return static_cast<unsigned int>(_SelList.size());
     }
 
@@ -579,7 +593,7 @@ public:
      *                 2 resolve sub-object with new style element name
      * @param index: optional position in the stack
      */
-    std::vector<Gui::SelectionObject> selStackGet(const char* pDocName=0,int resolve=1,int index=0) const;
+    std::vector<Gui::SelectionObject> selStackGet(const char* pDocName=nullptr, ResolveMode resolve = ResolveMode::OldStyleElement, int index=0) const;
 
     /** Go back selection history
      *
@@ -625,11 +639,11 @@ public:
     std::vector<SelectionSingleton::SelObj> getPickedList(const char* pDocName) const;
     /// Return selected object inside picked list grouped by top level parents
     std::vector<Gui::SelectionObject> getPickedListEx(
-            const char* pDocName=0, Base::Type typeId=App::DocumentObject::getClassTypeId()) const;
+            const char* pDocName=nullptr, Base::Type typeId=App::DocumentObject::getClassTypeId()) const;
     //@}
 
-    static SelectionSingleton& instance(void);
-    static void destruct (void);
+    static SelectionSingleton& instance();
+    static void destruct ();
     friend class SelectionFilter;
 
     // Python interface
@@ -672,7 +686,7 @@ protected:
     void slotDeletedObject(const App::DocumentObject&);
 
     /// helper to retrieve document by name
-    App::Document* getDocument(const char* pDocName=0) const;
+    App::Document* getDocument(const char* pDocName=nullptr) const;
 
     void slotSelectionChanged(const SelectionChanges& msg);
 
@@ -689,15 +703,15 @@ protected:
         std::string FeatName;
         std::string SubName;
         std::string TypeName;
-        App::Document* pDoc = 0;
-        App::DocumentObject* pObject = 0;
+        App::Document* pDoc = nullptr;
+        App::DocumentObject* pObject = nullptr;
         float x = 0.0f;
         float y = 0.0f;
         float z = 0.0f;
         bool logged = false;
 
         std::pair<std::string,std::string> elementName;
-        App::DocumentObject* pResolvedObject = 0;
+        App::DocumentObject* pResolvedObject = nullptr;
 
         void log(bool remove=false, bool clearPreselect=true);
     };
@@ -711,12 +725,12 @@ protected:
     std::deque<SelStackItem> _SelStackForward;
 
     int checkSelection(const char *pDocName, const char *pObjectName,
-            const char *pSubName,int resolve, _SelObj &sel, const std::list<_SelObj> *selList=0) const;
+            const char *pSubName, ResolveMode resolve, _SelObj &sel, const std::list<_SelObj> *selList=nullptr) const;
 
-    std::vector<Gui::SelectionObject> getObjectList(const char* pDocName,Base::Type typeId, std::list<_SelObj> &objs, int resolve, bool single=false) const;
+    std::vector<Gui::SelectionObject> getObjectList(const char* pDocName,Base::Type typeId, std::list<_SelObj> &objs, ResolveMode resolve, bool single=false) const;
 
     static App::DocumentObject *getObjectOfType(_SelObj &sel, Base::Type type,
-            int resolve, const char **subelement=0);
+            ResolveMode resolve, const char **subelement=nullptr);
 
     static SelectionSingleton* _pcSingleton;
 
@@ -726,7 +740,7 @@ protected:
     float hx,hy,hz;
 
     Gui::SelectionGate *ActiveGate;
-    int gateResolve;
+    ResolveMode gateResolve;
 
     int logDisabled = 0;
     bool logHasSelection = false;
@@ -736,7 +750,7 @@ protected:
  * A convenience template-based method that returns an array with the correct types already.
  */
 template<typename T>
-inline std::vector<T*> SelectionSingleton::getObjectsOfType(const char* pDocName, int resolve) const
+inline std::vector<T*> SelectionSingleton::getObjectsOfType(const char* pDocName, ResolveMode resolve) const
 {
     std::vector<T*> type;
     std::vector<App::DocumentObject*> obj = this->getObjectsOfType(T::getClassTypeId(), pDocName, resolve);
@@ -747,7 +761,7 @@ inline std::vector<T*> SelectionSingleton::getObjectsOfType(const char* pDocName
 }
 
 /// Get the global instance
-inline SelectionSingleton& Selection(void)
+inline SelectionSingleton& Selection()
 {
     return SelectionSingleton::instance();
 }
