@@ -24,6 +24,7 @@
 #ifndef GUI_SelectionFilter_H
 #define GUI_SelectionFilter_H
 
+#include <memory>
 #include <string>
 #include <CXX/Extensions.hxx>
 #include "Selection.h"
@@ -65,7 +66,7 @@ public:
      *  against the filter and returns true if the
      *  described object(s) are selected.
      */
-    bool match(void);
+    bool match();
     /** Test objects
      *  This method tests if a given object is described in the
      *  filter. If SubName is not NULL the Subelement gets also
@@ -80,15 +81,14 @@ public:
     std::vector<std::vector<SelectionObject> > Result;
 
     /// true if a valid filter is set
-    bool isValid(void) const {return Ast ? true : false;}
+    bool isValid() const {return Ast ? true : false;}
 
 protected:
     std::string Filter;
     std::string Errors;
-    bool parse(void);
-
-    Node_Block *Ast;
+    bool parse();
 
+    std::shared_ptr<Node_Block> Ast;
 };
 
 /** Filter object for the SelectionSengleton
@@ -109,6 +109,13 @@ public:
     virtual bool allow(App::Document*,App::DocumentObject*, const char*);
 
 protected:
+    static SelectionFilter* nullPointer() {
+        return nullptr;
+    }
+
+    static const char* nullString() {
+        return nullptr;
+    }
     SelectionFilterGate();
 
 protected:
@@ -147,7 +154,7 @@ public:
     SelectionFilter filter;
 
 public:
-    static void init_type(void);    // announce properties and methods
+    static void init_type();    // announce properties and methods
 
     SelectionFilterPy(const std::string&);
     ~SelectionFilterPy();
@@ -207,10 +214,8 @@ struct Node_Object
         :Slice(slc)
     {
         ObjectType = Base::Type::fromName(type->c_str());
-        delete (type);
-        if(subname){
+        if (subname) {
             SubName = *subname;
-            delete subname;
         }
     }
     ~Node_Object(){
@@ -220,11 +225,14 @@ struct Node_Object
     Node_Slice  *Slice;
     std::string SubName;
 };
+typedef std::shared_ptr<Node_Object> Node_ObjectPtr;
 
 struct Node_Block
 {
-    Node_Block(Node_Object* obj){Objects.push_back(obj);}
-    std::vector< Node_Object *> Objects;
+    Node_Block(Node_Object* obj){
+        Objects.emplace_back(obj);
+    }
+    std::vector<Node_ObjectPtr> Objects;
 };
 
 
