@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (c) 2009 Juergen Riegel (FreeCAD@juergen-riegel.net)             *
+ *   Copyright (c) 2009 Jürgen Riegel <FreeCAD@juergen-riegel.net>         *
  *                                                                         *
  *   This file is part of the FreeCAD CAx development system.              *
  *                                                                         *
@@ -20,7 +20,6 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 
 #include <sstream>
@@ -28,12 +27,13 @@
 #include <App/Application.h>
 #include <App/Document.h>
 #include <App/DocumentObject.h>
-#include <Base/Interpreter.h>
+#include <Gui/SelectionObjectPy.h>
 
 #include "SelectionObject.h"
 #include "Selection.h"
 #include "Application.h"
-#include <Gui/SelectionObjectPy.h>
+#include "Command.h"
+
 
 using namespace Gui;
 
@@ -51,7 +51,7 @@ SelectionObject::SelectionObject(const Gui::SelectionChanges& msg)
     TypeName = msg.pTypeName ? msg.pTypeName : "";
     if (msg.pSubName) {
         SubNames.push_back(msg.pSubName);
-        SelPoses.push_back(Base::Vector3d(msg.x, msg.y, msg.z));
+        SelPoses.emplace_back(msg.x, msg.y, msg.z);
     }
 }
 
@@ -66,24 +66,24 @@ SelectionObject::~SelectionObject()
 {
 }
 
-const App::DocumentObject * SelectionObject::getObject(void) const
+const App::DocumentObject * SelectionObject::getObject() const
 {
     if (!DocName.empty()) {
         App::Document *doc = App::GetApplication().getDocument(DocName.c_str());
         if (doc && !FeatName.empty())
             return doc->getObject(FeatName.c_str());
     }
-    return 0;
+    return nullptr;
 }
 
-App::DocumentObject * SelectionObject::getObject(void) 
+App::DocumentObject * SelectionObject::getObject()
 {
     if (!DocName.empty()) {
         App::Document *doc = App::GetApplication().getDocument(DocName.c_str());
         if (doc && !FeatName.empty())
             return doc->getObject(FeatName.c_str());
     }
-    return 0;
+    return nullptr;
 }
 
 bool SelectionObject::isObjectTypeOf(const Base::Type& typeId) const
@@ -92,24 +92,14 @@ bool SelectionObject::isObjectTypeOf(const Base::Type& typeId) const
     return (obj && obj->getTypeId().isDerivedFrom(typeId));
 }
 
-std::string SelectionObject::getAsPropertyLinkSubString(void)const
+std::string SelectionObject::getAsPropertyLinkSubString()const
 {
-    std::string buf;
-    buf += "(App.";
-    buf += "ActiveDocument";//getObject()->getDocument()->getName(); 
-    buf += ".";
-    buf += getObject()->getNameInDocument(); 
-    buf += ",[";
-    for(std::vector<std::string>::const_iterator it = SubNames.begin();it!=SubNames.end();++it){
-        buf += "\""; 
-        buf += *it; 
-        buf += "\"";
-        if(it != --SubNames.end())
-            buf += ",";
-    }
-    buf += "])";
-   
-    return buf;
+    std::ostringstream str;
+    str << "(" << Gui::Command::getObjectCmd(getObject()) << ",[";
+    for(std::vector<std::string>::const_iterator it = SubNames.begin();it!=SubNames.end();++it)
+        str << "'" << *it << "',";
+    str << "])";
+    return str.str();
 }
 
 PyObject* SelectionObject::getPyObject()
