@@ -20,22 +20,17 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #ifndef COIN_SOFCBOUNDINGBOX_H
 #define COIN_SOFCBOUNDINGBOX_H
 
-#include <Inventor/SbLinear.h>
 #include <Inventor/actions/SoAction.h>
-#include <Inventor/fields/SoSFFloat.h>
-#include <Inventor/fields/SoSFVec4f.h>
-#include <Inventor/fields/SoSFString.h>
+#include <Inventor/fields/SoSFBool.h>
+#include <Inventor/fields/SoSFVec3f.h>
 #include <Inventor/nodes/SoCoordinate3.h>
 #include <Inventor/nodes/SoIndexedLineSet.h>
 #include <Inventor/nodes/SoSeparator.h>
-#include <Inventor/nodes/SoText2.h>
-#include <Inventor/nodes/SoTransform.h>
 #include <Inventor/nodes/SoShape.h>
-#include <Inventor/fields/SoSFBool.h>
+
 
 namespace Gui {
 
