@@ -20,16 +20,17 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #ifndef GUI_SOFCCOLORBAR_H
 #define GUI_SOFCCOLORBAR_H
 
+#include <QElapsedTimer>
+#include <vector>
 #include <Inventor/SbVec2s.h>
 #include <Inventor/nodes/SoSeparator.h>
-#include <QElapsedTimer>
-#include <Base/Observer.h>
+
 #include <App/ColorModel.h>
-#include <vector>
+#include <Base/Observer.h>
+
 
 class SoSwitch;
 class SoEventCallback;
@@ -50,8 +51,8 @@ class GuiExport SoFCColorBarBase : public SoSeparator, public App::ValueFloatToR
   SO_NODE_ABSTRACT_HEADER(Gui::SoFCColorBarBase);
 
 public:
-  static void initClass(void);
-  static void finish(void);
+  static void initClass();
+  static void finish();
 
   virtual void GLRenderBelowPath ( SoGLRenderAction *action );
 
@@ -86,19 +87,24 @@ public:
    *
    * This method must be implemented in subclasses.
    */
-  virtual float getMinValue (void) const = 0;
+  virtual float getMinValue () const = 0;
   /** Returns the current maximum of the parameter range.
    *
    * This method must be implemented in subclasses.
    */
-  virtual float getMaxValue (void) const = 0;
+  virtual float getMaxValue () const = 0;
   /**
    * Opens a dialog to customize the current settings of the color bar.
-   * Returns true if the settings have been changed, false otherwise.
    *
    * This method must be implemented in subclasses.
    */
-  virtual bool customize() = 0;
+  virtual void customize(SoFCColorBarBase*) = 0;
+  /**
+   * Forward a triggered change
+   */
+  virtual void triggerChange(SoFCColorBarBase* base) {
+    base->triggerChange(this);
+  }
   /** Returns the name of the color bar.
    *
    * This method must be implemented in subclasses.
@@ -106,17 +112,33 @@ public:
   virtual const char* getColorBarName() const = 0;
 
 protected:
+  /** Computes the dimensions of the color bar and labels in coordinates with
+   * respect to the defined height of the camera.
+   * Returns the width of the bounding box
+   */
+  float getBounds(const SbVec2s& size, float& fMinX, float&fMinY, float& fMaxX, float& fMaxY);
+  /** Returns the width of the color bar and labels
+   *
+   * Computes the occupied width of the color bar and its labels.
+   * It therefore determines the bounding box.
+   */
+  float getBoundingWidth(const SbVec2s& size);
   /**
    * Sets the current viewer size to recalculate the new position.
    *
    * This method must be implemented in subclasses.
    */
   virtual void setViewportSize( const SbVec2s& size ) = 0;
+  /**
+   * Mark the object as modified.
+   */
+  void setModified();
 
-  SoFCColorBarBase (void);
+  SoFCColorBarBase ();
   virtual ~SoFCColorBarBase ();
 
 private:
+  float _boxWidth;
   SbVec2s _windowSize;
 };
 
@@ -132,9 +154,9 @@ class GuiExport SoFCColorBar : public SoFCColorBarBase, public Base::Subject<int
   SO_NODE_HEADER(Gui::SoFCColorBar);
 
 public:
-  static void initClass(void);
-  static void finish(void);
-  SoFCColorBar(void);
+  static void initClass();
+  static void finish();
+  SoFCColorBar();
 
   /**
    * Returns the currently active color bar object.
@@ -164,15 +186,19 @@ public:
   /**
    * Returns the current minimum of the parameter range of the currently active color bar.
    */
-  float getMinValue (void) const;
+  float getMinValue () const;
   /**
    * Returns the current maximum of the parameter range of the currently active color bar.
    */
-  float getMaxValue (void) const;
+  float getMaxValue () const;
   /**
    * Customizes the currently active color bar.
    */
-  bool customize();
+  void customize(SoFCColorBarBase*);
+  /**
+   * Notify observers
+   */
+  void triggerChange(SoFCColorBarBase*);
   /** Returns the name of the color bar.
    */
   const char* getColorBarName() const { return "Color Bar"; }
@@ -189,7 +215,6 @@ private:
   static void eventCallback(void * userdata, SoEventCallback * node);
 
 private:
-  float _fMaxX, _fMinX, _fMaxY, _fMinY;
   QElapsedTimer _timer;
 
   SoSwitch* pColorMode;
