@@ -20,62 +20,61 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 #ifndef _PreComp_
-# include <Inventor/actions/SoToVRML2Action.h>
-# include <Inventor/VRMLnodes/SoVRMLGroup.h>
-# include <Inventor/VRMLnodes/SoVRMLParent.h>
+# include <Inventor/SbSphere.h>
 # include <Inventor/SbString.h>
+# include <Inventor/SoInteraction.h>
+# include <Inventor/actions/SoGetBoundingBoxAction.h>
+# include <Inventor/actions/SoToVRML2Action.h>
+# include <Inventor/actions/SoWriteAction.h>
+# include <Inventor/fields/SoMFNode.h>
+# include <Inventor/fields/SoSFNode.h>
 # include <Inventor/nodes/SoGroup.h>
+# include <Inventor/VRMLnodes/SoVRMLGroup.h>
+# include <Inventor/VRMLnodes/SoVRMLIndexedFaceSet.h>
+# include <Inventor/VRMLnodes/SoVRMLNormal.h>
+# include <Inventor/VRMLnodes/SoVRMLParent.h>
+# include <Inventor/VRMLnodes/SoVRMLShape.h>
 # include <QDir>
 # include <QProcess>
 # include <QTemporaryFile>
 # include <sstream>
 #endif
 
-#include <Inventor/VRMLnodes/SoVRMLGeometry.h>
-#include <Inventor/VRMLnodes/SoVRMLNormal.h>
-#include <Inventor/VRMLnodes/SoVRMLIndexedFaceSet.h>
-#include <Inventor/VRMLnodes/SoVRMLShape.h>
-#include <Inventor/fields/SoSFNode.h>
-#include <Inventor/fields/SoMFNode.h>
-
 #include <Base/FileInfo.h>
 #include <Base/Stream.h>
 #include <Base/Tools.h>
 #include <zipios++/gzipoutputstream.h>
 
 #include "SoFCDB.h"
-#include "SoFCColorBar.h"
-#include "SoFCColorLegend.h"
-#include "SoFCColorGradient.h"
-#include "SoFCSelection.h"
+#include "Flag.h"
+#include "GestureNavigationStyle.h"
+#include "NavigationStyle.h"
+#include "SelectionObject.h"
+#include "SoAxisCrossKit.h"
 #include "SoFCBackgroundGradient.h"
 #include "SoFCBoundingBox.h"
-#include "SoFCSelection.h"
-#include "SoFCUnifiedSelection.h"
-#include "SoFCSelectionAction.h"
+#include "SoFCColorBar.h"
+#include "SoFCColorGradient.h"
+#include "SoFCColorLegend.h"
+#include "SoFCCSysDragger.h"
 #include "SoFCInteractiveElement.h"
+#include "SoFCSelection.h"
+#include "SoFCSelectionAction.h"
 #include "SoFCUnifiedSelection.h"
 #include "SoFCVectorizeSVGAction.h"
 #include "SoFCVectorizeU3DAction.h"
-#include "SoAxisCrossKit.h"
-#include "SoTextLabel.h"
+#include "SoMouseWheelEvent.h"
 #include "SoNavigationDragger.h"
-#include "Inventor/SoDrawingGrid.h"
-#include "Inventor/SoAutoZoomTranslation.h"
+#include "SoTextLabel.h"
+#include "View3DPy.h"
 #include "Inventor/MarkerBitmaps.h"
 #include "Inventor/SmSwitchboard.h"
-#include "SoFCCSysDragger.h"
-#include "SoMouseWheelEvent.h"
-
+#include "Inventor/SoAutoZoomTranslation.h"
+#include "Inventor/SoDrawingGrid.h"
 #include "propertyeditor/PropertyItem.h"
-#include "NavigationStyle.h"
-#include "GestureNavigationStyle.h"
-#include "Flag.h"
-#include "SelectionObject.h"
-#include "View3DPy.h"
+
 
 using namespace Gui;
 using namespace Gui::Inventor;
@@ -84,7 +83,7 @@ using namespace Gui::PropertyEditor;
 static SbBool init_done = false;
 static SoGroup *storage = nullptr;
 
-SbBool Gui::SoFCDB::isInitialized(void)
+SbBool Gui::SoFCDB::isInitialized()
 {
     return init_done;
 }
@@ -125,6 +124,7 @@ void Gui::SoFCDB::init()
     SoVRMLAction                    ::initClass();
     SoSkipBoundingGroup             ::initClass();
     SoTextLabel                     ::initClass();
+    SoColorBarLabel                 ::initClass();
     SoStringLabel                   ::initClass();
     SoFrameLabel                    ::initClass();
     TranslateManip                  ::initClass();
@@ -161,6 +161,7 @@ void Gui::SoFCDB::init()
     PropertyDirectionItem           ::init();
     PropertyMatrixItem              ::init();
     PropertyPlacementItem           ::init();
+    PropertyRotationItem            ::init();
     PropertyEnumItem                ::init();
     PropertyStringListItem          ::init();
     PropertyFloatListItem           ::init();
@@ -184,6 +185,8 @@ void Gui::SoFCDB::init()
     TouchpadNavigationStyle         ::init();
     GestureNavigationStyle          ::init();
     OpenCascadeNavigationStyle      ::init();
+    OpenSCADNavigationStyle         ::init();
+    TinkerCADNavigationStyle        ::init();
 
     GLGraphicsItem                  ::init();
     GLFlagWindow                    ::init();
@@ -231,32 +234,31 @@ void Gui::SoFCDB::finish()
 }
 
 // buffer acrobatics for inventor ****************************************************
-static char * static_buffer;
-static size_t static_buffer_size = 0;
-static std::string cReturnString;
+
+namespace {
+static std::vector<char> static_buffer;
 
 static void *
-buffer_realloc(void * bufptr, size_t size)
+buffer_realloc(void * /*bufptr*/, std::size_t size)
 {
-    static_buffer = (char *)realloc(bufptr, size);
-    static_buffer_size = size;
-    return static_buffer;
+    static_buffer.resize(size);
+    return static_buffer.data();
+}
 }
 
 const std::string& Gui::SoFCDB::writeNodesToString(SoNode * root)
 {
     SoOutput out;
-    static_buffer = (char *)malloc(1024);
-    static_buffer_size = 1024;
-    out.setBuffer(static_buffer, static_buffer_size, buffer_realloc);
+    static_buffer.resize(1024);
+    out.setBuffer(static_buffer.data(), static_buffer.size(), buffer_realloc);
     if (root && root->getTypeId().isDerivedFrom(SoVRMLParent::getClassTypeId()))
         out.setHeaderString("#VRML V2.0 utf8");
 
     SoWriteAction wa(&out);
     wa.apply(root);
 
-    cReturnString = static_buffer;
-    free(static_buffer);
+    static std::string cReturnString;
+    cReturnString = static_buffer.data();
     return cReturnString;
 }
 
