@@ -23,72 +23,47 @@
 #include "PreCompiled.h"
 
 #ifndef _PreComp_
-#  include <cassert>
-#  include <float.h>
-#  include <Inventor/actions/SoSearchAction.h>
-#  include <Inventor/actions/SoGetBoundingBoxAction.h>
-#  include <Inventor/nodes/SoCallback.h>
-#  include <Inventor/nodes/SoComplexity.h>
-#  include <Inventor/nodes/SoCube.h>
-#  include <Inventor/nodes/SoCamera.h>
-#  include <Inventor/nodes/SoCoordinate3.h>
-#  include <Inventor/nodes/SoCoordinate4.h>
-#  include <Inventor/nodes/SoFont.h>
-#  include <Inventor/nodes/SoMatrixTransform.h>
-#  include <Inventor/nodes/SoProfile.h>
-#  include <Inventor/nodes/SoProfileCoordinate2.h>
-#  include <Inventor/nodes/SoProfileCoordinate3.h>
-#  include <Inventor/nodes/SoSwitch.h>
-#  include <Inventor/nodes/SoTransformation.h>
-#  include <Inventor/nodes/SoIndexedLineSet.h>
-#  include <Inventor/nodes/SoIndexedFaceSet.h>
-#  include <Inventor/nodes/SoPointSet.h>
-#  include <Inventor/nodes/SoDrawStyle.h>
-#  include <Inventor/nodes/SoComplexity.h>
-#  include <Inventor/nodes/SoLightModel.h>
-#  include <Inventor/nodes/SoBaseColor.h>
+# include <Inventor/actions/SoSearchAction.h>
+# include <Inventor/actions/SoGetBoundingBoxAction.h>
+# include <Inventor/elements/SoComplexityElement.h>
+# include <Inventor/elements/SoComplexityTypeElement.h>
+# include <Inventor/elements/SoCoordinateElement.h>
+# include <Inventor/elements/SoFontNameElement.h>
+# include <Inventor/elements/SoFontSizeElement.h>
+# include <Inventor/elements/SoModelMatrixElement.h>
+# include <Inventor/elements/SoProfileCoordinateElement.h>
+# include <Inventor/elements/SoProfileElement.h>
+# include <Inventor/elements/SoProjectionMatrixElement.h>
+# include <Inventor/elements/SoShapeStyleElement.h>
+# include <Inventor/elements/SoSwitchElement.h>
+# include <Inventor/elements/SoUnitsElement.h>
+# include <Inventor/elements/SoViewingMatrixElement.h>
+# include <Inventor/elements/SoViewportRegionElement.h>
+# include <Inventor/elements/SoViewVolumeElement.h>
+# include <Inventor/nodes/SoBaseColor.h>
+# include <Inventor/nodes/SoCallback.h>
+# include <Inventor/nodes/SoCamera.h>
+# include <Inventor/nodes/SoComplexity.h>
+# include <Inventor/nodes/SoCoordinate3.h>
+# include <Inventor/nodes/SoCoordinate4.h>
+# include <Inventor/nodes/SoCube.h>
+# include <Inventor/nodes/SoDrawStyle.h>
+# include <Inventor/nodes/SoFont.h>
+# include <Inventor/nodes/SoIndexedLineSet.h>
+# include <Inventor/nodes/SoIndexedFaceSet.h>
+# include <Inventor/nodes/SoLightModel.h>
+# include <Inventor/nodes/SoMatrixTransform.h>
+# include <Inventor/nodes/SoPointSet.h>
+# include <Inventor/nodes/SoProfile.h>
+# include <Inventor/nodes/SoProfileCoordinate2.h>
+# include <Inventor/nodes/SoProfileCoordinate3.h>
+# include <Inventor/nodes/SoSeparator.h>
+# include <Inventor/nodes/SoSwitch.h>
+# include <Inventor/nodes/SoTransformation.h>
 #endif
 
-#include <Base/Console.h>
-
 #include "SoFCSelectionAction.h"
 #include "SoFCSelection.h"
-#include "SoFCUnifiedSelection.h"
-#include <Inventor/bundles/SoMaterialBundle.h>
-#include <Inventor/elements/SoSwitchElement.h>
-#include "Selection.h"
-
-#include <Inventor/elements/SoComplexityElement.h>
-#include <Inventor/elements/SoComplexityTypeElement.h>
-#include <Inventor/elements/SoCoordinateElement.h>
-#include <Inventor/elements/SoElements.h>
-#include <Inventor/elements/SoFontNameElement.h>
-#include <Inventor/elements/SoFontSizeElement.h>
-#include <Inventor/elements/SoModelMatrixElement.h>
-#include <Inventor/elements/SoShapeStyleElement.h>
-#include <Inventor/elements/SoProfileCoordinateElement.h>
-#include <Inventor/elements/SoProfileElement.h>
-#include <Inventor/elements/SoSwitchElement.h>
-#include <Inventor/elements/SoUnitsElement.h>
-#include <Inventor/elements/SoViewVolumeElement.h>
-#include <Inventor/elements/SoViewingMatrixElement.h>
-#include <Inventor/elements/SoViewportRegionElement.h>
-#include <Inventor/nodes/SoCamera.h>
-#include <Inventor/nodes/SoComplexity.h>
-#include <Inventor/nodes/SoCoordinate3.h>
-#include <Inventor/nodes/SoCoordinate4.h>
-#include <Inventor/nodes/SoCube.h>
-#include <Inventor/nodes/SoFont.h>
-#include <Inventor/nodes/SoGroup.h>
-#include <Inventor/nodes/SoSeparator.h>
-#include <Inventor/nodes/SoProfile.h>
-#include <Inventor/nodes/SoProfileCoordinate2.h>
-#include <Inventor/nodes/SoProfileCoordinate3.h>
-#include <Inventor/nodes/SoSphere.h>
-#include <Inventor/nodes/SoTransformation.h>
-
-
-
 
 
 using namespace Gui;
@@ -977,17 +952,17 @@ class SoBoxSelectionRenderActionP {
 public:
     SoBoxSelectionRenderActionP(SoBoxSelectionRenderAction * master)
       : master(master)
-      , searchaction(0)
-      , selectsearch(0)
-      , camerasearch(0)
-      , bboxaction(0)
-      , basecolor(0)
-      , postprocpath(0)
-      , highlightPath(0)
-      , localRoot(0)
-      , xform(0)
-      , cube(0)
-      , drawstyle(0)
+      , searchaction(nullptr)
+      , selectsearch(nullptr)
+      , camerasearch(nullptr)
+      , bboxaction(nullptr)
+      , basecolor(nullptr)
+      , postprocpath(nullptr)
+      , highlightPath(nullptr)
+      , localRoot(nullptr)
+      , xform(nullptr)
+      , cube(nullptr)
+      , drawstyle(nullptr)
     {
 
     }
@@ -1055,7 +1030,7 @@ SoBoxSelectionRenderActionP::initBoxGraph()
 void
 SoBoxSelectionRenderActionP::updateBbox(const SoPath * path)
 {
-    if (this->camerasearch == NULL) {
+    if (this->camerasearch == nullptr) {
         this->camerasearch = new SoSearchAction;
     }
 
@@ -1072,7 +1047,7 @@ SoBoxSelectionRenderActionP::updateBbox(const SoPath * path)
     this->localRoot->insertChild(this->camerasearch->getPath()->getTail(), 0);
     this->camerasearch->reset();
 
-    if (this->bboxaction == NULL) {
+    if (this->bboxaction == nullptr) {
         this->bboxaction = new SoGetBoundingBoxAction(SbViewportRegion(100, 100));
     }
     this->bboxaction->setViewportRegion(PUBLIC(this)->getViewportRegion());
@@ -1111,12 +1086,12 @@ SO_ACTION_SOURCE(SoBoxSelectionRenderAction)
 
 // Overridden from parent class.
 void
-SoBoxSelectionRenderAction::initClass(void)
+SoBoxSelectionRenderAction::initClass()
 {
     SO_ACTION_INIT_CLASS(SoBoxSelectionRenderAction, SoGLRenderAction);
 }
 
-SoBoxSelectionRenderAction::SoBoxSelectionRenderAction(void)
+SoBoxSelectionRenderAction::SoBoxSelectionRenderAction()
   : inherited(SbViewportRegion())
 {
     this->constructorCommon();
@@ -1132,7 +1107,7 @@ SoBoxSelectionRenderAction::SoBoxSelectionRenderAction(const SbViewportRegion &
 // private. called by both constructors
 //
 void
-SoBoxSelectionRenderAction::constructorCommon(void)
+SoBoxSelectionRenderAction::constructorCommon()
 {
     SO_ACTION_CONSTRUCTOR(SoBoxSelectionRenderAction);
 
@@ -1147,18 +1122,18 @@ SoBoxSelectionRenderAction::constructorCommon(void)
     PRIVATE(this)->basecolor->rgb.setValue(1.0f, 0.0f, 0.0f);
     PRIVATE(this)->drawstyle->linePattern = 0xffff;
     PRIVATE(this)->drawstyle->lineWidth = 1.0f;
-    PRIVATE(this)->searchaction = NULL;
-    PRIVATE(this)->selectsearch = NULL;
-    PRIVATE(this)->camerasearch = NULL;
-    PRIVATE(this)->bboxaction = NULL;
+    PRIVATE(this)->searchaction = nullptr;
+    PRIVATE(this)->selectsearch = nullptr;
+    PRIVATE(this)->camerasearch = nullptr;
+    PRIVATE(this)->bboxaction = nullptr;
 
     // SoBase-derived objects should be dynamically allocated.
     PRIVATE(this)->postprocpath = new SoTempPath(32);
     PRIVATE(this)->postprocpath->ref();
-    PRIVATE(this)->highlightPath = 0;
+    PRIVATE(this)->highlightPath = nullptr;
 }
 
-SoBoxSelectionRenderAction::~SoBoxSelectionRenderAction(void)
+SoBoxSelectionRenderAction::~SoBoxSelectionRenderAction()
 {
     // clear highlighting node
     if (PRIVATE(this)->highlightPath) {
@@ -1179,7 +1154,7 @@ SoBoxSelectionRenderAction::apply(SoNode * node)
 {
     SoGLRenderAction::apply(node);
     if (this->hlVisible) {
-        if (PRIVATE(this)->searchaction == NULL) {
+        if (PRIVATE(this)->searchaction == nullptr) {
             PRIVATE(this)->searchaction = new SoSearchAction;
         }
         PRIVATE(this)->searchaction->setType(SoFCSelection::getClassTypeId());
@@ -1194,7 +1169,7 @@ SoBoxSelectionRenderAction::apply(SoNode * node)
                 assert(selection->getTypeId().isDerivedFrom(SoFCSelection::getClassTypeId()));
                 if (selection->selected.getValue() && selection->style.getValue() == SoFCSelection::BOX) {
                     PRIVATE(this)->basecolor->rgb.setValue(selection->colorSelection.getValue());
-                    if (PRIVATE(this)->selectsearch == NULL) {
+                    if (PRIVATE(this)->selectsearch == nullptr) {
                         PRIVATE(this)->selectsearch = new SoSearchAction;
                     }
                     PRIVATE(this)->selectsearch->setType(SoShape::getClassTypeId());
@@ -1213,7 +1188,7 @@ SoBoxSelectionRenderAction::apply(SoNode * node)
                          selection->style.getValue() == SoFCSelection::BOX) {
                     PRIVATE(this)->basecolor->rgb.setValue(selection->colorHighlight.getValue());
 
-                    if (PRIVATE(this)->selectsearch == NULL) {
+                    if (PRIVATE(this)->selectsearch == nullptr) {
                       PRIVATE(this)->selectsearch = new SoSearchAction;
                     }
                     PRIVATE(this)->selectsearch->setType(SoShape::getClassTypeId());
@@ -1250,7 +1225,7 @@ SoBoxSelectionRenderAction::apply(SoPath * path)
         // This happens when dehighlighting the current shape
         if (PRIVATE(this)->highlightPath == path) {
             PRIVATE(this)->highlightPath->unref();
-            PRIVATE(this)->highlightPath = 0;
+            PRIVATE(this)->highlightPath = nullptr;
             // FIXME: Doing a redraw to remove the shown bounding box causes
             // some problems when moving the mouse from one shape to another
             // because this will destroy the box immediately
@@ -1261,7 +1236,7 @@ SoBoxSelectionRenderAction::apply(SoPath * path)
                  selection->style.getValue() == SoFCSelection::BOX) {
             PRIVATE(this)->basecolor->rgb.setValue(selection->colorHighlight.getValue());
 
-            if (PRIVATE(this)->selectsearch == NULL) {
+            if (PRIVATE(this)->selectsearch == nullptr) {
               PRIVATE(this)->selectsearch = new SoSearchAction;
             }
             PRIVATE(this)->selectsearch->setType(SoShape::getClassTypeId());
@@ -1298,7 +1273,7 @@ SoBoxSelectionRenderAction::setColor(const SbColor & color)
 }
 
 const SbColor &
-SoBoxSelectionRenderAction::getColor(void)
+SoBoxSelectionRenderAction::getColor()
 {
     return PRIVATE(this)->basecolor->rgb[0];
 }
@@ -1310,7 +1285,7 @@ SoBoxSelectionRenderAction::setLinePattern(unsigned short pattern)
 }
 
 unsigned short
-SoBoxSelectionRenderAction::getLinePattern(void) const
+SoBoxSelectionRenderAction::getLinePattern() const
 {
     return PRIVATE(this)->drawstyle->linePattern.getValue();
 }
@@ -1322,7 +1297,7 @@ SoBoxSelectionRenderAction::setLineWidth(const float width)
 }
 
 float
-SoBoxSelectionRenderAction::getLineWidth(void) const
+SoBoxSelectionRenderAction::getLineWidth() const
 {
     return PRIVATE(this)->drawstyle->lineWidth.getValue();
 }
