@@ -20,17 +20,16 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #ifndef _SoFCSelectionAction_h
 #define _SoFCSelectionAction_h
 
-//#include <Inventor/SoAction.h>
-#include <Inventor/actions/SoSubAction.h>
-#include <Inventor/events/SoSubEvent.h>
-#include <Inventor/actions/SoGLRenderAction.h>
 #include <Inventor/SbColor.h>
+#include <Inventor/actions/SoGLRenderAction.h>
+#include <Inventor/fields/SoSFColor.h>
+#include <Inventor/fields/SoSFString.h>
 #include <vector>
 
+
 class SoSFString;
 class SoSFColor;
 
@@ -101,7 +100,7 @@ public:
     SoFCEnableSelectionAction (const SbBool& sel);
     ~SoFCEnableSelectionAction();
 
-    const SbBool& selection;
+    SbBool selection;
 
     static void initClass();
     static void finish(void);
@@ -126,7 +125,7 @@ public:
     SoFCEnableHighlightAction (const SbBool& sel);
     ~SoFCEnableHighlightAction();
 
-    const SbBool& highlight;
+    SbBool highlight;
 
     static void initClass();
     static void finish(void);
@@ -151,7 +150,7 @@ public:
     SoFCSelectionColorAction (const SoSFColor& col);
     ~SoFCSelectionColorAction();
 
-    const SoSFColor& selectionColor;
+    SoSFColor selectionColor;
 
     static void initClass();
     static void finish(void);
@@ -176,7 +175,7 @@ public:
     SoFCHighlightColorAction (const SoSFColor& col);
     ~SoFCHighlightColorAction();
 
-    const SoSFColor& highlightColor;
+    SoSFColor highlightColor;
 
     static void initClass();
     static void finish(void);
@@ -201,7 +200,7 @@ public:
     SoFCDocumentAction (const SoSFString& docName);
     ~SoFCDocumentAction();
 
-    const SoSFString& documentName;
+    SoSFString documentName;
 
     static void initClass();
     static void finish(void);
