@@ -20,16 +20,16 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #ifndef GUI_SPLITVIEW3DINVENTOR_H
 #define GUI_SPLITVIEW3DINVENTOR_H
 
 #include "MDIView.h"
+#include "MDIViewPy.h"
 
 #include <Base/Parameter.h>
-#include <CXX/Extensions.hxx>
 #include <vector>
 
+
 namespace Gui {
 class View3DInventorViewer;
 class AbstractSplitViewPy;
@@ -39,26 +39,29 @@ class AbstractSplitViewPy;
  */
 class GuiExport AbstractSplitView : public MDIView, public ParameterGrp::ObserverType
 {
+    Q_OBJECT
+
     TYPESYSTEM_HEADER();
 
 public:
     AbstractSplitView(Gui::Document* pcDocument, QWidget* parent, Qt::WindowFlags wflags=Qt::WindowFlags());
     ~AbstractSplitView();
 
-    virtual const char *getName(void) const;
+    virtual const char *getName() const;
 
     /// Message handler
     virtual bool onMsg(const char* pMsg, const char** ppReturn);
     virtual bool onHasMsg(const char* pMsg) const;
     virtual void OnChange(ParameterGrp::SubjectType &rCaller,ParameterGrp::MessageType Reason);
-    virtual void onUpdate(void);
+    virtual void onUpdate();
     virtual void deleteSelf();
+    virtual void viewAll();
 
     View3DInventorViewer *getViewer(unsigned int) const;
     void setOverrideCursor(const QCursor&);
     virtual bool containsViewProvider(const ViewProvider*) const;
 
-    PyObject *getPyObject(void);
+    PyObject *getPyObject();
     void setPyObject(PyObject *);
     int getSize();
 
@@ -75,12 +78,16 @@ protected:
 class AbstractSplitViewPy : public Py::PythonExtension<AbstractSplitViewPy>
 {
 public:
-    static void init_type(void);    // announce properties and methods
+    using BaseType = Py::PythonExtension<AbstractSplitViewPy>;
+    static void init_type();    // announce properties and methods
 
     AbstractSplitViewPy(AbstractSplitView *vi);
     ~AbstractSplitViewPy();
+    AbstractSplitView* getSplitViewPtr();
 
     Py::Object repr();
+    Py::Object getattr(const char *);
+    Py::Object cast_to_base(const Py::Tuple&);
 
     Py::Object fitAll(const Py::Tuple&);
     Py::Object viewBottom(const Py::Tuple&);
@@ -91,14 +98,12 @@ public:
     Py::Object viewTop(const Py::Tuple&);
     Py::Object viewIsometric(const Py::Tuple&);
     Py::Object getViewer(const Py::Tuple&);
-    Py::Object sequence_item(ssize_t);
+    Py::Object sequence_item(Py_ssize_t);
     Py::Object close(const Py::Tuple&);
     int sequence_length();
 
 private:
-    AbstractSplitView* _view;
-    friend class AbstractSplitView;
-    void testExistence();
+    Gui::MDIViewPy base;
 };
 
 /** The SplitView3DInventor class allows to create a window with two or more Inventor views.
