@@ -20,11 +20,10 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 
 #include "SyntaxHighlighter.h"
-#include "TextEdit.h"
+
 
 using namespace Gui;
 
@@ -159,13 +158,7 @@ void SyntaxHighlighter::colorChanged(const QString& type, const QColor& col)
 {
     Q_UNUSED(type);
     Q_UNUSED(col);
-  // rehighlight
-#if QT_VERSION >= 0x040200
     rehighlight();
-#else
-    document()->setPlainText(document()->toPlainText());
-    document()->setModified(false);
-#endif
 }
 
 int SyntaxHighlighter::maximumUserState() const
