@@ -20,17 +20,14 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 
-#ifndef _PreComp_
-#endif
-
-#include "ui_DlgLocationPos.h"
 #include "ui_DlgLocationAngle.h"
+#include "ui_DlgLocationPos.h"
 
 #include "TaskDlgRelocation.h"
-#include <Gui/BitmapFactory.h>
+#include "BitmapFactory.h"
+
 
 using namespace Gui;
 
