@@ -38,7 +38,7 @@ class TaskBoxPosition : public Gui::TaskView::TaskBox
     Q_OBJECT
 
 public:
-    TaskBoxPosition(QWidget *parent = 0);
+    TaskBoxPosition(QWidget *parent = nullptr);
     ~TaskBoxPosition();
 
 
@@ -56,7 +56,7 @@ class TaskBoxAngle : public Gui::TaskView::TaskBox
     Q_OBJECT
 
 public:
-    TaskBoxAngle(QWidget *parent = 0);
+    TaskBoxAngle(QWidget *parent = nullptr);
     ~TaskBoxAngle();
 
 
@@ -92,7 +92,7 @@ public:
     virtual void helpRequested();
 
     /// returns for Close and Help button
-    virtual QDialogButtonBox::StandardButtons getStandardButtons(void) const
+    virtual QDialogButtonBox::StandardButtons getStandardButtons() const
 	{ return QDialogButtonBox::Ok|QDialogButtonBox::Cancel; }
 
 protected:
