@@ -20,7 +20,6 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 
 #ifndef _PreComp_
@@ -29,22 +28,22 @@
 # include <QPointer>
 #endif
 
-#include "TaskDialogPython.h"
-#include "TaskView.h"
-
+#include <Base/Interpreter.h>
 #include <Gui/Application.h>
 #include <Gui/BitmapFactory.h>
 #include <Gui/Command.h>
 #include <Gui/Control.h>
-#include <Gui/WidgetFactory.h>
-#include <Base/Interpreter.h>
-#include <Base/Console.h>
-#include <CXX/Objects.hxx>
+#include <Gui/UiLoader.h>
+#include <Gui/PythonWrapper.h>
+
+#include "TaskDialogPython.h"
+#include "TaskView.h"
+
 
 using namespace Gui;
 using namespace Gui::TaskView;
 
-ControlPy* ControlPy::instance = 0;
+ControlPy* ControlPy::instance = nullptr;
 
 ControlPy* ControlPy::getInstance()
 {
@@ -61,15 +60,38 @@ void ControlPy::init_type()
     behaviors().supportRepr();
     behaviors().supportGetattr();
     behaviors().supportSetattr();
-    add_varargs_method("showDialog",&ControlPy::showDialog,"showDialog()");
-    add_varargs_method("activeDialog",&ControlPy::activeDialog,"activeDialog()");
-    add_varargs_method("closeDialog",&ControlPy::closeDialog,"closeDialog()");
-    add_varargs_method("addTaskWatcher",&ControlPy::addTaskWatcher,"addTaskWatcher()");
-    add_varargs_method("clearTaskWatcher",&ControlPy::clearTaskWatcher,"clearTaskWatcher()");
-    add_varargs_method("isAllowedAlterDocument",&ControlPy::isAllowedAlterDocument,"isAllowedAlterDocument()");
-    add_varargs_method("isAllowedAlterView",&ControlPy::isAllowedAlterView,"isAllowedAlterView()");
-    add_varargs_method("isAllowedAlterSelection",&ControlPy::isAllowedAlterSelection,"isAllowedAlterSelection()");
-    add_varargs_method("showTaskView",&ControlPy::showTaskView,"showTaskView()");
+    add_varargs_method("showDialog",&ControlPy::showDialog,
+                        "show the given dialog in the task panel\n"
+                        "showDialog(dialog)\n"
+                        "--\n"
+                        "if a task is already active a RuntimeError is raised");
+    add_varargs_method("activeDialog",&ControlPy::activeDialog,
+                        "check if a dialog is active in the task panel\n"
+                        "activeDialog() --> bool");
+    add_varargs_method("closeDialog",&ControlPy::closeDialog,
+                        "close the active dialog\n"
+                        "closeDialog()");
+    add_varargs_method("addTaskWatcher",&ControlPy::addTaskWatcher,
+                        "install a (list of) TaskWatcher\n"
+                        "addTaskWatcher(TaskWatcher | list)");
+    add_varargs_method("clearTaskWatcher",&ControlPy::clearTaskWatcher,
+                        "remove all TaskWatchers\n"
+                        "clearTaskWatcher()");
+    add_varargs_method("isAllowedAlterDocument",&ControlPy::isAllowedAlterDocument,
+                        "return the permission to alter the current Document\n"
+                        "isAllowedAlterDocument() --> bool");
+    add_varargs_method("isAllowedAlterView",&ControlPy::isAllowedAlterView,
+                        "return the permission to alter the current View\n"
+                        "isAllowedAlterView() --> bool");
+    add_varargs_method("isAllowedAlterSelection",&ControlPy::isAllowedAlterSelection,
+                        "return the permission to alter the current Selection\n"
+                        "isAllowedAlterSelection() --> bool");
+    add_varargs_method("showTaskView",&ControlPy::showTaskView,
+                        "show the Task panel\n"
+                        "showTaskView()");
+    add_varargs_method("showModelView",&ControlPy::showModelView,
+                        "show the Model panel\n"
+                        "showModelView()");
 }
 
 ControlPy::ControlPy()
@@ -106,7 +128,7 @@ Py::Object ControlPy::activeDialog(const Py::Tuple& args)
     if (!PyArg_ParseTuple(args.ptr(), ""))
         throw Py::Exception();
     Gui::TaskView::TaskDialog* dlg = Gui::Control().activeDialog();
-    return Py::Boolean(dlg!=0);
+    return Py::Boolean(dlg!=nullptr);
 }
 
 Py::Object ControlPy::closeDialog(const Py::Tuple& args)
@@ -178,10 +200,18 @@ Py::Object ControlPy::showTaskView(const Py::Tuple& args)
     return Py::None();
 }
 
+Py::Object ControlPy::showModelView(const Py::Tuple& args)
+{
+    if (!PyArg_ParseTuple(args.ptr(), ""))
+        throw Py::Exception();
+    Gui::Control().showModelView();
+    return Py::None();
+}
+
 // ------------------------------------------------------------------
 
 TaskWatcherPython::TaskWatcherPython(const Py::Object& o)
-  : TaskWatcher(0), watcher(o)
+  : TaskWatcher(nullptr), watcher(o)
 {
     QString title;
     if (watcher.hasAttr(std::string("title"))) {
@@ -197,9 +227,9 @@ TaskWatcherPython::TaskWatcherPython(const Py::Object& o)
         icon = BitmapFactory().pixmap(s.c_str());
     }
 
-    Gui::TaskView::TaskBox *tb = 0;
+    Gui::TaskView::TaskBox *tb = nullptr;
     if (watcher.hasAttr(std::string("commands"))) {
-        tb = new Gui::TaskView::TaskBox(icon, title, true, 0);
+        tb = new Gui::TaskView::TaskBox(icon, title, true, nullptr);
         Py::Sequence cmds(watcher.getAttr(std::string("commands")));
         CommandManager &mgr = Gui::Application::Instance->commandManager();
         for (Py::Sequence::iterator it = cmds.begin(); it != cmds.end(); ++it) {
@@ -213,7 +243,7 @@ TaskWatcherPython::TaskWatcherPython(const Py::Object& o)
 
     if (watcher.hasAttr(std::string("widgets"))) {
         if (!tb && !title.isEmpty())
-            tb = new Gui::TaskView::TaskBox(icon, title, true, 0);
+            tb = new Gui::TaskView::TaskBox(icon, title, true, nullptr);
         Py::Sequence list(watcher.getAttr(std::string("widgets")));
 
         Gui::PythonWrapper wrap;
@@ -280,22 +310,20 @@ TaskDialogPython::TaskDialogPython(const Py::Object& o) : dlg(o)
 {
     if (dlg.hasAttr(std::string("ui"))) {
         UiLoader loader;
-#if QT_VERSION >= 0x040500
         loader.setLanguageChangeEnabled(true);
-#endif
         QString fn, icon;
         Py::String ui(dlg.getAttr(std::string("ui")));
         std::string path = (std::string)ui;
         fn = QString::fromUtf8(path.c_str());
 
         QFile file(fn);
-        QWidget* form = 0;
+        QWidget* form = nullptr;
         if (file.open(QFile::ReadOnly))
-            form = loader.load(&file, 0);
+            form = loader.load(&file, nullptr);
         file.close();
         if (form) {
             Gui::TaskView::TaskBox* taskbox = new Gui::TaskView::TaskBox(
-                QPixmap(icon), form->windowTitle(), true, 0);
+                QPixmap(icon), form->windowTitle(), true, nullptr);
             taskbox->groupLayout()->addWidget(form);
             Content.push_back(taskbox);
         }
@@ -305,7 +333,7 @@ TaskDialogPython::TaskDialogPython(const Py::Object& o) : dlg(o)
         }
     }
     else if (dlg.hasAttr(std::string("form"))) {
-        Py::Object f(dlg.getAttr(std::string("form"))); 
+        Py::Object f(dlg.getAttr(std::string("form")));
         Py::List widgets;
         if (f.isList()) {
             widgets = f;
@@ -322,7 +350,7 @@ TaskDialogPython::TaskDialogPython(const Py::Object& o) : dlg(o)
                     QWidget* form = qobject_cast<QWidget*>(object);
                     if (form) {
                         Gui::TaskView::TaskBox* taskbox = new Gui::TaskView::TaskBox(
-                            form->windowIcon().pixmap(32), form->windowTitle(), true, 0);
+                            form->windowIcon().pixmap(32), form->windowTitle(), true, nullptr);
                         taskbox->groupLayout()->addWidget(form);
                         Content.push_back(taskbox);
                     }
@@ -339,14 +367,7 @@ TaskDialogPython::~TaskDialogPython()
     Content.clear();
 
     Base::PyGILStateLocker lock;
-
-    // The widgets stored in the 'form' attribute will be deleted.
-    // Thus, set this attribute to None to make sure that when using
-    // the same dialog instance for a task panel won't segfault.
-    if (this->dlg.hasAttr(std::string("form"))) {
-        this->dlg.setAttr(std::string("form"), Py::None());
-    }
-    this->dlg = Py::None();
+    clearForm();
 
     // Assigning None to 'dlg' may destroy some of the stored widgets.
     // By guarding them with QPointer their pointers will be set to null
@@ -354,6 +375,22 @@ TaskDialogPython::~TaskDialogPython()
     Content.insert(Content.begin(), guarded.begin(), guarded.end());
 }
 
+void TaskDialogPython::clearForm()
+{
+    try {
+        // The widgets stored in the 'form' attribute will be deleted.
+        // Thus, set this attribute to None to make sure that when using
+        // the same dialog instance for a task panel won't segfault.
+        if (this->dlg.hasAttr(std::string("form"))) {
+            this->dlg.setAttr(std::string("form"), Py::None());
+        }
+        this->dlg = Py::None();
+    }
+    catch (Py::AttributeError& e) {
+        e.clear();
+    }
+}
+
 void TaskDialogPython::open()
 {
     Base::PyGILStateLocker lock;
@@ -441,7 +478,7 @@ void TaskDialogPython::helpRequested()
     }
 }
 
-QDialogButtonBox::StandardButtons TaskDialogPython::getStandardButtons(void) const
+QDialogButtonBox::StandardButtons TaskDialogPython::getStandardButtons() const
 {
     Base::PyGILStateLocker lock;
     try {
@@ -481,7 +518,7 @@ void TaskDialogPython::modifyStandardButtons(QDialogButtonBox *buttonBox)
     }
 }
 
-bool TaskDialogPython::isAllowedAlterDocument(void) const
+bool TaskDialogPython::isAllowedAlterDocument() const
 {
     Base::PyGILStateLocker lock;
     try {
@@ -500,7 +537,7 @@ bool TaskDialogPython::isAllowedAlterDocument(void) const
     return TaskDialog::isAllowedAlterDocument();
 }
 
-bool TaskDialogPython::isAllowedAlterView(void) const
+bool TaskDialogPython::isAllowedAlterView() const
 {
     Base::PyGILStateLocker lock;
     try {
@@ -519,7 +556,7 @@ bool TaskDialogPython::isAllowedAlterView(void) const
     return TaskDialog::isAllowedAlterView();
 }
 
-bool TaskDialogPython::isAllowedAlterSelection(void) const
+bool TaskDialogPython::isAllowedAlterSelection() const
 {
     Base::PyGILStateLocker lock;
     try {
