@@ -24,17 +24,11 @@
 #ifndef GUI_TASKVIEW_TASKWATCHER_H
 #define GUI_TASKVIEW_TASKWATCHER_H
 
-#include <map>
-#include <string>
 #include <vector>
 #include <QObject>
 
-#include <Gui/Selection.h>
 #include <Gui/SelectionFilter.h>
 
-namespace App {
-
-}
 
 namespace Gui {
 namespace TaskView {
@@ -50,11 +44,11 @@ public:
     TaskWatcher(const char* Filter);
     virtual ~TaskWatcher();
 
-    std::vector<QWidget*> &getWatcherContent(void);
+    std::vector<QWidget*> &getWatcherContent();
 
 public:
     /// is called wenn the document or the Selection changes. 
-    virtual bool shouldShow(void);
+    virtual bool shouldShow();
 
 protected:
     /// List of TaskBoxes of that dialog
@@ -74,7 +68,7 @@ public:
 
 public:
     /// is called wenn the document or the Selection changes. 
-    virtual bool shouldShow(void);
+    virtual bool shouldShow();
 
 };
 
@@ -90,7 +84,7 @@ public:
 
 public:
     /// is called wenn the document or the Selection changes. 
-    virtual bool shouldShow(void);
+    virtual bool shouldShow();
 
 };
 
@@ -107,7 +101,7 @@ public:
 
 public:
     /// is called wenn the document or the Selection changes. 
-    virtual bool shouldShow(void);
+    virtual bool shouldShow();
 
 };
 
