@@ -23,12 +23,14 @@
 #ifndef GUI_TRANSFORM_H
 #define GUI_TRANSFORM_H
 
-#include <Gui/InputVector.h>
-#include <Gui/Selection.h>
-#include <Gui/TaskView/TaskDialog.h>
-#include <Gui/TaskView/TaskView.h>
-#include <Base/Placement.h>
 #include <set>
+#include <Base/Placement.h>
+
+#include "InputVector.h"
+#include "Selection.h"
+#include "TaskView/TaskDialog.h"
+#include "TaskView/TaskView.h"
+
 
 namespace Gui {
 namespace Dialog {
@@ -71,7 +73,7 @@ class GuiExport Transform : public Gui::LocationDialog
     Q_OBJECT
 
 public:
-    Transform(QWidget* parent = 0, Qt::WindowFlags fl = Qt::WindowFlags());
+    Transform(QWidget* parent = nullptr, Qt::WindowFlags fl = Qt::WindowFlags());
     ~Transform();
     void accept();
     void reject();
