@@ -25,17 +25,17 @@
 #define GUI_TREE_H
 
 #include <unordered_map>
-#include <QTreeWidget>
 #include <QElapsedTimer>
 #include <QStyledItemDelegate>
+#include <QTreeWidget>
 
+#include <App/Application.h>
+#include <App/DocumentObject.h>
 #include <Base/Parameter.h>
 #include <Base/Persistence.h>
-#include <App/Document.h>
-#include <App/Application.h>
-
 #include <Gui/DockWindow.h>
 #include <Gui/Selection.h>
+#include <Gui/TreeItemMode.h>
 
 class QLineEdit;
 
@@ -48,26 +48,6 @@ typedef std::shared_ptr<DocumentObjectData> DocumentObjectDataPtr;
 
 class DocumentItem;
 
-/// highlight modes for the tree items
-enum class HighlightMode {
-    Underlined,
-    Italic,
-    Overlined,
-    Bold,
-    Blue,
-    LightBlue,
-    UserDefined
-};
-
-/// highlight modes for the tree items
-enum class TreeItemMode {
-    ExpandItem,
-    ExpandPath,
-    CollapseItem,
-    ToggleItem
-};
-
-
 /** Tree view that allows drag & drop of document objects.
  * @author Werner Mayer
  */
@@ -76,7 +56,7 @@ class TreeWidget : public QTreeWidget, public SelectionObserver
     Q_OBJECT
 
 public:
-    TreeWidget(const char *name, QWidget* parent=0);
+    TreeWidget(const char *name, QWidget* parent=nullptr);
     ~TreeWidget();
 
     static void scrollItemToTop();
@@ -98,7 +78,7 @@ public:
      * This function can return the non-group parent of the selected object,
      * which Gui::Selection() cannot provide.
      */
-    static std::vector<SelInfo> getSelection(App::Document *doc=0);
+    static std::vector<SelInfo> getSelection(App::Document *doc=nullptr);
 
     static TreeWidget *instance();
 
@@ -131,6 +111,8 @@ public:
 
     void synchronizeSelectionCheckBoxes();
 
+    QList<QTreeWidgetItem *> childrenOfItem(const QTreeWidgetItem &item) const;
+
 protected:
     /// Observer message from the Selection
     void onSelectionChanged(const SelectionChanges& msg) override;
@@ -164,6 +146,7 @@ protected Q_SLOTS:
     void onActivateDocument(QAction*);
     void onStartEditing();
     void onFinishEditing();
+    void onSelectDependents();
     void onSkipRecompute(bool on);
     void onAllowPartialRecompute(bool on);
     void onReloadDoc();
@@ -177,12 +160,12 @@ protected Q_SLOTS:
     void onSearchObjects();
 
 private Q_SLOTS:
-    void onItemSelectionChanged(void);
+    void onItemSelectionChanged();
     void onItemChanged(QTreeWidgetItem*, int);
     void onItemEntered(QTreeWidgetItem * item);
     void onItemCollapsed(QTreeWidgetItem * item);
     void onItemExpanded(QTreeWidgetItem * item);
-    void onUpdateStatus(void);
+    void onUpdateStatus();
 
 Q_SIGNALS:
     void emitSearchObjects();
@@ -208,10 +191,14 @@ private:
     void updateChildren(App::DocumentObject *obj,
             const std::set<DocumentObjectDataPtr> &data, bool output, bool force);
 
+    bool CheckForDependents();
+    void addDependentToSelection(App::Document* doc, App::DocumentObject* docObject);
+
 private:
     QAction* createGroupAction;
     QAction* relabelObjectAction;
     QAction* finishEditingAction;
+    QAction* selectDependentsAction;
     QAction* skipRecomputeAction;
     QAction* allowPartialRecomputeAction;
     QAction* markRecomputeAction;
@@ -275,7 +262,7 @@ public:
     ~DocumentItem();
 
     Gui::Document* document() const;
-    void clearSelection(DocumentObjectItem *exclude=0);
+    void clearSelection(DocumentObjectItem *exclude=nullptr);
     void updateSelection(QTreeWidgetItem *, bool unselect=false);
     void updateSelection();
     void updateItemSelection(DocumentObjectItem *);
@@ -287,7 +274,7 @@ public:
     };
     void selectItems(SelectionReason reason=SR_SELECT);
 
-    void testStatus(void);
+    void testStatus();
     void setData(int column, int role, const QVariant & value) override;
     void populateItem(DocumentObjectItem *item, bool refresh=false, bool delayUpdate=true);
     bool populateObject(App::DocumentObject *obj);
@@ -305,7 +292,7 @@ public:
 
     bool isObjectShowable(App::DocumentObject *obj);
 
-    virtual unsigned int getMemSize (void) const override;
+    virtual unsigned int getMemSize () const override;
     virtual void Save (Base::Writer &) const override;
     virtual void Restore(Base::XMLReader &) override;
 
@@ -333,7 +320,7 @@ protected:
     bool updateObject(const Gui::ViewProviderDocumentObject&, const App::Property &prop);
 
     bool createNewItem(const Gui::ViewProviderDocumentObject&,
-                    QTreeWidgetItem *parent=0, int index=-1,
+                    QTreeWidgetItem *parent=nullptr, int index=-1,
                     DocumentObjectDataPtr ptrs = DocumentObjectDataPtr());
 
     int findRootIndex(App::DocumentObject *childObj);
@@ -408,15 +395,15 @@ public:
 
     // return the owner, and full qualified subname
     App::DocumentObject *getFullSubName(std::ostringstream &str,
-            DocumentObjectItem *parent = 0) const;
+            DocumentObjectItem *parent = nullptr) const;
 
     // return the immediate descendent of the common ancestor of this item and
     // 'cousin'.
     App::DocumentObject *getRelativeParent(
             std::ostringstream &str,
             DocumentObjectItem *cousin,
-            App::DocumentObject **topParent=0,
-            std::string *topSubname=0) const;
+            App::DocumentObject **topParent=nullptr,
+            std::string *topSubname=nullptr) const;
 
     // return the top most linked group owner's name, and subname.  This method
     // is necessary despite have getFullSubName above is because native geo group
@@ -484,7 +471,7 @@ class TreeDockWidget : public Gui::DockWindow
     Q_OBJECT
 
 public:
-    TreeDockWidget(Gui::Document*  pcDocument,QWidget *parent=0);
+    TreeDockWidget(Gui::Document*  pcDocument,QWidget *parent=nullptr);
     ~TreeDockWidget();
 };
 
@@ -495,7 +482,7 @@ public:
 class TreeWidgetEditDelegate: public QStyledItemDelegate {
     Q_OBJECT
 public:
-    TreeWidgetEditDelegate(QObject* parent=0);
+    TreeWidgetEditDelegate(QObject* parent=nullptr);
     virtual QWidget* createEditor(QWidget *parent,
             const QStyleOptionViewItem &, const QModelIndex &index) const;
 };
@@ -523,6 +510,7 @@ public:
     TreeParams();
     void OnChange(Base::Subject<const char*> &, const char* sReason);
     static TreeParams *Instance();
+    bool getTreeViewStretchDescription() const;
 
 #define FC_TREEPARAM_DEFS \
     FC_TREEPARAM_DEF2(SyncSelection,bool,Bool,true) \
