@@ -26,12 +26,6 @@
 
 #include <QTreeView>
 
-#include <App/Document.h>
-#include <App/Application.h>
-
-#include <Gui/DockWindow.h>
-#include <Gui/Selection.h>
-
 namespace Gui {
 
 class GuiExport TreeView : public QTreeView
@@ -39,7 +33,7 @@ class GuiExport TreeView : public QTreeView
     Q_OBJECT
 
 public:
-    TreeView(QWidget* parent=0);
+    TreeView(QWidget* parent=nullptr);
     virtual ~TreeView();
 
 protected:
