@@ -20,20 +20,20 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 #ifndef _PreComp_
-# include <algorithm>
-# include <Inventor/SbMatrix.h>
 # include <Inventor/SbTesselator.h>
 # include <QAbstractItemModel>
 # include <QAbstractItemView>
 # include <QItemSelection>
 # include <QItemSelectionModel>
 #endif
-#include "Utilities.h"
+
 #include <App/DocumentObject.h>
 
+#include "Utilities.h"
+
+
 using namespace Gui;
 
 
