@@ -20,21 +20,20 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 
 #ifndef _PreComp_
+# include <string>
 # include <QAction>
 # include <QApplication>
-# include <QFileInfo>
 # include <QKeyEvent>
 # include <QEvent>
 # include <QDropEvent>
 # include <QDragEnterEvent>
-# include <QFileDialog>
 # include <QLayout>
 # include <QMdiSubWindow>
 # include <QMessageBox>
+# include <QMimeData>
 # include <QPainter>
 # include <QPrinter>
 # include <QPrintDialog>
@@ -42,58 +41,35 @@
 # include <QStackedWidget>
 # include <QTimer>
 # include <QUrl>
-# include <QMimeData>
-# include <Inventor/actions/SoWriteAction.h>
+# include <QWindow>
 # include <Inventor/actions/SoGetPrimitiveCountAction.h>
+# include <Inventor/fields/SoSFColor.h>
+# include <Inventor/fields/SoSFString.h>
 # include <Inventor/nodes/SoDirectionalLight.h>
-# include <Inventor/nodes/SoMaterial.h>
 # include <Inventor/nodes/SoOrthographicCamera.h>
 # include <Inventor/nodes/SoPerspectiveCamera.h>
 # include <Inventor/nodes/SoSeparator.h>
-# include <Inventor/nodes/SoShapeHints.h>
-# include <Inventor/events/SoEvent.h>
-# include <Inventor/fields/SoSFString.h>
-# include <Inventor/fields/SoSFColor.h>
-#endif
-# include <QStackedWidget>
-#include <QtOpenGL.h>
-
-#if defined(HAVE_QT5_OPENGL)
-# include <QWindow>
 #endif
 
-#include <Base/Exception.h>
+#include <App/Document.h>
 #include <Base/Console.h>
-#include <Base/FileInfo.h>
-
-#include <App/DocumentObject.h>
+#include <Base/Interpreter.h>
 
 #include "View3DInventor.h"
-#include "View3DInventorViewer.h"
+#include "Application.h"
 #include "Document.h"
 #include "FileDialog.h"
-#include "Application.h"
 #include "MainWindow.h"
-#include "MenuManager.h"
+#include "NavigationStyle.h"
+#include "SoFCDB.h"
+#include "SoFCSelectionAction.h"
+#include "SoFCVectorizeSVGAction.h"
+#include "View3DInventorExamples.h"
+#include "View3DInventorViewer.h"
+#include "View3DPy.h"
 #include "ViewProvider.h"
 #include "WaitCursor.h"
-#include "SoFCVectorizeSVGAction.h"
 
-// build in Inventor
-#include <Inventor/nodes/SoPerspectiveCamera.h>
-#include <Inventor/nodes/SoOrthographicCamera.h>
-
-#include "View3DInventorExamples.h"
-#include "ViewProviderDocumentObject.h"
-#include "SoFCSelectionAction.h"
-#include "View3DPy.h"
-#include "SoFCDB.h"
-#include "NavigationStyle.h"
-#include "PropertyView.h"
-#include "Selection.h"
-#include "SelectionObject.h"
-
-#include <locale>
 
 using namespace Gui;
 
@@ -110,7 +86,7 @@ TYPESYSTEM_SOURCE_ABSTRACT(Gui::View3DInventor,Gui::MDIView)
 
 View3DInventor::View3DInventor(Gui::Document* pcDocument, QWidget* parent,
                                const QtGLWidget* sharewidget, Qt::WindowFlags wflags)
-    : MDIView(pcDocument, parent, wflags), _viewerPy(0)
+    : MDIView(pcDocument, parent, wflags), _viewerPy(nullptr)
 {
     stack = new QStackedWidget(this);
     // important for highlighting
@@ -130,9 +106,6 @@ View3DInventor::View3DInventor(Gui::Document* pcDocument, QWidget* parent,
 
     if (samples > 1) {
         glformat = true;
-#if !defined(HAVE_QT5_OPENGL)
-        f.setSampleBuffers(true);
-#endif
         f.setSamples(samples);
     }
     else if (samples > 0) {
@@ -161,6 +134,7 @@ View3DInventor::View3DInventor(Gui::Document* pcDocument, QWidget* parent,
     // apply the user settings
     OnChange(*hGrp,"EyeDistance");
     OnChange(*hGrp,"CornerCoordSystem");
+    OnChange(*hGrp,"CornerCoordSystemSize");
     OnChange(*hGrp,"ShowAxisCross");
     OnChange(*hGrp,"UseAutoRotation");
     OnChange(*hGrp,"Gradient");
@@ -214,7 +188,7 @@ View3DInventor::~View3DInventor()
         QWidget* par = foc->parentWidget();
         while (par) {
             if (par == this) {
-                foc->setFocusProxy(0);
+                foc->setFocusProxy(nullptr);
                 foc->clearFocus();
                 break;
             }
@@ -223,7 +197,7 @@ View3DInventor::~View3DInventor()
     }
 
     if (_viewerPy) {
-        static_cast<View3DInventorPy*>(_viewerPy)->_view = 0;
+        Base::PyGILStateLocker lock;
         Py_DECREF(_viewerPy);
     }
 
@@ -233,12 +207,12 @@ View3DInventor::~View3DInventor()
 
 void View3DInventor::deleteSelf()
 {
-    _viewer->setSceneGraph(0);
-    _viewer->setDocument(0);
+    _viewer->setSceneGraph(nullptr);
+    _viewer->setDocument(nullptr);
     MDIView::deleteSelf();
 }
 
-PyObject *View3DInventor::getPyObject(void)
+PyObject *View3DInventor::getPyObject()
 {
     if (!_viewerPy)
         _viewerPy = new View3DInventorPy(this);
@@ -377,6 +351,9 @@ void View3DInventor::OnChange(ParameterGrp::SubjectType &rCaller,ParameterGrp::M
     else if (strcmp(Reason,"CornerCoordSystem") == 0) {
         _viewer->setFeedbackVisibility(rGrp.GetBool("CornerCoordSystem",true));
     }
+    else if (strcmp(Reason,"CornerCoordSystemSize") == 0) {
+        _viewer->setFeedbackSize(rGrp.GetInt("CornerCoordSystemSize",10));
+    }
     else if (strcmp(Reason,"ShowAxisCross") == 0) {
         _viewer->setAxisCross(rGrp.GetBool("ShowAxisCross",false));
     }
@@ -466,7 +443,7 @@ void View3DInventor::onRename(Gui::Document *pDoc)
     cAct.apply(_viewer->getSceneGraph());
 }
 
-void View3DInventor::onUpdate(void)
+void View3DInventor::onUpdate()
 {
 #ifdef FC_LOGUPDATECHAIN
     Base::Console().Log("Acti: Gui::View3DInventor::onUpdate()");
@@ -480,7 +457,7 @@ void View3DInventor::viewAll()
     _viewer->viewAll();
 }
 
-const char *View3DInventor::getName(void) const
+const char *View3DInventor::getName() const
 {
     return "View3DInventor";
 }
@@ -489,10 +466,13 @@ void View3DInventor::print()
 {
     QPrinter printer(QPrinter::ScreenResolution);
     printer.setFullPage(true);
+    restorePrinterSettings(&printer);
+
     QPrintDialog dlg(&printer, this);
     if (dlg.exec() == QDialog::Accepted) {
         Gui::WaitCursor wc;
         print(&printer);
+        savePrinterSettings(&printer);
     }
 }
 
@@ -504,6 +484,7 @@ void View3DInventor::printPdf()
         Gui::WaitCursor wc;
         QPrinter printer(QPrinter::ScreenResolution);
         printer.setOutputFormat(QPrinter::PdfFormat);
+        printer.setPageOrientation(QPageLayout::Landscape);
         printer.setOutputFileName(filename);
         print(&printer);
     }
@@ -513,24 +494,19 @@ void View3DInventor::printPreview()
 {
     QPrinter printer(QPrinter::ScreenResolution);
     printer.setFullPage(true);
-#if QT_VERSION >= 0x050300
-    printer.setPageSize(QPageSize(QPageSize::A4));
-    printer.setPageOrientation(QPageLayout::Landscape);
-#else
-    printer.setPageSize(QPrinter::A4);
-    printer.setOrientation(QPrinter::Landscape);
-#endif
+    restorePrinterSettings(&printer);
 
     QPrintPreviewDialog dlg(&printer, this);
     connect(&dlg, SIGNAL(paintRequested (QPrinter *)),
             this, SLOT(print(QPrinter *)));
     dlg.exec();
+    savePrinterSettings(&printer);
 }
 
 void View3DInventor::print(QPrinter* printer)
 {
     QPainter p(printer);
-    p.setRenderHints(QPainter::Antialiasing | QPainter::HighQualityAntialiasing);
+    p.setRenderHints(QPainter::Antialiasing);
     if (!p.isActive() && !printer->outputFileName().isEmpty()) {
         qApp->setOverrideCursor(Qt::ArrowCursor);
         QMessageBox::critical(this, tr("Opening file failed"),
@@ -539,11 +515,7 @@ void View3DInventor::print(QPrinter* printer)
         return;
     }
 
-#if QT_VERSION >= 0x050300
     QRect rect = printer->pageLayout().paintRectPixels(printer->resolution());
-#else
-    QRect rect = printer->pageRect();
-#endif
     QImage img;
     _viewer->imageFromFramebuffer(rect.width(), rect.height(), 8, QColor(255,255,255), img);
     p.drawImage(0,0,img);
@@ -612,7 +584,8 @@ bool View3DInventor::onMsg(const char* pMsg, const char** ppReturn)
     }
     else if(strcmp("GetCamera",pMsg) == 0 ) {
         SoCamera * Cam = _viewer->getSoRenderManager()->getCamera();
-        if (!Cam) return false;
+        if (!Cam)
+            return false;
         *ppReturn = SoFCDB::writeNodesToString(Cam).c_str();
         return true;
     }
@@ -949,7 +922,6 @@ void View3DInventor::setCurrentViewMode(ViewMode newmode)
     if (oldmode == newmode)
         return;
 
-#if defined(HAVE_QT5_OPENGL)
     if (newmode == Child) {
         // Fix in two steps:
         // The mdi view got a QWindow when it became a top-level widget and when resetting it to a child widget
@@ -961,11 +933,9 @@ void View3DInventor::setCurrentViewMode(ViewMode newmode)
         if (winHandle)
             winHandle->destroy();
     }
-#endif
 
     MDIView::setCurrentViewMode(newmode);
 
-#if defined(HAVE_QT5_OPENGL)
     // Internally the QOpenGLWidget switches of the multi-sampling and there is no
     // way to switch it on again. So as a workaround we just re-create a new viewport
     // The method is private but defined as slot to avoid to call it by accident.
@@ -973,7 +943,6 @@ void View3DInventor::setCurrentViewMode(ViewMode newmode)
     //if (index >= 0) {
     //    _viewer->qt_metacall(QMetaObject::InvokeMetaMethod, index, 0);
     //}
-#endif
 
     // This widget becomes the focus proxy of the embedded GL widget if we leave
     // the 'Child' mode. If we reenter 'Child' mode the focus proxy is reset to 0.
@@ -995,18 +964,16 @@ void View3DInventor::setCurrentViewMode(ViewMode newmode)
         qApp->installEventFilter(this);
     }
     else if (newmode == Child) {
-        _viewer->getGLWidget()->setFocusProxy(0);
+        _viewer->getGLWidget()->setFocusProxy(nullptr);
         qApp->removeEventFilter(this);
         QList<QAction*> acts = this->actions();
         for (QList<QAction*>::Iterator it = acts.begin(); it != acts.end(); ++it)
             this->removeAction(*it);
 
-#if defined(HAVE_QT5_OPENGL)
         // Step two
         QMdiSubWindow* mdi = qobject_cast<QMdiSubWindow*>(parentWidget());
         if (mdi && mdi->layout())
             mdi->layout()->invalidate();
-#endif
     }
 }
 
@@ -1038,16 +1005,6 @@ void View3DInventor::keyPressEvent (QKeyEvent* e)
     // of an MDI view because it causes rendering problems.
     // The only reliable solution is to clone the MDI view,
     // set its view mode and close the original MDI view.
-#if (QT_VERSION < QT_VERSION_CHECK(5, 0, 0))
-    ViewMode mode = MDIView::currentViewMode();
-    if (mode != Child) {
-        // If the widget is in fullscreen mode then we can return to normal mode either
-        // by pressing the matching accelerator or ESC.
-        if (e->key() == Qt::Key_Escape) {
-            setCurrentViewMode(Child);
-        }
-    }
-#endif
 
     QMainWindow::keyPressEvent(e);
 }
