@@ -20,17 +20,17 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #ifndef GUI_VIEW3DINVENTOR_H
 #define GUI_VIEW3DINVENTOR_H
 
-#include "MDIView.h"
-
-#include <Base/Parameter.h>
 #include <QImage>
 #include <QtOpenGL.h>
 
-class SoNode;
+#include <Base/Parameter.h>
+
+#include "MDIView.h"
+
+
 class QPrinter;
 class QStackedWidget;
 
@@ -45,7 +45,7 @@ class GuiExport GLOverlayWidget : public QWidget
     Q_OBJECT
 
 public:
-    GLOverlayWidget(QWidget* parent=0) : QWidget(parent)
+    GLOverlayWidget(QWidget* parent=nullptr) : QWidget(parent)
     {}
     ~GLOverlayWidget()
     {}
@@ -68,7 +68,7 @@ class GuiExport View3DInventor : public MDIView, public ParameterGrp::ObserverTy
     TYPESYSTEM_HEADER();
 
 public:
-    View3DInventor(Gui::Document* pcDocument, QWidget* parent, const QtGLWidget* sharewidget = 0, Qt::WindowFlags wflags=Qt::WindowFlags());
+    View3DInventor(Gui::Document* pcDocument, QWidget* parent, const QtGLWidget* sharewidget = nullptr, Qt::WindowFlags wflags=Qt::WindowFlags());
     ~View3DInventor();
 
     /// Message handler
@@ -79,9 +79,9 @@ public:
     virtual void OnChange(ParameterGrp::SubjectType &rCaller,ParameterGrp::MessageType Reason);
     /// get called when the document is updated
     virtual void onRename(Gui::Document *pDoc);
-    virtual void onUpdate(void);
+    virtual void onUpdate();
     virtual void viewAll();
-    virtual const char *getName(void) const;
+    virtual const char *getName() const;
 
     /// print function of the view
     virtual void print();
@@ -89,7 +89,7 @@ public:
     virtual void printPreview();
     virtual void print(QPrinter*);
 
-    virtual PyObject *getPyObject(void);
+    virtual PyObject *getPyObject();
     /**
      * If \a b is set to \a FullScreen the MDI view is displayed in full screen mode, if \a b
      * is set to \a TopLevel then it is displayed as an own top-level window, otherwise (\a Normal)
@@ -105,7 +105,7 @@ public:
     void setOverlayWidget(QWidget*);
     void removeOverlayWidget();
 
-    View3DInventorViewer *getViewer(void) const {return _viewer;}
+    View3DInventorViewer *getViewer() const {return _viewer;}
     virtual bool containsViewProvider(const ViewProvider*) const;
 
 public Q_SLOTS:
