@@ -29,17 +29,19 @@
 #include <set>
 #include <vector>
 
-#include <Base/Type.h>
-#include <Base/Placement.h>
-#include <Inventor/nodes/SoEventCallback.h>
-#include <Inventor/nodes/SoSwitch.h>
-#include <Inventor/SbRotation.h>
-#include <Gui/Quarter/SoQTQuarterAdaptor.h>
 #include <QCursor>
 #include <QImage>
 
-#include <Gui/Selection.h>
-#include <Gui/Namespace.h>
+#include <Inventor/SbRotation.h>
+#include <Inventor/nodes/SoEventCallback.h>
+#include <Inventor/nodes/SoSwitch.h>
+
+#include <Base/Placement.h>
+
+#include "Namespace.h"
+#include "Selection.h"
+#include "Quarter/SoQTQuarterAdaptor.h"
+
 
 class SoTranslation;
 class SoTransform;
@@ -128,8 +130,8 @@ public:
     };
     //@}
 
-    View3DInventorViewer (QWidget *parent, const QtGLWidget* sharewidget = 0);
-    View3DInventorViewer (const QtGLFormat& format, QWidget *parent, const QtGLWidget* sharewidget = 0);
+    View3DInventorViewer (QWidget *parent, const QtGLWidget* sharewidget = nullptr);
+    View3DInventorViewer (const QtGLFormat& format, QWidget *parent, const QtGLWidget* sharewidget = nullptr);
     virtual ~View3DInventorViewer();
 
     void init();
@@ -139,27 +141,27 @@ public:
     void checkGroupOnTop(const SelectionChanges &Reason);
     void clearGroupOnTop();
 
-    SoDirectionalLight* getBacklight(void) const;
+    SoDirectionalLight* getBacklight() const;
     void setBacklight(SbBool on);
-    SbBool isBacklight(void) const;
+    SbBool isBacklight() const;
     void setSceneGraph (SoNode *root);
     SbBool searchNode(SoNode*) const;
 
     void setAnimationEnabled(const SbBool enable);
-    SbBool isAnimationEnabled(void) const;
+    SbBool isAnimationEnabled() const;
 
     void setPopupMenuEnabled(const SbBool on);
-    SbBool isPopupMenuEnabled(void) const;
+    SbBool isPopupMenuEnabled() const;
 
     void startAnimating(const SbVec3f& axis, float velocity);
-    void stopAnimating(void);
-    SbBool isAnimating(void) const;
+    void stopAnimating();
+    SbBool isAnimating() const;
 
     void setFeedbackVisibility(const SbBool enable);
-    SbBool isFeedbackVisible(void) const;
+    SbBool isFeedbackVisible() const;
 
     void setFeedbackSize(const int size);
-    int getFeedbackSize(void) const;
+    int getFeedbackSize() const;
 
     /// Get the preferred samples from the user settings
     static int getNumSamples();
@@ -202,7 +204,7 @@ public:
     SbBool isEditingViewProvider() const;
     /// reset from edit mode
     void resetEditingViewProvider();
-    void setupEditingRoot(SoNode *node=0, const Base::Matrix4D *mat=0);
+    void setupEditingRoot(SoNode *node=nullptr, const Base::Matrix4D *mat=nullptr);
     void resetEditingRoot(bool updateLinks=true);
     void setEditingTransform(const Base::Matrix4D &mat);
     /** Helper method to get picked entities while editing.
@@ -236,13 +238,14 @@ public:
     /** @name Selection methods */
     //@{
     void startSelection(SelectionMode = Lasso);
+    void abortSelection();
     void stopSelection();
     bool isSelecting() const;
-    std::vector<SbVec2f> getGLPolygon(SelectionRole* role=0) const;
+    std::vector<SbVec2f> getGLPolygon(SelectionRole* role=nullptr) const;
     std::vector<SbVec2f> getGLPolygon(const std::vector<SbVec2s>&) const;
-    const std::vector<SbVec2s>& getPolygon(SelectionRole* role=0) const;
+    const std::vector<SbVec2s>& getPolygon(SelectionRole* role=nullptr) const;
     void setSelectionEnabled(const SbBool enable);
-    SbBool isSelectionEnabled(void) const;
+    SbBool isSelectionEnabled() const;
     //@}
 
     /// Returns the screen coordinates of the origin of the path's tail object
@@ -258,7 +261,7 @@ public:
     void setRedirectToSceneGraph(SbBool redirect) { this->redirected = redirect; }
     SbBool isRedirectedToSceneGraph() const { return this->redirected; }
     void setRedirectToSceneGraphEnabled(SbBool enable) { this->allowredir = enable; }
-    SbBool isRedirectToSceneGraphEnabled(void) const { return this->allowredir; }
+    SbBool isRedirectToSceneGraphEnabled() const { return this->allowredir; }
     //@}
 
     /** @name Pick actions */
@@ -275,11 +278,11 @@ public:
      * Set up a callback function \a cb which will be invoked for the given eventtype.
      * \a userdata will be given as the first argument to the callback function.
      */
-    void addEventCallback(SoType eventtype, SoEventCallbackCB * cb, void* userdata = 0);
+    void addEventCallback(SoType eventtype, SoEventCallbackCB * cb, void* userdata = nullptr);
     /**
      * Unregister the given callback function \a cb.
      */
-    void removeEventCallback(SoType eventtype, SoEventCallbackCB * cb, void* userdata = 0);
+    void removeEventCallback(SoType eventtype, SoEventCallbackCB * cb, void* userdata = nullptr);
 
     /** @name Clipping plane, near and far plane */
     //@{
@@ -294,7 +297,9 @@ public:
     /** Returns the orientation of the camera. */
     SbRotation getCameraOrientation() const;
     /** Returns the 3d point on the focal plane to the given 2d point. */
-    SbVec3f getPointOnScreen(const SbVec2s&) const;
+    SbVec3f getPointOnFocalPlane(const SbVec2s&) const;
+    /** Returns the 2d coordinates on the screen to the given 3d point. */
+    SbVec2s getPointOnScreen(const SbVec3f&) const;
     /** Returns the near plane represented by its normal and base point. */
     void getNearPlane(SbVec3f& rcPt, SbVec3f& rcNormal) const;
     /** Returns the far plane represented by its normal and base point. */
@@ -308,6 +313,10 @@ public:
     SbVec3f projectOnNearPlane(const SbVec2f&) const;
     /** Project the given normalized 2d point onto the far plane */
     SbVec3f projectOnFarPlane(const SbVec2f&) const;
+    /** Project the given 2d point to a line */
+    void projectPointToLine(const SbVec2s&, SbVec3f& pt1, SbVec3f& pt2) const;
+    /** Get the normalized position of the 2d point. */
+    SbVec2f getNormalizedPosition(const SbVec2s&) const;
     //@}
 
     /** @name Dimension controls
@@ -346,7 +355,12 @@ public:
     void viewAll(float factor);
 
     /// Breaks out a VR window for a Rift
-    void viewVR(void);
+    void viewVR();
+
+    /**
+     * Returns the bounding box of the scene graph.
+     */
+    SbBox3f getBoundingBox() const;
 
     /**
      * Reposition the current camera so we can see all selected objects
@@ -365,11 +379,11 @@ public:
     void setNavigationType(Base::Type);
 
     void setAxisCross(bool b);
-    bool hasAxisCross(void);
+    bool hasAxisCross();
 
     void setEnabledFPSCounter(bool b);
     void setEnabledNaviCube(bool b);
-    bool isEnabledNaviCube(void) const;
+    bool isEnabledNaviCube() const;
     void setNaviCubeCorner(int);
     NaviCube* getNavigationCube() const;
     void setEnabledVBO(bool b);
@@ -381,7 +395,7 @@ public:
     void setDocument(Gui::Document *pcDocument);
     Gui::Document* getDocument();
 
-    virtual PyObject *getPyObject(void);
+    virtual PyObject *getPyObject();
 
 protected:
     GLenum getInternalTextureFormat() const;
@@ -389,9 +403,9 @@ protected:
     void renderFramebuffer();
     void renderGLImage();
     void animatedViewAll(int steps, int ms);
-    virtual void actualRedraw(void);
+    virtual void actualRedraw();
     virtual void setSeekMode(SbBool enable);
-    virtual void afterRealizeHook(void);
+    virtual void afterRealizeHook();
     virtual bool processSoEvent(const SoEvent * ev);
     void dropEvent (QDropEvent * e);
     void dragEnterEvent (QDragEnterEvent * e);
@@ -401,13 +415,6 @@ protected:
     void printDimension();
     void selectAll();
 
-    enum eWinGestureTuneState{
-        ewgtsDisabled, //suppress tuning/re-tuning after errors
-        ewgtsNeedTuning, //gestures are to be re-tuned upon next event
-        ewgtsTuned
-    };
-    eWinGestureTuneState winGestureTuneState;//See ViewerEventFilter::eventFilter function for explanation
-
 private:
     static void setViewportCB(void * userdata, SoAction * action);
     static void clearBufferCB(void * userdata, SoAction * action);
@@ -422,8 +429,8 @@ private:
     static void deselectCB(void * closure, SoPath * p);
     static SoPath * pickFilterCB(void * data, const SoPickedPoint * pick);
     void initialize();
-    void drawAxisCross(void);
-    static void drawArrow(void);
+    void drawAxisCross();
+    static void drawArrow();
     void setCursorRepresentation(int mode);
     void aboutToDestroyGLContext();
     void createStandardCursors(double);
