@@ -20,50 +20,43 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 
 #ifndef _PreComp_
 # include <QApplication>
-# include <QPixmap>
 # include <QTimer>
 # include <Inventor/SoPickedPoint.h>
+# include <Inventor/actions/SoGetBoundingBoxAction.h>
+# include <Inventor/details/SoDetail.h>
+# include <Inventor/events/SoKeyboardEvent.h>
+# include <Inventor/events/SoLocation2Event.h>
+# include <Inventor/events/SoMouseButtonEvent.h>
 # include <Inventor/nodes/SoSeparator.h>
 # include <Inventor/nodes/SoSwitch.h>
-# include <Inventor/details/SoDetail.h>
 # include <Inventor/nodes/SoTransform.h>
-# include <Inventor/nodes/SoCamera.h>
-# include <Inventor/events/SoMouseButtonEvent.h>
-# include <Inventor/events/SoLocation2Event.h>
-# include <Inventor/actions/SoGetMatrixAction.h>
-# include <Inventor/actions/SoSearchAction.h>
-# include <Inventor/actions/SoGetBoundingBoxAction.h>
-# include <boost_bind_bind.hpp>
 #endif
 
-/// Here the FreeCAD includes sorted by Base,App,Gui......
+#include <Base/BoundBox.h>
 #include <Base/Console.h>
 #include <Base/Exception.h>
-#include <Base/BoundBox.h>
 #include <Base/Matrix.h>
-#include <App/PropertyGeo.h>
 
+#include "SoMouseWheelEvent.h"
 #include "ViewProvider.h"
-#include "Application.h"
 #include "ActionFunction.h"
-#include "Document.h"
-#include "ViewProviderPy.h"
+#include "Application.h"
 #include "BitmapFactory.h"
+#include "Document.h"
+#include "SoFCDB.h"
 #include "View3DInventor.h"
 #include "View3DInventorViewer.h"
-#include "SoFCDB.h"
-#include "ViewProviderExtension.h"
-#include "SoFCUnifiedSelection.h"
-#include "ViewProviderLink.h"
 #include "ViewParams.h"
+#include "ViewProviderExtension.h"
+#include "ViewProviderLink.h"
+#include "ViewProviderPy.h"
 
 
-FC_LOG_LEVEL_INIT("ViewProvider",true,true)
+FC_LOG_LEVEL_INIT("ViewProvider", true, true)
 
 using namespace std;
 using namespace Gui;
@@ -95,8 +88,8 @@ void coinRemoveAllChildren(SoGroup *group) {
 PROPERTY_SOURCE_ABSTRACT(Gui::ViewProvider, App::TransactionalObject)
 
 ViewProvider::ViewProvider()
-    : pcAnnotation(0)
-    , pyViewObject(0)
+    : pcAnnotation(nullptr)
+    , pyViewObject(nullptr)
     , overrideMode("As Is")
     , _iActualMode(-1)
     , _iEditMode(-1)
@@ -147,7 +140,7 @@ ViewProvider *ViewProvider::startEditing(int ModNum)
         _iEditMode = ModNum;
         return this;
     }
-    return 0;
+    return nullptr;
 }
 
 int ViewProvider::getEditingMode() const
@@ -224,12 +217,25 @@ void ViewProvider::eventCallback(void * ud, SoEventCallback * node)
                     // holding the mouse button while using some SoDragger.
                     // Therefore, we shall ignore ESC while any mouse button is
                     // pressed, until this Coin bug is fixed.
+                    if (!press) {
+                        // react only on key release
+                        // Let first selection mode terminate
+                        Gui::Document* doc = Gui::Application::Instance->activeDocument();
+                        Gui::View3DInventor* view = static_cast<Gui::View3DInventor*>(doc->getActiveView());
+                        if (view)
+                        {
+                            Gui::View3DInventorViewer* viewer = view->getViewer();
+                            if (viewer->isSelecting())
+                            {
+                                return;
+                            }
+                        }
 
-                    Gui::TimerFunction* func = new Gui::TimerFunction();
-                    func->setAutoDelete(true);
-                    Gui::Document* doc = Gui::Application::Instance->activeDocument();
-                    func->setFunction(boost::bind(&Document::resetEdit, doc));
-                    QTimer::singleShot(0, func, SLOT(timeout()));
+                        Gui::TimerFunction* func = new Gui::TimerFunction();
+                        func->setAutoDelete(true);
+                        func->setFunction(boost::bind(&Document::resetEdit, doc));
+                        QTimer::singleShot(0, func, SLOT(timeout()));
+                    }
                 }
                 else if (press) {
                     FC_WARN("Please release all mouse buttons before exiting editing");
@@ -253,6 +259,12 @@ void ViewProvider::eventCallback(void * ud, SoEventCallback * node)
             if (self->mouseButtonPressed(button,press,ev->getPosition(),viewer))
                 node->setHandled();
         }
+        else if (ev->getTypeId().isDerivedFrom(SoMouseWheelEvent::getClassTypeId())) {
+            const SoMouseWheelEvent * const event = (const SoMouseWheelEvent *) ev;
+
+            if (self->mouseWheelEvent(event->getDelta(), event->getPosition(), viewer))
+                node->setHandled();
+        }
         // Mouse Movement handling
         else if (ev->getTypeId().isDerivedFrom(SoLocation2Event::getClassTypeId())) {
             if (self->mouseMove(ev->getPosition(),viewer))
@@ -279,7 +291,7 @@ void ViewProvider::eventCallback(void * ud, SoEventCallback * node)
     }
 }
 
-SoSeparator* ViewProvider::getAnnotation(void)
+SoSeparator* ViewProvider::getAnnotation()
 {
     if (!pcAnnotation) {
         pcAnnotation = new SoSeparator();
@@ -300,7 +312,7 @@ void ViewProvider::update(const App::Property* prop)
     if (vis) ViewProvider::show();
 }
 
-QIcon ViewProvider::getIcon(void) const
+QIcon ViewProvider::getIcon() const
 {
     return mergeGreyableOverlayIcons (Gui::BitmapFactory().pixmap(sPixmap));
 }
@@ -392,7 +404,7 @@ SoNode* ViewProvider::getDisplayMaskMode(const char* type) const
         return pcModeSwitch->getChild(it->second);
     }
 
-    return 0;
+    return nullptr;
 }
 
 std::vector<std::string> ViewProvider::getDisplayMaskModes() const
@@ -421,10 +433,10 @@ void ViewProvider::setDisplayMode(const char* ModeName)
 
 const char* ViewProvider::getDefaultDisplayMode() const {
 
-    return 0;
+    return nullptr;
 }
 
-vector<std::string> ViewProvider::getDisplayModes(void) const {
+vector<std::string> ViewProvider::getDisplayModes() const {
 
     std::vector< std::string > modes;
     auto vector = getExtensionsDerivedFromType<Gui::ViewProviderExtension>();
@@ -435,12 +447,12 @@ vector<std::string> ViewProvider::getDisplayModes(void) const {
     return modes;
 }
 
-std::string ViewProvider::getActiveDisplayMode(void) const
+std::string ViewProvider::getActiveDisplayMode() const
 {
     return _sCurrentMode;
 }
 
-void ViewProvider::hide(void)
+void ViewProvider::hide()
 {
     auto exts = getExtensionsDerivedFromType<Gui::ViewProviderExtension>();
 
@@ -455,7 +467,7 @@ void ViewProvider::hide(void)
         ext->extensionHide();
 }
 
-void ViewProvider::show(void)
+void ViewProvider::show()
 {
     setModeSwitch();
 
@@ -465,7 +477,7 @@ void ViewProvider::show(void)
         ext->extensionShow();
 }
 
-bool ViewProvider::isShow(void) const
+bool ViewProvider::isShow() const
 {
     return pcModeSwitch->whichChild.getValue() != -1;
 }
@@ -665,6 +677,14 @@ bool ViewProvider::mouseButtonPressed(int button, bool pressed,
     return false;
 }
 
+bool ViewProvider::mouseWheelEvent(int delta, const SbVec2s &cursorPos, const View3DInventorViewer* viewer)
+{
+    (void) delta;
+    (void) cursorPos;
+    (void) viewer;
+    return false;
+}
+
 void ViewProvider::setupContextMenu(QMenu* menu, QObject* receiver, const char* method)
 {
     auto vector = getExtensionsDerivedFromType<Gui::ViewProviderExtension>();
@@ -827,7 +847,7 @@ void ViewProvider::updateData(const App::Property* prop)
         ext->extensionUpdateData(prop);
 }
 
-SoSeparator* ViewProvider::getBackRoot(void) const
+SoSeparator* ViewProvider::getBackRoot() const
 {
     auto vector = getExtensionsDerivedFromType<Gui::ViewProviderExtension>();
     for (Gui::ViewProviderExtension* ext : vector) {
@@ -838,7 +858,7 @@ SoSeparator* ViewProvider::getBackRoot(void) const
     return nullptr;
 }
 
-SoGroup* ViewProvider::getChildRoot(void) const
+SoGroup* ViewProvider::getChildRoot() const
 {
     auto vector = getExtensionsDerivedFromType<Gui::ViewProviderExtension>();
     for (Gui::ViewProviderExtension* ext : vector) {
@@ -849,7 +869,7 @@ SoGroup* ViewProvider::getChildRoot(void) const
     return nullptr;
 }
 
-SoSeparator* ViewProvider::getFrontRoot(void) const
+SoSeparator* ViewProvider::getFrontRoot() const
 {
     auto vector = getExtensionsDerivedFromType<Gui::ViewProviderExtension>();
     for (Gui::ViewProviderExtension* ext : vector) {
@@ -860,7 +880,7 @@ SoSeparator* ViewProvider::getFrontRoot(void) const
     return nullptr;
 }
 
-std::vector< App::DocumentObject* > ViewProvider::claimChildren(void) const
+std::vector< App::DocumentObject* > ViewProvider::claimChildren() const
 {
     std::vector< App::DocumentObject* > vec;
     auto vector = getExtensionsDerivedFromType<Gui::ViewProviderExtension>();
@@ -872,7 +892,7 @@ std::vector< App::DocumentObject* > ViewProvider::claimChildren(void) const
     return vec;
 }
 
-std::vector< App::DocumentObject* > ViewProvider::claimChildren3D(void) const
+std::vector< App::DocumentObject* > ViewProvider::claimChildren3D() const
 {
     std::vector< App::DocumentObject* > vec;
     auto vector = getExtensionsDerivedFromType<Gui::ViewProviderExtension>();
@@ -884,13 +904,14 @@ std::vector< App::DocumentObject* > ViewProvider::claimChildren3D(void) const
     return vec;
 }
 bool ViewProvider::getElementPicked(const SoPickedPoint *pp, std::string &subname) const {
-    if(!isSelectable()) return false;
+    if(!isSelectable())
+        return false;
     auto vector = getExtensionsDerivedFromType<Gui::ViewProviderExtension>();
     for(Gui::ViewProviderExtension* ext : vector) {
         if(ext->extensionGetElementPicked(pp,subname))
             return true;
     }
-    subname = getElement(pp?pp->getDetail():0);
+    subname = getElement(pp?pp->getDetail():nullptr);
     return true;
 }
 
@@ -942,7 +963,7 @@ int ViewProvider::partialRender(const std::vector<std::string> &elements, bool c
         if(hidden)
             element.resize(element.size()-hiddenMarker().size());
         path->truncate(0);
-        SoDetail *det = 0;
+        SoDetail *det = nullptr;
         if(getDetailPath(element.c_str(),path,false,det)) {
             if(!hidden && !det) {
                 FC_LOG("partial render element not found: " << element);
@@ -1008,7 +1029,7 @@ Base::BoundBox3d ViewProvider::getBoundingBox(const char *subname, bool transfor
     SoTempPath path(20);
     path.ref();
     if(subname && subname[0]) {
-        SoDetail *det=0;
+        SoDetail *det=nullptr;
         if(!getDetailPath(subname,&path,true,det)) {
             if(mode < 0)
                 pcModeSwitch->whichChild = mode;
