@@ -20,22 +20,22 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #ifndef GUI_VIEWPROVIDER_H
 #define GUI_VIEWPROVIDER_H
 
-#include <map>
-#include <vector>
-#include <string>
 #include <bitset>
+#include <map>
+#include <string>
+#include <vector>
 #include <QIcon>
 #include <boost_signals2.hpp>
 #include <boost/intrusive_ptr.hpp>
 
-#include <App/TransactionalObject.h>
 #include <App/Material.h>
-#include <Base/Vector3D.h>
+#include <App/TransactionalObject.h>
 #include <Base/BoundBox.h>
+#include <Base/Vector3D.h>
+
 
 class SbVec2s;
 class SbVec3f;
@@ -128,18 +128,18 @@ public:
     virtual ~ViewProvider();
 
     // returns the root node of the Provider (3D)
-    virtual SoSeparator* getRoot(void) const {return pcRoot;}
+    virtual SoSeparator* getRoot() const {return pcRoot;}
     // return the mode switch node of the Provider (3D)
-    SoSwitch *getModeSwitch(void) const {return pcModeSwitch;}
+    SoSwitch *getModeSwitch() const {return pcModeSwitch;}
     SoTransform *getTransformNode() const {return pcTransform;}
     // returns the root for the Annotations.
-    SoSeparator* getAnnotation(void);
+    SoSeparator* getAnnotation();
     // returns the root node of the Provider (3D)
-    virtual SoSeparator* getFrontRoot(void) const;
+    virtual SoSeparator* getFrontRoot() const;
     // returns the root node where the children gets collected(3D)
-    virtual SoGroup* getChildRoot(void) const;
+    virtual SoGroup* getChildRoot() const;
     // returns the root node of the Provider (3D)
-    virtual SoSeparator* getBackRoot(void) const;
+    virtual SoSeparator* getBackRoot() const;
     ///Indicate whether to be added to scene graph or not
     virtual bool canAddToSceneGraph() const {return true;}
 
@@ -149,7 +149,7 @@ public:
       * scene graph. This affects the visibility and the 3D
       * position of the object.
       */
-    virtual std::vector<App::DocumentObject*> claimChildren3D(void) const;
+    virtual std::vector<App::DocumentObject*> claimChildren3D() const;
 
     /** @name Selection handling
       * This group of methods do the selection handling.
@@ -159,14 +159,14 @@ public:
     //@{
 
     /// indicates if the ViewProvider use the new Selection model
-    virtual bool useNewSelectionModel(void) const;
-    virtual bool isSelectable(void) const {return true;}
+    virtual bool useNewSelectionModel() const;
+    virtual bool isSelectable() const {return true;}
     /// return a hit element given the picked point which contains the full node path
     virtual bool getElementPicked(const SoPickedPoint *, std::string &subname) const;
     /// return a hit element to the selection path or 0
     virtual std::string getElement(const SoDetail *) const { return std::string(); }
     /// return the coin node detail of the subelement
-    virtual SoDetail* getDetail(const char *) const { return 0; }
+    virtual SoDetail* getDetail(const char *) const { return nullptr; }
 
     /** return the coin node detail and path to the node of the subelement
      *
@@ -209,7 +209,7 @@ public:
      * This method shall work regardless whether the current view object is
      * visible or not.
      */
-    Base::BoundBox3d getBoundingBox(const char *subname=0, bool transform=true, MDIView *view=0) const;
+    Base::BoundBox3d getBoundingBox(const char *subname=nullptr, bool transform=true, MDIView *view=nullptr) const;
 
     /**
      * Get called if the object is about to get deleted.
@@ -241,7 +241,7 @@ public:
      */
     //@{
     /// deliver the icon shown in the tree view
-    virtual QIcon getIcon(void) const;
+    virtual QIcon getIcon() const;
 
      /** @name Methods used by the Tree
      * If you want to take control over the
@@ -258,7 +258,7 @@ public:
       * be used for any kind of grouping needed for a special
       * purpose.
       */
-    virtual std::vector<App::DocumentObject*> claimChildren(void) const;
+    virtual std::vector<App::DocumentObject*> claimChildren() const;
     //@}
 
     /** @name Drag and drop
@@ -379,19 +379,19 @@ public:
     /** @name Display mode methods
      */
     //@{
-    std::string getActiveDisplayMode(void) const;
+    std::string getActiveDisplayMode() const;
     /// set the display mode
     virtual void setDisplayMode(const char* ModeName);
     /// get the default display mode
     virtual const char* getDefaultDisplayMode() const;
     /// returns a list of all possible display modes
-    virtual std::vector<std::string> getDisplayModes(void) const;
+    virtual std::vector<std::string> getDisplayModes() const;
     /// Hides the view provider
-    virtual void hide(void);
+    virtual void hide();
     /// Shows the view provider
-    virtual void show(void);
+    virtual void show();
     /// checks whether the view provider is visible or not
-    virtual bool isShow(void) const;
+    virtual bool isShow() const;
     void setVisible(bool);
     bool isVisible() const;
     void setLinkVisible(bool);
@@ -404,7 +404,7 @@ public:
     /** @name Color management methods
      */
     //@{
-    virtual std::map<std::string, App::Color> getElementColors(const char *element=0) const {
+    virtual std::map<std::string, App::Color> getElementColors(const char *element=nullptr) const {
         (void)element;
         return {};
     }
@@ -420,6 +420,9 @@ public:
      * you can handle most of the events in the viewer by yourself
      */
     //@{
+    // the below enum is reflected in 'userEditModes' std::map in Application.h
+    // so it is possible for the user to choose a default one through GUI
+    // if you add a mode here, consider to make it accessible there too
     enum EditMode {Default = 0,
                    Transform,
                    Cutting,
@@ -459,12 +462,14 @@ public:
     /// If null is returned then no transaction will be opened.
     virtual const char* getTransactionText() const { return nullptr; }
     /// is called by the tree if the user double clicks on the object
-    virtual bool doubleClicked(void) { return false; }
+    virtual bool doubleClicked() { return false; }
     /// is called when the provider is in edit and the mouse is moved
     virtual bool mouseMove(const SbVec2s &cursorPos, View3DInventorViewer* viewer);
     /// is called when the Provider is in edit and the mouse is clicked
     virtual bool mouseButtonPressed(int button, bool pressed, const SbVec2s &cursorPos,
                                     const View3DInventorViewer* viewer);
+
+    virtual bool mouseWheelEvent(int delta, const SbVec2s &cursorPos, const View3DInventorViewer* viewer);
     /// set up the context-menu with the supported edit modes
     virtual void setupContextMenu(QMenu*, QObject*, const char*);
 
