@@ -20,48 +20,37 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 
 #ifndef _PreComp_
-# include <QByteArray>
-# include <qpixmap.h>
-# include <Inventor/actions/SoSearchAction.h>
-# include <Inventor/nodes/SoDrawStyle.h>
-# include <Inventor/nodes/SoMaterial.h>
-# include <Inventor/nodes/SoSeparator.h>
-# include <Inventor/nodes/SoSwitch.h>
-# include <Inventor/nodes/SoTransform.h>
-# include <Inventor/SoPickedPoint.h>
+# include <QAction>
+# include <QMenu>
 # include <Inventor/SoFullPath.h>
-# include <Inventor/misc/SoChildList.h>
+# include <Inventor/SoPickedPoint.h>
+# include <Inventor/actions/SoSearchAction.h>
 # include <Inventor/details/SoDetail.h>
+# include <Inventor/misc/SoChildList.h>
+# include <Inventor/nodes/SoSeparator.h>
 #endif
 
-/// Here the FreeCAD includes sorted by Base,App,Gui......
-#include <Base/Tools.h>
-#include <Base/Console.h>
-#include <Base/Tools.h>
-#include <Base/BoundBox.h>
-#include <App/Material.h>
-#include <App/DocumentObjectGroup.h>
-#include <App/DocumentObserver.h>
+#include <App/Document.h>
 #include <App/Origin.h>
+#include <Base/Tools.h>
+
+#include "ViewProviderDocumentObjectPy.h"
+#include "ActionFunction.h"
 #include "Application.h"
+#include "Command.h"
 #include "Document.h"
-#include "Selection.h"
-#include "MainWindow.h"
 #include "MDIView.h"
-#include "View3DInventor.h"
-#include "View3DInventorViewer.h"
-#include "TaskView/TaskAppearance.h"
-#include "ViewProviderDocumentObject.h"
-#include "ViewProviderExtension.h"
 #include "SoFCUnifiedSelection.h"
 #include "Tree.h"
-#include <Gui/ViewProviderDocumentObjectPy.h>
+#include "ViewProviderDocumentObject.h"
+#include "ViewProviderExtension.h"
+#include "TaskView/TaskAppearance.h"
 
-FC_LOG_LEVEL_INIT("Gui",true,true)
+
+FC_LOG_LEVEL_INIT("Gui", true, true)
 
 using namespace Gui;
 
@@ -80,10 +69,10 @@ ViewProviderDocumentObject::ViewProviderDocumentObject()
     ADD_PROPERTY_TYPE(ShowInTree, (true), dogroup, App::Prop_None, "Show the object in the tree view");
 
     ADD_PROPERTY_TYPE(SelectionStyle, ((long)0), sgroup, App::Prop_None, "Set the object selection style");
-    static const char *SelectionStyleEnum[] = {"Shape","BoundBox",0};
+    static const char *SelectionStyleEnum[] = {"Shape","BoundBox",nullptr};
     SelectionStyle.setEnums(SelectionStyleEnum);
 
-    static const char* OnTopEnum[]= {"Disabled","Enabled","Object","Element",NULL};
+    static const char* OnTopEnum[]= {"Disabled","Enabled","Object","Element",nullptr};
     ADD_PROPERTY_TYPE(OnTopWhenSelected,((long int)0), sgroup, App::Prop_None,
             "Enabled: Display the object on top of any other object when selected\n"
             "Object: On top only if the whole object is selected\n"
@@ -96,7 +85,8 @@ ViewProviderDocumentObject::ViewProviderDocumentObject()
 ViewProviderDocumentObject::~ViewProviderDocumentObject()
 {
     // Make sure that the property class does not destruct our string list
-    DisplayMode.setEnums(0);
+    DisplayMode.setContainer(nullptr);
+    DisplayMode.setEnums(nullptr);
 }
 
 void ViewProviderDocumentObject::getTaskViewContent(std::vector<Gui::TaskView::TaskContent*>& vec) const
@@ -166,7 +156,7 @@ void ViewProviderDocumentObject::onBeforeChange(const App::Property* prop)
 {
     if (isAttachedToDocument()) {
         App::DocumentObject* obj = getObject();
-        App::Document* doc = obj ? obj->getDocument() : 0;
+        App::Document* doc = obj ? obj->getDocument() : nullptr;
         if (doc) {
             onBeforeChangeProperty(doc, prop);
         }
@@ -196,12 +186,19 @@ void ViewProviderDocumentObject::onChanged(const App::Property* prop)
             // this is undesired behaviour. So, if this change marks the document as
             // modified then it must be be reversed.
             if (!testStatus(Gui::ViewStatus::TouchDocument)) {
-                bool mod = false;
-                if (pcDocument)
-                    mod = pcDocument->isModified();
+                // Note: reverting document modified status like that is not
+                // appropriate because we can't tell if there is any other
+                // property being changed due to the change of Visibility here.
+                // Temporary setting the Visibility property as 'NoModify' is
+                // the proper way.
+                Base::ObjectStatusLocker<App::Property::Status,App::Property> guard(
+                        App::Property::NoModify, &Visibility);
+                // bool mod = false;
+                // if (pcDocument)
+                //     mod = pcDocument->isModified();
                 getObject()->Visibility.setValue(Visibility.getValue());
-                if (pcDocument)
-                    pcDocument->setModified(mod);
+                // if (pcDocument)
+                //     pcDocument->setModified(mod);
             }
             else {
                 getObject()->Visibility.setValue(Visibility.getValue());
@@ -215,7 +212,10 @@ void ViewProviderDocumentObject::onChanged(const App::Property* prop)
         }
     }
 
-    if (pcDocument && !pcDocument->isModified() && testStatus(Gui::ViewStatus::TouchDocument)) {
+    if (prop && !prop->testStatus(App::Property::NoModify)
+             && pcDocument
+             && !pcDocument->isModified()
+             && testStatus(Gui::ViewStatus::TouchDocument)) {
         if (prop)
             FC_LOG(prop->getFullName() << " changed");
         pcDocument->setModified(true);
@@ -224,7 +224,7 @@ void ViewProviderDocumentObject::onChanged(const App::Property* prop)
     ViewProvider::onChanged(prop);
 }
 
-void ViewProviderDocumentObject::hide(void)
+void ViewProviderDocumentObject::hide()
 {
     ViewProvider::hide();
     // use this bit to check whether 'Visibility' must be adjusted
@@ -256,12 +256,31 @@ void ViewProviderDocumentObject::setShowable(bool enable)
     }
 }
 
+void ViewProviderDocumentObject::startDefaultEditMode()
+{
+    QString text = QObject::tr("Edit %1").arg(QString::fromUtf8(getObject()->Label.getValue()));
+    Gui::Command::openCommand(text.toUtf8());
+
+    Gui::Document* document = this->getDocument();
+    if (document) {
+        document->setEdit(this, ViewProvider::Default);
+    }
+}
+
+void ViewProviderDocumentObject::addDefaultAction(QMenu* menu, const QString& text)
+{
+    QAction* act = menu->addAction(text);
+    act->setData(QVariant((int)ViewProvider::Default));
+    Gui::ActionFunction* func = new Gui::ActionFunction(menu);
+    func->trigger(act, boost::bind(&ViewProviderDocumentObject::startDefaultEditMode, this));
+}
+
 void ViewProviderDocumentObject::setModeSwitch() {
     if(isShowable())
         ViewProvider::setModeSwitch();
 }
 
-void ViewProviderDocumentObject::show(void)
+void ViewProviderDocumentObject::show()
 {
     if(TreeWidget::isObjectShowable(getObject()))
         ViewProvider::show();
@@ -327,7 +346,7 @@ void ViewProviderDocumentObject::attach(App::DocumentObject *pcObj)
     for (std::vector<std::string>::iterator it = aDisplayModesArray.begin(); it != aDisplayModesArray.end(); ++it) {
         aDisplayEnumsArray.push_back( it->c_str() );
     }
-    aDisplayEnumsArray.push_back(0); // null termination
+    aDisplayEnumsArray.push_back(nullptr); // null termination
     DisplayMode.setEnums(&(aDisplayEnumsArray[0]));
 
     if(!isRestoring()) {
@@ -422,7 +441,7 @@ Gui::MDIView* ViewProviderDocumentObject::getViewOfNode(SoNode* node) const
 SoNode* ViewProviderDocumentObject::findFrontRootOfType(const SoType& type) const
 {
     if(!pcObject)
-        return 0;
+        return nullptr;
     // first get the document this object is part of and get its GUI counterpart
     App::Document* pAppDoc = pcObject->getDocument();
     Gui::Document* pGuiDoc = Gui::Application::Instance->getDocument(pAppDoc);
@@ -451,7 +470,7 @@ SoNode* ViewProviderDocumentObject::findFrontRootOfType(const SoType& type) cons
         }
     }
 
-    return 0;
+    return nullptr;
 }
 
 void ViewProviderDocumentObject::setActiveMode()
@@ -562,7 +581,8 @@ bool ViewProviderDocumentObject::showInTree() const {
 
 bool ViewProviderDocumentObject::getElementPicked(const SoPickedPoint *pp, std::string &subname) const
 {
-    if(!isSelectable()) return false;
+    if(!isSelectable())
+        return false;
     auto vector = getExtensionsDerivedFromType<Gui::ViewProviderExtension>();
     for(Gui::ViewProviderExtension* ext : vector)
         if(ext->extensionGetElementPicked(pp,subname))
@@ -582,7 +602,8 @@ bool ViewProviderDocumentObject::getElementPicked(const SoPickedPoint *pp, std::
     if(idx<0 || idx+1>=path->getLength())
         return false;
     auto vp = getDocument()->getViewProvider(path->getNode(idx+1));
-    if(!vp) return false;
+    if(!vp)
+        return false;
     auto obj = vp->getObject();
     if(!obj || !obj->getNameInDocument())
         return false;
@@ -606,17 +627,21 @@ bool ViewProviderDocumentObject::getDetailPath(const char *subname, SoFullPath *
 
     if(det) {
         delete det;
-        det = 0;
+        det = nullptr;
     }
 
     const char *dot = strchr(subname,'.');
-    if(!dot) return false;
+    if(!dot)
+        return false;
     auto obj = getObject();
-    if(!obj || !obj->getNameInDocument()) return false;
+    if(!obj || !obj->getNameInDocument())
+        return false;
     auto sobj = obj->getSubObject(std::string(subname,dot-subname+1).c_str());
-    if(!sobj) return false;
+    if(!sobj)
+        return false;
     auto vp = Application::Instance->getViewProvider(sobj);
-    if(!vp) return false;
+    if(!vp)
+        return false;
 
     auto childRoot = getChildRoot();
     if(!childRoot)
@@ -665,5 +690,5 @@ ViewProviderDocumentObject *ViewProviderDocumentObject::getLinkedViewProvider(
 std::string ViewProviderDocumentObject::getFullName() const {
     if(pcObject)
         return pcObject->getFullName() + ".ViewObject";
-    return std::string();
+    return std::string("?");
 }
