@@ -70,9 +70,9 @@ public:
     /// Set the active mode, i.e. the first item of the 'Display' property.
     void setActiveMode();
     /// Hide the object in the view
-    virtual void hide(void) override;
+    virtual void hide() override;
     /// Show the object in the view
-    virtual void show(void) override;
+    virtual void show() override;
     /// Is called by the tree if the user double clicks on the object. It returns the string
     /// for the transaction that will be shown in the undo/redo dialog.
     /// If null is returned then no transaction will be opened.
@@ -91,7 +91,7 @@ public:
     /// Run a redraw
     void updateView();
     /// Get the object of this ViewProvider object
-    App::DocumentObject *getObject(void) const {return pcObject;}
+    App::DocumentObject *getObject() const {return pcObject;}
     /// Asks the view provider if the given object can be deleted.
     virtual bool canDelete(App::DocumentObject* obj) const override;
     /// Get the GUI document to this ViewProvider object
@@ -124,8 +124,8 @@ public:
     virtual bool removeDynamicProperty(const char* prop) override;
 
     virtual App::Property* addDynamicProperty(
-            const char* type, const char* name=0,
-            const char* group=0, const char* doc=0,
+            const char* type, const char* name=nullptr,
+            const char* group=nullptr, const char* doc=nullptr,
             short attr=0, bool ro=false, bool hidden=false) override;
 
     /** Return the linked view object
@@ -140,7 +140,7 @@ public:
      * itself.
      */
     virtual ViewProviderDocumentObject *getLinkedViewProvider(
-            std::string *subname=0, bool recursive=false) const;
+            std::string *subname=nullptr, bool recursive=false) const;
 
     virtual std::string getFullName() const override;
 
@@ -155,6 +155,9 @@ public:
     void setShowable(bool enable);
     bool isShowable() const;
 
+    /** Start the edit mode with ViewProvider::Default */
+    void startDefaultEditMode();
+
 protected:
     /*! Get the active mdi view of the document this view provider is part of.
       @note The returned mdi view doesn't need to be a 3d view but can be e.g.
@@ -203,6 +206,9 @@ protected:
 
     virtual void setModeSwitch() override;
 
+    /** Adds a menu item and bind it with \ref startDefaultEditMode().  */
+    void addDefaultAction(QMenu*, const QString&);
+
 protected:
     App::DocumentObject *pcObject;
     Gui::Document* pcDocument;
