@@ -24,12 +24,24 @@
 #ifndef GUI_VIEWPROVIDEREXTENSION_H
 #define GUI_VIEWPROVIDEREXTENSION_H
 
-#include "App/Extension.h"
-#include "ViewProvider.h"
-#include "ViewProviderDocumentObject.h"
+#include <QIcon>
+#include <App/Extension.h>
+
+
+class SoDetail;
+class SoFullPath;
+class SoGroup;
+class SoPickedPoint;
+class SoSeparator;
+
+class QMenu;
+class QObject;
 
 namespace Gui {
 
+class ViewProvider;
+class ViewProviderDocumentObject;
+
 /**
  * @brief Extension with special viewprovider calls
  *
@@ -49,13 +61,13 @@ public:
     Gui::ViewProviderDocumentObject*       getExtendedViewProvider();
     const Gui::ViewProviderDocumentObject* getExtendedViewProvider() const;
 
-    virtual std::vector<App::DocumentObject*> extensionClaimChildren3D(void) const {
+    virtual std::vector<App::DocumentObject*> extensionClaimChildren3D() const {
         return std::vector<App::DocumentObject*>(); }
 
     virtual bool extensionOnDelete(const std::vector<std::string> &){ return true;}
     virtual void extensionBeforeDelete(){}
 
-    virtual std::vector<App::DocumentObject*> extensionClaimChildren(void) const {
+    virtual std::vector<App::DocumentObject*> extensionClaimChildren() const {
         return std::vector<App::DocumentObject*>(); }
 
     virtual bool extensionCanDragObjects() const { return false; }
@@ -76,19 +88,19 @@ public:
         { return -1; }
 
     /// Hides the view provider
-    virtual void extensionHide(void) { }
+    virtual void extensionHide() { }
     /// Shows the view provider
-    virtual void extensionShow(void) { }
+    virtual void extensionShow() { }
 
-    virtual void extensionModeSwitchChange(void) { }
+    virtual void extensionModeSwitchChange() { }
 
-    virtual SoSeparator* extensionGetFrontRoot(void) const {return nullptr;}
-    virtual SoGroup*     extensionGetChildRoot(void) const {return nullptr;}
-    virtual SoSeparator* extensionGetBackRoot(void) const {return nullptr;}
+    virtual SoSeparator* extensionGetFrontRoot() const {return nullptr;}
+    virtual SoGroup*     extensionGetChildRoot() const {return nullptr;}
+    virtual SoSeparator* extensionGetBackRoot() const {return nullptr;}
     virtual void extensionAttach(App::DocumentObject* ) { }
     virtual void extensionReattach(App::DocumentObject* ) { }
     virtual void extensionSetDisplayMode(const char* ) { }
-    virtual std::vector<std::string> extensionGetDisplayModes(void) const {return std::vector<std::string>();}
+    virtual std::vector<std::string> extensionGetDisplayModes() const {return std::vector<std::string>();}
     virtual void extensionSetupContextMenu(QMenu*, QObject*, const char*) {}
 
     //update data of extended opject
@@ -115,28 +127,6 @@ private:
   //Gui::ViewProviderDocumentObject* m_viewBase = nullptr;
 };
 
-/**
- * Generic Python extension class which allows to behave every extension
- * derived class as Python extension -- simply by subclassing.
- */
-template <class ExtensionT>
-class ViewProviderExtensionPythonT : public ExtensionT
-{
-    EXTENSION_PROPERTY_HEADER(Gui::ViewProviderExtensionPythonT<ExtensionT>);
-
-public:
-    typedef ExtensionT Inherited;
-
-    ViewProviderExtensionPythonT() {
-        ExtensionT::m_isPythonExtension = true;
-        ExtensionT::initExtensionType(ViewProviderExtensionPythonT::getExtensionClassTypeId());
-    }
-    virtual ~ViewProviderExtensionPythonT() {
-    }
-};
-
-typedef ViewProviderExtensionPythonT<Gui::ViewProviderExtension> ViewProviderExtensionPython;
-
 } //Gui
 
 #endif // GUI_VIEWPROVIDEREXTENSION_H
