@@ -21,15 +21,8 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 
-#ifndef _PreComp_
-# include <Inventor/nodes/SoGroup.h>
-#endif
-
-#include <App/GeoFeatureGroupExtension.h>
-
 #include "ViewProviderGeoFeatureGroup.h"
 
 
