@@ -20,53 +20,34 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 
 #ifndef _PreComp_
-# include <cfloat>
-# include <QAction>
-# include <QMenu>
+# include <Inventor/SoPickedPoint.h>
+# include <Inventor/actions/SoRayPickAction.h>
 # include <Inventor/actions/SoSearchAction.h>
-# include <Inventor/draggers/SoDragger.h>
-# include <Inventor/draggers/SoCenterballDragger.h>
-# include <Inventor/manips/SoCenterballManip.h>
 # include <Inventor/nodes/SoBaseColor.h>
 # include <Inventor/nodes/SoCamera.h>
 # include <Inventor/nodes/SoDrawStyle.h>
+# include <Inventor/nodes/SoFont.h>
 # include <Inventor/nodes/SoMaterial.h>
 # include <Inventor/nodes/SoSeparator.h>
 # include <Inventor/nodes/SoSwitch.h>
 # include <Inventor/nodes/SoDirectionalLight.h>
-# include <Inventor/nodes/SoPickStyle.h>
-# include <Inventor/sensors/SoNodeSensor.h>
-# include <Inventor/SoPickedPoint.h>
-# include <Inventor/actions/SoRayPickAction.h>
 #endif
 
-/// Here the FreeCAD includes sorted by Base,App,Gui......
+#include <Inventor/nodes/SoResetTransform.h>
+
+#include <App/GeoFeature.h>
+#include <App/PropertyGeo.h>
+
 #include "ViewProviderGeometryObject.h"
-#include "View3DInventorViewer.h"
-#include "SoFCSelection.h"
-#include "SoFCBoundingBox.h"
 #include "Application.h"
 #include "Document.h"
-#include "Window.h"
+#include "SoFCBoundingBox.h"
+#include "SoFCSelection.h"
+#include "View3DInventorViewer.h"
 
-#include <Base/Console.h>
-#include <Base/Placement.h>
-#include <App/PropertyGeo.h>
-#include <App/GeoFeature.h>
-#include <Inventor/draggers/SoCenterballDragger.h>
-#include <Inventor/nodes/SoResetTransform.h>
-#if (COIN_MAJOR_VERSION > 2)
-#include <Inventor/nodes/SoDepthBuffer.h>
-#endif
-#include "SoFCUnifiedSelection.h"
-#include "SoFCCSysDragger.h"
-#include "Control.h"
-#include "TaskCSysDragger.h"
-#include <boost/math/special_functions/fpclassify.hpp>
 
 using namespace Gui;
 
@@ -75,8 +56,8 @@ PROPERTY_SOURCE(Gui::ViewProviderGeometryObject, Gui::ViewProviderDragger)
 const App::PropertyIntegerConstraint::Constraints intPercent = {0,100,1};
 
 ViewProviderGeometryObject::ViewProviderGeometryObject()
-    : pcBoundSwitch(0)
-    , pcBoundColor(0)
+    : pcBoundSwitch(nullptr)
+    , pcBoundColor(nullptr)
 {
     ParameterGrp::handle hGrp = App::GetApplication().GetParameterGroupByPath("User parameter:BaseApp/Preferences/View");
     bool randomColor = hGrp->GetBool("RandomColor", false);
@@ -156,6 +137,8 @@ void ViewProviderGeometryObject::onChanged(const App::Property* prop)
         }
     }
     else if (prop == &ShapeMaterial) {
+        if (getObject() && getObject()->testStatus(App::ObjectStatus::TouchOnColorChange))
+            getObject()->touch(true);
         const App::Material& Mat = ShapeMaterial.getValue();
         long value = (long)(100*Mat.transparency);
         if (value != Transparency.getValue())
@@ -240,7 +223,7 @@ SoPickedPoint* ViewProviderGeometryObject::getPickedPoint(const SbVec2s& pos, co
     // returns a copy of the point
     SoPickedPoint* pick = rp.getPickedPoint();
     //return (pick ? pick->copy() : 0); // needs the same instance of CRT under MS Windows
-    return (pick ? new SoPickedPoint(*pick) : 0);
+    return (pick ? new SoPickedPoint(*pick) : nullptr);
 }
 
 unsigned long ViewProviderGeometryObject::getBoundColor() const
@@ -250,6 +233,14 @@ unsigned long ViewProviderGeometryObject::getBoundColor() const
     return bbcol;
 }
 
+namespace {
+float getBoundBoxFontSize()
+{
+    ParameterGrp::handle hGrp = App::GetApplication().GetParameterGroupByPath("User parameter:BaseApp/Preferences/View");
+    return hGrp->GetFloat("BoundingBoxFontSize", 10.0);
+}
+}
+
 void ViewProviderGeometryObject::showBoundingBox(bool show)
 {
     if (!pcBoundSwitch && show) {
@@ -265,6 +256,9 @@ void ViewProviderGeometryObject::showBoundingBox(bool show)
 
         pcBoundColor->rgb.setValue(r, g, b);
         pBoundingSep->addChild(pcBoundColor);
+        SoFont* font = new SoFont();
+        font->size.setValue(getBoundBoxFontSize());
+        pBoundingSep->addChild(font);
 
         pBoundingSep->addChild(new SoResetTransform());
         pBoundingSep->addChild(pcBoundingBox);
