@@ -20,26 +20,24 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "PreCompiled.h"
 
 #ifndef _PreComp_
+# include <QMessageBox>
 #endif
 
-//#include "ViewProviderGroupExtensionPy.h"
-#include "ViewProviderGroupExtension.h"
-
-#include "Command.h"
-#include "Application.h"
-#include "Document.h"
-#include "MainWindow.h"
-#include <Base/Tools.h>
 #include <App/Document.h>
 #include <App/DocumentObject.h>
 #include <App/GroupExtension.h>
-#include <App/Expression.h>
 #include <Base/Console.h>
-#include <QMessageBox>
+#include <Base/Tools.h>
+
+#include "ViewProviderGroupExtension.h"
+#include "ViewProviderDocumentObject.h"
+#include "Command.h"
+#include "Document.h"
+#include "MainWindow.h"
+
 
 using namespace Gui;
 
@@ -110,13 +108,13 @@ void ViewProviderGroupExtension::extensionDropObject(App::DocumentObject* obj) {
     Gui::Command::doCommand(Gui::Command::App, cmd.toUtf8());
 }
 
-std::vector< App::DocumentObject* > ViewProviderGroupExtension::extensionClaimChildren(void) const {
+std::vector< App::DocumentObject* > ViewProviderGroupExtension::extensionClaimChildren() const {
 
     auto* group = getExtendedViewProvider()->getObject()->getExtensionByType<App::GroupExtension>();
     return std::vector<App::DocumentObject*>(group->Group.getValues());
 }
 
-void ViewProviderGroupExtension::extensionShow(void) {
+void ViewProviderGroupExtension::extensionShow() {
 
     // avoid possible infinite recursion
     if (guard)
@@ -136,7 +134,7 @@ void ViewProviderGroupExtension::extensionShow(void) {
     ViewProviderExtension::extensionShow();
 }
 
-void ViewProviderGroupExtension::extensionHide(void) {
+void ViewProviderGroupExtension::extensionHide() {
 
     // avoid possible infinite recursion
     if (guard)
@@ -163,7 +161,7 @@ void ViewProviderGroupExtension::extensionHide(void) {
 bool ViewProviderGroupExtension::extensionOnDelete(const std::vector< std::string >& ) {
 
     auto* group = getExtendedViewProvider()->getObject()->getExtensionByType<App::GroupExtension>();
-    // If the group is nonempty ask the user if he wants to delete its content
+    // If the group is nonempty ask the user if they want to delete its content
     if (group->Group.getSize() > 0) {
         QMessageBox::StandardButton choice =
             QMessageBox::question(getMainWindow(), QObject::tr ( "Delete group content?" ),
