@@ -20,13 +20,11 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #ifndef GUI_VIEWPROVIDER_ViewProviderPart_H
 #define GUI_VIEWPROVIDER_ViewProviderPart_H
 
-
-#include "ViewProviderOriginGroup.h"
 #include "ViewProviderDragger.h"
+#include "ViewProviderOriginGroup.h"
 #include "ViewProviderPythonFeature.h"
 
 
@@ -43,12 +41,19 @@ public:
     /// destructor.
     virtual ~ViewProviderPart();
 
-    virtual bool doubleClicked(void) override;
+    virtual bool doubleClicked() override;
     virtual void setupContextMenu(QMenu* menu, QObject* receiver, const char* member) override;
+    
+    /// deliver the icon shown in the tree view
+    /// override from ViewProvider.h
+    virtual QIcon getIcon() const override;
 
 protected:
     /// get called by the container whenever a property has been changed
     virtual void onChanged(const App::Property* prop) override;
+    /// a second icon for the Assembly type
+    const char* aPixmap;
+
 };
 
 typedef ViewProviderPythonFeatureT<ViewProviderPart> ViewProviderPartPython;
