@@ -20,18 +20,17 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #ifndef GUI_VIEWPROVIDERPYTHONFEATURE_H
 #define GUI_VIEWPROVIDERPYTHONFEATURE_H
 
-#include <App/Application.h>
 #include <App/AutoTransaction.h>
-#include <Gui/ViewProviderGeometryObject.h>
-#include <Gui/Document.h>
 #include <App/PropertyPythonObject.h>
-#include <App/DynamicProperty.h>
 #include <App/FeaturePython.h>
 
+#include "ViewProviderGeometryObject.h"
+#include "Document.h"
+
+
 class SoSensor;
 class SoDragger;
 class SoNode;
@@ -65,7 +64,7 @@ public:
     ValueT unsetEdit(int ModNum);
     ValueT setEditViewer(View3DInventorViewer*, int ModNum);
     ValueT unsetEditViewer(View3DInventorViewer*);
-    ValueT doubleClicked(void);
+    ValueT doubleClicked();
     bool setupContextMenu(QMenu* menu);
 
     /** @name Update data methods*/
@@ -86,7 +85,7 @@ public:
     /// get the default display mode
     bool getDefaultDisplayMode(std::string &mode) const;
     /// returns a list of all possible modes
-    std::vector<std::string> getDisplayModes(void) const;
+    std::vector<std::string> getDisplayModes() const;
     /// set the display mode
     std::string setDisplayMode(const char* ModeName);
     //@}
@@ -125,6 +124,8 @@ public:
 
     bool getDropPrefix(std::string &prefix) const;
 
+    bool editProperty(const char *propName);
+
 private:
     ViewProviderDocumentObject* object;
     App::PropertyPythonObject &Proxy;
@@ -170,6 +171,7 @@ private:
     FC_PY_ELEMENT(getDropPrefix) \
     FC_PY_ELEMENT(replaceObject) \
     FC_PY_ELEMENT(getLinkedViewProvider) \
+    FC_PY_ELEMENT(editProperty) \
 
 #undef FC_PY_ELEMENT
 #define FC_PY_ELEMENT(_name) FC_PY_ELEMENT_DEFINE(_name)
@@ -264,7 +266,7 @@ public:
         return name;
     }
     virtual SoDetail* getDetail(const char* name) const override {
-        SoDetail *det = 0;
+        SoDetail *det = nullptr;
         if(imp->getDetail(name,det))
             return det;
         return ViewProviderT::getDetail(name);
@@ -452,7 +454,7 @@ public:
         return ViewProviderT::getDefaultDisplayMode();
     }
     /// returns a list of all possible modes
-    virtual std::vector<std::string> getDisplayModes(void) const override {
+    virtual std::vector<std::string> getDisplayModes() const override {
         std::vector<std::string> modes = ViewProviderT::getDisplayModes();
         std::vector<std::string> more_modes = imp->getDisplayModes();
         modes.insert(modes.end(), more_modes.begin(), more_modes.end());
@@ -568,13 +570,18 @@ protected:
     }
 
     virtual ViewProviderDocumentObject *getLinkedViewProvider(
-            std::string *subname=0, bool recursive=false) const override{
-        ViewProviderDocumentObject *res = 0;
+            std::string *subname=nullptr, bool recursive=false) const override{
+        ViewProviderDocumentObject *res = nullptr;
         if(!imp->getLinkedViewProvider(res, subname, recursive))
             res = ViewProviderT::getLinkedViewProvider(subname,recursive);
         return res;
     }
 
+    virtual void editProperty(const char *propName) override {
+        if (!imp->editProperty(propName))
+            ViewProviderT::editProperty(propName);
+    }
+
 public:
     virtual void setupContextMenu(QMenu* menu, QObject* recipient, const char* member) override
     {
@@ -583,7 +590,7 @@ public:
     }
 
 protected:
-    virtual bool doubleClicked(void) override
+    virtual bool doubleClicked() override
     {
         App::AutoTransaction committer;
         switch (imp->doubleClicked()) {
