@@ -22,27 +22,22 @@
 
 
 #include "PreCompiled.h"
-#ifndef _PreComp_
-# include <sstream>
-#endif
 
 #include <Base/Console.h>
-#include <Base/Exception.h>
+
 #include "WorkbenchManager.h"
 #include "Workbench.h"
+#include "DockWindowManager.h"
 #include "MenuManager.h"
 #include "ToolBarManager.h"
-#include "ToolBoxManager.h"
-#include "DockWindowManager.h"
-#include "MainWindow.h"
 
 using namespace Gui;
 
-WorkbenchManager* WorkbenchManager::_instance = 0;
+WorkbenchManager* WorkbenchManager::_instance = nullptr;
 
 WorkbenchManager* WorkbenchManager::instance()
 {
-    if (_instance == 0)
+    if (_instance == nullptr)
         _instance = new WorkbenchManager;
     return _instance;
 }
@@ -50,10 +45,10 @@ WorkbenchManager* WorkbenchManager::instance()
 void WorkbenchManager::destruct()
 {
     delete _instance;
-    _instance = 0;
+    _instance = nullptr;
 }
 
-WorkbenchManager::WorkbenchManager() : _activeWorkbench(0)
+WorkbenchManager::WorkbenchManager() : _activeWorkbench(nullptr)
 {
 }
 
@@ -76,23 +71,17 @@ Workbench* WorkbenchManager::createWorkbench (const std::string& name, const std
 
     if (!wb) {
         // try to create an instance now
-        Base::BaseClass* base = static_cast<Base::BaseClass*>
-            (Base::Type::createInstanceByName(className.c_str(),false));
-        if (base) {
-            if (!base->getTypeId().isDerivedFrom(Gui::Workbench::getClassTypeId())) {
-                delete base;
-                std::stringstream str;
-                str << "'" << className << "' not a workbench type" << std::ends;
-                throw Base::TypeError(str.str());
-            }
-
-            wb = static_cast<Workbench*>(base);
-            wb->setName(name);
-            _workbenches[name] = wb;
+        Base::Type type = Base::Type::getTypeIfDerivedFrom(className.c_str(), Workbench::getClassTypeId(), false);
+        wb = static_cast<Workbench*>(type.createInstance());
+        // createInstance could return a null pointer
+        if (!wb) {
+            std::stringstream str;
+            str << "'" << className << "' not a workbench type" << std::ends;
+            throw Base::TypeError(str.str());
         }
-        else
-            Base::Console().Log("WorkbenchManager::createWorkbench(): Can not create "
-                "Workbench instance with type: %s\n",className.c_str());
+
+        wb->setName(name);
+        _workbenches[name] = wb;
     }
 
     return wb;
@@ -105,14 +94,14 @@ void WorkbenchManager::removeWorkbench(const std::string& name)
         Workbench* wb = it->second;
         _workbenches.erase(it);
         if (_activeWorkbench == wb)
-            _activeWorkbench = 0;
+            _activeWorkbench = nullptr;
         delete wb;
     }
 }
 
 Workbench* WorkbenchManager::getWorkbench (const std::string& name) const
 {
-    Workbench* wb=0;
+    Workbench* wb=nullptr;
 
     std::map<std::string, Workbench*>::const_iterator it = _workbenches.find(name);
     if (it != _workbenches.end()) {
