@@ -24,22 +24,25 @@
 #ifndef PROPERTYEDITORITEM_H
 #define PROPERTYEDITORITEM_H
 
+#include <QItemEditorFactory>
 #include <QObject>
 #include <QPointer>
+#include <QPushButton>
 #include <QItemEditorFactory>
 #include <vector>
 
+#include <App/PropertyStandard.h>
 #include <Base/Factory.h>
-#include <Base/Vector3D.h>
 #include <Base/Matrix.h>
 #include <Base/Placement.h>
 #include <Base/Quantity.h>
+#include <Base/Vector3D.h>
 #include <Base/UnitsApi.h>
-#include <App/DocumentObserver.h>
-#include <App/PropertyStandard.h>
-#include <Gui/Widgets.h>
 #include <Gui/ExpressionBinding.h>
 #include <Gui/MetaTypes.h>
+#include <Gui/Widgets.h>
+
+#include <FCGlobal.h>
 
 #ifdef Q_MOC_RUN
 Q_DECLARE_METATYPE(Base::Vector3f)
@@ -47,10 +50,12 @@ Q_DECLARE_METATYPE(Base::Vector3d)
 Q_DECLARE_METATYPE(QList<Base::Vector3d>)
 Q_DECLARE_METATYPE(Base::Matrix4D)
 Q_DECLARE_METATYPE(Base::Placement)
+Q_DECLARE_METATYPE(Base::Rotation)
 Q_DECLARE_METATYPE(Base::Quantity)
 Q_DECLARE_METATYPE(QList<Base::Quantity>)
 #endif
 
+
 #define PROPERTYITEM_HEADER \
 public: \
     static void *create(void); \
@@ -74,6 +79,8 @@ class DlgPropertyLink;
 namespace PropertyEditor {
 
 class PropertyItem;
+class PropertyModel;
+class PropertyEditorWidget;
 
 /**
  * The PropertyItemFactory provides methods for the dynamic creation of property items.
@@ -108,6 +115,11 @@ public:
     }
 };
 
+class PropertyItemAttorney {
+public:
+    static QVariant toString(PropertyItem* item, const QVariant& v);
+};
+
 class GuiExport PropertyItem : public QObject, public ExpressionBinding
 {
     Q_OBJECT
@@ -136,6 +148,8 @@ public:
     void setExpressionEditorData(QWidget *editor, const QVariant& data) const;
     QVariant expressionEditorData(QWidget *editor) const;
 
+    PropertyEditorWidget* createPropertyEditorWidget(QWidget* parent) const;
+
     /**override the bind functions to ensure we issue the propertyBound() call, which is then overloaded by 
        childs which like to be informed of a binding*/
     virtual void bind(const App::Property& prop);
@@ -147,6 +161,7 @@ public:
     PropertyItem *parent() const;
     void appendChild(PropertyItem *child);
     void insertChild(int, PropertyItem *child);
+    void moveChild(int from, int to);
     void removeChildren(int from, int to);
     PropertyItem *takeChild(int);
 
@@ -159,16 +174,19 @@ public:
     void setLinked(bool);
     bool isLinked() const;
 
+    bool isExpanded() const;
+    void setExpanded(bool e);
+
     PropertyItem *child(int row);
     int childCount() const;
     int columnCount() const;
     QString propertyName() const;
-    void setPropertyName(const QString&);
+    void setPropertyName(QString name, QString realName=QString());
     void setPropertyValue(const QString&);
     virtual QVariant data(int column, int role) const;
     bool setData (const QVariant& value);
     Qt::ItemFlags flags(int column) const;
-    int row() const;
+    virtual int row() const;
     void reset();
 
     bool hasAnyExpression() const;
@@ -195,8 +213,10 @@ protected:
     QList<PropertyItem*> childItems;
     bool readonly;
     int precision;
-    bool cleared;
     bool linked;
+    bool expanded;
+
+    friend class PropertyItemAttorney;
 };
 
 /**
@@ -252,6 +272,14 @@ class GuiExport PropertySeparatorItem : public PropertyItem
 
     bool isSeparator() const { return true; }
     QWidget* createEditor(QWidget* parent, const QObject* receiver, const char* method) const;
+
+    virtual int row() const {
+        return _row<0?PropertyItem::row():_row;
+    }
+
+private:
+    friend PropertyModel;
+    int _row = -1;
 };
 
 /**
@@ -466,13 +494,13 @@ private:
     PropertyFloatItem* m_z;
 };
 
-class VectorListWidget : public QWidget
+class PropertyEditorWidget : public QWidget
 {
     Q_OBJECT
 
 public:
-    VectorListWidget (int decimals, QWidget * parent = nullptr);
-    virtual ~VectorListWidget();
+    PropertyEditorWidget (QWidget * parent = nullptr);
+    virtual ~PropertyEditorWidget();
 
     QVariant value() const;
 
@@ -480,20 +508,34 @@ public Q_SLOTS:
     void setValue(const QVariant&);
 
 protected:
-    void showValue(const QVariant& data);
+    virtual void showValue(const QVariant& data);
     void resizeEvent(QResizeEvent*);
 
+Q_SIGNALS:
+    void buttonClick();
+    void valueChanged(const QVariant &);
+
+protected:
+    QVariant variant;
+    QLineEdit *lineEdit;
+    QPushButton *button;
+};
+
+class VectorListWidget : public PropertyEditorWidget
+{
+    Q_OBJECT
+
+public:
+    VectorListWidget (int decimals, QWidget * parent = nullptr);
+
+protected:
+    virtual void showValue(const QVariant& data) override;
+
 private Q_SLOTS:
     void buttonClicked();
 
-Q_SIGNALS:
-    void valueChanged(const QVariant &);
-
 private:
     int decimals;
-    QVariant variant;
-    QLineEdit *lineEdit;
-    QPushButton *button;
 };
 
 /**
@@ -656,12 +698,71 @@ private:
     PropertyFloatItem* m_a44; 
 };
 
+class RotationHelper
+{
+public:
+    RotationHelper();
+    void setChanged(bool);
+    bool hasChangedAndReset();
+    bool isAxisInitialized() const;
+    void setValue(const Base::Vector3d& axis, double angle);
+    void getValue(Base::Vector3d& axis, double& angle) const;
+    double getAngle(const Base::Rotation& val) const;
+    Base::Rotation setAngle(double);
+    Base::Vector3d getAxis() const;
+    Base::Rotation setAxis(const Base::Rotation& value, const Base::Vector3d& axis);
+    void assignProperty(const Base::Rotation& value, double eps);
+
+private:
+    bool init_axis;
+    bool changed_value;
+    double rot_angle;
+    Base::Vector3d rot_axis;
+};
+
+/**
+ * Edit properties of rotation type.
+ * \author Werner Mayer
+ */
+class GuiExport PropertyRotationItem: public PropertyItem
+{
+    Q_OBJECT
+    Q_PROPERTY(Base::Quantity Angle READ getAngle WRITE setAngle DESIGNABLE true USER true)
+    Q_PROPERTY(Base::Vector3d Axis READ getAxis WRITE setAxis DESIGNABLE true USER true)
+    PROPERTYITEM_HEADER
+
+    virtual QWidget* createEditor(QWidget* parent, const QObject* receiver, const char* method) const;
+    virtual void setEditorData(QWidget *editor, const QVariant& data) const;
+    virtual QVariant editorData(QWidget *editor) const;
+
+    virtual void propertyBound();
+    virtual void assignProperty(const App::Property*);
+
+    Base::Quantity getAngle() const;
+    void setAngle(Base::Quantity);
+    Base::Vector3d getAxis() const;
+    void setAxis(const Base::Vector3d&);
+
+protected:
+    PropertyRotationItem();
+    ~PropertyRotationItem();
+    virtual QVariant toolTip(const App::Property*) const;
+    virtual QVariant toString(const QVariant&) const;
+    virtual QVariant value(const App::Property*) const;
+    virtual void setValue(const QVariant&);
+
+private:
+    mutable RotationHelper h;
+    PropertyUnitItem * m_a;
+    PropertyVectorItem* m_d;
+};
+
 class PlacementEditor : public Gui::LabelButton
 {
     Q_OBJECT
 
 public:
-    PlacementEditor(const QString& name, QWidget * parent = 0);
+    PlacementEditor(const QString& name, QWidget * parent = nullptr);
     ~PlacementEditor();
 
 private Q_SLOTS:
@@ -711,15 +812,14 @@ protected:
     virtual void setValue(const QVariant&);
 
 private:
-    bool init_axis;
-    bool changed_value;
-    double rot_angle;
-    Base::Vector3d rot_axis;
+    mutable RotationHelper h;
     PropertyUnitItem * m_a;
     PropertyVectorItem* m_d;
     PropertyVectorDistanceItem* m_p;
 };
 
+class PropertyStringListItem;
+
 /**
  * Edit properties of enum type. 
  * \author Werner Mayer
@@ -727,18 +827,38 @@ private:
 class GuiExport PropertyEnumItem: public PropertyItem
 {
     Q_OBJECT
+    Q_PROPERTY(QStringList Enum READ getEnum WRITE setEnum DESIGNABLE true USER true)
     PROPERTYITEM_HEADER
 
     virtual QWidget* createEditor(QWidget* parent, const QObject* receiver, const char* method) const;
     virtual void setEditorData(QWidget *editor, const QVariant& data) const;
     virtual QVariant editorData(QWidget *editor) const;
 
+    QStringList getEnum() const;
+    void setEnum(QStringList);
+
 protected:
     virtual QVariant value(const App::Property*) const;
     virtual void setValue(const QVariant&);
+    virtual void propertyBound();
 
 protected:
     PropertyEnumItem();
+
+private:
+    PropertyStringListItem* m_enum;
+};
+
+class PropertyEnumButton : public QPushButton
+{
+    Q_OBJECT
+public:
+    PropertyEnumButton(QWidget *parent = nullptr)
+        :QPushButton(parent)
+    {}
+
+Q_SIGNALS:
+    void picked();
 };
 
 /**
@@ -1086,13 +1206,8 @@ public:
     PropertyItemEditorFactory();
     virtual ~PropertyItemEditorFactory();
 
-#if (QT_VERSION >= 0x050300)
     virtual QWidget *createEditor(int userType, QWidget *parent) const;
     virtual QByteArray valuePropertyName(int userType) const;
-#else
-    virtual QWidget * createEditor(QVariant::Type type, QWidget * parent) const;
-    virtual QByteArray valuePropertyName (QVariant::Type type) const;
-#endif
 };
 
 } // namespace PropertyEditor
