@@ -20,7 +20,6 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include <FCConfig.h>
 
 #if HAVE_CONFIG_H
@@ -33,19 +32,19 @@
 
 #include <QApplication>
 #include <QIcon>
-#include <QThread>
 #if defined(Q_OS_WIN)
 #include <windows.h>
 #elif defined(Q_WS_X11)
 #include <QX11EmbedWidget>
 #endif
 #include <thread>
+
 // FreeCAD Base header
-#include <CXX/WrapPython.h>
+#include <App/Application.h>
 #include <Base/Exception.h>
 #include <Base/Factory.h>
 #include <Base/Interpreter.h>
-#include <App/Application.h>
+#include <Base/PyObjectBase.h>
 #include <Gui/Application.h>
 #include <Gui/BitmapFactory.h>
 #include <Gui/MainWindow.h>
@@ -55,6 +54,7 @@
 #include <Inventor/SoInteraction.h>
 #include <Inventor/nodekits/SoNodeKit.h>
 
+
 static bool _isSetupWithoutGui = false;
 
 static
@@ -97,7 +97,7 @@ FreeCADGui_showMainWindow(PyObject * /*self*/, PyObject *args)
 
     PyObject* inThread = Py_False;
     if (!PyArg_ParseTuple(args, "|O!", &PyBool_Type, &inThread))
-        return NULL;
+        return nullptr;
 
     static bool thr = false;
     if (!qApp) {
@@ -105,10 +105,8 @@ FreeCADGui_showMainWindow(PyObject * /*self*/, PyObject *args)
             thr = true;
             std::thread t([]() {
                 static int argc = 0;
-                static char **argv = {0};
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 9, 0))
+                static char **argv = {nullptr};
                 QApplication::setAttribute(Qt::AA_ShareOpenGLContexts);
-#endif
                 // This only works well if the QApplication is the very first created instance
                 // of a QObject. Otherwise the application lives in a different thread than the
                 // main thread which will cause hazardous behaviour.
@@ -132,7 +130,7 @@ FreeCADGui_showMainWindow(PyObject * /*self*/, PyObject *args)
                 FilterProc, 0, GetCurrentThreadId());
 #elif !defined(QT_NO_GLIB)
             static int argc = 0;
-            static char **argv = {0};
+            static char **argv = {nullptr};
             (void)new QApplication(argc, argv);
 #else
             PyErr_SetString(PyExc_RuntimeError, "Must construct a QApplication before a QPaintDevice\n");
@@ -142,16 +140,24 @@ FreeCADGui_showMainWindow(PyObject * /*self*/, PyObject *args)
     }
     else if (!qobject_cast<QApplication*>(qApp)) {
         PyErr_SetString(PyExc_RuntimeError, "Cannot create widget when no GUI is being used\n");
-        return NULL;
+        return nullptr;
     }
 
     if (!thr) {
         if (!setupMainWindow()) {
             PyErr_SetString(PyExc_RuntimeError, "Cannot create main window\n");
-            return NULL;
+            return nullptr;
         }
     }
 
+    // if successful then enable Console logger
+    Base::ILogger *console = Base::Console().Get("Console");
+    if (console) {
+        console->bMsg = true;
+        console->bWrn = true;
+        console->bErr = true;
+    }
+
     Py_INCREF(Py_None);
     return Py_None;
 }
@@ -160,15 +166,15 @@ static PyObject *
 FreeCADGui_exec_loop(PyObject * /*self*/, PyObject *args)
 {
     if (!PyArg_ParseTuple(args, ""))
-        return NULL;
+        return nullptr;
 
     if (!qApp) {
         PyErr_SetString(PyExc_RuntimeError, "Must construct a QApplication before a QPaintDevice\n");
-        return NULL;
+        return nullptr;
     }
     else if (!qobject_cast<QApplication*>(qApp)) {
         PyErr_SetString(PyExc_RuntimeError, "Cannot create widget when no GUI is being used\n");
-        return NULL;
+        return nullptr;
     }
 
     qApp->exec();
@@ -181,18 +187,13 @@ static PyObject *
 FreeCADGui_setupWithoutGUI(PyObject * /*self*/, PyObject *args)
 {
     if (!PyArg_ParseTuple(args, ""))
-        return NULL;
+        return nullptr;
 
     if (!Gui::Application::Instance) {
         static Gui::Application *app = new Gui::Application(false);
         _isSetupWithoutGui = true;
         Q_UNUSED(app);
     }
-    else {
-        PyErr_SetString(PyExc_RuntimeError, "FreeCADGui already initialized");
-        return 0;
-    }
-
     if (!SoDB::isInitialized()) {
         // init the Inventor subsystem
         SoDB::init();
@@ -212,12 +213,12 @@ FreeCADGui_embedToWindow(PyObject * /*self*/, PyObject *args)
 {
     char* pointer;
     if (!PyArg_ParseTuple(args, "s", &pointer))
-        return NULL;
+        return nullptr;
 
     QWidget* widget = Gui::getMainWindow();
     if (!widget) {
-        PyErr_SetString(Base::BaseExceptionFreeCADError, "No main window");
-        return 0;
+        PyErr_SetString(Base::PyExc_FC_GeneralError, "No main window");
+        return nullptr;
     }
 
     std::string pointer_str = pointer;
@@ -247,7 +248,7 @@ FreeCADGui_embedToWindow(PyObject * /*self*/, PyObject *args)
     x11->show();
 #else
     PyErr_SetString(PyExc_NotImplementedError, "Not implemented for this platform");
-    return 0;
+    return nullptr;
 #endif
 
     Py_INCREF(Py_None);
@@ -266,7 +267,7 @@ struct PyMethodDef FreeCADGui_methods[] = {
      "an event loop or showing up any GUI\n"},
     {"embedToWindow",FreeCADGui_embedToWindow,METH_VARARGS,
      "embedToWindow() -- Embeds the main window into another window\n"},
-    {NULL, NULL, 0, NULL}  /* sentinel */
+    {nullptr, nullptr, 0, nullptr}  /* sentinel */
 };
 
 static
@@ -282,7 +283,7 @@ QWidget* setupMainWindow()
         if (hasMainWindow) {
             // if a main window existed and has been deleted it's not supported
             // to re-create it
-            return 0;
+            return nullptr;
         }
 
         Base::PyGILStateLocker lock;
@@ -314,8 +315,8 @@ QWidget* setupMainWindow()
                 Base::Interpreter().runString(Base::ScriptFactory().ProduceScript("FreeCADGuiInit"));
             }
             catch (const Base::Exception& e) {
-                PyErr_Format(Base::BaseExceptionFreeCADError, "Error in FreeCADGuiInit.py: %s\n", e.what());
-                return 0;
+                PyErr_Format(Base::PyExc_FC_GeneralError, "Error in FreeCADGuiInit.py: %s\n", e.what());
+                return nullptr;
             }
             init = true;
         }
@@ -364,25 +365,21 @@ PyMOD_INIT_FUNC(FreeCADGui)
         Base::Interpreter().loadModule("FreeCAD");
         App::Application::Config()["AppIcon"] = "freecad";
         App::Application::Config()["SplashScreen"] = "freecadsplash";
-        App::Application::Config()["CopyrightInfo"] = "\xc2\xa9 Juergen Riegel, Werner Mayer, Yorik van Havre and others 2001-2020\n";
+        App::Application::Config()["CopyrightInfo"] = "\xc2\xa9 Juergen Riegel, Werner Mayer, Yorik van Havre and others 2001-2022\n";
         App::Application::Config()["LicenseInfo"] = "FreeCAD is free and open-source software licensed under the terms of LGPL2+ license.\n";
         App::Application::Config()["CreditsInfo"] = "FreeCAD wouldn't be possible without FreeCAD community.\n";
         // it's possible that the GUI is already initialized when the Gui version of the executable
         // is started in command mode
         if (Base::Type::fromName("Gui::BaseView").isBad())
             Gui::Application::initApplication();
-#if PY_MAJOR_VERSION >= 3
         static struct PyModuleDef FreeCADGuiModuleDef = {
             PyModuleDef_HEAD_INIT,
             "FreeCADGui", "FreeCAD GUI module\n", -1,
             FreeCADGui_methods,
-            NULL, NULL, NULL, NULL
+            nullptr, nullptr, nullptr, nullptr
         };
         PyObject* module = PyModule_Create(&FreeCADGuiModuleDef);
         return module;
-#else
-        Py_InitModule3("FreeCADGui", FreeCADGui_methods, "FreeCAD GUI module\n");
-#endif
     }
     catch (const Base::Exception& e) {
         PyErr_Format(PyExc_ImportError, "%s\n", e.what());
@@ -390,8 +387,6 @@ PyMOD_INIT_FUNC(FreeCADGui)
     catch (...) {
         PyErr_SetString(PyExc_ImportError, "Unknown runtime error occurred");
     }
-#if PY_MAJOR_VERSION >= 3
-    return 0;
-#endif
+    return nullptr;
 }
 
