@@ -35,31 +35,27 @@
 #   include <config.h>
 #endif // HAVE_CONFIG_H
 
+#include <cstdio>
 #include <map>
-#include <vector>
-#include <algorithm>
 #include <stdexcept>
 
-#include <cstdio>
 #include <QApplication>
-#include <QFile>
-#include <QMessageBox>
 #include <QLocale>
+#include <QMessageBox>
 #include <QTextCodec>
 
 // FreeCAD header
-#include <Base/Console.h>
+#include <App/Application.h>
+#include <Base/ConsoleObserver.h>
 #include <Base/Interpreter.h>
 #include <Base/Parameter.h>
 #include <Base/Exception.h>
-#include <Base/Factory.h>
-#include <App/Application.h>
-#include <Gui/BitmapFactory.h>
 #include <Gui/Application.h>
 
+
 void PrintInitHelp(void);
 
-const char sBanner[] = "\xc2\xa9 Juergen Riegel, Werner Mayer, Yorik van Havre and others 2001-2021\n"\
+const char sBanner[] = "\xc2\xa9 Juergen Riegel, Werner Mayer, Yorik van Havre and others 2001-2022\n"\
 "FreeCAD is free and open-source software licensed under the terms of LGPL2+ license.\n"\
 "FreeCAD wouldn't be possible without FreeCAD community.\n"\
 "  #####                 ####  ###   ####  \n" \
@@ -120,13 +116,6 @@ int main( int argc, char ** argv )
     // Make sure to setup the Qt locale system before setting LANG and LC_ALL to C.
     // which is needed to use the system locale settings.
     (void)QLocale::system();
-#if QT_VERSION < 0x050000
-    // http://www.freecadweb.org/tracker/view.php?id=399
-    // Because of setting LANG=C the Qt automagic to use the correct encoding
-    // for file names is broken. This is a workaround to force the use of UTF-8 encoding
-    QFile::setEncodingFunction(myEncoderFunc);
-    QFile::setDecodingFunction(myDecoderFunc);
-#endif
     // See https://forum.freecadweb.org/viewtopic.php?f=18&t=20600
     // See Gui::Application::runApplication()
     putenv("LC_NUMERIC=C");
@@ -134,6 +123,11 @@ int main( int argc, char ** argv )
 #elif defined(FC_OS_MACOSX)
     (void)QLocale::system();
     putenv("PYTHONPATH=");
+#elif defined(__MINGW32__)
+    const char* mingw_prefix = getenv("MINGW_PREFIX");
+    const char* py_home = getenv("PYTHONHOME");
+    if (!py_home && mingw_prefix)
+        _putenv_s("PYTHONHOME", mingw_prefix);
 #else
     _putenv("PYTHONPATH=");
     // https://forum.freecadweb.org/viewtopic.php?f=4&t=18288
@@ -166,32 +160,30 @@ int main( int argc, char ** argv )
     }
 #endif
 
-#if PY_MAJOR_VERSION >= 3
 #if defined(_MSC_VER) && _MSC_VER <= 1800
     // See InterpreterSingleton::init
     Redirection out(stdout), err(stderr), inp(stdin);
 #endif
-#endif // PY_MAJOR_VERSION
 
     // Name and Version of the Application
     App::Application::Config()["ExeName"] = "FreeCAD";
     App::Application::Config()["ExeVendor"] = "FreeCAD";
     App::Application::Config()["AppDataSkipVendor"] = "true";
-    App::Application::Config()["MaintainerUrl"] = "http://www.freecadweb.org/wiki/Main_Page";
+    App::Application::Config()["MaintainerUrl"] = "http://www.freecad.org/wiki/Main_Page";
 
     // set the banner (for logging and console)
     App::Application::Config()["CopyrightInfo"] = sBanner;
     App::Application::Config()["AppIcon"] = "freecad";
     App::Application::Config()["SplashScreen"] = "freecadsplash";
+    App::Application::Config()["AboutImage"] = "freecadabout";
     App::Application::Config()["StartWorkbench"] = "StartWorkbench";
     //App::Application::Config()["HiddenDockWindow"] = "Property editor";
     App::Application::Config()["SplashAlignment" ] = "Bottom|Left";
     App::Application::Config()["SplashTextColor" ] = "#ffffff"; // white
     App::Application::Config()["SplashInfoColor" ] = "#c8c8c8"; // light grey
+    App::Application::Config()["SplashInfoPosition" ] = "15.210";
 
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 7, 0))
     QGuiApplication::setDesktopFileName(QStringLiteral("org.freecadweb.FreeCAD.desktop"));
-#endif
 
     try {
         // Init phase ===========================================================
@@ -231,7 +223,7 @@ int main( int argc, char ** argv )
         QString appName = QString::fromLatin1(App::Application::Config()["ExeName"].c_str());
         QString msg = QString::fromLatin1(e.what());
         QString s = QLatin1String("<pre>") + msg + QLatin1String("</pre>");
-        QMessageBox::critical(0, appName, s);
+        QMessageBox::critical(nullptr, appName, s);
         exit(1);
     }
     catch (const Base::ProgramInformation& e) {
@@ -257,15 +249,7 @@ int main( int argc, char ** argv )
                           "Python is searching for its files in the following directories:\n%3\n\n"
                           "Python version information:\n%4\n")
                           .arg(appName, QString::fromUtf8(e.what()),
-#if PY_MAJOR_VERSION >= 3
-#if PY_MINOR_VERSION >= 5
-                          QString::fromUtf8(Py_EncodeLocale(Py_GetPath(),NULL)), QString::fromLatin1(Py_GetVersion()));
-#else
-                          QString::fromUtf8(_Py_wchar2char(Py_GetPath(),NULL)), QString::fromLatin1(Py_GetVersion()));
-#endif
-#else
-                          QString::fromUtf8(Py_GetPath()), QString::fromLatin1(Py_GetVersion()));
-#endif
+                          QString::fromUtf8(Py_EncodeLocale(Py_GetPath(),nullptr)), QString::fromLatin1(Py_GetVersion()));
         const char* pythonhome = getenv("PYTHONHOME");
         if (pythonhome) {
             msg += QObject::tr("\nThe environment variable PYTHONHOME is set to '%1'.")
@@ -276,7 +260,7 @@ int main( int argc, char ** argv )
             msg += QObject::tr("\nPlease contact the application's support team for more information.\n\n");
         }
 
-        QMessageBox::critical(0, QObject::tr("Initialization of %1 failed").arg(appName), msg);
+        QMessageBox::critical(nullptr, QObject::tr("Initialization of %1 failed").arg(appName), msg);
         exit(100);
     }
     catch (...) {
@@ -285,7 +269,7 @@ int main( int argc, char ** argv )
         QString appName = QString::fromLatin1(App::Application::Config()["ExeName"].c_str());
         QString msg = QObject::tr("Unknown runtime error occurred while initializing %1.\n\n"
                                   "Please contact the application's support team for more information.\n\n").arg(appName);
-        QMessageBox::critical(0, QObject::tr("Initialization of %1 failed").arg(appName), msg);
+        QMessageBox::critical(nullptr, QObject::tr("Initialization of %1 failed").arg(appName), msg);
         exit(101);
     }
 
