@@ -2,3 +2,7 @@
 # FreeCAD init script of the AddonManager module
 # (c) 2001 Juergen Riegel
 # License LGPL
+
+import FreeCAD
+
+FreeCAD.__unit_test__ += ["TestAddonManagerApp"]
