@@ -6,4 +6,8 @@
 import AddonManager
 
 FreeCADGui.addLanguagePath(":/translations")
-FreeCADGui.addCommand('Std_AddonMgr', AddonManager.CommandAddonManager())
+FreeCADGui.addCommand("Std_AddonMgr", AddonManager.CommandAddonManager())
+
+import FreeCAD
+
+FreeCAD.__unit_test__ += ["TestAddonManagerGui"]
