@@ -4,9 +4,9 @@
   <context>
     <name>AddonInstaller</name>
     <message>
-      <location filename="addonmanager_workers.py" line="536"/>
+      <location filename="addonmanager_workers.py" line="531"/>
       <source>Installed location</source>
-      <translation type="unfinished">Installed location</translation>
+      <translation>설치 위치</translation>
     </message>
   </context>
   <context>
@@ -14,7 +14,7 @@
     <message>
       <location filename="addonmanager_macro.py" line="157"/>
       <source>Unable to fetch the code of this macro.</source>
-      <translation type="unfinished">Unable to fetch the code of this macro.</translation>
+      <translation>이 매크로의 코드를 가져올 수 없습니다.</translation>
     </message>
     <message>
       <location filename="addonmanager_macro.py" line="164"/>
@@ -27,252 +27,252 @@
       <translation type="unfinished">The addons that can be installed here are not officially part of FreeCAD, and are not reviewed by the FreeCAD team. Make sure you know what you are installing!</translation>
     </message>
     <message>
-      <location filename="AddonManager.py" line="200"/>
+      <location filename="AddonManager.py" line="199"/>
       <source>Addon manager</source>
       <translation>추가 기능 관리</translation>
     </message>
     <message>
-      <location filename="AddonManager.py" line="205"/>
+      <location filename="AddonManager.py" line="204"/>
       <source>You must restart FreeCAD for changes to take effect. Press Ok to restart FreeCAD now, or Cancel to restart later.</source>
       <translation>추가기능을 사용하려면 FreeCAD를 재시작해야 합니다. 지금 바로 재시작하려면 OK버튼, 나중에 재시작하려면 취소버튼을 누르세요.</translation>
     </message>
     <message>
-      <location filename="AddonManager.py" line="244"/>
+      <location filename="AddonManager.py" line="243"/>
       <source>Checking for updates...</source>
       <translation>업데이트 확인 중...</translation>
     </message>
     <message>
-      <location filename="AddonManager.py" line="263"/>
+      <location filename="AddonManager.py" line="262"/>
       <source>Apply</source>
       <translation>적용</translation>
     </message>
     <message>
-      <location filename="AddonManager.py" line="264"/>
+      <location filename="AddonManager.py" line="263"/>
       <source>update(s)</source>
       <translation>업데이트</translation>
     </message>
     <message>
-      <location filename="AddonManager.py" line="267"/>
+      <location filename="AddonManager.py" line="266"/>
       <source>No update available</source>
       <translation>사용가능한 업데이트가 없습니다.</translation>
     </message>
     <message>
-      <location filename="AddonManager.py" line="434"/>
+      <location filename="AddonManager.py" line="433"/>
       <source>Macro successfully installed. The macro is now available from the Macros dialog.</source>
       <translation>매크로가 설치되었습니다. 이제 매크로 창을 열어 사용할 수 있습니다.</translation>
     </message>
     <message>
-      <location filename="AddonManager.py" line="436"/>
+      <location filename="AddonManager.py" line="435"/>
       <source>Unable to install</source>
       <translation>설치할 수 없습니다.</translation>
     </message>
     <message>
-      <location filename="AddonManager.py" line="495"/>
+      <location filename="AddonManager.py" line="494"/>
       <source>Addon successfully removed. Please restart FreeCAD</source>
       <translation>추가기능이 제거되었습니다. FreeCAD를 다시 시작 해주세요.</translation>
     </message>
     <message>
-      <location filename="AddonManager.py" line="497"/>
+      <location filename="AddonManager.py" line="496"/>
       <source>Unable to remove this addon</source>
       <translation>이 추가기능을 제거할 수 없습니다.</translation>
     </message>
     <message>
-      <location filename="AddonManager.py" line="503"/>
+      <location filename="AddonManager.py" line="502"/>
       <source>Macro successfully removed.</source>
       <translation>매크로가 제거되었습니다.</translation>
     </message>
     <message>
-      <location filename="AddonManager.py" line="505"/>
+      <location filename="AddonManager.py" line="504"/>
       <source>Macro could not be removed.</source>
       <translation>매크로를 제거할 수 없습니다.</translation>
     </message>
     <message>
-      <location filename="addonmanager_workers.py" line="172"/>
+      <location filename="addonmanager_workers.py" line="167"/>
       <source>Unable to download addon list.</source>
       <translation type="unfinished">Unable to download addon list.</translation>
     </message>
     <message>
-      <location filename="addonmanager_workers.py" line="177"/>
+      <location filename="addonmanager_workers.py" line="172"/>
       <source>Workbenches list was updated.</source>
       <translation>작업대 목록이 갱신되었습니다.</translation>
     </message>
     <message>
-      <location filename="addonmanager_workers.py" line="735"/>
+      <location filename="addonmanager_workers.py" line="734"/>
       <source>Outdated GitPython detected, consider upgrading with pip.</source>
       <translation type="unfinished">Outdated GitPython detected, consider upgrading with pip.</translation>
     </message>
     <message>
-      <location filename="addonmanager_workers.py" line="297"/>
+      <location filename="addonmanager_workers.py" line="292"/>
       <source>List of macros successfully retrieved.</source>
       <translation type="unfinished">List of macros successfully retrieved.</translation>
     </message>
     <message>
-      <location filename="addonmanager_workers.py" line="648"/>
+      <location filename="addonmanager_workers.py" line="647"/>
       <source>Retrieving description...</source>
       <translation type="unfinished">Retrieving description...</translation>
     </message>
     <message>
-      <location filename="addonmanager_workers.py" line="392"/>
+      <location filename="addonmanager_workers.py" line="387"/>
       <source>Retrieving info from</source>
       <translation type="unfinished">Retrieving info from</translation>
     </message>
     <message>
-      <location filename="addonmanager_workers.py" line="534"/>
+      <location filename="addonmanager_workers.py" line="529"/>
       <source>An update is available for this addon.</source>
       <translation>이 추가기능을 업데이트 할 수 있습니다.</translation>
     </message>
     <message>
-      <location filename="addonmanager_workers.py" line="522"/>
+      <location filename="addonmanager_workers.py" line="517"/>
       <source>This addon is already installed.</source>
       <translation>이 추가기능은 이미 설치되어 있습니다.</translation>
     </message>
     <message>
-      <location filename="addonmanager_workers.py" line="650"/>
+      <location filename="addonmanager_workers.py" line="649"/>
       <source>Retrieving info from git</source>
       <translation type="unfinished">Retrieving info from git</translation>
     </message>
     <message>
-      <location filename="addonmanager_workers.py" line="653"/>
+      <location filename="addonmanager_workers.py" line="652"/>
       <source>Retrieving info from wiki</source>
       <translation type="unfinished">Retrieving info from wiki</translation>
     </message>
     <message>
-      <location filename="addonmanager_workers.py" line="697"/>
+      <location filename="addonmanager_workers.py" line="696"/>
       <source>GitPython not found. Using standard download instead.</source>
       <translation type="unfinished">GitPython not found. Using standard download instead.</translation>
     </message>
     <message>
-      <location filename="addonmanager_workers.py" line="702"/>
+      <location filename="addonmanager_workers.py" line="701"/>
       <source>Your version of python doesn&apos;t appear to support ZIP files. Unable to proceed.</source>
       <translation type="unfinished">Your version of python doesn&apos;t appear to support ZIP files. Unable to proceed.</translation>
     </message>
     <message>
-      <location filename="addonmanager_workers.py" line="783"/>
+      <location filename="addonmanager_workers.py" line="782"/>
       <source>Workbench successfully installed. Please restart FreeCAD to apply the changes.</source>
       <translation>설치완료.새로 추가한 작업대를 사용하려면 FreeCAD를 다시 시작하세요.</translation>
     </message>
     <message>
-      <location filename="addonmanager_workers.py" line="832"/>
+      <location filename="addonmanager_workers.py" line="831"/>
       <source>Missing workbench</source>
-      <translation type="unfinished">Missing workbench</translation>
+      <translation>작업대 누락</translation>
     </message>
     <message>
-      <location filename="addonmanager_workers.py" line="841"/>
+      <location filename="addonmanager_workers.py" line="840"/>
       <source>Missing python module</source>
       <translation type="unfinished">Missing python module</translation>
     </message>
     <message>
-      <location filename="addonmanager_workers.py" line="851"/>
+      <location filename="addonmanager_workers.py" line="850"/>
       <source>Missing optional python module (doesn&apos;t prevent installing)</source>
       <translation type="unfinished">Missing optional python module (doesn&apos;t prevent installing)</translation>
     </message>
     <message>
-      <location filename="addonmanager_workers.py" line="854"/>
+      <location filename="addonmanager_workers.py" line="853"/>
       <source>Some errors were found that prevent to install this workbench</source>
       <translation type="unfinished">Some errors were found that prevent to install this workbench</translation>
     </message>
     <message>
-      <location filename="addonmanager_workers.py" line="856"/>
+      <location filename="addonmanager_workers.py" line="855"/>
       <source>Please install the missing components first.</source>
       <translation type="unfinished">Please install the missing components first.</translation>
     </message>
     <message>
-      <location filename="addonmanager_workers.py" line="877"/>
+      <location filename="addonmanager_workers.py" line="876"/>
       <source>Error: Unable to download</source>
       <translation>오류: 내려받을 수 없음</translation>
     </message>
     <message>
-      <location filename="addonmanager_workers.py" line="890"/>
+      <location filename="addonmanager_workers.py" line="889"/>
       <source>Successfully installed</source>
       <translation>설치 완료</translation>
     </message>
     <message>
-      <location filename="addonmanager_workers.py" line="311"/>
+      <location filename="addonmanager_workers.py" line="306"/>
       <source>GitPython not installed! Cannot retrieve macros from git</source>
       <translation type="unfinished">GitPython not installed! Cannot retrieve macros from git</translation>
     </message>
     <message>
-      <location filename="AddonManager.py" line="568"/>
+      <location filename="AddonManager.py" line="567"/>
       <source>Installed</source>
       <translation>설치됨</translation>
     </message>
     <message>
-      <location filename="AddonManager.py" line="587"/>
+      <location filename="AddonManager.py" line="586"/>
       <source>Update available</source>
       <translation>사용 가능한 업데이트가 있습니다</translation>
     </message>
     <message>
-      <location filename="AddonManager.py" line="543"/>
+      <location filename="AddonManager.py" line="542"/>
       <source>Restart required</source>
       <translation>다시 시작 필요</translation>
     </message>
     <message>
-      <location filename="addonmanager_workers.py" line="662"/>
+      <location filename="addonmanager_workers.py" line="661"/>
       <source>This macro is already installed.</source>
       <translation>이 매크로는 이미 설치되어 있습니다.</translation>
     </message>
     <message>
-      <location filename="addonmanager_workers.py" line="796"/>
+      <location filename="addonmanager_workers.py" line="795"/>
       <source>A macro has been installed and is available under Macro -&gt; Macros menu</source>
       <translation type="unfinished">A macro has been installed and is available under Macro -&gt; Macros menu</translation>
     </message>
     <message>
-      <location filename="addonmanager_workers.py" line="548"/>
+      <location filename="addonmanager_workers.py" line="543"/>
       <source>This addon is marked as obsolete</source>
       <translation type="unfinished">This addon is marked as obsolete</translation>
     </message>
     <message>
-      <location filename="addonmanager_workers.py" line="552"/>
+      <location filename="addonmanager_workers.py" line="547"/>
       <source>This usually means it is no longer maintained, and some more advanced addon in this list provides the same functionality.</source>
       <translation type="unfinished">This usually means it is no longer maintained, and some more advanced addon in this list provides the same functionality.</translation>
     </message>
     <message>
-      <location filename="addonmanager_workers.py" line="870"/>
+      <location filename="addonmanager_workers.py" line="869"/>
       <source>Error: Unable to locate zip from</source>
       <translation type="unfinished">Error: Unable to locate zip from</translation>
     </message>
     <message>
-      <location filename="addonmanager_workers.py" line="320"/>
+      <location filename="addonmanager_workers.py" line="315"/>
       <source>Something went wrong with the Git Macro Retrieval, possibly the Git executable is not in the path</source>
       <translation type="unfinished">Something went wrong with the Git Macro Retrieval, possibly the Git executable is not in the path</translation>
     </message>
     <message>
-      <location filename="addonmanager_workers.py" line="560"/>
+      <location filename="addonmanager_workers.py" line="555"/>
       <source>This addon is marked as Python 2 Only</source>
       <translation type="unfinished">This addon is marked as Python 2 Only</translation>
     </message>
     <message>
-      <location filename="addonmanager_workers.py" line="565"/>
+      <location filename="addonmanager_workers.py" line="560"/>
       <source>This workbench may no longer be maintained and installing it on a Python 3 system will more than likely result in errors at startup or while in use.</source>
       <translation type="unfinished">This workbench may no longer be maintained and installing it on a Python 3 system will more than likely result in errors at startup or while in use.</translation>
     </message>
     <message>
-      <location filename="addonmanager_workers.py" line="724"/>
+      <location filename="addonmanager_workers.py" line="723"/>
       <source>User requested updating a Python 2 workbench on a system running Python 3 - </source>
       <translation type="unfinished">User requested updating a Python 2 workbench on a system running Python 3 - </translation>
     </message>
     <message>
-      <location filename="addonmanager_workers.py" line="760"/>
+      <location filename="addonmanager_workers.py" line="759"/>
       <source>Workbench successfully updated. Please restart FreeCAD to apply the changes.</source>
       <translation type="unfinished">Workbench successfully updated. Please restart FreeCAD to apply the changes.</translation>
     </message>
     <message>
-      <location filename="addonmanager_workers.py" line="768"/>
+      <location filename="addonmanager_workers.py" line="767"/>
       <source>User requested installing a Python 2 workbench on a system running Python 3 - </source>
       <translation type="unfinished">User requested installing a Python 2 workbench on a system running Python 3 - </translation>
     </message>
     <message>
-      <location filename="addonmanager_workers.py" line="344"/>
+      <location filename="addonmanager_workers.py" line="339"/>
       <source>Appears to be an issue connecting to the Wiki, therefore cannot retrieve Wiki macro list at this time</source>
       <translation type="unfinished">Appears to be an issue connecting to the Wiki, therefore cannot retrieve Wiki macro list at this time</translation>
     </message>
     <message>
-      <location filename="addonmanager_workers.py" line="434"/>
+      <location filename="addonmanager_workers.py" line="429"/>
       <source>Raw markdown displayed</source>
       <translation type="unfinished">Raw markdown displayed</translation>
     </message>
     <message>
-      <location filename="addonmanager_workers.py" line="436"/>
+      <location filename="addonmanager_workers.py" line="431"/>
       <source>Python Markdown library is missing.</source>
       <translation type="unfinished">Python Markdown library is missing.</translation>
     </message>
@@ -414,12 +414,12 @@ to be scanned for available addons</translation>
   <context>
     <name>Std_AddonMgr</name>
     <message>
-      <location filename="AddonManager.py" line="70"/>
+      <location filename="AddonManager.py" line="68"/>
       <source>&amp;Addon manager</source>
       <translation type="unfinished">&amp;Addon manager</translation>
     </message>
     <message>
-      <location filename="AddonManager.py" line="71"/>
+      <location filename="AddonManager.py" line="69"/>
       <source>Manage external workbenches and macros</source>
       <translation type="unfinished">Manage external workbenches and macros</translation>
     </message>
