@@ -261,7 +261,7 @@ class Macro(object):
                     FreeCAD.Console.PrintWarning(
                         translate(
                             "AddonsInstaller",
-                            "Unable to open macro code URL {rawcodeurl}",
+                            "Unable to open macro code URL {}",
                         ).format(self.raw_code_url)
                         + "\n"
                     )
