@@ -457,7 +457,7 @@ class BuildingPart(ArchIFC.IfcProduct):
         shapes = []
         solidindex = 0
         materialstable = {}
-        for child in Draft.get_group_contents(obj):
+        for child in Draft.get_group_contents(obj, walls=True):
             if not Draft.get_type(child) in ["Space"]:
                 if hasattr(child,'Shape') and child.Shape:
                     shapes.append(child.Shape)
@@ -660,6 +660,7 @@ class ViewProviderBuildingPart:
         self.sep.addChild(self.dst)
         self.lco = coin.SoCoordinate3()
         self.sep.addChild(self.lco)
+        import PartGui # Required for "SoBrepEdgeSet" (because a BuildingPart is not a Part::FeaturePython object).
         lin = coin.SoType.fromName("SoBrepEdgeSet").createInstance()
         if lin:
             lin.coordIndex.setValues([0,1,-1,2,3,-1,4,5,-1])
@@ -733,7 +734,7 @@ class ViewProviderBuildingPart:
         "recursively get the colors of objects inside this BuildingPart"
 
         colors = []
-        for child in Draft.get_group_contents(obj):
+        for child in Draft.get_group_contents(obj, walls=True):
             if not Draft.get_type(child) in ["Space"]:
                 if hasattr(child,'Shape') and (hasattr(child.ViewObject,"DiffuseColor") or hasattr(child.ViewObject,"ShapeColor")):
                     if hasattr(child.ViewObject,"DiffuseColor") and len(child.ViewObject.DiffuseColor) == len(child.Shape.Faces):
