@@ -21,9 +21,10 @@
 
 import FreeCAD
 if FreeCAD.GuiUp:
-    import FreeCADGui, Arch_rc, os
+    import FreeCADGui, os
+    import Arch_rc # Needed for access to icons # lgtm [py/unused_import]
     from PySide import QtCore, QtGui
-    from DraftTools import translate
+    from draftutils.translate import translate
     from PySide.QtCore import QT_TRANSLATE_NOOP
 else:
     # \cond
@@ -50,7 +51,7 @@ def makeMaterial(name="Material",color=None,transparency=None):
     if not FreeCAD.ActiveDocument:
         FreeCAD.Console.PrintError("No active document. Aborting\n")
         return
-    obj = FreeCAD.ActiveDocument.addObject("App::MaterialObjectPython",name)
+    obj = FreeCAD.ActiveDocument.addObject("App::MaterialObjectPython","Material")
     obj.Label = name
     _ArchMaterial(obj)
     if FreeCAD.GuiUp:
@@ -82,7 +83,7 @@ def getMaterialContainer():
 def makeMultiMaterial(name="MultiMaterial"):
 
     '''makeMultiMaterial(name): makes an Material object'''
-    obj = FreeCAD.ActiveDocument.addObject("App::FeaturePython",name)
+    obj = FreeCAD.ActiveDocument.addObject("App::FeaturePython","MultiMaterial")
     obj.Label = name
     _ArchMultiMaterial(obj)
     if FreeCAD.GuiUp:
@@ -537,7 +538,6 @@ class _ArchMaterialTaskPanel:
         except Exception:
             self.form.ButtonCode.hide()
         else:
-            import os
             self.form.ButtonCode.setIcon(QtGui.QIcon(os.path.join(os.path.dirname(BimClassification.__file__),"icons","BIM_Classification.svg")))
         if self.obj:
             if hasattr(self.obj,"Material"):
@@ -645,18 +645,20 @@ class _ArchMaterialTaskPanel:
                 self.material["Father"] = text
 
     def getColor(self):
-        "opens a color picker dialog"
-        color = QtGui.QColorDialog.getColor()
-        colorPix = QtGui.QPixmap(16,16)
-        colorPix.fill(color)
-        self.form.ButtonColor.setIcon(QtGui.QIcon(colorPix))
+        self.getColorForButton(self.form.ButtonColor)
 
     def getSectionColor(self):
+        self.getColorForButton(self.form.ButtonSectionColor)
+
+    def getColorForButton(self,button):
         "opens a color picker dialog"
-        color = QtGui.QColorDialog.getColor()
-        colorPix = QtGui.QPixmap(16,16)
-        colorPix.fill(color)
-        self.form.ButtonSectionColor.setIcon(QtGui.QIcon(colorPix))
+        icon = button.icon()
+        pixel = icon.pixmap(16,16).toImage().pixel(0,0)
+        color = QtGui.QColorDialog.getColor(QtGui.QColor(pixel))
+        if color.isValid():
+            colorPix = QtGui.QPixmap(16,16)
+            colorPix.fill(color)
+            button.setIcon(QtGui.QIcon(colorPix))
 
     def fillMaterialCombo(self):
         "fills the combo with the existing FCMat cards"
