@@ -29,9 +29,7 @@ Beams, pillars, slabs and panels"""
 import ArchCommands,ArchComponent,FreeCAD
 from FreeCAD import Vector
 if FreeCAD.GuiUp:
-    import FreeCADGui
-    from PySide import QtCore, QtGui
-    from DraftTools import translate
+    from draftutils.translate import translate
     from PySide.QtCore import QT_TRANSLATE_NOOP
 else:
     # \cond
