@@ -145,11 +145,11 @@ ConditioningTypes = [
 "NaturallyVentedOnly"
 ]
 
-import FreeCAD,ArchComponent,ArchCommands,math,Draft,sys
+import FreeCAD,ArchComponent,ArchCommands,Draft,sys
 if FreeCAD.GuiUp:
     import FreeCADGui
     from PySide import QtCore, QtGui
-    from DraftTools import translate
+    from draftutils.translate import translate
     from PySide.QtCore import QT_TRANSLATE_NOOP
 else:
     # \cond
@@ -609,7 +609,7 @@ class _ViewProviderSpace(ArchComponent.ViewProviderComponent):
                 except (AttributeError, RuntimeError):
                     pos = FreeCAD.Vector()
             else:
-                pos = vobj.TextPosition
+                pos = vobj.Object.Placement.multVec(vobj.TextPosition)
         # placement's displacement will be already added by the coin node
         pos = vobj.Object.Placement.inverse().multVec(pos)
         return pos
@@ -672,11 +672,13 @@ class _ViewProviderSpace(ArchComponent.ViewProviderComponent):
                 if hasattr(vobj,"FirstLine"):
                     scale = vobj.FirstLine.Value/vobj.FontSize.Value
                     self.header.scaleFactor.setValue([scale,scale,scale])
+                    self.onChanged(vobj, "TextPosition")
 
         elif (prop == "FirstLine"):
             if hasattr(self,"header") and hasattr(vobj,"FontSize") and hasattr(vobj,"FirstLine"):
                 scale = vobj.FirstLine.Value/vobj.FontSize.Value
                 self.header.scaleFactor.setValue([scale,scale,scale])
+                self.onChanged(vobj, "TextPosition")
 
         elif prop == "TextColor":
             if hasattr(self,"color") and hasattr(vobj,"TextColor"):
