@@ -24,16 +24,13 @@ __title__  = "FreeCAD Arch Truss"
 __author__ = "Yorik van Havre"
 __url__    = "https://www.freecadweb.org"
 
-import math,sys
+import math
 import FreeCAD
-import Draft
 import ArchComponent
-import ArchCommands
 
 if FreeCAD.GuiUp:
     import FreeCADGui
-    from PySide import QtCore, QtGui
-    from DraftTools import translate
+    from draftutils.translate import translate
     from PySide.QtCore import QT_TRANSLATE_NOOP
 else:
     # \cond
