@@ -34,7 +34,7 @@ from FreeCAD import Vector
 if FreeCAD.GuiUp:
     import FreeCADGui
     from PySide import QtCore, QtGui
-    from DraftTools import translate
+    from draftutils.translate import translate
     from PySide.QtCore import QT_TRANSLATE_NOOP
     import draftguitools.gui_trackers as DraftTrackers
 else:
@@ -57,7 +57,7 @@ __title__  = "FreeCAD Wall"
 __author__ = "Yorik van Havre"
 __url__    = "https://www.freecadweb.org"
 
-def makeWall(baseobj=None,height=None,length=None,width=None,align="Center",face=None,name=None):
+def makeWall(baseobj=None,height=None,length=None,width=None,align=None,face=None,name=None):
     """Create a wall based on a given object, and returns the generated wall.
 
     TODO: It is unclear what defines which units this function uses.
@@ -128,7 +128,10 @@ def makeWall(baseobj=None,height=None,length=None,width=None,align="Center",face
         obj.Height = height
     else:
         obj.Height = p.GetFloat("WallHeight",3000)
-    obj.Align = align
+    if align:
+        obj.Align = align
+    else:
+        obj.Align = ["Center","Left","Right"][p.GetInt("WallAlignment",0)]
     if obj.Base and FreeCAD.GuiUp:
         if Draft.getType(obj.Base) != "Space":
             obj.Base.ViewObject.hide()
@@ -829,8 +832,7 @@ class _Wall(ArchComponent.Component):
                         # let pass invalid objects if they have solids...
                         return
                 elif obj.Base.Shape.Solids:
-                    base = obj.Base.Shape.copy()
-
+                    base = Part.Shape(obj.Base.Shape)
                 # blocks calculation
                 elif hasattr(obj,"MakeBlocks") and hasattr(self,"basewires"):
                     if obj.MakeBlocks and self.basewires and extdata and obj.Width and obj.Height:
@@ -847,7 +849,17 @@ class _Wall(ArchComponent.Component):
                                         offset = obj.OffsetFirst.Value
                                     else:
                                         offset = obj.OffsetSecond.Value
-                                    for edge in self.basewires[0].Edges:
+                                    # only 1 wire (first) is supported
+                                    if len(obj.Base.Shape.Edges) == 1:
+                                        # If there is a single edge, the wire was used
+                                        baseEdges = self.basewires[0].Edges
+                                    elif obj.Base.isDerivedFrom("Sketcher::SketchObject"):
+                                        # if obj.Base is Sketch, self.baseWires[0] returned is already a list of edge
+                                        baseEdges = self.basewires[0]
+                                    else:
+                                        # otherwise, it is wire
+                                        baseEdges = self.basewires[0].Edges
+                                    for edge in baseEdges:
                                         while offset < (edge.Length-obj.Joint.Value):
                                             #print i," Edge ",edge," : ",edge.Length," - ",offset
                                             if offset:
@@ -858,15 +870,14 @@ class _Wall(ArchComponent.Component):
                                                 p2 = edge.valueAt(offset).add(p.negative())
                                                 sh = Part.LineSegment(p1,p2).toShape()
                                                 if obj.Joint.Value:
-                                                    sh = sh.extrude(t.multiply(obj.Joint.Value))
+                                                    sh = sh.extrude(-t.multiply(obj.Joint.Value))
                                                 sh = sh.extrude(n)
                                                 if i == 0:
                                                     cuts1.append(sh)
                                                 else:
                                                     cuts2.append(sh)
                                             offset += (obj.BlockLength.Value + obj.Joint.Value)
-                                        else:
-                                            offset -= (edge.Length - obj.Joint.Value)
+                                        offset -= (edge.Length - obj.Joint.Value)
 
                             if isinstance(bplates,list):
                                 bplates = bplates[0]
@@ -891,28 +902,28 @@ class _Wall(ArchComponent.Component):
                                 plate2 = bplates.Faces
                             blocks2 = Part.makeCompound([f.extrude(bvec) for f in plate2])
                             interval = extv.Length/(fsize)
-                            entires = int(interval)
-                            rest = (interval - entires)
-                            for i in range(entires):
+                            entire = int(interval)
+                            rest = (interval - entire)
+                            for i in range(entire):
                                 if i % 2: # odd
-                                    b = blocks2.copy()
+                                    b = Part.Shape(blocks2)
                                 else:
-                                    b = blocks1.copy()
+                                    b = Part.Shape(blocks1)
                                 if i:
                                     t = FreeCAD.Vector(svec)
                                     t.multiply(i)
                                     b.translate(t)
                                 blocks.append(b)
                             if rest:
-                                rest = extv.Length-(entires*fsize)
+                                rest = extv.Length - (entire * fsize)
                                 rvec = FreeCAD.Vector(n)
                                 rvec.multiply(rest)
-                                if entires % 2:
+                                if entire % 2:
                                     b = Part.makeCompound([f.extrude(rvec) for f in plate2])
                                 else:
                                     b = Part.makeCompound([f.extrude(rvec) for f in plate1])
                                 t = FreeCAD.Vector(svec)
-                                t.multiply(entires)
+                                t.multiply(entire)
                                 b.translate(t)
                                 blocks.append(b)
                             if blocks:
@@ -977,6 +988,8 @@ class _Wall(ArchComponent.Component):
         If "Length" has changed, record the old length so that .onChanged() can
         be sure that the base needs to be changed.
 
+        Also call ArchComponent.Component.onBeforeChange().
+
         Parameters
         ----------
         prop: string
@@ -985,6 +998,7 @@ class _Wall(ArchComponent.Component):
 
         if prop == "Length":
             self.oldLength = obj.Length.Value
+        ArchComponent.Component.onBeforeChange(self,obj,prop)
 
     def onChanged(self, obj, prop):
         """Method called when the object has a property changed.
@@ -1337,7 +1351,7 @@ class _Wall(ArchComponent.Component):
 
                             if not DraftVecUtils.isNull(dvec):
                                 dvec.normalize()
-                            sh = None
+                            face = None
 
                             curAligns = aligns[0]
                             off = obj.Offset.Value
@@ -1385,7 +1399,7 @@ class _Wall(ArchComponent.Component):
                                                                normal=normal,
                                                                basewireOffset=off)
 
-                                sh = DraftGeomUtils.bind(w1,w2)
+                                face = DraftGeomUtils.bind(w1, w2, per_segment=True)
 
                             elif curAligns == "Right":
                                 dvec = dvec.negative()
@@ -1426,7 +1440,7 @@ class _Wall(ArchComponent.Component):
                                                                normal=normal,
                                                                basewireOffset=off)
 
-                                sh = DraftGeomUtils.bind(w1,w2)
+                                face = DraftGeomUtils.bind(w1, w2, per_segment=True)
 
                             #elif obj.Align == "Center":
                             elif curAligns == "Center":
@@ -1459,18 +1473,16 @@ class _Wall(ArchComponent.Component):
                                                                    alignList=aligns,
                                                                    normal=normal,
                                                                    basewireOffset=off)
-                                sh = DraftGeomUtils.bind(w1,w2)
+                                face = DraftGeomUtils.bind(w1, w2, per_segment=True)
 
                             del widths[0:edgeNum]
                             del aligns[0:edgeNum]
-                            if sh:
+                            if face:
 
                                 if layers and (layers[i] < 0):
                                     # layers with negative values are not drawn
                                     continue
 
-                                sh.fix(0.1,0,1) # fixes self-intersecting wires
-                                f = Part.Face(sh)
                                 if baseface:
 
                                     # To allow exportIFC.py to work properly on
@@ -1491,14 +1503,14 @@ class _Wall(ArchComponent.Component):
                                     # - 1st finding : if a rectangle + 1 line, can't removesSplitter properly...
                                     # - 2nd finding : if 2 faces do not touch, can't form a shell; then, subsequently for remaining faces even though touch each faces, can't form a shell
 
-                                    baseface.append(f)
+                                    baseface.append(face)
                                     # The above make Refine methods below (in else) useless, regardless removeSpitters yet to be improved for cases do not work well
-                                    '''  Whether layers or not, all baseface.append(f) '''
+                                    '''  Whether layers or not, all baseface.append(face) '''
 
                                 else:
-                                    baseface = [f]
+                                    baseface = [face]
 
-                                    '''  Whether layers or not, all baseface = [f] '''
+                                    '''  Whether layers or not, all baseface = [face] '''
 
                         if baseface:
                             base,placement = self.rebase(baseface)
@@ -1700,6 +1712,23 @@ class _ViewProviderWall(ArchComponent.ViewProviderComponent):
             return "Wireframe"
         return ArchComponent.ViewProviderComponent.setDisplayMode(self,mode)
 
+    def setupContextMenu(self,vobj,menu):
+
+        from PySide import QtCore,QtGui
+        action1 = QtGui.QAction(QtGui.QIcon(":/icons/Arch_Wall_Tree.svg"),"Flip direction",menu)
+        QtCore.QObject.connect(action1,QtCore.SIGNAL("triggered()"),self.flipDirection)
+        menu.addAction(action1)
+
+    def flipDirection(self):
+
+       if hasattr(self,"Object") and self.Object:
+           obj = self.Object
+           if obj.Align == "Left":
+                obj.Align = "Right"
+                FreeCAD.ActiveDocument.recompute()
+           elif obj.Align == "Right":
+                obj.Align = "Left"
+                FreeCAD.ActiveDocument.recompute()
 
 if FreeCAD.GuiUp:
     FreeCADGui.addCommand('Arch_Wall',_CommandWall())
