@@ -21,14 +21,16 @@
 
 import os
 
-import FreeCAD,Draft,ArchComponent,DraftVecUtils,ArchCommands
+import FreeCAD, Draft, ArchComponent, DraftVecUtils, ArchCommands
 import ArchWindowPresets
 from FreeCAD import Units
 from FreeCAD import Vector
+from draftutils.messages import _wrn
+
 if FreeCAD.GuiUp:
     import FreeCADGui
     from PySide import QtCore, QtGui, QtSvg
-    from DraftTools import translate
+    from draftutils.translate import translate
     from PySide.QtCore import QT_TRANSLATE_NOOP
     import draftguitools.gui_trackers as DraftTrackers
 else:
@@ -94,7 +96,11 @@ def makeWindow(baseobj=None,width=None,height=None,parts=None,name=None):
     else:
         if baseobj:
             if baseobj.getLinkedObject().isDerivedFrom("Part::Part2DObject"):
+                # create default component
                 if baseobj.Shape.Wires:
+                    tp = "Frame"
+                    if len(baseobj.Shape.Wires) == 1:
+                        tp = "Solid panel"
                     i = 0
                     ws = ''
                     for w in baseobj.Shape.Wires:
@@ -102,7 +108,7 @@ def makeWindow(baseobj=None,width=None,height=None,parts=None,name=None):
                             if ws: ws += ","
                             ws += "Wire" + str(i)
                             i += 1
-                    obj.WindowParts = ["Default","Frame",ws,"1","0"]
+                    obj.WindowParts = ["Default",tp,ws,"1","0"]
             else:
                 # bind properties from base obj if existing
                 for prop in ["Height","Width","Subvolume","Tag","Description","Material"]:
@@ -237,6 +243,20 @@ class _CommandWindow:
         FreeCADGui.Snapper.getPoint(callback=self.getPoint,movecallback=self.update,extradlg=self.taskbox())
         #FreeCADGui.Snapper.setSelectMode(True)
 
+    def has_width_and_height_constraint(self, sketch):
+        width_found = False
+        height_found = False
+
+        for constr in sketch.Constraints:
+            if constr.Name == "Width":
+                width_found = True
+            elif constr.Name == "Height":
+                height_found = True
+            elif width_found and height_found:
+                break
+
+        return (width_found and height_found)
+
     def getPoint(self,point=None,obj=None):
 
         "this function is called by the snapper when it has a 3D point"
@@ -249,47 +269,63 @@ class _CommandWindow:
             obj = self.sel[0]
         point = point.add(FreeCAD.Vector(0,0,self.Sill))
         FreeCAD.ActiveDocument.openTransaction(translate("Arch","Create Window"))
+
+        FreeCADGui.doCommand("import math, FreeCAD, Arch, WorkingPlane")
+
+        if self.baseFace is not None:
+            FreeCADGui.doCommand("pl = WorkingPlane.getPlacementFromFace(FreeCAD.ActiveDocument." + self.baseFace[0].Name + ".Shape.Faces[" + str(self.baseFace[1]) + "])")
+        else:
+            FreeCADGui.doCommand("m = FreeCAD.Matrix()")
+            FreeCADGui.doCommand("m.rotateX(math.pi/2)")
+            FreeCADGui.doCommand("pl = FreeCAD.Placement(m)")
+
+        FreeCADGui.doCommand("pl.Base = FreeCAD.Vector(" + str(point.x) + ", " + str(point.y) + ", " + str(point.z) + ")")
+
         if self.Preset >= len(WindowPresets):
             # library object
-            col = list(FreeCAD.ActiveDocument.Objects)
-            path = self.librarypresets[self.Preset-len(WindowPresets)][1]
-            FreeCADGui.doCommand("FreeCADGui.ActiveDocument.mergeProject('"+path+"')")
+            col = FreeCAD.ActiveDocument.Objects
+            path = self.librarypresets[self.Preset - len(WindowPresets)][1]
+            FreeCADGui.doCommand("FreeCADGui.ActiveDocument.mergeProject('" + path + "')")
             # find the latest added window
-            nol = list(FreeCAD.ActiveDocument.Objects)
-            nol.reverse()
-            for o in nol:
-                if (Draft.getType(o) == "Window") and (not o in col):
-                    lastobj = o
-                    FreeCADGui.doCommand("FreeCAD.ActiveDocument.getObject('"+o.Name+"').Placement.Base = FreeCAD.Vector(" + str(point.x) + "," + str(point.y) + ","+ str(point.z) + ")")
-                    FreeCADGui.doCommand("FreeCAD.ActiveDocument.getObject('"+o.Name+"').Width = "+str(self.Width))
-                    FreeCADGui.doCommand("FreeCAD.ActiveDocument.getObject('"+o.Name+"').Height = "+str(self.Height))
+            nol = FreeCAD.ActiveDocument.Objects
+            for o in nol[len(col):]:
+                if Draft.getType(o) == "Window":
+                    if Draft.getType(o.Base) != "Sketcher::SketchObject":
+                        _wrn(translate("Arch", "Window not based on sketch. Window not aligned or resized."))
+                        self.Include = False
+                        break
+                    FreeCADGui.doCommand("win = FreeCAD.ActiveDocument.getObject('" + o.Name + "')")
+                    FreeCADGui.doCommand("win.Base.Placement = pl")
+                    FreeCADGui.doCommand("win.Normal = pl.Rotation.multVec(FreeCAD.Vector(0, 0, -1))")
+                    FreeCADGui.doCommand("win.Width = " + str(self.Width))
+                    FreeCADGui.doCommand("win.Height = " + str(self.Height))
+                    FreeCADGui.doCommand("win.Base.recompute()")
+                    if not self.has_width_and_height_constraint(o.Base):
+                        _wrn(translate("Arch", "No Width and/or Height constraint in window sketch. Window not resized."))
                     break
+            else:
+                _wrn(translate("Arch", "No window found. Cannot continue."))
+                self.Include = False
 
         else:
             # preset
-            FreeCADGui.doCommand("import math,FreeCAD,Arch,WorkingPlane")
-            if self.baseFace != None:
-                FreeCADGui.doCommand("pl = WorkingPlane.getPlacementFromFace(FreeCAD.ActiveDocument." + self.baseFace[0].Name + ".Shape.Faces[" + str(self.baseFace[1]) + "])")
-            else:
-                FreeCADGui.doCommand("m = FreeCAD.Matrix()")
-                FreeCADGui.doCommand("m.rotateX(math.pi/2)")
-                FreeCADGui.doCommand("pl = FreeCAD.Placement(m)")
-            FreeCADGui.doCommand("pl.Base = FreeCAD.Vector(" + str(point.x) + "," + str(point.y) + ","+ str(point.z) + ")")
             wp = ""
             for p in self.wparams:
-                wp += p.lower() + "=" + str(getattr(self,p)) + ","
-            FreeCADGui.doCommand("win = Arch.makeWindowPreset(\"" + WindowPresets[self.Preset] + "\"," + wp + "placement=pl)")
-            if self.Include:
-                host = None
-                if self.baseFace != None:
-                    host = self.baseFace[0]
-                elif obj:
-                    host = obj
-                if Draft.getType(host) in AllowedHosts:
-                    FreeCADGui.doCommand("win.Hosts = [FreeCAD.ActiveDocument."+host.Name+"]")
-                    siblings = host.Proxy.getSiblings(host)
-                    for sibling in siblings:
-                        FreeCADGui.doCommand("win.Hosts = win.Hosts+[FreeCAD.ActiveDocument."+sibling.Name+"]")
+                wp += p.lower() + "=" + str(getattr(self,p)) + ", "
+            FreeCADGui.doCommand("win = Arch.makeWindowPreset('" + WindowPresets[self.Preset] + "', " + wp + "placement=pl)")
+
+        if self.Include:
+            host = None
+            if self.baseFace is not None:
+                host = self.baseFace[0]
+            elif obj:
+                host = obj
+            if Draft.getType(host) in AllowedHosts:
+                FreeCADGui.doCommand("win.Hosts = [FreeCAD.ActiveDocument." + host.Name + "]")
+                siblings = host.Proxy.getSiblings(host)
+                for sibling in siblings:
+                    FreeCADGui.doCommand("win.Hosts = win.Hosts + [FreeCAD.ActiveDocument." + sibling.Name + "]")
+
         FreeCAD.ActiveDocument.commitTransaction()
         FreeCAD.ActiveDocument.recompute()
         return
@@ -340,31 +376,29 @@ class _CommandWindow:
         grid.addWidget(values,1,1,1,1)
         QtCore.QObject.connect(values,QtCore.SIGNAL("valueChanged(double)"),self.setSill)
 
-        # check for Parts library
-        self.librarypresets = []
-        librarypath = FreeCAD.ParamGet('User parameter:Plugins/parts_library').GetString('destination','')
-        if librarypath:
-            if os.path.exists(librarypath):
-                for wtype in ["Windows","Doors"]:
-                    wdir = os.path.join(librarypath,"Architectural Parts",wtype)
-                    if os.path.exists(wdir):
-                        for subtype in os.listdir(wdir):
-                            subdir = os.path.join(wdir,subtype)
-                            if os.path.exists(subdir):
-                                for subfile in os.listdir(subdir):
-                                    if subfile.lower().endswith(".fcstd"):
-                                        self.librarypresets.append([wtype+" - "+subtype+" - "+os.path.splitext(subfile)[0],os.path.join(subdir,subfile)])
-            else:
-                librarypath = None
-        # check for existing presets
-        presetdir = os.path.join(FreeCAD.getUserAppDataDir(),"Arch")
-        for tp in ["Windows","Doors"]:
-            wdir = os.path.join(presetdir,tp)
-            if os.path.exists(wdir):
-                for wfile in os.listdir(wdir):
-                    if wfile.lower().endswith(".fcstd"):
-                        self.librarypresets.append([tp[:-1]+" - "+wfile[:-6],wfile])
+        # check for Parts library and Arch presets
 
+        # because of the use of FreeCADGui.doCommand() backslashes in the
+        # paths in librarypresets need to be double escaped "\\\\", so let's
+        # use forward slashes instead...
+        self.librarypresets = []
+        librarypath = FreeCAD.ParamGet("User parameter:Plugins/parts_library").GetString("destination", "")
+        # librarypath should have only forward slashes already, but let's use replace() anyway just to be sure:
+        librarypath = librarypath.replace("\\", "/") + "/Architectural Parts"
+        presetdir = FreeCAD.getUserAppDataDir().replace("\\", "/") + "/Arch"
+        for path in [librarypath, presetdir]:
+            if os.path.isdir(path):
+                for wtype in ["Windows", "Doors"]:
+                    wdir = path + "/" + wtype
+                    if os.path.isdir(wdir):
+                        for subtype in os.listdir(wdir):
+                            subdir = wdir + "/" + subtype
+                            if os.path.isdir(subdir):
+                                for subfile in os.listdir(subdir):
+                                    if (os.path.isfile(subdir + "/" + subfile)
+                                            and subfile.lower().endswith(".fcstd")):
+                                        self.librarypresets.append([wtype + " - " + subtype + " - " + subfile[:-6],
+                                                                    subdir + "/" + subfile])
 
         # presets box
         labelp = QtGui.QLabel(translate("Arch","Preset"))
@@ -531,6 +565,25 @@ class _Window(ArchComponent.Component):
         obj.IfcType = "Window"
         obj.MoveWithHost = True
 
+        # Add features in the SketchArch External Add-on
+        self.addSketchArchFeatures(obj)
+
+    def addSketchArchFeatures(self,obj,linkObj=None,mode=None):
+        '''
+           To add features in the SketchArch External Add-on  (https://github.com/paullee0/FreeCAD_SketchArch)
+           -  import ArchSketchObject module, and
+           -  set properties that are common to ArchObjects (including Links) and ArchSketch
+              to support the additional features
+
+           To install SketchArch External Add-on, see https://github.com/paullee0/FreeCAD_SketchArch#iv-install
+        '''
+
+        try:
+            import ArchSketchObject
+            ArchSketchObject.ArchSketch.setPropertiesLinkCommon(self, obj, linkObj, mode)
+        except:
+            pass
+
     def setProperties(self,obj):
 
         lp = obj.PropertiesList
@@ -580,6 +633,9 @@ class _Window(ArchComponent.Component):
         ArchComponent.Component.onDocumentRestored(self,obj)
         self.setProperties(obj)
 
+        # Add features in the SketchArch External Add-on
+        self.addSketchArchFeatures(obj, mode='ODR')
+
     def onBeforeChange(self,obj,prop):
 
         if prop in ["Base","WindowParts","Placement","HoleDepth","Height","Width","Hosts"]:
@@ -595,8 +651,8 @@ class _Window(ArchComponent.Component):
                 if hasattr(self,prop):
                     if getattr(self,prop) != getattr(obj,prop):
                         touchhosts = True
-                if touchhosts and hasattr(obj,"Hosts"):
-                    for host in obj.Hosts:
+                if touchhosts and hasattr(self, "Hosts") and hasattr(obj, "Hosts"):
+                    for host in set(self.Hosts + obj.Hosts): # use set to remove duplicates
                         # mark host to recompute so it can detect this object
                         host.touch()
             if prop in ["Width","Height","Frame"]:
@@ -632,7 +688,10 @@ class _Window(ArchComponent.Component):
                 elif "Edge" in s:
                     hinge = int(s[4:])-1
                 elif "Mode" in s:
-                    omode = int(s[-1])
+                    omode = int(s[4:])
+                    if omode >= len(WindowOpeningModes):
+                        # Ignore modes not listed in WindowOpeningModes
+                        omode = None
             if wires:
                 max_length = 0
                 for w in wires:
@@ -863,6 +922,39 @@ class _Window(ArchComponent.Component):
         if hasattr(obj,"Area"):
             obj.Area = obj.Width.Value * obj.Height.Value
 
+        self.executeSketchArchFeatures(obj)
+
+    def executeSketchArchFeatures(self, obj, linkObj=None, index=None, linkElement=None):
+        '''
+           To execute features in the SketchArch External Add-on  (https://github.com/paullee0/FreeCAD_SketchArch)
+           -  import ArchSketchObject module, and
+           -  execute features that are common to ArchObjects (including Links) and ArchSketch
+
+           To install SketchArch External Add-on, see https://github.com/paullee0/FreeCAD_SketchArch#iv-install
+        '''
+
+        # To execute features in SketchArch External Add-on
+        try:
+            import ArchSketchObject  # Why needed ? Should have try: addSketchArchFeatures() before !  Need 'per method' ?
+            # Execute SketchArch Feature - Intuitive Automatic Placement for Arch Windows/Doors, Equipment etc.
+            # see https://forum.freecadweb.org/viewtopic.php?f=23&t=50802
+            ArchSketchObject.updateAttachmentOffset(obj, linkObj)
+        except:
+            pass
+
+    def appLinkExecute(self, obj, linkObj, index, linkElement):
+        '''
+            Default Link Execute method() -
+            See https://forum.freecadweb.org/viewtopic.php?f=22&t=42184&start=10#p361124
+            @realthunder added support to Links to run Linked Scripted Object's methods()
+        '''
+
+        # Add features in the SketchArch External Add-on
+        self.addSketchArchFeatures(obj, linkObj)
+
+        # Execute features in the SketchArch External Add-on
+        self.executeSketchArchFeatures(obj, linkObj)
+
     def getSubVolume(self,obj,plac=None):
 
         "returns a subvolume for cutting in a base object"
@@ -1144,6 +1236,9 @@ class _ViewProviderWindow(ArchComponent.ViewProviderComponent):
 
         pairs = [["Edge6","Edge8"],["Edge5","Edge7"]]
         self.invertPairs(pairs)
+        # Also invert opening direction, so the door still opens towards
+        # the same side of the wall
+        self.invertOpening()
 
     def invertPairs(self,pairs):
 
@@ -1442,6 +1537,8 @@ class _ArchWindowTaskPanel:
         self.field3.setText('')
         self.field4.setText('')
         self.field5.setText('')
+        self.field6.setText(QtGui.QApplication.translate("Arch", "Get selected edge", None))
+        self.field7.setCurrentIndex(0)
         self.addp4.setChecked(False)
         self.addp5.setChecked(False)
         self.newtitle.setVisible(True)
@@ -1489,6 +1586,8 @@ class _ArchWindowTaskPanel:
             if self.obj:
                 if comp in self.obj.WindowParts:
                     ind = self.obj.WindowParts.index(comp)
+                    self.field6.setText(QtGui.QApplication.translate("Arch", "Get selected edge", None))
+                    self.field7.setCurrentIndex(0)
                     for i in range(5):
                         f = getattr(self,"field"+str(i+1))
                         t = self.obj.WindowParts[ind+i]
@@ -1506,7 +1605,11 @@ class _ArchWindowTaskPanel:
                                 elif "Edge" in l:
                                     self.field6.setText(l)
                                 elif "Mode" in l:
-                                    self.field7.setCurrentIndex(int(l[-1]))
+                                    if int(l[4:]) < len(WindowOpeningModes):
+                                        self.field7.setCurrentIndex(int(l[4:]))
+                                    else:
+                                        # Ignore modes not listed in WindowOpeningModes
+                                        self.field7.setCurrentIndex(0)
                             if wires:
                                 f.setText(",".join(wires))
 
