@@ -23,10 +23,10 @@ __title__  = "FreeCAD GbXml exporter"
 __author__ = "Yorik van Havre"
 __url__    = "https://www.freecadweb.org"
 
-import os,FreeCAD,Draft
+import FreeCAD,Draft
 
 if FreeCAD.GuiUp:
-    from DraftTools import translate
+    from draftutils.translate import translate
 else:
     # \cond
     def translate(ctx,txt):
