@@ -35,7 +35,6 @@ but which can also be used in other workbenches and in macros.
 # flake8 --ignore=E226,E266,E401,W503
 
 import math
-import sys
 
 import FreeCAD
 from FreeCAD import Vector
@@ -45,13 +44,6 @@ __title__ = "FreeCAD Draft Workbench - Vector library"
 __author__ = "Yorik van Havre, Werner Mayer, Martin Burbaum, Ken Cline"
 __url__ = "https://www.freecadweb.org"
 
-# Python 2 has two integer types, int and long.
-# In Python 3 there is no 'long' anymore, so make it 'int'.
-try:
-    long
-except NameError:
-    long = int
-
 params = FreeCAD.ParamGet("User parameter:BaseApp/Preferences/Mod/Draft")
 
 ## \addtogroup DRAFTVECUTILS
@@ -230,12 +222,7 @@ def scale(u, scalar):
     Base::Vector3
         The new vector with each of its elements multiplied by `scalar`.
     """
-    # Python 2 has two integer types, int and long.
-    # In Python 3 there is no 'long' anymore.
-    if sys.version_info.major < 3:
-        typecheck([(u, Vector), (scalar, (long, int, float))], "scale")
-    else:
-        typecheck([(u, Vector), (scalar, (int, int, float))], "scale")
+    typecheck([(u, Vector), (scalar, (int, int, float))], "scale")
     return Vector(u.x*scalar, u.y*scalar, u.z*scalar)
 
 
@@ -265,12 +252,7 @@ def scaleTo(u, l):
         The new vector with each of its elements scaled by a factor.
         Or the same input vector `u`, if it is `(0, 0, 0)`.
     """
-    # Python 2 has two integer types, int and long.
-    # In Python 3 there is no 'long' anymore.
-    if sys.version_info.major < 3:
-        typecheck([(u, Vector), (l, (long, int, float))], "scaleTo")
-    else:
-        typecheck([(u, Vector), (l, (int, int, float))], "scaleTo")
+    typecheck([(u, Vector), (l, (int, int, float))], "scaleTo")
     if u.Length == 0:
         return Vector(u)
     else:
@@ -829,4 +811,76 @@ def removeDoubles(vlist):
     nlist.append(vlist[-1])
     return nlist
 
+def get_spherical_coords(x, y, z):
+    """Get the Spherical coordinates of the vector represented
+    by Cartesian coordinates (x, y, z).
+
+    Parameters
+    ----------
+    vector : Base::Vector3
+        The input vector.
+
+    Returns
+    -------
+    tuple of float
+        Tuple (radius, theta, phi) with the Spherical coordinates.
+        Radius is the radial coordinate, theta the polar angle and
+        phi the azimuthal angle in radians.
+
+    Notes
+    -----
+    The vector (0, 0, 0) has undefined values for theta and phi, while
+    points on the z axis has undefined value for phi. The following
+    conventions are used (useful in DraftToolBar methods):
+    (0, 0, 0) -> (0, pi/2, 0)
+    (0, 0, z) -> (radius, theta, 0)
+    """
+
+    v = Vector(x,y,z)
+    x_axis = Vector(1,0,0)
+    z_axis = Vector(0,0,1)
+    y_axis = Vector(0,1,0)
+    rad = v.Length
+
+    if not bool(round(rad, precision())):
+        return (0, math.pi/2, 0)
+
+    theta = v.getAngle(z_axis)
+    v.projectToPlane(Vector(0,0,0), z_axis)
+    phi = v.getAngle(x_axis)
+    if math.isnan(phi):
+        return (rad, theta, 0)
+    # projected vector is on 3rd or 4th quadrant
+    if v.dot(Vector(y_axis)) < 0:
+        phi = -1*phi
+
+    return (rad, theta, phi)
+
+
+def get_cartesian_coords(radius, theta, phi):
+    """Get the three-dimensional Cartesian coordinates of the vector
+    represented by Spherical coordinates (radius, theta, phi).
+
+    Parameters
+    ----------
+    radius : float, int
+        Radial coordinate of the vector.
+    theta : float, int
+        Polar coordinate of the vector in radians.
+    phi : float, int
+        Azimuthal coordinate of the vector in radians.
+
+    Returns
+    -------
+    tuple of float :
+        Tuple (x, y, z) with the Cartesian coordinates.
+    """
+
+    x = radius*math.sin(theta)*math.cos(phi)
+    y = radius*math.sin(theta)*math.sin(phi)
+    z = radius*math.cos(theta)
+
+    return (x, y, z)
+
+
 ##  @}
